<?php
// Heading
$_['heading_title']    = 'Developer Settings';

// Text
$_['text_success']     = 'Success: You have modified developer settings!';
$_['text_theme']       = 'theme';
$_['text_sass']        = 'SASS';
$_['text_cache']       = 'Success: You have cleared the %s cache!';

// Column
$_['column_component'] = 'Component';
$_['column_action']    = 'Action';

// Entry
$_['entry_theme']      = 'Theme';
$_['entry_sass']       = 'SASS';
$_['entry_cache']      = 'Cache';

// Button
$_['button_on']        = 'On';
$_['button_off']       = 'Off';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify developer settings!';