<?php
// Heading
$_['heading_title']		 = 'NOCHEX';

// Text
$_['text_extension']	 = 'Extensions';
$_['text_success']		 = 'Success: You have modified NOCHEX account details!';
$_['text_edit']          = 'Edit NOCHEX';
$_['text_nochex']		 = '<a href="https://secure.nochex.com/apply/merchant_info.aspx?partner_id=172198798" target="_blank"><img src="view/image/payment/nochex.png" alt="NOCHEX" title="NOCHEX" style="border: 1px solid #EEEEEE;" /></a>';
$_['text_seller']		 = 'Seller / Personal Account';
$_['text_merchant']		 = 'Merchant Account';

// Entry
$_['entry_email']		 = 'E-Mail';
$_['entry_account']		 = 'Account Type';
$_['entry_merchant']	 = 'Merchant ID';
$_['entry_template']	 = 'Pass Template';
$_['entry_test']		 = 'Test';
$_['entry_total']		 = 'Total';
$_['entry_order_status'] = 'Order Status';
$_['entry_geo_zone']     = 'Geo Zone';
$_['entry_status']	     = 'Status';
$_['entry_sort_order']   = 'Sort Order';

// Help
$_['help_total']	     = 'The checkout total the order must reach before this payment method becomes active.';

// Error
$_['error_permission']   = 'Warning: You do not have permission to modify payment NOCHEX!';
$_['error_email']	     = 'E-Mail Required!';
$_['error_merchant']     = 'Merchant ID Required!';