!function(e){function t(n){if(r[n])return r[n].exports;var o=r[n]={i:n,l:!1,exports:{}};return e[n].call(o.exports,o,o.exports,t),o.l=!0,o.exports}var r={};t.m=e,t.c=r,t.d=function(e,r,n){t.o(e,r)||Object.defineProperty(e,r,{configurable:!1,enumerable:!0,get:n})},t.n=function(e){var r=e&&e.__esModule?function(){return e.default}:function(){return e};return t.d(r,"a",r),r},t.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},t.p="",t(t.s=0)}([function(e,t,r){function n(e){var t=e.$elems,r=NTCD.textual.lang;return new u.default(1e3*e.end_time,function(e){var n=e.expired,o=e.days,i=e.hours,u=e.mins,s=e.secs;if(n)t.html(r.view_expired);else{var c=r.view_active.replace("{days}",String(o)).replace("{hours}",a.padLeft(i,2)).replace("{minutes}",a.padLeft(u,2)).replace("{seconds}",a.padLeft(s,2)),l=new RegExp("{day_number:([\\wЀ-ӿԀ-ԯⷠ-ⷿꙀ-ꚟᲀ-᲏ᴫᵸ︮︯:]*)}"),f=l.exec(c),d="";null!==f&&(d=a.grammarNumber(r._code,o,f[1].split(":"))),c=c.replace(l,d),t.html(c)}},e.delta)}var o=this&&this.__extends||function(){var e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r])};return function(t,r){function n(){this.constructor=t}e(t,r),t.prototype=null===r?Object.create(r):(n.prototype=r.prototype,new n)}}();t.__esModule=!0;var i=r(1),u=r(2),a=r(3);new(function(e){function t(){return e.call(this,"textual",".ntcd-textual",n)||this}return o(t,e),t}(i.default))},function(e,t){function r(e,t,r,o){var i="[Neat Countdown]";return"jQuery"in window?(jQuery(function(){if("NTCD"in window){var o=NTCD[e];o.builtInsts||n(o,jQuery(t),r)}else console.error(i+" No NTCD object.")}),!0):(o&&console.error(i+" No jQuery."),!1)}function n(e,t,r){var n=e.builtInsts=Object.create(null),i=e.insts,u=(new Date).getTime();t.each(function(e,t){var r=jQuery(t),o=r.data("inst");if(n[o])return void n[o].elems.push(t);var a=Object.create(i[o]);if(a.elems=[t],a.delta=0,"combo"==a.type||"server"==a.type){var s=u-1e3*a.server_time-3e3,c=Math.abs(s)>1e3*a.critdiff,l="server"==a.type||"combo"==a.type&&c;a.delta=l?s:0}n[o]=a});for(var a=0,s=Object.keys(n);a<s.length;a++){var c=s[a],l=n[c];l.$elems=jQuery(l.elems);o(l,r(l))}}function o(e,t){if(window.IntersectionObserver){var r=e.elems.length,n=0,o=new IntersectionObserver(function(e){r=e.reduce(function(e,t){return e+(t.intersectionRatio>0?n:-1)},r),r?t.start():t.stop(),n||(n=1)});e.elems.forEach(function(e){return o.observe(e)})}else t.start()}t.__esModule=!0;var i=function(){function e(e,t,n){r(e,t,n)||window.addEventListener("load",function(){return r(e,t,n,!0)},!1)}return e}();t.default=i},function(e,t){t.__esModule=!0;var r=function(){function e(e,t,r){this.endTime=e,this.renderFn=t,this.clientServerDelta=r,this.started=!1}return e.prototype.timerCb=function(){var e=this,t=this.calcRemain();this.render(t),t.expired?this.stop():this.timeoutID=setTimeout(function(){return e.timerCb()},this.calcDelay(new Date))},e.prototype.calcDelay=function(e){return(1e3-e.getMilliseconds()+this.clientServerDelta)%1e3||1e3},e.prototype.start=function(){this.started||(this.started=!0,this.timerCb())},e.prototype.stop=function(){this.started&&(this.started=!1,clearTimeout(this.timeoutID))},e.prototype.render=function(e){this.renderFn(e)},e.prototype.calcRemain=function(){return this._calcRemain(new Date)},e.prototype._calcRemain=function(e){var t=this.endTime-e.getTime()+this.clientServerDelta;if(t>=500){var r=1e3-t%1e3;return r<=500&&(t+=r),{expired:!1,days:Math.floor(t/864e5),hours:Math.floor(t%864e5/36e5),mins:Math.floor(t%36e5/6e4),secs:Math.floor(t%6e4/1e3)}}return{expired:!0,days:0,hours:0,mins:0,secs:0}},e}();t.default=r},function(e,t){function r(e,t){e=String(e);for(var r=t-e.length;r>0;r--)e="0"+e;return e}function n(e,t,r){return i[e](t,r)}t.__esModule=!0,t.padLeft=r;var o=function(e,t){if(11==e||12==e||13==e||14==e)return t[2];switch(e%10){case 1:return t[0];case 2:case 3:case 4:return t[1];default:return t[2]}},i={en:function(e,t){return 1==e?t[0]:t[1]},ru:o,uk:o};t.grammarNumber=n}]);