<?php
/**
 * @package		OpenCart
 * @author		Meng Wenbin
 * @copyright	Copyright (c) 2010 - 2017, Chengdu Guangda Network Technology Co. Ltd. (https://www.opencart.cn/)
 * @license		https://opensource.org/licenses/GPL-3.0
 * @link		https://www.opencart.cn
 */

// Heading
$_['heading_title']              = 'Wechat QR Code Pay';

// Text
$_['text_title']                 = 'Wechat Pay';
$_['text_checkout']              = 'Checkout';
$_['text_qrcode']                = 'QrCode';
$_['text_qrcode_description']    = 'Please scan the QR code in WeChat app to pay your order!';
