<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  9320 => 'Kabul',
  9321 => 'Parwan',
  9322 => 'Kapisa',
  9323 => 'Bamian',
  9324 => 'Wardak',
  9325 => 'Logar',
  9326 => 'Dorkondi',
  9327 => 'Khost',
  9328 => 'Panjshar',
  9330 => 'Kandahar',
  9331 => 'Ghazni',
  9332 => 'Uruzgan',
  9333 => 'Zabol',
  9334 => 'Helmand',
  9340 => 'Heart',
  9341 => 'Badghis',
  9342 => 'Ghowr',
  9343 => 'Farah',
  9344 => 'Nimruz',
  9350 => 'Balkh',
  9351 => 'Kunduz',
  9352 => 'Badkhshan',
  9353 => 'Takhar',
  9354 => 'Jowzjan',
  9355 => 'Samangan',
  9356 => 'Sar-E Pol',
  9357 => 'Faryab',
  9358 => 'Baghlan',
  9360 => 'Nangarhar',
  9361 => 'Nurestan',
  9362 => 'Kunarha',
  9363 => 'Laghman',
  9364 => 'Paktia',
  9365 => 'Paktika',
);
