<div class="tile tile-primary">
  <div class="tile-heading">{{ heading_title }}</div>
  <div class="tile-body"><i class="fa fa-users"></i>
    <h2 class="pull-right">{{ total }}</h2>
  </div>
  <div class="tile-footer"><a href="{{ online }}">{{ text_view }}</a></div>
</div>
