{{ header }}{{ column_left }}
<div id="content">
  <div class="page-header">
    <div class="container-fluid">
      <div class="pull-right">
        <button type="submit" form="form-module" data-toggle="tooltip" title="{{ button_save }}" class="btn btn-primary"><i class="fa fa-save"></i></button>
        <a href="{{ cancel }}" data-toggle="tooltip" title="{{ button_cancel }}" class="btn btn-default"><i class="fa fa-reply"></i></a></div>
      <h1>{{ heading_title }}</h1>
      <ul class="breadcrumb">
        {% for breadcrumb in breadcrumbs %}
        <li><a href="{{ breadcrumb.href }}">{{ breadcrumb.text }}</a></li>
        {% endfor %}
      </ul>
    </div>
  </div>
  <div class="container-fluid">
    {% if error_warning %}
    <div class="alert alert-danger alert-dismissible"><i class="fa fa-exclamation-circle"></i> {{ error_warning }}
      <button type="button" class="close" data-dismiss="alert">&times;</button>
    </div>
    {% endif %}
    <div class="panel panel-default">
      <div class="panel-heading">
        <h3 class="panel-title"><i class="fa fa-pencil"></i> {{ text_edit }}</h3>
      </div>
      <div class="panel-body">
        <form action="{{ action }}" method="post" enctype="multipart/form-data" id="form-module" class="form-horizontal">
         <div class="form-group">
                <label class="col-sm-2 control-label" for="input-album-image-size">{{ entry_author_size}}</label>
                <div class="col-sm-5">
                   <input type="text" name="module_testimonials_aheight" value="{{ module_testimonials_aheight }}" placeholder="{{ entry_height }}" id="input-aheight" class="form-control" />
                </div>
                <div class="col-sm-5">
                    <input type="text" name="module_testimonials_awidth" value="{{ module_testimonials_awidth }}" placeholder="{{ entry_width }}" id="input-awidth" class="form-control" />
                </div>
              </div>
          <div class="form-group">
            <label class="col-sm-2 control-label" for="input-status">{{ entry_status }}</label>
            <div class="col-sm-10">
              <select name="module_testimonials_status" id="input-status" class="form-control">
                {% if module_testimonials_status %}
                <option value="1" selected="selected">{{ text_enabled }}</option>
                <option value="0">{{ text_disabled }}</option>
                {% else %}
                <option value="1">{{ text_enabled }}</option>
                <option value="0" selected="selected">{{ text_disabled }}</option>
                {% endif %}
              </select>
            </div>
          </div>
        
               
          
              
              <!--    <div class="form-group">
                <label class="col-sm-2 control-label" for="input-album-image-size">{{ entry_bgclr}}</label>
                <div class="col-sm-10">
                   <input type="text" name="module_testimonials_bgclr" value="{{ module_testimonials_bgclr }}" placeholder="{{ entry_bgclr }}" id="input-bgclr}}" class="form-control" />
                </div>
              
              </div>
              <div class="form-group">
                <label class="col-sm-2 control-label" for="input-album-image-size">{{ entry_font_clr}}</label>
                <div class="col-sm-10">
                   <input type="text" name="module_testimonials_fontclr" value="{{ module_testimonials_fontclr }}" placeholder="{{ entry_height }}" id="input-fontclrs }}" class="form-control" />
                </div>
            </div>
            <div class="form-group">
                <label class="col-sm-2 control-label" for="input-album-image-size">{{ entry_head}}</label>
                <div class="col-sm-10">
                   <input type="text" name="module_testimonials_heading" value="{{ module_testimonials_heading }}" placeholder="{{ entry_head }}" id="input-fontclrs }}" class="form-control" />
                </div>
              
              </div>-->
        </form>
      </div>
    </div>
  </div>
</div>
{{ footer }}