<?php
// Heading
$_['heading_title']    					= 'PayPal Smart Button';

// Text
$_['text_extensions']   				= 'Extensions';
$_['text_edit']        					= 'Edit PayPal Smart Button Module';
$_['text_general']				 	 	= 'General';
$_['text_product_page']					= 'Product Page';
$_['text_cart_page']					= 'Cart Page';
$_['text_insert_prepend']				= 'Insert Into Begin';
$_['text_insert_append']				= 'Insert Into End';
$_['text_insert_before']				= 'Insert Before';
$_['text_insert_after']					= 'Insert After';
$_['text_align_left']					= 'Align Left';
$_['text_align_center']					= 'Align Center';
$_['text_align_right']					= 'Align Right';
$_['text_small']			 			= 'Small';
$_['text_medium']			 	 		= 'Medium';
$_['text_large']			 	 		= 'Large';
$_['text_responsive']			 	 	= 'Responsive';
$_['text_gold']			 	 			= 'Gold';
$_['text_blue']			 	 			= 'Blue';
$_['text_silver']			 	 		= 'Silver';
$_['text_white']			 	 		= 'White';
$_['text_black']			 	 		= 'Black';
$_['text_pill']			 	 			= 'Pill';
$_['text_rect']			 	 			= 'Rect';
$_['text_checkout']			 	 		= 'Checkout';
$_['text_pay']			 	 			= 'Pay';
$_['text_buy_now']			 	 		= 'Buy Now';
$_['text_pay_pal']			 	 		= 'PayPal';
$_['text_installment']			 	 	= 'Installment';
$_['text_yes']			 	 			= 'Yes';
$_['text_no']			 	 			= 'No';

// Entry
$_['entry_status']     					= 'Status';
$_['entry_product_page_status']     	= 'Product Page Status';
$_['entry_cart_page_status']     		= 'Cart Page Status';
$_['entry_insert_tag']     				= 'Insert Tag';
$_['entry_insert_type']     			= 'Insert Type';
$_['entry_button_align']     			= 'Button Align';
$_['entry_button_size'] 				= 'Button Size';
$_['entry_button_color'] 				= 'Button Color';
$_['entry_button_shape'] 				= 'Button Shape';
$_['entry_button_label'] 				= 'Button Label';
$_['entry_button_tagline'] 				= 'Button Tagline';

// Success
$_['success_save']						= 'Success: You have modified PayPal Smart Button module!';

// Error
$_['error_permission'] 					= 'Warning: You do not have permission to modify PayPal Express Checkout Button module!';