<?php
// Heading
$_['heading_title']                  = 'Settings';

// Text
$_['text_stores']                    = 'Stores';
$_['text_success']                   = 'Success: You have modified settings!';
$_['text_edit']                      = 'Edit Setting';
$_['text_product']                   = 'Products';
$_['text_review']                    = 'Reviews';
$_['text_voucher']                   = 'Vouchers';
$_['text_tax']                       = 'Taxes';
$_['text_account']                   = 'Account';
$_['text_checkout']                  = 'Checkout';
$_['text_stock']                     = 'Stock';
$_['text_affiliate']                 = 'Affiliates';
$_['text_captcha']                   = 'Captcha';
$_['text_register']                  = 'Register';
$_['text_guest']                     = 'Guest Checkout';
$_['text_return']                    = 'Returns';
$_['text_contact']                   = 'Contact';
$_['text_shipping']                  = 'Shipping Address';
$_['text_payment']                   = 'Payment Address';
$_['text_mail']                      = 'Mail';
$_['text_smtp']                      = 'SMTP';
$_['text_mail_alert']                = 'Mail Alerts';
$_['text_mail_account']              = 'Register';
$_['text_mail_affiliate']            = 'Affiliate';
$_['text_mail_order']                = 'Orders';
$_['text_mail_review']               = 'Reviews';
$_['text_general']                   = 'General';
$_['text_security']                  = 'Security';
$_['text_upload']                    = 'Uploads';
$_['text_error']                     = 'Error Handling';

// Entry
$_['entry_meta_title']               = 'Meta Title';
$_['entry_meta_description']         = 'Meta Tag Description';
$_['entry_meta_keyword']             = 'Meta Tag Keywords';
$_['entry_layout']                   = 'Default Layout';
$_['entry_theme']                    = 'Theme';
$_['entry_name']                     = 'Store Name';
$_['entry_owner']                    = 'Store Owner';
$_['entry_address']                  = 'Address';
$_['entry_geocode']                  = 'Geocode';
$_['entry_email']                    = 'E-Mail';
$_['entry_telephone']                = 'Telephone';
$_['entry_fax']                      = 'Fax';
$_['entry_image']                    = 'Image';
$_['entry_open']                     = 'Opening Times';
$_['entry_comment']                  = 'Comment';
$_['entry_location']                 = 'Store Location';
$_['entry_country']                  = 'Country';
$_['entry_zone']                     = 'Region / State';
$_['entry_language']                 = 'Language';
$_['entry_admin_language']           = 'Administration Language';
$_['entry_currency']                 = 'Currency';
$_['entry_currency_auto']            = 'Auto Update Currency';
$_['entry_length_class']             = 'Length Class';
$_['entry_weight_class']             = 'Weight Class';
$_['entry_limit_admin']              = 'Default Items Per Page (Admin)';
$_['entry_product_count']            = 'Category Product Count';
$_['entry_review']                   = 'Allow Reviews';
$_['entry_review_guest']             = 'Allow Guest Reviews';
$_['entry_voucher_min']              = 'Voucher Min';
$_['entry_voucher_max']              = 'Voucher Max';
$_['entry_tax']                      = 'Display Prices With Tax';
$_['entry_tax_default']              = 'Use Store Tax Address';
$_['entry_tax_customer']             = 'Use Customer Tax Address';
$_['entry_customer_online']          = 'Customers Online';
$_['entry_customer_activity']        = 'Customers Activity';
$_['entry_customer_search']          = 'Log Customer Searches';
$_['entry_customer_group']           = 'Customer Group';
$_['entry_customer_group_display']   = 'Customer Groups';
$_['entry_customer_price']           = 'Login Display Prices';
$_['entry_login_attempts']           = 'Max Login Attempts';
$_['entry_account']                  = 'Account Terms';
$_['entry_cart_weight']              = 'Display Weight on Cart Page';
$_['entry_checkout_guest']           = 'Guest Checkout';
$_['entry_checkout']                 = 'Checkout Terms';
$_['entry_invoice_prefix']           = 'Invoice Prefix';
$_['entry_order_status']             = 'Order Status';
$_['entry_processing_status']        = 'Processing Order Status';
$_['entry_complete_status']          = 'Complete Order Status';
$_['entry_fraud_status']             = 'Fraud Order Status';
$_['entry_api']                      = 'API User';
$_['entry_stock_display']            = 'Display Stock';
$_['entry_stock_warning']            = 'Show Out Of Stock Warning';
$_['entry_stock_checkout']           = 'Stock Checkout';
$_['entry_affiliate_group']          = 'Affiliate Group';
$_['entry_affiliate_approval']       = 'Affiliate Requires Approval';
$_['entry_affiliate_auto']           = 'Automatic Commission';
$_['entry_affiliate_commission']     = 'Affiliate Commission (%)';
$_['entry_affiliate']                = 'Affiliate Terms';
$_['entry_return']                   = 'Return Terms';
$_['entry_return_status']            = 'Return Status';
$_['entry_captcha']                  = 'Captcha';
$_['entry_captcha_page']             = 'Captcha Page';
$_['entry_logo']                     = 'Store Logo';
$_['entry_icon']                     = 'Icon';
$_['entry_mail_engine']              = 'Mail Engine';
$_['entry_mail_parameter']           = 'Mail Parameters';
$_['entry_mail_smtp_hostname']       = 'SMTP Hostname';
$_['entry_mail_smtp_username']       = 'SMTP Username';
$_['entry_mail_smtp_password']       = 'SMTP Password';
$_['entry_mail_smtp_port']           = 'SMTP Port';
$_['entry_mail_smtp_timeout']        = 'SMTP Timeout';
$_['entry_mail_alert']               = 'Alert Mail';
$_['entry_mail_alert_email']         = 'Additional Alert Mail';
$_['entry_secure']                   = 'Use SSL';
$_['entry_shared']                   = 'Use Shared Sessions';
$_['entry_robots']                   = 'Robots';
$_['entry_seo_url']                  = 'Use SEO URLs';
$_['entry_file_max_size']            = 'Max File Size';
$_['entry_file_ext_allowed']         = 'Allowed File Extensions';
$_['entry_file_mime_allowed']        = 'Allowed File Mime Types';
$_['entry_maintenance']              = 'Maintenance Mode';
$_['entry_password']                 = 'Allow Forgotten Password';
$_['entry_encryption']               = 'Encryption Key';
$_['entry_compression']              = 'Output Compression Level';
$_['entry_error_display']            = 'Display Errors';
$_['entry_error_log']                = 'Log Errors';
$_['entry_error_filename']           = 'Error Log Filename';
$_['entry_status']                   = 'Status';

// Help
$_['help_geocode']                   = 'Please enter your store location geocode manually.';
$_['help_open']                      = 'Fill in your store\'s opening times.';
$_['help_comment']                   = 'This field is for any special notes you would like to tell the customer i.e. Store does not accept cheques.';
$_['help_location']                  = 'The different store locations you have that you want displayed on the contact us form.';
$_['help_currency']                  = 'Change the default currency. Clear your browser cache to see the change and reset your existing cookie.';
$_['help_currency_auto']             = 'Set your store to automatically update currencies daily.';
$_['help_limit_admin']               = 'Determines how many admin items are shown per page (orders, customers, etc).';
$_['help_product_count']             = 'Show the number of products inside the subcategories in the storefront header category menu. Be warned, this will cause an extreme performance hit for stores with a lot of subcategories!';
$_['help_review']                    = 'Enable/Disable new review entry and display of existing reviews.';
$_['help_review_guest']              = 'Allow guests to post reviews.';
$_['help_voucher_min']               = 'Minimum amount a customer can purchase a voucher for.';
$_['help_voucher_max']               = 'Maximum amount a customer can purchase a voucher for.';
$_['help_tax_default']               = 'Use the store address to calculate taxes if customer is not logged in. You can choose to use the store address for the customer\'s shipping or payment address.';
$_['help_tax_customer']              = 'Use the customer\'s default address when they login to calculate taxes. You can choose to use the default address for the customer\'s shipping or payment address.';
$_['help_customer_online']           = 'Track customers online via the customer reports section.';
$_['help_customer_activity']         = 'Track customers activity via the customer reports section.';
$_['help_customer_group']            = 'Default customer group.';
$_['help_customer_group_display']    = 'Display customer groups that new customers can select to use such as wholesale and business when signing up.';
$_['help_customer_price']            = 'Only show prices when a customer is logged in.';
$_['help_login_attempts']            = 'Maximum login attempts allowed before the account is locked for 1 hour. Customer and affliate accounts can be unlocked on the customer or affliate admin pages.';
$_['help_account']                   = 'Forces people to agree to terms before an account can be created.';
$_['help_invoice_prefix']            = 'Set the invoice prefix (e.g. INV-2011-00). Invoice IDs will start at 1 for each unique prefix.';
$_['help_cart_weight']               = 'Show the cart weight on the cart page.';
$_['help_checkout_guest']            = 'Allow customers to checkout without creating an account. This will not be available when a downloadable product is in the shopping cart.';
$_['help_checkout']                  = 'Forces people to agree to terms before a customer can checkout.';
$_['help_order_status']              = 'Set the default order status when an order is processed.';
$_['help_processing_status']         = 'Set the order status the customer\'s order must reach before the order starts stock subtraction and coupon, voucher and rewards redemption.';
$_['help_complete_status']           = 'Set the order status the customer\'s order must reach before they are allowed to access their downloadable products and gift vouchers.';
$_['help_fraud_status']              = 'Set the order status when a customer is suspected of trying to alter the order payment details or use a coupon, gift voucher or reward points that have already been used.';
$_['help_api']                       = 'Default API user the admin should use.';
$_['help_stock_display']             = 'Display stock quantity on the product page.';
$_['help_stock_warning']             = 'Display out of stock message on the shopping cart page if a product is out of stock but stock checkout is yes. (Warning always shows if stock checkout is no)';
$_['help_stock_checkout']            = 'Allow customers to still checkout if the products they are ordering are not in stock.';
$_['help_affiliate_approval']        = 'Automatically approve any new affiliates who sign up.';
$_['help_affiliate_auto']            = 'Automatically add commission when each order reaches the complete status.';
$_['help_affiliate_commission']      = 'The default affiliate commission percentage.';
$_['help_affiliate']                 = 'Forces people to agree to terms before an affiliate account can be created.';
$_['help_return']                    = 'Forces people to agree to terms before a return can be created.';
$_['help_return_status']             = 'Set the default return status when a return request is submitted.';
$_['help_captcha']                   = 'Captcha to use for registration, login, contact and reviews.';
$_['help_icon']                      = 'The icon should be a PNG that is 16px x 16px.';
$_['help_mail_engine']               = 'Only choose \'Mail\' unless your host has disabled the php mail function.';
$_['help_mail_parameter']            = 'When using \'Mail\', additional mail parameters can be added here (e.g. -f email@storeaddress.com).';
$_['help_mail_smtp_hostname']        = 'Add \'tls://\' or \'ssl://\' prefix if security connection is required. (e.g. tls://smtp.gmail.com, ssl://smtp.gmail.com).';
$_['help_mail_smtp_password']        = 'For gmail you might need to setup a application specific password here: https://security.google.com/settings/security/apppasswords.';
$_['help_mail_alert']                = 'Select which features you would like to receive an alert email on when a customer uses them.';
$_['help_mail_alert_email']          = 'Any additional emails you want to receive the alert email, in addition to the main store email. (comma separated).';
$_['help_secure']                    = 'To use SSL check with your host if a SSL certificate is installed and add the SSL URL to the catalog and admin config files.';
$_['help_shared']                    = 'Try to share the session cookie between stores so the cart can be passed between different domains.';
$_['help_robots']                    = 'A list of web crawler user agents that shared sessions will not be used with. Use separate lines for each user agent.';
$_['help_seo_url']                   = 'To use SEO URLs, apache module mod-rewrite must be installed and you need to rename the htaccess.txt to .htaccess.';
$_['help_file_max_size']             = 'The maximum image file size you can upload in Image Manager. Enter as byte.';
$_['help_file_ext_allowed']          = 'Add which file extensions are allowed to be uploaded. Use a new line for each value.';
$_['help_file_mime_allowed']         = 'Add which file mime types are allowed to be uploaded. Use a new line for each value.';
$_['help_maintenance']               = 'Prevents customers from browsing your store. They will instead see a maintenance message. If logged in as admin, you will see the store as normal.';
$_['help_password']                  = 'Allow forgotten password to be used for the admin. This will be disabled automatically if the system detects a hack attempt.';
$_['help_encryption']                = 'Please provide a secret key that will be used to encrypt private information when processing orders.';
$_['help_compression']               = 'GZIP for more efficient transfer to requesting clients. Compression level must be between 0 - 9.';

// Error
$_['error_warning']                  = 'Warning: Please check the form carefully for errors!';
$_['error_permission']               = 'Warning: You do not have permission to modify settings!';
$_['error_meta_title']               = 'Title must be between 3 and 32 characters!';
$_['error_name']                     = 'Store Name must be between 3 and 32 characters!';
$_['error_owner']                    = 'Store Owner must be between 3 and 64 characters!';
$_['error_address']                  = 'Store Address must be between 10 and 256 characters!';
$_['error_email']                    = 'E-Mail Address does not appear to be valid!';
$_['error_telephone']                = 'Telephone must be between 3 and 32 characters!';
$_['error_limit']                    = 'Limit required!';
$_['error_login_attempts']           = 'Login Attempts must be greater than 0!';
$_['error_customer_group_display'] = 'You must include the default customer group if you are going to use this feature!';
$_['error_voucher_min']              = 'Minimum voucher amount required!';
$_['error_voucher_max']              = 'Maximum voucher amount required!';
$_['error_processing_status']        = 'You must choose at least 1 order process status';
$_['error_complete_status']          = 'You must choose at least 1 order complete status';
$_['error_log_required']             = 'Error Log Filename required!';
$_['error_log_invalid']              = 'Error Log Filename invalid!';
$_['error_log_extension']            = 'Error Log Filename extension needs to be .log!';
$_['error_encryption']               = 'Encryption Key must be between 32 and 1024 characters!';