<?php
// Heading
$_['heading_title']     = 'Uploads';

// Text
$_['text_success']      = 'Success: You have modified uploads!';
$_['text_list']         = 'Upload List';

// Column
$_['column_name']       = 'Upload Name';
$_['column_filename']   = 'Filename';
$_['column_date_added'] = 'Date Added';
$_['column_action']     = 'Action';

// Entry
$_['entry_name']        = 'Upload Name';
$_['entry_filename']    = 'Filename';
$_['entry_date_added']  = 'Date Added';

// Error
$_['error_permission']  = 'Warning: You do not have permission to modify uploads!';