<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  822 => 'סאול',
  8231 => 'מחוז קיאנגי',
  8232 => 'אינצ\'און',
  8233 => 'מחוז קאנגוואן',
  8241 => 'מחוז דרום צ\'הונגצ\'האנג',
  8242 => 'טג\'אן',
  8243 => 'מחוז צפון צְ\'הוּ‏נגצְ\'הַ‏א‏נג',
  8251 => 'פוסאן',
  8252 => 'אורסן',
  8253 => 'טגו',
  8254 => 'מחוז צפון קיאנגסאנג',
  8255 => 'מחוז דרום קיאנגסאנג',
  8261 => 'מחוז דרום צ\'אלה',
  8262 => 'קוואנגג\'ו',
  8263 => 'מחוז צפון צַ‏\'אלּ‏ַ‏ה',
  8264 => 'מחוז ג\'ג\'ו',
);
