/**
 * alertifyjs 1.11.1 http://alertifyjs.com
 * AlertifyJS is a javascript framework for developing pretty browser dialogs and notifications.
 * Copyright 2018 Mohammad Younes <Mohammad@alertifyjs.com> (http://alertifyjs.com) 
 * Licensed under GPL 3 <https://opensource.org/licenses/gpl-3.0>*/

.alertify .ajs-dimmer {
    background-color: #000;
    opacity: .5;
}

.alertify .ajs-dialog {
    max-width: 600px;
    min-height: 122px;
    background-color: #fff;
    border: 1px solid rgba(0, 0, 0, 0.2);
    -webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
    box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
    border-radius: 6px;
}

.alertify .ajs-header {
    color: #333;
    border-bottom: 1px solid #e5e5e5;
    border-radius: 6px 6px 0 0;
    font-size: 18px;
}

.alertify .ajs-body {
    color: black;
}

.alertify .ajs-body .ajs-content {
    padding: 15px 0px;
    font-size: 16px;
    line-height: 24px;
}

.alertify.ajs-resizable .ajs-content,
.alertify.ajs-maximized:not(.ajs-resizable) .ajs-content {
    top: 58px;
    bottom: 68px;
}

.alertify .ajs-footer {
    background-color: #fff;
    padding: 15px;
    border-top: 1px solid #e5e5e5;
    border-radius: 0 0 6px 6px;
}

.alertify-notifier .ajs-message {
    background: rgba(255, 255, 255, 0.95);
    color: #000;
    text-align: center;
    border: solid 1px #ddd;
    border-radius: 2px;
}

.alertify-notifier .ajs-message.ajs-success {
    color: #fff;
    background: rgba(91, 189, 114, 0.95);
    text-shadow: -1px -1px 0 rgba(0, 0, 0, 0.5);
}

.alertify-notifier .ajs-message.ajs-error {
    color: #fff;
    background: rgba(217, 92, 92, 0.95);
    text-shadow: -1px -1px 0 rgba(0, 0, 0, 0.5);
}

.alertify-notifier .ajs-message.ajs-warning {
    background: rgba(252, 248, 215, 0.95);
    border-color: #999;
}