<?php
// Text
$_['text_title']				= 'Credit or Debit Card (Processed securely by PayPal)';
$_['text_wait']					= 'Please wait!';
$_['text_credit_card']			= 'Credit Card Details';

// Entry
$_['entry_cc_type']				= 'Card Type';
$_['entry_cc_number']			= 'Card Number';
$_['entry_cc_start_date']		= 'Card Valid From Date';
$_['entry_cc_expire_date']		= 'Card Expiry Date';
$_['entry_cc_cvv2']				= 'Card Security Code (CVV2)';
$_['entry_cc_issue']			= 'Card Issue Number';

// Help
$_['help_start_date']			= '(if available)';
$_['help_issue']				= '(for Maestro and Solo cards only)';