<div class="panel panel-default">
  <div class="panel-heading">
    <h3 class="panel-title"><i class="fa fa-shopping-cart"></i> {{ heading_title }}</h3>
  </div>
  <div class="table-responsive">
    <table class="table">
      <thead>
        <tr>
          <td class="text-right">{{ column_order_id }}</td>
          <td>{{ column_customer }}</td>
          <td>{{ column_status }}</td>
          <td>{{ column_date_added }}</td>
          <td class="text-right">{{ column_total }}</td>
          <td class="text-right">{{ column_action }}</td>
        </tr>
      </thead>
      <tbody>
        {% if orders %}
        {% for order in orders %}
        <tr>
          <td class="text-right">{{ order.order_id }}</td>
          <td>{{ order.customer }}</td>
          <td>{{ order.status }}</td>
          <td>{{ order.date_added }}</td>
          <td class="text-right">{{ order.total }}</td>
          <td class="text-right"><a href="{{ order.view }}" data-toggle="tooltip" title="{{ button_view }}" class="btn btn-info"><i class="fa fa-eye"></i></a></td>
        </tr>
        {% endfor %}
        {% else %}
        <tr>
          <td class="text-center" colspan="6">{{ text_no_results }}</td>
        </tr>
        {% endif %}
      </tbody>
    </table>
  </div>
</div>
