
/* DIFF TEST */

.Differences {
    width: 100%;
    border-collapse: collapse;
    border-spacing: 0;
    empty-cells: show;
    color: #e9e4e5;
    background: #333;
    box-shadow: 0 3px 0 rgba(0, 0, 0, .05), 0 10px 30px rgba(0, 0, 0, .05), inset 0 0 1px 0 rgba(255, 255, 255, .07);

    thead th {
        text-align: left;
        // border-bottom: 1px solid #000;
        background: #303030;
        color: #a29d9d;
        padding: 4px;
    }

    tbody th {
        text-align: right;
        background: #303030;
        color: #A5A5A5;
        width: 4em;
        padding: 1px 2px;
        // border-right: 1px solid #000;
        vertical-align: top;
        font-size: 12px;
    }

    td {
        padding: 1px 2px;
        font-family: Consolas, monospace;
        font-size: 12px;
    }

    ins, del {
        text-decoration: none;
    }

    .Skipped {
        background: rgba(153, 153, 153, 0.1);
    }
}

.DifferencesSideBySide {

    .ChangeInsert td {

        &.Left {
            background: rgba(67, 235, 171, .07);
        }

        &.Right {
            background: rgba(67, 235, 171, .07);
        }

        ins, del {
            background: rgba(67, 235, 171, .17);
        }
    }

    .ChangeDelete td {

        &.Left {
            background: rgba(250, 91, 109, .07);
        }

        &.Right {
            background: rgba(250, 91, 109, .07);
        }
    }

    .ChangeReplace {

        .Left {
            background: rgba(255, 100, 100, .07);
        }

        .Right {
            background: rgba(255, 100, 100, .07);
        }

        ins, del {
            background: rgba(255, 100, 100, .17);
        }
    }

}

.DifferencesInline {

    .ChangeReplace {

        .Left {
            background: #fdd;
        }

        .Right {
            background: #dfd;
        }

        ins {
            background: #9e9;
        }

        del {
            background: #e99;
        }
    }

    .ChangeDelete {

        .Left {
            background: #dfd;
        }
    }

    .ChangeInsert {

        .Right {
            background: #dfd;
        }
    }
}

