<?php
// Heading
$_['heading_title']         = 'Customer Orders Report';

// Text
$_['text_extension']        = 'Extensions';
$_['text_edit']             = 'Edit Customer Orders Report';
$_['text_success']          = 'Success: You have modified customer orders report!';
$_['text_filter']           = 'Filter';
$_['text_all_status']       = 'All Statuses';

// Column
$_['column_customer']       = 'Customer Name';
$_['column_email']          = 'E-Mail';
$_['column_customer_group'] = 'Customer Group';
$_['column_status']         = 'Status';
$_['column_orders']         = 'No. Orders';
$_['column_products']       = 'No. Products';
$_['column_total']          = 'Total';
$_['column_action']         = 'Action';

// Entry
$_['entry_date_start']      = 'Date Start';
$_['entry_date_end']        = 'Date End';
$_['entry_customer']        = 'Customer';
$_['entry_status']          = 'Order Status';
$_['entry_status']          = 'Status';
$_['entry_sort_order']      = 'Sort Order';

// Error
$_['error_permission']  = 'Warning: You do not have permission to modify customer orders report!';