<?php
// Heading
$_['heading_title']    = 'Weight Based Shipping';

// Text
$_['text_extension']   = 'Extensions';
$_['text_success']     = 'Success: You have modified weight based shipping!';
$_['text_edit']        = 'Edit Weight Based Shipping';

// Entry
$_['entry_rate']       = 'Rates';
$_['entry_tax_class']  = 'Tax Class';
$_['entry_geo_zone']   = 'Geo Zone';
$_['entry_status']     = 'Status';
$_['entry_sort_order'] = 'Sort Order';

// Help
$_['help_rate']        = 'Example: 5:10.00,7:12.00 Weight:Cost,Weight:Cost, etc..';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify weight based shipping!';