<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  2341 => 'Lagos',
  2342 => 'Ibadan',
  23430 => 'Ado Ekiti',
  23431 => 'Ilorin',
  23433 => 'New Bussa',
  23434 => 'Akura',
  23435 => 'Oshogbo',
  23436 => 'Ile Ife',
  23437 => 'Ijebu Ode',
  23438 => 'Oyo',
  23439 => 'Abeokuta',
  23441 => 'Wukari',
  23442 => 'Enugu',
  23443 => 'Abakaliki',
  23444 => 'Makurdi',
  23445 => 'Ogoja',
  23446 => 'Onitsha',
  23447 => 'Lafia',
  23448 => 'Awka',
  23450 => 'Ikare',
  23451 => 'Owo',
  23452 => 'Benin',
  23453 => 'Warri',
  23454 => 'Sapele',
  23455 => 'Agbor',
  23456 => 'Asaba',
  23457 => 'Auchi',
  23458 => 'Lokoja',
  23459 => 'Okitipupa',
  23460 => 'Sokobo',
  23461 => 'Kafanchau',
  23462 => 'Kaduna',
  23463 => 'Gusau',
  23464 => 'Kano',
  23465 => 'Katsina',
  23466 => 'Minna',
  23467 => 'Kontagora',
  23468 => 'Birnin-Kebbi',
  23469 => 'Zaria',
  2347020 => 'Pank Shin',
  23471 => 'Azare',
  23472 => 'Gombe',
  23473 => 'Jos',
  23474 => 'Damaturu',
  23475 => 'Yola',
  23476 => 'Maiduguri',
  23477 => 'Bauchi',
  23478 => 'Hadejia',
  23479 => 'Jalingo',
  23482 => 'Aba',
  23483 => 'Owerri',
  23484 => 'Port Harcourt',
  23485 => 'Uyo',
  23486 => 'Ahoada',
  23487 => 'Calabar',
  23488 => 'Umuahia',
  23489 => 'Yenegoa',
  2349 => 'Abuja',
);
