<?php
// Heading
$_['heading_title']                    = 'Divido';

// Text
$_['text_divido']                      = '<a href="http://divido.com" target="_blank"><img src="view/image/payment/divido.png"></a>';
$_['text_edit']                        = 'Edit Divido';
$_['text_extension']                   = 'Extensions';
$_['text_order_info']                  = 'Divido info';
$_['text_success']                     = 'Success: You have modified the Divido module';
$_['text_proposal_id']                 = 'Proposal ID';
$_['text_application_id']              = 'Application ID';
$_['text_deposit_amount']              = 'Deposit amount';

// Entry
$_['entry_order_status']               = 'Order status when approved';
$_['entry_sort_order']                 = 'Sort order';
$_['entry_status']                     = 'Status';
$_['entry_api_key']                    = 'API-key';
$_['entry_title']                      = 'Title';
$_['entry_productselection']           = 'Product selection';
$_['entry_planselection']              = 'Show default plan';
$_['entry_planlist']                   = 'Plans';
$_['entry_plans_options_all']          = 'Show all plans';
$_['entry_plans_options_selected']     = 'Select default plans';
$_['entry_products_options_all']       = 'All products';
$_['entry_products_options_selected']  = 'Only selected products';
$_['entry_products_options_threshold'] = 'All products above a defined price';
$_['entry_price_threshold']            = 'Product price threshold';
$_['entry_cart_threshold']             = 'Cart total threshold';
$_['entry_threshold_list']             = 'Plan thresholds';
$_['entry_category']                   = 'Categories';

// Help
$_['help_api_key']                     = 'Key that identifies you with Divido (obtained from Divido)';
$_['help_status']                      = 'Status of the payment method';
$_['help_order_status']                = 'Status of the order when lender has approved';
$_['help_title']                       = 'Title of the payment option, shown in checkout';
$_['help_planselection']               = 'Choose whether to manually select plans or show the default set';
$_['help_productselection']            = 'Select what products are available on finance';
$_['help_category']                    = 'Limit what categories where financing is available';
$_['help_cart_threshold']              = 'Hard lower limit on cart amount for Divido to be available';