<?php
// Heading
$_['heading_title']         = 'United States Postal Service';

// Text
$_['text_extension']        = 'Extensions';
$_['text_success']          = 'Success: You have modified United States Postal Service!';
$_['text_edit']             = 'Edit United States Postal Service Shipping';
$_['text_domestic_00']      = 'First-Class Mail Parcel';
$_['text_domestic_01']      = 'First-Class Mail Large Envelope';
$_['text_domestic_02']      = 'First-Class Mail Letter';
$_['text_domestic_03']      = 'First-Class Mail Postcards';
$_['text_domestic_1']       = 'Priority Mail';
$_['text_domestic_2']       = 'Express Mail Hold for Pickup';
$_['text_domestic_3']       = 'Express Mail';
$_['text_domestic_4']       = 'Parcel Post';
$_['text_domestic_5']       = 'Bound Printed Matter';
$_['text_domestic_6']       = 'Media Mail';
$_['text_domestic_7']       = 'Library';
$_['text_domestic_12']      = 'First-Class Postcard Stamped';
$_['text_domestic_13']      = 'Express Mail Flat-Rate Envelope';
$_['text_domestic_16']      = 'Priority Mail Flat-Rate Envelope';
$_['text_domestic_17']      = 'Priority Mail Regular Flat-Rate Box';
$_['text_domestic_18']      = 'Priority Mail Keys and IDs';
$_['text_domestic_19']      = 'First-Class Keys and IDs';
$_['text_domestic_22']      = 'Priority Mail Flat-Rate Large Box';
$_['text_domestic_23']      = 'Express Mail Sunday/Holiday';
$_['text_domestic_25']      = 'Express Mail Flat-Rate Envelope Sunday/Holiday';
$_['text_domestic_27']      = 'Express Mail Flat-Rate Envelope Hold For Pickup';
$_['text_domestic_28']      = 'Priority Mail Small Flat-Rate Box';
$_['text_international_1']  = 'Express Mail International';
$_['text_international_2']  = 'Priority Mail International';
$_['text_international_4']  = 'Global Express Guaranteed (Document and Non-document)';
$_['text_international_5']  = 'Global Express Guaranteed Document used';
$_['text_international_6']  = 'Global Express Guaranteed Non-Document Rectangular shape';
$_['text_international_7']  = 'Global Express Guaranteed Non-Document Non-Rectangular';
$_['text_international_8']  = 'Priority Mail Flat Rate Envelope';
$_['text_international_9']  = 'Priority Mail Flat Rate Box';
$_['text_international_10'] = 'Express Mail International Flat Rate Envelope';
$_['text_international_11'] = 'Priority Mail Flat Rate Large Box';
$_['text_international_12'] = 'Global Express Guaranteed Envelope';
$_['text_international_13'] = 'First Class Mail International Letters';
$_['text_international_14'] = 'First Class Mail International Flats';
$_['text_international_15'] = 'First Class Mail International Parcels';
$_['text_international_16'] = 'Priority Mail Flat Rate Small Box';
$_['text_international_21'] = 'Postcards';
$_['text_regular']          = 'Regular';
$_['text_large']            = 'Large';
$_['text_rectangular']      = 'Rectangular';
$_['text_non_rectangular']  = 'Non Rectangular';
$_['text_variable']         = 'Variable';

// Entry
$_['entry_user_id']         = 'User ID';
$_['entry_postcode']        = 'Zip Code';
$_['entry_domestic']        = 'Domestic Services';
$_['entry_international']   = 'International Services';
$_['entry_size']            = 'Size';
$_['entry_container']       = 'Container';
$_['entry_machinable']      = 'Machinable';
$_['entry_dimension']       = 'Dimensions (L x W x H)';
$_['entry_length']          = 'Length';
$_['entry_height']          = 'Height';
$_['entry_width']           = 'Width';
$_['entry_display_time']    = 'Display Delivery Time';
$_['entry_display_weight']  = 'Display Delivery Weight';
$_['entry_weight_class']    = 'Weight Class';
$_['entry_tax']             = 'Tax Class';
$_['entry_geo_zone']        = 'Geo Zone';
$_['entry_status']          = 'Status';
$_['entry_sort_order']      = 'Sort Order';
$_['entry_debug']           = 'Debug Mode';

// Help
$_['help_dimension']        = 'Average package dimensions for shipping package. Product dimensions are not used for shipping at this time.';
$_['help_display_time']     = 'Do you want to display the shipping time? (e.g. Ships within 3 to 5 days)';
$_['help_display_weight']   = 'Do you want to display the shipping weight? (e.g. Delivery Weight : 2.7674 kg)';
$_['help_weight_class']     = 'Must be set to Pound.';
$_['help_debug']            = 'Saves send/recv data to the system log';

// Error
$_['error_permission']      = 'Warning: You do not have permission to modify United States Postal Service!';
$_['error_user_id']         = 'User ID Required!';
$_['error_postcode']        = 'Zip Code Required!';
$_['error_width']           = 'Width Required!';
$_['error_length']          = 'Length Required!';
$_['error_height']          = 'Height Required!';
$_['error_girth']           = 'Girth Required!';