{{ header }}{{ column_left }}
<div id="content">
  <div class="page-header">
    <div class="container-fluid">
      <div class="pull-right">
        <button type="submit" form="form-payment" data-toggle="tooltip" title="{{ button_save }}" class="btn btn-primary"><i class="fa fa-save"></i></button>
        <a href="{{ cancel }}" data-toggle="tooltip" title="{{ button_cancel }}" class="btn btn-default"><i class="fa fa-reply"></i></a></div>
      <h1>{{ heading_title }}</h1>
      <ul class="breadcrumb">
        {% for breadcrumb in breadcrumbs %}
        <li><a href="{{ breadcrumb.href }}">{{ breadcrumb.text }}</a></li>
        {% endfor %}
      </ul>
    </div>
  </div>
  <div class="container-fluid">
    {% if error_warning %}
    <div class="alert alert-danger alert-dismissible"><i class="fa fa-exclamation-circle"></i> {{ error_warning }}
      <button type="button" class="close" data-dismiss="alert">&times;</button>
    </div>
    {% endif %}
    <div class="panel panel-default">
      <div class="panel-heading">
        <h3 class="panel-title"><i class="fa fa-pencil"></i> {{ text_edit }}</h3>
      </div>
      <div class="panel-body">
        <form action="{{ action }}" method="post" enctype="multipart/form-data" id="form-payment" class="form-horizontal">
          <div class="tab-content">
            <div class="form-group required">
              <label class="col-sm-2 control-label" for="entry-app-id">{{ entry_app_id }}</label>
              <div class="col-sm-10">
                <input type="text" name="payment_wechat_pay_app_id" value="{{ payment_wechat_pay_app_id }}" placeholder="{{ entry_app_id }}" id="entry-app-id" class="form-control"/>
                {% if error_app_id %}
                <div class="text-danger">{{ error_app_id }}</div>
                {% endif %}
              </div>
            </div>
            <div class="form-group required">
              <label class="col-sm-2 control-label" for="entry-app-secret">{{ entry_app_secret }}</label>
              <div class="col-sm-10">
                <input type="text" name="payment_wechat_pay_app_secret" value="{{ payment_wechat_pay_app_secret }}" placeholder="{{ entry_app_secret }}" id="entry-app-secret" class="form-control"/>
                {% if error_app_secret %}
                  <div class="text-danger">{{ error_app_secret }}</div>
                {% endif %}
              </div>
            </div>
            <div class="form-group required">
              <label class="col-sm-2 control-label" for="entry-mch-id">{{ entry_mch_id }}</label>
              <div class="col-sm-10">
                <input type="text" name="payment_wechat_pay_mch_id" value="{{ payment_wechat_pay_mch_id }}" placeholder="{{ entry_mch_id }}" id="entry-mch-id" class="form-control"/>
                {% if error_mch_id %}
                  <div class="text-danger">{{ error_mch_id }}</div>
                {% endif %}
              </div>
            </div>
            <div class="form-group required">
              <label class="col-sm-2 control-label" for="entry-api-secret">{{ entry_api_secret }}</label>
              <div class="col-sm-10">
                <input type="text" name="payment_wechat_pay_api_secret" value="{{ payment_wechat_pay_api_secret }}" placeholder="{{ entry_api_secret }}" id="entry-api-secret" class="form-control"/>
                {% if error_api_secret %}
                  <div class="text-danger">{{ error_api_secret }}</div>
                {% endif %}
              </div>
            </div>
            <div class="form-group">
              <label class="col-sm-2 control-label" for="input-total"><span data-toggle="tooltip" title="{{ help_total }}">{{ entry_total }}</span></label>
              <div class="col-sm-10">
                <input type="text" name="payment_wechat_pay_total" value="{{ payment_wechat_pay_total }}" placeholder="{{ entry_total }}" id="input-total" class="form-control"/>
              </div>
            </div>
            <div class="form-group">
              <label class="col-sm-2 control-label" for="input-currency"><span data-toggle="tooltip" title="{{ help_currency }}">{{ entry_currency }}</span></label>
              <div class="col-sm-10">
                <input type="text" name="payment_wechat_pay_currency" value="{{ payment_wechat_pay_currency }}" placeholder="{{ entry_currency }}" id="input-currency" class="form-control"/>
              </div>
            </div>
            <div class="form-group">
              <label class="col-sm-2 control-label" for="input-completed-status">{{ entry_completed_status }}</label>
              <div class="col-sm-10">
                <select name="payment_wechat_pay_completed_status_id" id="input-completed-status" class="form-control">
                  {% for order_status in order_statuses %}
                    {% if order_status.order_status_id == payment_wechat_pay_completed_status_id %}
                      <option value="{{ order_status.order_status_id }}" selected="selected">{{ order_status.name }}</option>
                    {% else %}
                      <option value="{{ order_status.order_status_id }}">{{ order_status.name }}</option>
                    {% endif %}
                  {% endfor %}
                </select>
              </div>
            </div>
            <div class="form-group">
              <label class="col-sm-2 control-label" for="input-geo-zone">{{ entry_geo_zone }}</label>
              <div class="col-sm-10">
                <select name="payment_wechat_pay_geo_zone_id" id="input-geo-zone" class="form-control">
                  <option value="0">{{ text_all_zones }}</option>
                  {% for geo_zone in geo_zones %}
                  {% if geo_zone.geo_zone_id == payment_wechat_pay_geo_zone_id %}
                  <option value="{{ geo_zone.geo_zone_id }}" selected="selected">{{ geo_zone.name }}</option>
                  {% else %}
                  <option value="{{ geo_zone.geo_zone_id }}">{{ geo_zone.name }}</option>
                  {% endif %}
                  {% endfor %}
                </select>
              </div>
            </div>
            <div class="form-group">
              <label class="col-sm-2 control-label" for="input-status">{{ entry_status }}</label>
              <div class="col-sm-10">
                <select name="payment_wechat_pay_status" id="input-status" class="form-control">
                  {% if payment_wechat_pay_status %}
                  <option value="1" selected="selected">{{ text_enabled }}</option>
                  <option value="0">{{ text_disabled }}</option>
                  {% else %}
                  <option value="1">{{ text_enabled }}</option>
                  <option value="0" selected="selected">{{ text_disabled }}</option>
                  {% endif %}
                </select>
              </div>
            </div>
            <div class="form-group">
              <label class="col-sm-2 control-label" for="input-sort-order">{{ entry_sort_order }}</label>
              <div class="col-sm-10">
                <input type="text" name="payment_wechat_pay_sort_order" value="{{ payment_wechat_pay_sort_order }}" placeholder="{{ entry_sort_order }}" id="input-sort-order" class="form-control"/>
              </div>
            </div>
          </div>
        </form>
        <div class="alert alert-info">{{ help_wechat_pay_setup }}</div>
      </div>
    </div>
  </div>
</div>
{{ footer }}