<?php
// Heading
$_['heading_title']            = 'Lay-Buy Information';

// Text
$_['text_reference_info']      = 'Reference Information';
$_['text_laybuy_ref_no']       = 'Lay-Buy Reference ID:';
$_['text_paypal_profile_id']   = 'PayPal Profile ID:';
$_['text_payment_plan']        = 'Payment Plan';
$_['text_status']              = 'Status:';
$_['text_amount']              = 'Amount:';
$_['text_downpayment_percent'] = 'Down Payment Percent:';
$_['text_months']              = 'Months:';
$_['text_downpayment_amount']  = 'Down Payment Amount:';
$_['text_payment_amounts']     = 'Payment Amounts:';
$_['text_first_payment_due']   = 'First Payment Due:';
$_['text_last_payment_due']    = 'Last Payment Due:';
$_['text_downpayment']         = 'Down Payment';
$_['text_month']               = 'Month';

// Column
$_['column_instalment']        = 'Instalment';
$_['column_amount']            = 'Amount';
$_['column_date']              = 'Date';
$_['column_pp_trans_id']       = 'PayPal Transaction ID';
$_['column_status']            = 'Status';