<?php
// Heading
$_['heading_title']         = 'Profile';

// Text
$_['text_success']          = 'Success: You have modified your profile!';
$_['text_edit']             = 'Edit Your Profile';

// Column
$_['column_username']       = 'Username';
$_['column_status']         = 'Status';
$_['column_date_added']     = 'Date Added';
$_['column_action']         = 'Action';

// Entry
$_['entry_username']        = 'Username';
$_['entry_password']        = 'Password';
$_['entry_confirm']         = 'Confirm';
$_['entry_firstname']       = 'First Name';
$_['entry_lastname']        = 'Last Name';
$_['entry_email']           = 'E-Mail';
$_['entry_image']           = 'Image';

// Error
$_['error_permission']      = 'Warning: You do not have permission to modify your profile!';
$_['error_exists_username'] = 'Warning: Username is already in use!';
$_['error_username']        = 'Username must be between 3 and 20 characters!';
$_['error_password']        = 'Password must be between 4 and 20 characters!';
$_['error_confirm']         = 'Password and password confirmation do not match!';
$_['error_firstname']       = 'First Name must be between 1 and 32 characters!';
$_['error_lastname']        = 'Last Name must be between 1 and 32 characters!';
$_['error_email']           = 'E-Mail Address does not appear to be valid!';
$_['error_exists_email']    = 'Warning: E-Mail Address is already registered!';