<?php
// Heading
$_['heading_title']     = 'Languages';

// Text
$_['text_success']      = 'Success: You have modified languages!';
$_['text_list']         = 'Language List';
$_['text_add']          = 'Add Language';
$_['text_edit']         = 'Edit Language';

// Column
$_['column_name']       = 'Language Name';
$_['column_code']       = 'Code';
$_['column_sort_order'] = 'Sort Order';
$_['column_action']     = 'Action';

// Entry
$_['entry_name']        = 'Language Name';
$_['entry_code']        = 'Code';
$_['entry_locale']      = 'Locale';
$_['entry_status']      = 'Status';
$_['entry_sort_order']  = 'Sort Order';

// Help
$_['help_locale']       = 'Example: en_US.UTF-8,en_US,en-gb,en_gb,english';
$_['help_status']       = 'Hide/Show it in language dropdown';

// Error
$_['error_permission']  = 'Warning: You do not have permission to modify languages!';
$_['error_exists']      = 'Warning: You added before the language!';
$_['error_name']        = 'Language Name must be between 3 and 32 characters!';
$_['error_code']        = 'Language Code must at least 2 characters!';
$_['error_locale']      = 'Locale required!';
$_['error_default']     = 'Warning: This language cannot be deleted as it is currently assigned as the default store language!';
$_['error_admin']       = 'Warning: This Language cannot be deleted as it is currently assigned as the administration language!';
$_['error_store']       = 'Warning: This language cannot be deleted as it is currently assigned to %s stores!';
$_['error_order']       = 'Warning: This language cannot be deleted as it is currently assigned to %s orders!';