<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  245320 => 'Bissau',
  245321 => 'Bissau',
  245322 => 'Sta. Luzia',
  245325 => 'Brá',
  245331 => 'Mansôa',
  245332 => 'Bigene/Bissorã',
  245334 => 'Mansaba',
  245335 => 'Farim',
  245341 => 'Bafatá',
  245342 => 'Bambadinca',
  245351 => 'Gabú',
  245352 => 'Sonaco',
  245353 => 'Pirada',
  245354 => 'Pitche',
  245370 => 'Buba',
  245391 => 'Canchungo',
  245392 => 'Cacheu',
  245393 => 'S. Domingos',
  245394 => 'Bula',
  245396 => 'Ingoré',
);
