<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  21821 => 'Tripoli',
  21823 => 'Zawia',
  21824 => 'Sabratha',
  21825 => 'Zuara',
  218252 => 'Zahra',
  21851 => 'Misratah',
  21854 => 'Sirt',
  21857 => 'Hun',
  21861 => 'Benghazi',
  218623 => 'Gmines',
  218624 => 'Elkuwaifia',
  218625 => 'Deriana',
  218626 => 'Kaalifa',
  218627 => 'Jerdina',
  218628 => 'Seluk',
  218629 => 'Elmagrun',
  21863 => 'Benina',
  21867 => 'Elmareg',
  2187 => 'Sebha',
);
