<?php
// Heading
$_['heading_title']    = 'Length Classes';

// Text
$_['text_success']     = 'Success: You have modified length classes!';
$_['text_list']        = 'Length Class List';
$_['text_add']         = 'Add Length Class';
$_['text_edit']        = 'Edit Length Class';

// Column
$_['column_title']     = 'Length Title';
$_['column_unit']      = 'Length Unit';
$_['column_value']     = 'Value';
$_['column_action']    = 'Action';

// Entry
$_['entry_title']      = 'Length Title';
$_['entry_unit']       = 'Length Unit';
$_['entry_value']      = 'Value';

// Help
$_['help_value']       = 'Set to 1.00000 if this is your default length.';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify length classes!';
$_['error_title']      = 'Length Title must be between 3 and 32 characters!';
$_['error_unit']       = 'Length Unit must be between 1 and 4 characters!';
$_['error_default']    = 'Warning: This length class cannot be deleted as it is currently assigned as the default store length class!';
$_['error_product']    = 'Warning: This length class cannot be deleted as it is currently assigned to %s products!';