<?php
// Text
$_['text_success']       = 'You have successfully modified customers';

// Error
$_['error_permission']   = 'Warning: You do not have permission to access the API!';
$_['error_customer']     = 'You must select a customer!';
$_['error_firstname']    = 'First Name must be between 1 and 32 characters!';
$_['error_lastname']     = 'Last Name must be between 1 and 32 characters!';
$_['error_email']        = 'E-Mail Address does not appear to be valid!';
$_['error_telephone']    = 'Telephone must be between 3 and 32 characters!';
$_['error_custom_field'] = '%s required!';