<form action="{{ action }}" method="post">
    <div class="buttons">
        <div class="pull-right">
            <input type="submit" value="{{ button_confirm }}" class="btn btn-primary" />
        </div>
    </div>
</form>
