@import "../scss/variable";

body {
	line-height: 1.42857;
}
hr {
	border-top: 1px solid $border_color;
	margin-top: 6.5px;
}
code {
	background-color: $code-bgc;
	color: $code-c;
}
.tile {
	background-color: $tile-bgc;
	.tile-body {
		color: $tile-c;
	}
}
.rotate {
	-webkit-animation-name: rotation;
	-webkit-animation-duration: 2s;
	-webkit-animation-iteration-count: infinite;
	-webkit-animation-timing-function: linear;
	-moz-animation-name: rotation;
	-moz-animation-duration: 2s;
	-moz-animation-iteration-count: infinite;
	-moz-animation-timing-function: linear;
	-o-animation-name: rotation;
	-o-animation-duration: 2s;
	-o-animation-iteration-count: infinite;
	-o-animation-timing-function: linear;
	animation-name: rotation;
	animation-duration: 2s;
	animation-iteration-count: infinite;
	animation-timing-function: linear;
}
@-webkit-keyframes rotation {
	0% {-webkit-transform:rotate(0deg);
	-moz-transform:rotate(0deg);
	-o-transform:rotate(0deg);
	transform:rotate(0deg);}
	100% {-webkit-transform:rotate(360deg);
	-moz-transform:rotate(360deg);
	-o-transform:rotate(360deg);
	transform:rotate(360deg);}
}
@-moz-keyframes rotation {
	0% {-webkit-transform:rotate(0deg);
	-moz-transform:rotate(0deg);
	-o-transform:rotate(0deg);
	transform:rotate(0deg);}
	100% {-webkit-transform:rotate(360deg);
	-moz-transform:rotate(360deg);
	-o-transform:rotate(360deg);
	transform:rotate(360deg);}
}
@-o-keyframes rotation {
	0% {-webkit-transform:rotate(0deg);
	-moz-transform:rotate(0deg);
	-o-transform:rotate(0deg);
	transform:rotate(0deg);}
	100% {-webkit-transform:rotate(360deg);
	-moz-transform:rotate(360deg);
	-o-transform:rotate(360deg);
	transform:rotate(360deg);}
}
@keyframes rotation {
	0% {-webkit-transform:rotate(0deg);
	-moz-transform:rotate(0deg);
	-o-transform:rotate(0deg);
	transform:rotate(0deg);}
	100% {-webkit-transform:rotate(360deg);
	-moz-transform:rotate(720deg);
	-o-transform:rotate(360deg);
	transform:rotate(360deg);}
}