<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  822 => 'سول',
  8231 => 'جيونجي دو',
  8232 => 'مدينة إنتشيون الكبرى',
  8233 => 'جانجون-دو',
  8241 => 'تشانجتشيونجنام دو',
  8242 => 'مدينة دايجون الكبرى',
  8243 => 'تشانجتشيونج دو',
  8251 => 'مدينة بوسان الكبرى',
  8252 => 'مدينة أولسان الكبرى',
  8253 => 'مدينة دياجو الكبرى',
  8254 => 'جيونجسانجبك دو',
  8255 => 'جيونسانجنام-دو',
  8261 => 'جولانام-دو',
  8262 => 'مدينة جوانججو الكبرى',
  8263 => 'جولابوك-دو',
  8264 => 'جيجو دو',
);
