<div id="cart" class="btn-group btn-block cart_block">
   <button type="button" data-toggle="dropdown" data-loading-text="{{ text_loading }}" class="btn btn-inverse btn-block btn-lg dropdown-toggle{% if products or vouchers %} active{% endif %}"><span class="cart-text">{{ heading_title_cart }}</span><span class="cart-total">{{ text_items }}</span><span class="cart-total-res">{{ text_items_res }}</span>
  </button>
  <a href="{{ cart }}" class="addtocart btn{% if products or vouchers %} active{% endif %}">
<span class="cart-text">{{ heading_title_cart }}</span>
<span class="cart-total-res">{{ text_items_res }}</span>
</a>
  <ul class="dropdown-menu pull-right">
    {% if products or vouchers %}
    <li>
      <table class="table table-striped">
        {% for product in products %}
        <tr>
          <td class="text-center">{% if product.thumb %} <a href="{{ product.href }}"><img src="{{ product.thumb }}" alt="{{ product.name }}" title="{{ product.name }}" class="img-thumbnail" /></a> {% endif %}</td>
          <td class="text-left"><a href="{{ product.href }}">{{ product.name }}</a> {% if product.option %}
            {% for option in product.option %} <br />
            - <small>{{ option.name }} {{ option.value }}</small> {% endfor %}
            {% endif %}
            {% if product.recurring %} <br />
            - <small>{{ text_recurring }} {{ product.recurring }}</small> {% endif %}</td>
          <td class="text-right">x {{ product.quantity }}</td>
          <td class="text-right">{{ product.total }}</td>
          <td class="text-center"><button type="button" onclick="cart.remove('{{ product.cart_id }}');" title="{{ button_remove }}" class="btn btn-danger btn-xs"><i class="fa fa-times"></i></button></td>
        </tr>
        {% endfor %}
        {% for voucher in vouchers %}
        <tr>
          <td class="text-center"></td>
          <td class="text-left">{{ voucher.description }}</td>
          <td class="text-right">x&nbsp;1</td>
          <td class="text-right">{{ voucher.amount }}</td>
          <td class="text-center text-danger"><button type="button" onclick="voucher.remove('{{ voucher.key }}');" title="{{ button_remove }}" class="btn btn-danger btn-xs"><i class="fa fa-times"></i></button></td>
        </tr>
        {% endfor %}
      </table>
    </li>
    <li>
      <div>
        <table class="table table-bordered">
          {% for total in totals %}
          <tr>
            <td class="text-right"><strong>{{ total.title }}</strong></td>
            <td class="text-right">{{ total.text }}</td>
          </tr>
          {% endfor %}
        </table>
       <div class="text-right button-container"><a href="{{ cart }}" class="addtocart"><strong>{{ text_cart}}</strong></a><a href="{{ checkout }}" class="checkout"><strong>{{ text_checkout }}</strong></a></div>	   
      </div>
    </li>
    {% else %}
    <li>
      <p class="text-center">{{ text_empty }}</p>
    </li>
    {% endif %}
  </ul>
</div>
