{{ text_order_id }} {{ order_id }}
{{ text_date_added }} {{ date_added }}

{{ text_order_status }}

{{ order_status }}

{% if link %}
{{ text_link }}

{{ link }}
{% endif %}
{% if comment %}

{{ text_comment }}

{{ comment }}
{{ text_footer }}
{% else %} 
{{ text_footer }}
{% endif %}