<?php
// Heading
$_['heading_title']        = 'Mail';

// Text
$_['text_success']         = 'Your message has been successfully sent!';
$_['text_sent']            = 'Your message has been successfully sent to %s of %s recipients!';
$_['text_list']            = 'Mail List';
$_['text_default']         = 'Default';
$_['text_newsletter']      = 'All Newsletter Subscribers';
$_['text_customer_all']    = 'All Customers';
$_['text_customer_group']  = 'Customer Group';
$_['text_customer']        = 'Customers';
$_['text_affiliate_all']   = 'All Affiliates';
$_['text_affiliate']       = 'Affiliates';
$_['text_product']         = 'Products';

// Entry
$_['entry_store']          = 'From';
$_['entry_to']             = 'To';
$_['entry_customer_group'] = 'Customer Group';
$_['entry_customer']       = 'Customer';
$_['entry_affiliate']      = 'Affiliate';
$_['entry_product']        = 'Products';
$_['entry_subject']        = 'Subject';
$_['entry_message']        = 'Message';

// Help
$_['help_customer']        = '(Autocomplete)';
$_['help_affiliate']       = '(Autocomplete)';
$_['help_product']         = 'Send only to customers who have ordered products in the list. (Autocomplete)';

// Error
$_['error_permission']     = 'Warning: You do not have permission to send E-Mails!';
$_['error_subject']        = 'E-Mail Subject required!';
$_['error_message']        = 'E-Mail Message required!';