<?php
// Text
$_['text_subject']        = '%s - Affiliate Program';
$_['text_welcome']        = 'Thank you for joining the %s Affiliate Program!';
$_['text_login']          = 'Your account has now been created and you can log in by using your e-mail address and password by visiting our website or at the following URL:';
$_['text_approval']       = 'Your account must be approved before you can login. Once approved you can log in by using your e-mail address and password by visiting our website or at the following URL:';
$_['text_service']        = 'Upon logging in, you will be able to generate tracking codes, track commission payments and edit your account information.';
$_['text_thanks']         = 'Thanks,';
$_['text_new_affiliate']  = 'New Affiliate';
$_['text_signup']         = 'A new affiliate has signed up:';
$_['text_website']        = 'Web Site:';
$_['text_customer_group'] = 'Customer Group:';
$_['text_firstname']      = 'First Name:';
$_['text_lastname']       = 'Last Name:';
$_['text_company']        = 'Company:';
$_['text_email']          = 'E-Mail:';
$_['text_telephone']      = 'Telephone:';