<?php
$_['d_quickcheckout_payment_language'] = array(
    'heading_title' => 'text_payment',
    'description_payment' => '',
);
$_['d_quickcheckout_payment'] = array(
    'id' => 'payment',
    'icon' => '',
    'text' => 'heading_title',
    'description' => 'description_payment',
    'default_payment_popup' => 0,
    'payment_popups' => '',
    'style' => 'clear',
    'account' => array(
        'guest' => array(
            'display' => 1
        ),
        'register' => array(
            'display' => 1
        ),
        'logged' => array(
            'display' => 1
        )
    )
);