#sapphire {
    line-height: 25px;
    font-size: 24px;
    font-weight: 500;
    cursor: pointer;
    color: rgba(67, 235, 171, 0.6);

    a {
      color: rgba(67, 235, 171, 0.6);
    }

    .sph_unprotected {
      color: #fa5b6d;
    }
}

