<footer>
  <div id="footer">
    <div class="container">
        <div class="footer_block">
       <div class="row">
        <div class="col-xs-12 col-sm-12 col-md-3 column myaccount">
          <h4>{{ text_account }}</h4>
          <h5 class="collapsed" data-target="#dropdown-account" data-toggle="collapse">{{ text_account }} <span class="icon"></span></h5>
          <ul class="list-unstyled collapse" id="dropdown-account">
            <li><a href="{{ account }}">{{ text_account }}</a></li>
            <li><a href="{{ order }}">{{ text_order }}</a></li>
            <li><a href="{{ wishlist }}">{{ text_wishlist }}</a></li>
            <li><a href="{{ newsletter }}">{{ text_newsletter }}</a></li>
            <li><a href="{{ contact }}">{{ text_contact }}</a></li>
          </ul>
        </div>
        {% if informations %}
        <div class="col-xs-12 col-sm-12 col-md-3 column information">
          <h4>{{ text_information }}</h4>
          <h5 class="collapsed" data-target="#dropdown-information" data-toggle="collapse">{{ text_information }} <span class="icon"></span></h5>
          <ul class="list-unstyled collapse" id="dropdown-information">
            {% for information in informations %}
            <li><a href="{{ information.href }}">{{ information.title }}</a></li>
            {% endfor %}
            <li><a href="{{ return }}">{{ text_return }}</a></li>
          </ul>
        </div>
        {% endif %}
    	{{ footer_top }}
        <div class="col-xs-12 col-sm-12 col-md-3 column extra">
          <h4>{{ text_extra }}</h4>
          <h5 class="collapsed" data-target="#dropdown-extra" data-toggle="collapse">{{ text_extra }} <span class="icon"></span></h5>
          <ul class="list-unstyled collapse" id="dropdown-extra">
            <li><a href="{{ manufacturer }}">{{ text_manufacturer }}</a></li>
            <li><a href="{{ voucher }}">{{ text_voucher }}</a></li>
            <li><a href="{{ affiliate }}">{{ text_affiliate }}</a></li>
            <li><a href="{{ special }}">{{ text_special }}</a></li>
            <li><a href="{{ sitemap }}">{{ text_sitemap }}</a></li>
          </ul>
        </div>
         <div class="col-xs-12 col-sm-12 col-md-3 column contacts"> {{ footer_left }} </div>
         </div>
        <div class="footer-bottom-up">{{ footer_bottom }} </div>
      </div>
    </div>
    <div class="container">
      <div class="row">
       <div class="footer-bottom-down col-md-12 col-sm-12 col-xs-12">{{ footer_right }} </div>

        <div class="footer-bottom">
          <div class="copy-right col-md-12 col-sm-12 col-xs-12">
             <div id="powered">{{ powered }}</div>
          </div>
        </div>
      </div>
    </div>
  </div>
</footer>

        {% if module_live_search_status %}

			<script><!--
				var live_search = {
					selector: '#search input[name=\'search\']',
					text_no_matches: '{{ text_empty }}',
					height: '50px'
				}

				$(document).ready(function() {
					var html = '';
					html += '<div class="live-search">';
					html += '	<ul>';
					html += '	</ul>';
					html += '<div class="result-text"></div>';
					html += '</div>';

					//$(live_search.selector).parent().closest('div').after(html);
					$(live_search.selector).after(html);

					$(live_search.selector).autocomplete({
						'source': function(request, response) {
							var filter_name = $(live_search.selector).val();
							var cat_id = 0;
							var module_live_search_min_length = '{{ module_live_search_min_length|abs }}';
							if (filter_name.length < module_live_search_min_length) {
								$('.live-search').css('display','none');
							}
							else{
								var html = '';
								html += '<li style="text-align: center;height:10px;">';
								html +=	'<img class="loading" src="catalog/view/theme/oc01/image/loading.gif" />';
								html +=	'</li>';
								$('.live-search ul').html(html);
								$('.live-search').css('display','block');

								$.ajax({
									url: 'index.php?route=extension/module/live_search&filter_name=' +  encodeURIComponent(filter_name),
									dataType: 'json',
									success: function(result) {
										var products = result.products;
										$('.live-search ul li').remove();
										$('.result-text').html('');
										if (!$.isEmptyObject(products)) {
											var show_image = {{ module_live_search_show_image|abs }};
											var show_price = {{ module_live_search_show_price|abs }};
											var show_description = {{ module_live_search_show_description|abs }};
											$('.result-text').html('<a href="{{ module_live_search_href }}'+filter_name+'" class="view-all-results">{{ text_view_all_results|e }} ('+result.total+')</a>');

											$.each(products, function(index,product) {
												var html = '';

												html += '<li>';
												html += '<a href="' + product.url + '" title="' + product.name + '">';
												if(product.image && show_image){
													html += '	<div class="product-image"><img alt="' + product.name + '" src="' + product.image + '"></div>';
												}
												html += '	<div class="product-name">' + product.name ;
												if(show_description){
													html += '<p>' + product.extra_info + '</p>';
												}												
												html += '</div>';
												if(show_price){
													if (product.special) {
														html += '	<div class="product-price"><span class="special">' + product.price + '</span><span class="price">' + product.special + '</span></div>';
													} else {
														html += '	<div class="product-price"><span class="price">' + product.price + '</span></div>';
													}
												}												       	
												html += '<span style="clear:both"></span>';
												html += '</a>';
												html += '<div class="button-group"><button type="button" class="btn btn-primary btn-block ajaxcart" onclick="addtocart.add('+ product.product_id +')" >{{ button_cart }}</button><div>';       
												html += '</li>';
												$('.live-search ul').append(html);
											});
										} else {
											var html = '';
											html += '<li style="text-align: center;height:10px;">';
											html +=	live_search.text_no_matches;
											html +=	'</li>';

											$('.live-search ul').html(html);
										}
										$('.live-search').css('display','block');
										return false;
									}
								});
							}
						},
						'select': function(product) {
							$(live_search.selector).val(product.name);
						}
					});

					$(document).bind( "mouseup touchend", function(e){
					  var container = $('.live-search');
					  if (!container.is(e.target) && container.has(e.target).length === 0)
					  {
					    container.hide();
					  }
					});
				});
			//--></script>
		{% endif %}


<link rel="stylesheet" href="catalog/view/javascript/jquery/owl-carousel/owl.transitions.css" />
<script>
$('button[id^=\'button-upload\']').on('click', function() {
	var node = this;

	$('#form-upload').remove();

	$('body').prepend('<form enctype="multipart/form-data" id="form-upload" style="display: none;"><input type="file" name="file" /></form>');

	$('#form-upload input[name=\'file\']').trigger('click');

	if (typeof timer != 'undefined') {
    	clearInterval(timer);
	}

	timer = setInterval(function() {
		if ($('#form-upload input[name=\'file\']').val() != '') {
			clearInterval(timer);

			$.ajax({
				url: 'index.php?route=tool/upload',
				type: 'post',
				dataType: 'json',
				data: new FormData($('#form-upload')[0]),
				cache: false,
				contentType: false,
				processData: false,
				beforeSend: function() {
					$(node).button('loading');
				},
				complete: function() {
					$(node).button('reset');
				},
				success: function(json) {
					$('.text-danger').remove();

					if (json['error']) {
						$(node).parent().find('input').after('<div class="text-danger">' + json['error'] + '</div>');
					}

					if (json['success']) {
						alert(json['success']);

						$(node).parent().find('input').val(json['code']);
					}
				},
				error: function(xhr, ajaxOptions, thrownError) {
					alert(thrownError + "\r\n" + xhr.statusText + "\r\n" + xhr.responseText);
				}
			});
		}
	}, 500);
});
</script>
<script>
$(document).ready(function(){

$('.productpage-carousel').owlCarousel({
    items: 5,
    autoPlay: false,
    singleItem: false,
    navigation: true,
    pagination: false,
    itemsDesktop : [1199,4],
    itemsDesktopSmall : [991,3],
    itemsTablet : [479,2],
    itemsMobile : [319,1]
  });
});
function addtoCart(product_id){
          $.ajax({
            url: 'index.php?route=checkout/cart/add',
            type: 'post',
            data: $('#product-' + product_id + ' input[type=\'text\'],#product-' + product_id + ' input[type=\'number\'], #product-' + product_id + ' input[type=\'hidden\'], #product-' + product_id + ' input[type=\'radio\']:checked, #product-' + product_id + ' input[type=\'checkbox\']:checked, #product-' + product_id + ' select, #product-' + product_id + ' textarea'),
            dataType: 'json',
            beforeSend: function() {
              $('#add-cart-'+ product_id).button('loading');
            },
            complete: function() {
              $('#add-cart-'+ product_id).button('reset');
            },
            success: function(json) {
              $('.alert, .text-danger').remove();
              $('.form-group').removeClass('has-error');

              if (json['error']) {
                if (json['error']['option']) {
                  for (i in json['error']['option']) {
                    var element = $('#input-option' + i.replace('_', '-'));

                    if (element.parent().hasClass('input-group')) {
                      element.parent().after('<div class="text-danger">' + json['error']['option'][i] + '</div>');
                    } else {
                      element.after('<div class="text-danger">' + json['error']['option'][i] + '</div>');
                    }
                  }
                }

                if (json['error']['recurring']) {
                  $('select[name=\'recurring_id\']').after('<div class="text-danger">' + json['error']['recurring'] + '</div>');
                }

                // Highlight any found errors
                $('.text-danger').parent().addClass('has-error');
              }

              if (json['success']) {
                $('.breadcrumb').after('<div class="alertmsg"><div class="alert alert-success alert-dismissible">' + json['success'] + '<button type="button" class="close" data-dismiss="alert">&times;</button></div></div>');

               $('#cart > .btn').addClass('active');
        $('#cart > .btn').html('<span class="cart-text">My basket</span><span class="cart-total">Item ' + json['total'] + '</span><span class="cart-total-res">' + json['total'] +'</span>');
        $('.alertmsg').delay(1500).fadeOut();

        //$('html, body').animate({ scrollTop: 0 }, 'slow');

        $('#cart > ul').load('index.php?route=common/cart/info ul li');
        $("button.close").click(function() {
                        $(".alertmsg").remove()
                    })
              }
            },
            error: function(xhr, ajaxOptions, thrownError) {
              alert(thrownError + "\r\n" + xhr.statusText + "\r\n" + xhr.responseText);
            }
          });         
        }
</script>


<!-- Go to www.addthis.com/dashboard to customize your tools -->
<script src="//s7.addthis.com/js/300/addthis_widget.js#pubid=ra-5b45d725b77d622c"></script>

<!--
OpenCart is open source software and you are free to remove the powered by OpenCart if you want, but its generally accepted practise to make a small donation.
Please donate via PayPal to donate@opencart.com
//-->
</body></html>
