<?php
// Heading
$_['heading_title']    = 'PayPal (Powered by Braintree) Button';

// Text
$_['text_extension']   = 'Extensions';
$_['text_success']     = 'Success: You have modified PayPal (Powered by Braintree) Button module!';
$_['text_edit']        = 'Edit PayPal (Powered by Braintree) Button Module';
$_['text_info']        = 'The button will <u>not</u> appear under certain conditions:';
$_['text_info_li1']    = 'The cart is empty and no vouchers have been applied';
$_['text_info_li2']    = 'The cart has downloads or recurring payments and the user is not logged in';
$_['text_info_li3']    = 'Out of stock item checkout is disabled and the cart contains an out of stock item';
$_['text_layouts']     = 'After enabling the module, use the layout manager to add the button to areas on the store.';
$_['text_layout_link'] = 'Click here to access layouts page';

// Entry
$_['entry_status']     = 'Status';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify PayPal (Powered by Braintree) Button module!';