<?php
// Text
$_['text_success']     = 'Success: Your reward points discount has been applied!';

// Error
$_['error_permission'] = 'Warning: You do not have permission to access the API!';
$_['error_reward']     = 'Warning: Please enter the amount of reward points to use!';
$_['error_points']     = 'Warning: You don\'t have %s reward points!';
$_['error_maximum']    = 'Warning: The maximum number of points that can be applied is %s!';