<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  37250 => 'EMT',
  372519 => 'EMT',
  37252 => 'EMT',
  372530 => 'EMT',
  372533 => 'EMT',
  372534 => 'EMT',
  372536 => 'EMT',
  372537 => 'EMT',
  372538 => 'EMT',
  372539 => 'EMT',
  372545 => 'Elisa',
  37255 => 'Tele 2',
  37256 => 'Elisa',
  372577 => 'Elisa',
  37258 => 'Tele 2',
  372590 => 'EMT',
);
