<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  822 => 'Сеул',
  8232 => 'Инчон',
  8251 => 'Бусан',
  8252 => 'Улсан',
  8253 => 'Тегу',
  8262 => 'Квангџу',
  8264 => 'Чеџу',
);
