<?php
// Heading
$_['heading_title']     = 'Online Report';

// Text
$_['text_extension']    = 'Extensions';
$_['text_success']      = 'Success: You have modified customers online report!';
$_['text_list']         = 'Online List';
$_['text_filter']       = 'Filter';
$_['text_guest']        = 'Guest';

// Column
$_['column_ip']         = 'IP';
$_['column_customer']   = 'Customer';
$_['column_url']        = 'Last Page Visited';
$_['column_referer']    = 'Referer';
$_['column_date_added'] = 'Last Click';
$_['column_action']     = 'Action';

// Entry
$_['entry_ip']          = 'IP';
$_['entry_customer']    = 'Customer';
$_['entry_status']      = 'Status';
$_['entry_sort_order']  = 'Sort Order';

// Error
$_['error_permission']  = 'Warning: You do not have permission to modify customers online report!';