<?php
// Text
$_['text_success']     = 'Success: You have modified extensions!';
$_['text_unzip']       = 'Extracting files!';
$_['text_move']        = 'Copying files!';
$_['text_xml']         = 'Applying modifications!';
$_['text_remove']      = 'Removing temporary files!';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify extensions!';
$_['error_install']    = 'Extension installation taking place please wait a few seconds before trying to install!';
$_['error_unzip']      = 'Zip file could not be opened!';
$_['error_file']       = 'Install file could not be found!';
$_['error_directory']  = 'Install directory could not be found!';
$_['error_code']       = 'Unique code is required for modification XML!';
$_['error_xml']        = 'Modification %s is already being used!';
$_['error_exists']     = 'The file %s already exists!';
$_['error_allowed']    = 'The directory %s is not allowed to be written to!';