<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;

/* oc01/template/extension/module/featuredcategory.twig */
class __TwigTemplate_d52bc4e785dda6cab4b3924e8dad64f07d7cf16d61cc7bc97eac52b09cc80b5e extends \Twig\Template
{
    private $source;
    private $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = [])
    {
        $macros = $this->macros;
        // line 1
        echo "<div class=\"category-banner-block wow fadeInUp\" data-wow-duration=\"0.5s\" data-wow-delay=\"0.5s\">
<h3>";
        // line 2
        echo ($context["box_title"] ?? null);
        echo "</h3>
<div class=\"row\">
  ";
        // line 4
        $context['_parent'] = $context;
        $context['_seq'] = twig_ensure_traversable(($context["categories"] ?? null));
        foreach ($context['_seq'] as $context["_key"] => $context["category"]) {
            // line 5
            echo "    <div class=\"product-layout col-lg-2 col-md-2 col-sm-4 col-xs-4\">
      <div class=\"product-thumb transition\">
         <div class=\"caption categoryname\">
          <h4><a href=\"";
            // line 8
            echo twig_get_attribute($this->env, $this->source, $context["category"], "href", [], "any", false, false, false, 8);
            echo "\">";
            echo twig_get_attribute($this->env, $this->source, $context["category"], "name", [], "any", false, false, false, 8);
            echo "</a></h4>
        </div>
        <div class=\"image\"><a href=\"";
            // line 10
            echo twig_get_attribute($this->env, $this->source, $context["category"], "href", [], "any", false, false, false, 10);
            echo "\"><img src=\"";
            echo twig_get_attribute($this->env, $this->source, $context["category"], "thumb2", [], "any", false, false, false, 10);
            echo "\" alt=\"";
            echo twig_get_attribute($this->env, $this->source, $context["category"], "name", [], "any", false, false, false, 10);
            echo "\" title=\"";
            echo twig_get_attribute($this->env, $this->source, $context["category"], "name", [], "any", false, false, false, 10);
            echo "\" class=\"img-responsive\"/></a></div>       
      </div>
    </div>
  ";
        }
        $_parent = $context['_parent'];
        unset($context['_seq'], $context['_iterated'], $context['_key'], $context['category'], $context['_parent'], $context['loop']);
        $context = array_intersect_key($context, $_parent) + $_parent;
        // line 14
        echo "</div>
</div>
";
    }

    public function getTemplateName()
    {
        return "oc01/template/extension/module/featuredcategory.twig";
    }

    public function isTraitable()
    {
        return false;
    }

    public function getDebugInfo()
    {
        return array (  77 => 14,  61 => 10,  54 => 8,  49 => 5,  45 => 4,  40 => 2,  37 => 1,);
    }

    public function getSourceContext()
    {
        return new Source("", "oc01/template/extension/module/featuredcategory.twig", "");
    }
}
