<?php

$_['d_social_login_yahoo'] = array(
    "Yahoo" => array(
        "enabled" => true,
        "name" => "Yahoo",
        "keys"    => array("id" => "", "secret" => ""),
        "id" => 'yahoo',
        "sort_order" => 4,
        "icon" => 'yahoo.svg',
        "background_color" => '#500095',
        "background_color_active" => '#3d026f',
        "background_color_hover" => '#3d026f',
        "documentation_url" => "https://doc.99logins.com/yahoo",
    ),

);