<?php
// Heading
$_['heading_title']      = 'Australia Post';

// Text
$_['text_extension']     = 'Extensions';
$_['text_success']       = 'Success: You have modified Australia Post shipping!';
$_['text_edit']          = 'Edit Australia Post Shipping';

// Entry
$_['entry_api']          = 'API Key';
$_['entry_postcode']     = 'Post Code';
$_['entry_weight_class'] = 'Weight Class';
$_['entry_tax_class']    = 'Tax Class';
$_['entry_geo_zone']     = 'Geo Zone';
$_['entry_status']       = 'Status';
$_['entry_sort_order']   = 'Sort Order';

// Help
$_['help_weight_class']  = 'Set to kilograms.';

// Error
$_['error_permission']   = 'Warning: You do not have permission to modify Australia Post shipping!';
$_['error_postcode']     = 'Post Code must be 4 digits!';