<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  6661 => 'AIS',
  6662 => 'AIS',
  6663 => 'AIS',
  6664 => 'Penguin SIM',
  6665 => 'AIS',
  6666 => 'DTAC',
  66800 => 'AIS',
  66801 => 'AIS',
  66802 => 'AIS',
  66803 => 'True Move',
  66804 => 'DTAC',
  66805 => 'DTAC',
  66806 => 'AIS',
  6681 => 'AIS',
  66813 => 'DTAC',
  66814 => 'DTAC',
  66815 => 'DTAC',
  66816 => 'DTAC',
  6682 => 'AIS',
  6683 => 'True Move',
  6684 => 'AIS',
  6685 => 'DTAC',
  66854 => 'AIS',
  6686 => 'True Move',
  6687 => 'AIS',
  6688 => 'True Move',
  6689 => 'DTAC',
  6690 => 'DTAC',
  66901 => 'AIS',
  66909 => 'True Move/AIS',
  6691 => 'True Move',
  6692 => 'AIS',
  6693 => 'True Move/AIS',
  66931 => 'AIS',
  66935 => 'AIS',
  66936 => 'AIS',
  6694 => 'True Move/DTAC',
  66940 => 'True Move',
  66941 => 'True Move',
  669422 => 'True Move',
  669423 => 'True Move',
  6695 => 'True Move/DTAC/AIS',
  66956 => 'True Move',
  66958 => 'True Move',
  6696 => 'True Move',
  6697 => 'True Move/AIS',
  6698 => 'AIS',
  6699 => 'True Move/AIS',
  66995 => 'True Move',
);
