<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  472 => 'Oslo',
  4731 => 'Buskerud',
  4732 => 'Buskerud',
  4733 => 'Vestfold',
  4735 => 'Telemark',
  4737 => 'Aust-Agder',
  4738 => 'Vest-Agder',
  4751 => 'Rogaland',
  4752 => 'Rogaland',
  4753 => 'Hordaland',
  4755 => 'Hordaland',
  4756 => 'Hordaland',
  4757 => 'Sogn og Fjordane',
  4761 => 'Oppland',
  4762 => 'Hedmark',
  4763 => 'Akershus',
  4764 => 'Akershus',
  4766 => 'Akershus',
  4767 => 'Akershus',
  4769 => 'Østfold',
  4770 => 'Møre og Romsdal',
  4771 => 'Møre og Romsdal',
  4772 => 'Sør-Trøndelag',
  4773 => 'Sør-Trøndelag',
  4774 => 'Nord-Trøndelag',
  4775 => 'Nordland',
  4776 => 'Nordland',
  4777 => 'Troms',
  4778 => 'Finnmark',
);
