<?php
// Heading
$_['heading_title']			= 'Please Choose Your Payment Plan';

// Text
$_['text_title']			= 'PUT IT ON LAY-BUY powered by PayPal';
$_['text_plan_preview']		= 'Plan Preview';
$_['text_payment']			= 'Payment';
$_['text_due_date']			= 'Due Date';
$_['text_amount']			= 'Amount';
$_['text_downpayment']		= 'Down Payment';
$_['text_today']			= 'Today';
$_['text_delivery_msg']		= 'Your goods/services will be delivered once your final payment has been received.';
$_['text_fee_msg']			= 'A 0.9% admin fee is payable to Lay-Buys.com.';
$_['text_month']			= 'Month';
$_['text_months']			= 'Months';
$_['text_status_1']			= 'Pending';
$_['text_status_5']			= 'Completed';
$_['text_status_7']			= 'Canceled';
$_['text_status_50']		= 'Revise Requested';
$_['text_status_51']		= 'Revised';
$_['text_comment']			= 'Updated by Lay-Buy';

// Entry
$_['entry_initial']			= 'Initial Payment';
$_['entry_months']			= 'Months';

// Button
$_['button_confirm']		= 'Confirm Order';