<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  68025 => 'Sonsorol State and Hatohobei State',
  68027 => 'Angaur State',
  6803 => 'Peleliu State',
  6804 => 'Koror State',
  68053 => 'Ngatpang State',
  68054 => 'Aimeliik State',
  68058 => 'Airai State',
  680622 => 'Ngchesar State',
  68065 => 'Melekeok State',
  68067 => 'Ngiwal State',
  68073 => 'Ngaremlengui State',
  68074 => 'Ngardmau State',
  68082 => 'Ngaraard State',
  68085 => 'Ngarchelong State',
  68087 => 'Kayangel State',
);
