<?php
$_['text_title'] = 'Credit / Debit card';
$_['text_card_details'] = 'Card details';
$_['text_wait'] = 'Processing your payment';
$_['text_auth_code'] = 'Authorisation code: %s';
$_['text_postcode_check'] = 'Postcode check: %s';
$_['text_security_code_check'] = 'CVV2 check: %s';
$_['text_address_check'] = 'Address check: %s';
$_['text_3d_secure_check'] = '3D Secure: %s';
$_['text_not_given'] = 'Not given';
$_['text_not_checked'] = 'Not checked';
$_['text_match'] = 'Matched';
$_['text_not_match'] = 'Not matched';
$_['text_authenticated'] = 'Authenticated';
$_['text_not_authenticated'] = 'Not authenticated';
$_['text_authentication_not_completed'] = 'Attempted but not completed';
$_['text_unable_to_perform'] = 'Unable to perform';
$_['text_transaction_declined'] = 'Your bank has declined the transaction. Please use a different payment method.';
$_['text_transaction_failed'] = 'Could not process the payment. Please check the details you provided.';
$_['text_connection_error'] = 'Please try again later or use a different payment method.';

$_['entry_type'] = 'Card type';
$_['entry_number'] = 'Card number';
$_['entry_expire_date'] = 'Expiry date';
$_['entry_cvv2'] = 'Security Code (CVV2)';

$_['button_confirm'] = 'Confirm';

$_['error_failure'] = 'Could not complete transaction. Please try again later or use a different payment method.';