<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  97250 => 'Pelephone',
  97251 => 'Xphone',
  97252 => 'Cellcom',
  97253 => 'Hot Mobile',
  97254 => 'Orange',
  972550 => 'Beezz',
  9725522 => 'Home Cellular',
  9725523 => 'Home Cellular',
  9725524 => 'Telzar',
  9725525 => 'Telzar',
  972553 => 'Free Telecom',
  9725550 => 'Annatel',
  972556 => 'Rami Levy',
  9725570 => 'Cellact',
  9725571 => 'Cellact',
  9725572 => 'Cellact',
  972558 => 'Alon',
  972559 => 'Telzar',
  97256 => 'Wataniya',
  97258 => 'Golan Telecom',
  97259 => 'Jawwal',
);
