<h1>{{ heading_title }}</h1>
<p><div class="alert alert-danger">{{ error }}</div></p>
<div class="buttons clearfix">
  <div class="pull-right"><a href="{{ continue }}" class="btn btn-primary">{{ button_continue }}</a></div>
</div>