<?php
// Heading
$_['heading_title']         = 'Statistics';

// Text
$_['text_success']          = 'Success: You have modified statistics!';
$_['text_list']             = 'Statistics List';
$_['text_order_sale']       = 'Order Sales';
$_['text_order_processing'] = 'Orders Processing';
$_['text_order_complete']   = 'Orders Complete';
$_['text_order_other']      = 'Orders Other';
$_['text_returns']          = 'Returns';
$_['text_customer']         = 'Customers Waiting for Approval';
$_['text_affiliate']        = 'Affiliates Waiting for Approval';
$_['text_product']          = 'Out of stock products';
$_['text_review']           = 'Pending Reviews';

// Column
$_['column_name']           = 'Statistics Name';
$_['column_value']	        = 'Value';
$_['column_action']         = 'Action';

// Error
$_['error_permission']      = 'Warning: You do not have permission to modify statistics!';