<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  9986 => 'MTS',
  99870 => 'MTS',
  99872 => 'MTS',
  99873 => 'MTS',
  99874 => 'MTS',
  99875 => 'MTS',
  99876 => 'MTS',
  99879 => 'MTS',
  99890 => 'Beeline',
  99891 => 'Beeline',
  99892 => 'MTS',
  99893 => 'Ucell',
  99894 => 'Ucell',
  99897 => 'MTS',
);
