<?php
// Heading
$_['heading_title']					 = 'PayPal Payments Standard';

// Text
$_['text_extension']				 = 'Extensions';
$_['text_success']					 = 'Success: You have modified PayPal account details!';
$_['text_edit']                      = 'Edit PayPal Payments Standard';
$_['text_pp_standard']				 = '<a target="_BLANK" href="https://www.paypal.com/uk/mrb/pal=V4T754QB63XXL"><img src="view/image/payment/paypal.png" alt="PayPal Website Payment Pro" title="PayPal Website Payment Pro iFrame" style="border: 1px solid #EEEEEE;" /></a>';
$_['text_authorization']			 = 'Authorization';
$_['text_sale']						 = 'Sale'; 

// Entry
$_['entry_email']					 = 'E-Mail';
$_['entry_test']					 = 'Sandbox Mode';
$_['entry_transaction']				 = 'Transaction Method';
$_['entry_debug']					 = 'Debug Mode';
$_['entry_total']					 = 'Total';
$_['entry_canceled_reversal_status'] = 'Canceled Reversal Status';
$_['entry_completed_status']		 = 'Completed Status';
$_['entry_denied_status']			 = 'Denied Status';
$_['entry_expired_status']			 = 'Expired Status';
$_['entry_failed_status']			 = 'Failed Status';
$_['entry_pending_status']			 = 'Pending Status';
$_['entry_processed_status']		 = 'Processed Status';
$_['entry_refunded_status']			 = 'Refunded Status';
$_['entry_reversed_status']			 = 'Reversed Status';
$_['entry_voided_status']			 = 'Voided Status';
$_['entry_geo_zone']				 = 'Geo Zone';
$_['entry_status']					 = 'Status';
$_['entry_sort_order']				 = 'Sort Order';

// Tab
$_['tab_general']					 = 'General';
$_['tab_order_status']       		 = 'Order Status';

// Help
$_['help_test']						 = 'Use the live or testing (sandbox) gateway server to process transactions?';
$_['help_debug']			    	 = 'Logs additional information to the system log';
$_['help_total']					 = 'The checkout total the order must reach before this payment method becomes active';

// Error
$_['error_permission']				 = 'Warning: You do not have permission to modify payment PayPal!';
$_['error_email']					 = 'E-Mail required!';