<?php
// Text
$_['text_title']                = 'Square';
$_['text_canceled']             = 'Success: You have succesfully canceled this payment! We sent you a confirmation e-mail.';
$_['text_confirm_cancel']       = 'Are you sure you want to cancel the recurring payments?';
$_['text_order_history_cancel'] = 'You canceled your recurring profile. Your card will no longer be charged.';

// Button
$_['button_cancel']             = 'Cancel Recurring Payment';

// Error
$_['error_not_cancelled']       = 'Error: %s';
$_['error_not_found']           = 'Could not cancel recurring profile';