<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  822 => 'Séoul',
  8241 => 'Chungcheong du Sud',
  8243 => 'Chungcheong du Nord',
  8244 => 'Sejong (ville)',
  8254 => 'Gyeongsang du Nord',
  8255 => 'Gyeongsang du Sud',
  8261 => 'Jeonranamdo',
  8263 => 'Jeonrabugdo',
  8264 => 'Jejudo',
);
