<?php

$_['d_social_login_google'] = array(
    "Google" => array(
        "enabled" => true,
        "name" => "Google+",
        "keys" => array("id" => "", "secret" => ""),
        "scope" => 'https://www.googleapis.com/auth/userinfo.email',
        "id" => 'google',
        "sort_order" => 1,
        "icon" => 'google.svg',
        "background_color" => '#dd4b39',
        "background_color_active" => '#be3e2e',
        "background_color_hover" => '#be3e2e',
        "documentation_url" => "https://doc.99logins.com/google",
    )
);
