<?php
// Heading
$_['heading_title']    = 'Image Manager';

// Text
$_['text_uploaded']    = 'Success: Your file has been uploaded!';
$_['text_directory']   = 'Success: Directory created!';
$_['text_delete']      = 'Success: Your file or directory has been deleted!';

// Entry
$_['entry_search']     = 'Search..';
$_['entry_folder']     = 'Folder Name';

// Error
$_['error_permission'] = 'Warning: Permission Denied!';
$_['error_filename']   = 'Warning: Filename must be between 3 and 255!';
$_['error_folder']     = 'Warning: Folder name must be between 3 and 255!';
$_['error_exists']     = 'Warning: A file or directory with the same name already exists!';
$_['error_directory']  = 'Warning: Directory does not exist!';
$_['error_filesize']   = 'Warning: Incorrect file size!';
$_['error_filetype']   = 'Warning: Incorrect file type!';
$_['error_upload']     = 'Warning: File could not be uploaded for an unknown reason!';
$_['error_delete']     = 'Warning: You can not delete this directory!';