<?php
// Heading
$_['heading_title']    = 'User Groups';

// Text
$_['text_success']     = 'Success: You have modified user groups!';
$_['text_list']        = 'User Group';
$_['text_add']         = 'Add User Group';
$_['text_edit']        = 'Edit User Group';

// Column
$_['column_name']      = 'User Group Name';
$_['column_action']    = 'Action';

// Entry
$_['entry_name']       = 'User Group Name';
$_['entry_access']     = 'Access Permission';
$_['entry_modify']     = 'Modify Permission';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify user groups!';
$_['error_name']       = 'User Group Name must be between 3 and 64 characters!';
$_['error_user']       = 'Warning: This user group cannot be deleted as it is currently assigned to %s users!';