<?php
// Heading
$_['heading_title']          = 'Default Menu';

// Text
$_['text_extension']         = 'Extensions';
$_['text_success']           = 'Success: You have modified Google Base feed!';
$_['text_edit']              = 'Edit Google Base';
$_['text_import']            = 'To download the latest Google category list by <a href="https://support.google.com/merchants/answer/160081?hl=en" target="_blank" class="alert-link">clicking here</a> and choose taxonomy with numeric IDs in Plain Text (.txt) file. Upload via the green import button.';

// Column
$_['column_google_category'] = 'Google Category';
$_['column_category']        = 'Category';
$_['column_action']          = 'Action';

// Entry
$_['entry_google_category']  = 'Google Category';
$_['entry_category']         = 'Category';
$_['entry_data_feed']        = 'Data Feed Url';
$_['entry_status']           = 'Status';

// Error
$_['error_permission']       = 'Warning: You do not have permission to modify Google Base feed!';
$_['error_upload']           = 'File could not be uploaded!';
$_['error_filetype']         = 'Invalid file type!';