<?php
// Heading
$_['heading_title']         = 'Sagepay Direct Cards';

// Text
$_['text_empty']		    = 'You have no saved cards';
$_['text_account']          = 'Account';
$_['text_card']			    = 'SagePay Direct Card Management';
$_['text_fail_card']	    = 'There was an issue removing your SagePay card, Please contact the shop administrator for help.';
$_['text_success_card']     = 'SagePay card successfully removed';
$_['text_success_add_card'] = 'SagePay card successfully added';

// Column
$_['column_type']		    = 'Card Type';
$_['column_digits']	        = 'Last Digits';
$_['column_expiry']		    = 'Expiry';

// Entry
$_['entry_cc_owner']        = 'Card Owner';
$_['entry_cc_type']         = 'Card Type';
$_['entry_cc_number']       = 'Card Number';
$_['entry_cc_expire_date']  = 'Card Expiry Date';
$_['entry_cc_cvv2']         = 'Card Security Code (CVV2)';
$_['entry_cc_choice']       = 'Choose an Existing Card';

// Button
$_['button_add_card']       = 'Add Card';
$_['button_new_card']       = 'Add New Card';



