<script type="text/javascript">
    console.log("[GTAG] Submit cart view: " + {{ ecomm_prodid }});

    gtag('event', 'page_view', {
        'send_to': '{{ send_to }}',
        'name': 'cart',
        'ecomm_prodid': {{ ecomm_prodid }},
        'ecomm_pagetype': 'cart',
        'ecomm_totalvalue': {{ ecomm_totalvalue }},
        'value': {{ ecomm_totalvalue }},
        'items': {{ items }}
    });
</script>