<script src="//www.google.com/recaptcha/api.js" type="text/javascript"></script>
<fieldset>
  <legend>{{ text_captcha }}</legend>
  <div class="form-group required">{% if route|slice(0, 9) == 'checkout/' %}
    <label class="control-label" for="input-payment-captcha">{{ entry_captcha }}</label>
    <div id="input-payment-captcha" class="g-recaptcha" data-sitekey="{{ site_key }}"></div>
    {% if error_captcha %}
    <div class="text-danger">{{ error_captcha }}</div>
    {% endif %}
    {% else %}
    <label class="col-sm-2 control-label">{{ entry_captcha }}</label>
    <div class="col-sm-10">
      <div class="g-recaptcha" data-sitekey="{{ site_key }}"></div>
      {% if error_captcha %}
      <div class="text-danger">{{ error_captcha }}</div>
      {% endif %}</div>
    {% endif %}</div>
</fieldset>
