<?php
// Heading
$_['heading_title']      = 'Address Book';

// Text
$_['text_account']       = 'Account';
$_['text_address_book']  = 'Address Book Entries';
$_['text_address_add']   = 'Add Address';
$_['text_address_edit']  = 'Edit Address';
$_['text_add']           = 'Your address has been successfully added';
$_['text_edit']          = 'Your address has been successfully updated';
$_['text_delete']        = 'Your address has been successfully deleted';
$_['text_empty']         = 'You have no addresses in your account.';

// Entry
$_['entry_firstname']    = 'First Name';
$_['entry_lastname']     = 'Last Name';
$_['entry_company']      = 'Company';
$_['entry_address_1']    = 'Address 1';
$_['entry_address_2']    = 'Address 2';
$_['entry_postcode']     = 'Post Code';
$_['entry_city']         = 'City';
$_['entry_country']      = 'Country';
$_['entry_zone']         = 'Region / State';
$_['entry_default']      = 'Default Address';

// Error
$_['error_delete']       = 'Warning: You must have at least one address!';
$_['error_default']      = 'Warning: You can not delete your default address!';
$_['error_firstname']    = 'First Name must be between 1 and 32 characters!';
$_['error_lastname']     = 'Last Name must be between 1 and 32 characters!';
$_['error_address_1']    = 'Address must be between 3 and 128 characters!';
$_['error_postcode']     = 'Postcode must be between 2 and 10 characters!';
$_['error_city']         = 'City must be between 2 and 128 characters!';
$_['error_country']      = 'Please select a country!';
$_['error_zone']         = 'Please select a region / state!';
$_['error_custom_field'] = '%s required!';