<?php
// Heading
$_['heading_title'] = 'Account Logout';

// Text
$_['text_message']  = '<p>You have been logged off your account. It is now safe to leave the computer.</p><p>Your shopping cart has been saved, the items inside it will be restored whenever you log back into your account.</p>';
$_['text_account']  = 'Account';
$_['text_logout']   = 'Logout';