<?php
// Heading
$_['heading_title']     = 'Theme Editor';

// Text
$_['text_success']      = 'Success: You have modified themes!';
$_['text_edit']         = 'Edit Theme';
$_['text_store']        = 'Choose your store';
$_['text_template']     = 'Choose a template';
$_['text_default']      = 'Default';
$_['text_history']      = 'Theme History';
$_['text_twig']         = 'The theme editor uses the template language Twig. You can read about <a href="http://twig.sensiolabs.org/documentation" target="_blank" class="alert-link">Twig syntax here</a>.';

// Column
$_['column_store']      = 'Store';
$_['column_route']      = 'Route';
$_['column_theme']      = 'Theme';
$_['column_date_added'] = 'Date Added';
$_['column_action']     = 'Action';

// Error
$_['error_permission']  = 'Warning: You do not have permission to modify the theme editor!';
$_['error_twig']        = 'Warning: You can only save .twig files!';