<h3>{{ text_payment_info }}</h3>
<div class="alert alert-success" style="display: none;"><i class="fa fa-check-circle"></i></div>
<div id="table-action"></div>

<script type="text/javascript"><!--
function getTransaction() {
	$.ajax({
		url: 'index.php?route=extension/payment/pp_braintree/getTransaction&user_token={{ user_token }}',
		dataType: 'html',
		data: {
			order_id: '{{ order_id }}'
		},
		beforeSend: function() {
			$('#button-filter').button('loading');

			$('#table-action').html('<i class="braintree-loading fa fa-spinner fa-spin fa-5x" style="text-align: center; margin: 0 auto; width: 100%; font-size: 5em;"></i>');
		},
		complete: function() {
			$('#button-filter').button('reset');
		},
		success: function(html) {
			$('#table-action').html(html);
		}
	});
}

getTransaction();
//--></script>
