<?php
// Heading
$_['heading_title']     = 'Filters';

// Text
$_['text_success']      = 'Success: You have modified filters!';
$_['text_list']         = 'Filter List';
$_['text_add']          = 'Add Filter';
$_['text_edit']         = 'Edit Filter';
$_['text_group']        = 'Filter Group';
$_['text_value']        = 'Filter Values';

// Column
$_['column_group']      = 'Filter Group';
$_['column_sort_order'] = 'Sort Order';
$_['column_action']     = 'Action';

// Entry
$_['entry_group']       = 'Filter Group Name';
$_['entry_name']        = 'Filter Name';
$_['entry_sort_order']  = 'Sort Order';

// Error
$_['error_permission']  = 'Warning: You do not have permission to modify filters!';
$_['error_group']       = 'Filter Group Name must be between 1 and 64 characters!';
$_['error_name']        = 'Filter Name must be between 1 and 64 characters!';