<?php
// Heading
$_['heading_title']                 = 'Affiliate Program';

// Text
$_['text_account']                  = 'Account';
$_['text_login']                    = 'Login';
$_['text_description']              = '<p>%s affiliate program is free and enables members to earn revenue by placing a link or links on their web site which advertises %s or specific products on it. Any sales made to customers who have clicked on those links will earn the affiliate commission. The standard commission rate is currently %s.</p><p>For more information, visit our FAQ page or see our Affiliate terms &amp; conditions.</p>';
$_['text_new_affiliate']            = 'New Affiliate';
$_['text_register_account']         = '<p>I am not currently an affiliate.</p><p>Click Continue below to create a new affiliate account. Please note that this is not connected in any way to your customer account.</p>';
$_['text_returning_affiliate']      = 'Affiliate Login';
$_['text_i_am_returning_affiliate'] = 'I am a returning affiliate.';
$_['text_forgotten']                = 'Forgotten Password';

// Entry
$_['entry_email']                   = 'Affiliate E-Mail';
$_['entry_password']                = 'Password';

// Error
$_['error_login']                   = 'Warning: No match for E-Mail Address and/or Password.';
$_['error_attempts']                = 'Warning: Your account has exceeded allowed number of login attempts. Please try again in 1 hour.';
$_['error_approved']                = 'Warning: Your account requires approval before you can login.';