<?php
// Heading
$_['heading_title']           = 'Countries';

// Text
$_['text_success']            = 'Success: You have modified countries!';
$_['text_list']               = 'Country List';
$_['text_add']                = 'Add Country';
$_['text_edit']               = 'Edit Country';

// Column
$_['column_name']             = 'Country Name';
$_['column_iso_code_2']       = 'ISO Code (2)';
$_['column_iso_code_3']       = 'ISO Code (3)';
$_['column_action']           = 'Action';

// Entry
$_['entry_name']              = 'Country Name';
$_['entry_iso_code_2']        = 'ISO Code (2)';
$_['entry_iso_code_3']        = 'ISO Code (3)';
$_['entry_address_format']    = 'Address Format';
$_['entry_postcode_required'] = 'Postcode Required';
$_['entry_status']            = 'Status';

// Help
$_['help_address_format']     = 'First Name = {firstname}<br />Last Name = {lastname}<br />Company = {company}<br />Address 1 = {address_1}<br />Address 2 = {address_2}<br />City = {city}<br />Postcode = {postcode}<br />Zone = {zone}<br />Zone Code = {zone_code}<br />Country = {country}';

// Error
$_['error_permission']        = 'Warning: You do not have permission to modify countries!';
$_['error_name']              = 'Country Name must be between 1 and 128 characters!';
$_['error_default']           = 'Warning: This country cannot be deleted as it is currently assigned as the default store country!';
$_['error_store']             = 'Warning: This country cannot be deleted as it is currently assigned to %s stores!';
$_['error_address']           = 'Warning: This country cannot be deleted as it is currently assigned to %s address book entries!';
$_['error_affiliate']         = 'Warning: This country cannot be deleted as it is currently assigned to %s affiliates!';
$_['error_zone']              = 'Warning: This country cannot be deleted as it is currently assigned to %s zones!';
$_['error_zone_to_geo_zone']  = 'Warning: This country cannot be deleted as it is currently assigned to %s zones to geo zones!';