<?php
// Heading
$_['heading_title']          = 'Testimonials';

// Text
$_['text_success']           = 'Success: You have modified Testimonials!';
$_['text_list']              = 'Testimonials List';
$_['text_add']               = 'Add Testimonials';
$_['text_edit']              = 'Edit Testimonials';
$_['text_default']           = 'Default';
$_['text_keyword']           = 'Do not use spaces, instead replace spaces with - and make sure the SEO URL is globally unique.';

// Column
$_['column_title']           = 'Testimonials Title';
$_['column_sort_order']      = 'Sort Order';
$_['column_action']          = 'Action';

//Tab
$_['tab_images']             = 'Testimonials';
$_['tab_size']               = 'Images Size';
$_['entry_designation']             = 'Designation';

// Entry
$_['entry_title']            = 'Author';
$_['entry_image']            = 'Image';
$_['entry_description']      = 'Description';
$_['entry_meta_title']       = 'Meta Tag Title';
$_['entry_meta_keyword']     = 'Meta Tag Keywords';
$_['entry_meta_description'] = 'Meta Tag Description';
$_['entry_store']            = 'Stores';
$_['entry_keyword']          = 'Keyword';
$_['entry_bottom']           = 'Bottom';
$_['entry_status']           = 'Status';
$_['entry_sort_order']       = 'Sort Order';
$_['entry_layout']           = 'Layout Override';

$_['entry_width']            = 'Width';
$_['entry_height']           = 'Height';

$_['entry_img_size']         = 'Gallery Image Size';
$_['entry_img_pop_size']     = 'Gallery Image Pop Up Size';
$_['column_img_title']       = 'Title';
$_['column_img_link']        = 'Link';
$_['column_img_name']        = 'Image';
$_['column_sort_order']      = 'Sort Order';

//
$_['entry_album_imagesize']      = 'Album Image Size';
$_['entry_position']      = 'Position';
$_['text_right']      = 'Right';
$_['text_left']      = 'Left';
$_['text_center']      = 'Center';
$_['entry_gallery_imagesize']      = 'Gallery Image Size';
$_['entry_popup_type']      = 'Popup Type';
$_['text_magnific_popup']      = 'Magnific';
$_['text_bootstrap_popup']      = 'Bootstrap';
$_['text_lightbox']      = 'Lightbox';
$_['entry_popup_image_resize']      = 'Popup Image Resize';
$_['text_resize']      = 'Resize';
$_['text_donot_resize']      = 'Do not resize';
$_['entry_gallery_imagesize_popsize']      = 'Popup Image Size';
$_['entry_imageperrow']      = 'Image Per Row';
$_['entry_album_imageper_page']      = 'Image per page';
$_['column_sort_order']      = 'Sort Order';
$_['column_sort_order']      = 'Sort Order';
$_['column_sort_order']      = 'Sort Order';
$_['column_sort_order']      = 'Sort Order';




// Help
$_['help_bottom']            = 'Display in the bottom footer.';

// Error
$_['error_warning']          = 'Warning: Please check the form carefully for errors!';
$_['error_permission']       = 'Warning: You do not have permission to modify gallery album!';
$_['error_title']            = 'Gallery Album Title must be between 1 and 64 characters!';
$_['error_description']      = 'Description must be more than 3 characters!';
$_['error_meta_title']       = 'Meta Title must be greater than 1 and less than 255 characters!';
$_['error_keyword']          = 'SEO URL already in use!';
$_['error_unique']           = 'SEO URL must be unique!';
$_['error_account']          = 'Warning: This gallery album page cannot be deleted as it is currently assigned as the store account terms!';
$_['error_checkout']         = 'Warning: This gallery album page cannot be deleted as it is currently assigned as the store checkout terms!';
$_['error_affiliate']        = 'Warning: This gallery album page cannot be deleted as it is currently assigned as the store affiliate terms!';
$_['error_return']           = 'Warning: This gallery album page cannot be deleted as it is currently assigned as the store return terms!';
$_['error_store']            = 'Warning: This gallery album page cannot be deleted as it is currently used by %s stores!';