<?php
// Text
$_['text_items']     = 'Item %s';
$_['text_items_res'] = '%s';
$_['heading_title_cart'] = 'My basket';
$_['text_empty']     = 'Your shopping cart is empty!';
$_['text_cart']      = 'View Cart';
$_['text_checkout']  = 'Checkout';
$_['text_recurring'] = 'Payment Profile';