<?php
// Heading
$_['heading_title']                        = 'Recurring Payments';

// Text
$_['text_account']                         = 'Account';
$_['text_recurring']                       = 'Recurring Payment Information';
$_['text_recurring_detail']                = 'Recurring Payment Details';
$_['text_order_recurring_id']              = 'Recurring ID:';
$_['text_date_added']                      = 'Date Added:';
$_['text_status']                          = 'Status:';
$_['text_payment_method']                  = 'Payment Method:';
$_['text_order_id']                        = 'Order ID:';
$_['text_product']                         = 'Product:';
$_['text_quantity']                        = 'Quantity:';
$_['text_description']                     = 'Description';
$_['text_reference']                       = 'Reference';
$_['text_transaction']                     = 'Transactions';
$_['text_status_1']                        = 'Active';
$_['text_status_2']                        = 'Inactive';
$_['text_status_3']                        = 'Cancelled';
$_['text_status_4']                        = 'Suspended';
$_['text_status_5']                        = 'Expired';
$_['text_status_6']                        = 'Pending';
$_['text_transaction_date_added']          = 'Created';
$_['text_transaction_payment']             = 'Payment';
$_['text_transaction_outstanding_payment'] = 'Outstanding payment';
$_['text_transaction_skipped']             = 'Payment skipped';
$_['text_transaction_failed']              = 'Payment failed';
$_['text_transaction_cancelled']           = 'Cancelled';
$_['text_transaction_suspended']           = 'Suspended';
$_['text_transaction_suspended_failed']    = 'Suspended from failed payment';
$_['text_transaction_outstanding_failed']  = 'Outstanding payment failed';
$_['text_transaction_expired']             = 'Expired';
$_['text_empty']                           = 'No recurring payments found!';
$_['text_error']                           = 'The recurring order you requested could not be found!';
$_['text_cancelled']                       = 'Recurring payment has been cancelled';

// Column
$_['column_date_added']                    = 'Date Added';
$_['column_type']                          = 'Type';
$_['column_amount']                        = 'Amount';
$_['column_status']                        = 'Status';
$_['column_product']                       = 'Product';
$_['column_order_recurring_id']            = 'Recurring ID';

// Error
$_['error_not_cancelled']                  = 'Error: %s';
$_['error_not_found']                      = 'Could not cancel recurring';

// Button
$_['button_return']                        = 'Return';