<?php
// Heading
$_['heading_title']    = 'Backup &amp; Restore';

// Text
$_['text_success']     = 'Success: You have successfully imported your database!';

// Entry
$_['entry_progress']   = 'Progress';
$_['entry_export']     = 'Export';

// Tab
$_['tab_backup']       = 'Backup';
$_['tab_restore']      = 'Restore';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify Backup &amp; Restore!';
$_['error_export']     = 'Warning: You must select at least one table to export!';
$_['error_file']       = 'File could not be found!';
