<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  22520 => 'Plateau, Abidjan',
  22521 => 'Abidjan (southeast)',
  22522 => 'Cocody, Abidjan',
  22523 => 'Banco, Abidjan',
  22524 => 'Abobo, Abidjan',
  22530 => 'Yamoussoukro',
  22531 => 'Bouaké',
  22532 => 'Daloa',
  22533 => 'Man',
  22534 => 'San-Pédro',
  22535 => 'Abengourou',
  22536 => 'Korhogo',
);
