<?php
// Text
$_['text_subject'] = '%s - Your Account has been activated!';
$_['text_welcome'] = 'Welcome and thank you for registering at %s!';
$_['text_login']   = 'Your account has now been created and you can log in by using your email address and password by visiting our website or at the following URL:';
$_['text_service'] = 'Upon logging in, you will be able to access other services including reviewing past orders, printing invoices and editing your account information.';
$_['text_thanks']  = 'Thanks,';