<?php
// Heading
$_['heading_title']    = 'SEO URL';

// Text
$_['text_success']     = 'Success: You have modified SEO URL!';
$_['text_list']        = 'SEO URL List';
$_['text_add']         = 'Add SEO URL';
$_['text_edit']        = 'Edit SEO URL';
$_['text_filter']      = 'Filter';
$_['text_default']     = 'Default';

// Column
$_['column_query']     = 'Query';
$_['column_keyword']   = 'Keyword';
$_['column_store']     = 'Store';
$_['column_language']  = 'Language';
$_['column_action']    = 'Action';

// Entry
$_['entry_query']      = 'Query';
$_['entry_keyword']    = 'Keyword';
$_['entry_store']      = 'Store';
$_['entry_language']   = 'Language';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify SEO URL!';
$_['error_query']      = 'Query must be between 3 and 64 characters!';
$_['error_keyword']    = 'Keyword must be between 3 and 64 characters!';
$_['error_exists']     = 'Keyword already in use!';
