<?php
// Text
$_['text_success']           = 'Success: You have modified orders!';

// Error
$_['error_permission']       = 'Warning: You do not have permission to access the API!';
$_['error_customer']         = 'Warning: Customer details needs to be set!';
$_['error_payment_address']  = 'Warning: Payment address required!';
$_['error_payment_method']   = 'Warning: Payment method required!';
$_['error_no_payment']       = 'Warning: No Payment options are available!';
$_['error_shipping_address'] = 'Warning: Shipping address required!';
$_['error_shipping_method']  = 'Warning: Shipping method required!';
$_['error_no_shipping']      = 'Warning: No Shipping options are available!';
$_['error_stock']            = 'Warning: Products marked with *** are not available in the desired quantity or not in stock!';
$_['error_minimum']          = 'Warning: Minimum order amount for %s is %s!';
$_['error_not_found']        = 'Warning: Order could not be found!';