<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  3751511 => 'Берестовица, Гродненская область',
  3751512 => 'Волковыск',
  3751513 => 'Свислочь, Гродненская область',
  3751514 => 'Щучин, Гродненская область',
  3751515 => 'Мосты, Гродненская область',
  375152 => 'Гродно',
  375154 => 'Лида',
  3751562 => 'Слоним',
  3751563 => 'Дятлово, Гродненская область',
  3751564 => 'Зельва, Гродненская область',
  3751591 => 'Островец, Гродненская область',
  3751592 => 'Сморгонь',
  3751593 => 'Ошмяны',
  3751594 => 'Вороново, Гродненская область',
  3751595 => 'Ивье, Гродненская область',
  3751596 => 'Кореличи, Гродненская область',
  3751597 => 'Новогрудок',
  375162 => 'Брест',
  375163 => 'Барановичи',
  3751631 => 'Каменец, Брестская область',
  3751632 => 'Пружаны, Брестская область',
  3751633 => 'Ляховичи, Брестская область',
  3751641 => 'Жабинка, Брестская область',
  3751642 => 'Кобрин',
  3751643 => 'Береза, Брестская область',
  3751644 => 'Дрогичин, Брестская область',
  3751645 => 'Ивацевичи, Брестская область',
  3751646 => 'Ганцевичи, Брестская область',
  3751647 => 'Лунинец, Брестская область',
  375165 => 'Пинск',
  3751651 => 'Малорита, Брестская область',
  3751652 => 'Иваново, Брестская область',
  3751655 => 'Столин, Брестская область',
  37517 => 'Минск',
  3751713 => 'Марьина Горка, Минская область',
  3751714 => 'Червень',
  3751715 => 'Березино, Минская область',
  3751716 => 'Дзержинск',
  3751717 => 'Столбцы',
  3751718 => 'Узда, Минская область',
  3751719 => 'Копыль, Минская область',
  375174 => 'Солигорск',
  375176 => 'Молодечно',
  375177 => 'Борисов',
  3751770 => 'Несвиж',
  3751771 => 'Вилейка',
  3751772 => 'Воложин',
  3751774 => 'Логойск',
  3751775 => 'Жодино',
  3751776 => 'Смолевичи',
  3751792 => 'Старые Дороги, Минская область',
  3751793 => 'Клецк, Минская область',
  3751794 => 'Любань, Минская область',
  3751795 => 'Слуцк',
  3751796 => 'Крупки, Минская область',
  3751797 => 'Мядель',
  375212 => 'Витебск',
  3752130 => 'Шумилино, Витебская область',
  3752131 => 'Бешенковичи, Витебская область',
  3752132 => 'Лепель',
  3752133 => 'Чашники, Витебская область',
  3752135 => 'Сенно, Витебская область',
  3752136 => 'Толочин',
  3752137 => 'Дубровно, Витебская область',
  3752138 => 'Лиозно, Витебская область',
  3752139 => 'Городок, Витебская область',
  375214 => 'Полоцк/Новополоцк',
  3752151 => 'Верхнедвинск, Витебская область',
  3752152 => 'Миоры, Витебская область',
  3752153 => 'Браслав',
  3752154 => 'Шарковщина, Витебская область',
  3752155 => 'Поставы',
  3752156 => 'Глубокое',
  3752157 => 'Докшицы, Витебская область',
  3752158 => 'Ушачи, Витебская область',
  3752159 => 'Россоны, Витебская область',
  375216 => 'Орша',
  375222 => 'Могилев',
  3752230 => 'Глуск, Могилевская область',
  3752231 => 'Быхов, Могилевская область',
  3752232 => 'Белыничи, Могилевская область',
  3752233 => 'Горки, Могилевская область',
  3752234 => 'Круглое, Могилевская область',
  3752235 => 'Осиповичи',
  3752236 => 'Кличев, Могилевская область',
  3752237 => 'Кировск, Могилевская область',
  3752238 => 'Краснополье, Могилевская область',
  3752239 => 'Шклов',
  3752240 => 'Мстиславль',
  3752241 => 'Кричев, Могилевская область',
  3752242 => 'Чаусы, Могилевская область',
  3752243 => 'Чериков, Могилевская область',
  3752244 => 'Климовичи, Могилевская область',
  3752245 => 'Костюковичи, Могилевская область',
  3752246 => 'Славгород, Могилевская область',
  3752247 => 'Хотимск, Могилевская область',
  3752248 => 'Дрибин, Могилевская область',
  375225 => 'Бобруйск',
  375232 => 'Гомель',
  3752330 => 'Ветка, Гомельская область',
  3752332 => 'Чечерск, Гомельская область',
  3752333 => 'Добруш, Гомельская область',
  3752334 => 'Жлобин',
  3752336 => 'Буда-Кошелево, Гомельская область',
  3752337 => 'Корма, Гомельская область',
  3752339 => 'Рогачев',
  3752340 => 'Речица',
  3752342 => 'Светлогорск',
  3752344 => 'Брагин, Гомельская область',
  3752345 => 'Калинковичи',
  3752346 => 'Хойники, Гомельская область',
  3752347 => 'Лоев, Гомельская область',
  3752350 => 'Петриков, Гомельская область',
  3752353 => 'Житковичи, Гомельская область',
  3752354 => 'Ельск, Гомельская область',
  3752355 => 'Наровля, Гомельская область',
  3752356 => 'Лельчицы, Гомельская область',
  3752357 => 'Октябрьский, Гомельская область',
  375236 => 'Мозырь',
);
