<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  4121 => 'Lausanne',
  4122 => 'Geneva',
  4124 => 'Yverdon/Aigle',
  4126 => 'Fribourg',
  4127 => 'Sion',
  4131 => 'Berne',
  4132 => 'Bienne/Neuchâtel/Soleure/Jura',
  4133 => 'Thun',
  4134 => 'Burgdorf/Langnau i.E.',
  4141 => 'Lucerne',
  4143 => 'Zurich',
  4144 => 'Zurich',
  4152 => 'Winterthur',
  4155 => 'Rapperswil',
  4156 => 'Baden',
  4161 => 'Basel',
  4162 => 'Olten',
  4171 => 'St. Gallen',
  4181 => 'Chur',
  4191 => 'Bellinzona',
);
