<?php
// Heading
$_['heading_title']    = 'Free Shipping';

// Text
$_['text_extension']   = 'Extensions';
$_['text_success']     = 'Success: You have modified free shipping!';
$_['text_edit']        = 'Edit Free Shipping';

// Entry
$_['entry_total']      = 'Total';
$_['entry_geo_zone']   = 'Geo Zone';
$_['entry_status']     = 'Status';
$_['entry_sort_order'] = 'Sort Order';

// Help
$_['help_total']       = 'Sub-Total amount needed before the free shipping module becomes available.';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify free shipping!';