<?php
// Heading 
$_['heading_title'] = 'Account';

//button
$_['button_sign_in'] = 'Sign in with';
$_['button_sign_in_mail'] = 'Sign up';

//placeholder
$_['text_email'] = 'Enter your email';
$_['text_firstname'] = 'Enter your firstname';
$_['text_lastname'] = 'Enter your lastname';
$_['text_telephone'] = 'Enter your phone';
$_['text_address_1'] = 'Enter your address';
$_['text_address_2'] = 'Enter your address (extra)';
$_['text_city'] = 'Enter your city';
$_['text_postcode'] = 'Enter your postcode';
$_['text_country_id'] = 'Select country';
$_['text_zone_id'] = 'Select region';
$_['text_company'] = 'Enter company name';
$_['text_password'] = 'Enter you password';
$_['text_confirm'] = 'Confirm you password';
$_['text_wait_provider'] = '<strong>We are waiting results from your provider</strong>';
$_['text_email_intro'] = 'You are almost done. Please fill in the required information below to complete the registration. You can edit it later from your shop account page.';
$_['text_help_required'] = '* — fields are required';

//confirm text
$_['text_confirm_finish'] = '<h2 >Thank you!</h2>';

//errors
$_['error_email_taken'] = 'Sorry, This email is taken.';
$_['error_email_incorrect'] = 'Sorry, this is an invalid email.';
$_['error_fill_all_fields'] = 'Sorry, please fill in all the fields.';
$_['error_password_and_confirm_different'] = 'Sorry, your password is different from the confirm field.';
//hybrid errors
$_['unspecified_error'] = 'Unspecified error';
$_['hybriauth_error'] = 'Hybriauth configuration error.';
$_['provider_not_configured_error'] = 'Provider not properly configured.';
$_['disabled_provider_error'] = 'Unknown or disabled provider.';
$_['missing_provider_error'] = 'Missing provider application credentials.';
$_['auth_fail_error'] = 'Authentication failed. The user has canceled the authentication or the provider refused the connection.';
$_['profile_request_error'] = 'User profile request failed. Most likely the user is not connected to the provider and he should to authenticate again.';
$_['user_no_provider_error'] = 'User not connected to the provider.';

//lables
$_['text_entry_email'] = 'Email:';
$_['text_entry_firstname'] = 'Firstname:';
$_['text_entry_lastname'] = 'Lastname:';
$_['text_entry_telephone'] = 'Phone:';
$_['text_entry_address_1'] = 'Address 1:';
$_['text_entry_address_2'] = 'Address 2:';
$_['text_entry_city'] = 'City:';
$_['text_entry_postcode'] = 'Postcode:';
$_['text_entry_country_id'] = 'Country:';
$_['text_entry_zone_id'] = 'Zone:';
$_['text_entry_company'] = 'Company:';
$_['text_entry_password'] = 'Password';
$_['text_entry_confirm'] = 'Confirm your password:';

?>
