<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  67615 => 'U-Call',
  67616 => 'U-Call',
  67617 => 'U-Call',
  67618 => 'U-Call',
  67619 => 'U-Call',
  67646 => 'U-Call',
  67649 => 'U-Call',
  67653 => 'U-Call',
  67654 => 'U-Call',
  67655 => 'U-Call',
  67656 => 'U-Call',
  67657 => 'U-Call',
  67658 => 'U-Call',
  67659 => 'U-Call',
  67663 => 'U-Call',
  67664 => 'U-Call',
  67665 => 'U-Call',
  67666 => 'U-Call',
  67667 => 'U-Call',
  67668 => 'U-Call',
  67669 => 'U-Call',
  67675 => 'U-Call',
  67676 => 'U-Call',
  67677 => 'U-Call',
  67678 => 'U-Call',
);
