<?php
// Heading
$_['heading_title']    = 'Sub-Total';

// Text
$_['text_extension']   = 'Extensions';
$_['text_success']     = 'Success: You have modified sub-total total!';
$_['text_edit']        = 'Edit Sub-Total Total';

// Entry
$_['entry_status']     = 'Status';
$_['entry_sort_order'] = 'Sort Order';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify sub-total total!';