<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  23320 => 'Vodafone',
  23323 => 'Globacom (Zain)',
  23324 => 'MTN',
  23326 => 'Airtel',
  23327 => 'tiGO',
  23328 => 'Expresso',
  23350 => 'Vodafone',
  23354 => 'MTN',
  233553 => 'MTN',
  233554 => 'MTN',
  233555 => 'MTN',
  233556 => 'MTN',
  233557 => 'MTN',
  233558 => 'MTN',
  23356 => 'Airtel',
  23357 => 'tiGO',
);
