<?php
$_['entry_background_image']           = 'Background Image';
$_['text_background_positon']           = 'Background Position:';
$_['entry_background_positon']          = array(
          'fixed' => 'fixed',
           'cover' => 'cover',
   );
$_['text_like_extension']          = 'If you Liked this extension and want to add more Options init then <a href="http://www.opencart.com/index.php?route=extension/extension/info&extension_id=17473" target="_blank">click here</a>';
// Heading
$_['heading_title']    	 = 'Newsletters';

// Text
$_['text_extension']     = 'Extensions';
$_['text_success']     	 = 'Success: You have modified newsletters!';
$_['text_edit']          = 'Edit newsletters Module';
$_['entry_background_banner']          = 'Background banner';


// Entry
$_['entry_status']     	 = 'Status';

// Error
$_['error_permission']   = 'Warning: You do not have permission to modify Newsletters module!';