<?php

// Heading
$_['heading_title'] = "Advertising";


// Columns
$_['column_name']   = "Advertising Name";
$_['column_status'] = "Status";
$_['column_action'] = "Action";


// Text
$_['text_success']   = "<strong>Success:</strong> You have modified advertising!";

// Error
$_['error_adblock'] = "It looks like you are using an ad blocker. In order to use this Advertising section, please disable your ad blocker for your OpenCart admin panel.";
