<div class="table-responsive">
  <table class="table table-bordered table-hover">
    <thead>
      <tr>
        <td class="text-left">{{ column_ip }}</td>
        <td class="text-right">{{ column_total }}</td>
        <td class="text-left">{{ column_date_added }}</td>
        <td class="text-right">{{ column_action }}</td>
      </tr>
    </thead>
    <tbody>
      {% if ips %}
      {% for ip in ips %}
      <tr>
        <td class="text-left"><a href="http://www.geoiptool.com/en/?IP={{ ip.ip }}" target="_blank">{{ ip.ip }}</a></td>
        <td class="text-right"><a href="{{ ip.filter_ip }}" target="_blank">{{ ip.total }}</a></td>
        <td class="text-left">{{ ip.date_added }}</td>
        <td class="text-right"><button type="button" value="{{ ip.ip }}" data-toggle="tooltip" title="{{ button_remove }}" data-loading-text="{{ text_loading }}" class="btn btn-danger"><i class="fa fa-minus-circle"></i></button></td>
      </tr>
      {% endfor %}
      {% else %}
      <tr>
        <td class="text-center" colspan="4">{{ text_no_results }}</td>
      </tr>
      {% endif %}
    </tbody>
  </table>
</div>
<div class="row">
  <div class="col-sm-6 text-left">{{ pagination }}</div>
  <div class="col-sm-6 text-right">{{ results }}</div>
</div>
