<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  822 => 'Σεούλ',
  8231 => 'Γκιόνγκι-ντο',
  8232 => 'Ίντσον',
  8233 => 'Γκάνγουον-ντο (Νότιας Κορέας)',
  8242 => 'Ντέτζον',
  8251 => 'Μπούσαν',
  8252 => 'Ούλσαν',
  8253 => 'Ντέγκου',
  8262 => 'Γκουάνγκτζου',
);
