.qc-checkout-product {
    overflow: hidden;
    tr {
        td {
            vertical-align: middle;
        }
    }
    .qc-total {
        text-align: right;
    }
    .qc-quantity {
        .input-group,
        .ve-input-group {
            max-width: 180px;
        }
    }
    .qc-image {
        a {
            display: inline-block;
        }
    }
    .qc-totals {
        margin-top: 30px;
        >.qc-total {
            padding-bottom: 10px;
            .text-right {
                font-weight: 600;
            }
        }
        >.qc-total:last-child {
            border-top: 1px solid #efefef;
            margin-top: 5px;
            padding-top: 15px;
            >* {
                font-size: 16px;
                font-weight: bold;
            }
        }
    }
}