<?php
// Text
$_['text_title']           = 'United Parcel Service';
$_['text_weight']          = 'Weight:';
$_['text_us_origin_01']    = 'UPS Next Day Air';
$_['text_us_origin_02']    = 'UPS 2nd Day Air';
$_['text_us_origin_03']    = 'UPS Ground';
$_['text_us_origin_07']    = 'UPS Worldwide Express';
$_['text_us_origin_08']    = 'UPS Worldwide Expedited';
$_['text_us_origin_11']    = 'UPS Standard';
$_['text_us_origin_12']    = 'UPS 3 Day Select';
$_['text_us_origin_13']    = 'UPS Next Day Air Saver';
$_['text_us_origin_14']    = 'UPS Next Day Air Early A.M.';
$_['text_us_origin_54']    = 'UPS Worldwide Express Plus';
$_['text_us_origin_59']    = 'UPS 2nd Day Air A.M.';
$_['text_us_origin_65']    = 'UPS Saver';
$_['text_ca_origin_01']    = 'UPS Express';
$_['text_ca_origin_02']    = 'UPS Expedited';
$_['text_ca_origin_07']    = 'UPS Worldwide Express';
$_['text_ca_origin_08']    = 'UPS Worldwide Expedited';
$_['text_ca_origin_11']    = 'UPS Standard';
$_['text_ca_origin_12']    = 'UPS 3 Day Select';
$_['text_ca_origin_13']    = 'UPS Saver';
$_['text_ca_origin_14']    = 'UPS Express Early A.M.';
$_['text_ca_origin_54']    = 'UPS Worldwide Express Plus';
$_['text_ca_origin_65']    = 'UPS Saver';
$_['text_eu_origin_07']    = 'UPS Express';
$_['text_eu_origin_08']    = 'UPS Expedited';
$_['text_eu_origin_11']    = 'UPS Standard';
$_['text_eu_origin_54']    = 'UPS Worldwide Express Plus';
$_['text_eu_origin_65']    = 'UPS Saver';
$_['text_eu_origin_82']    = 'UPS Today Standard';
$_['text_eu_origin_83']    = 'UPS Today Dedicated Courier';
$_['text_eu_origin_84']    = 'UPS Today Intercity';
$_['text_eu_origin_85']    = 'UPS Today Express';
$_['text_eu_origin_86']    = 'UPS Today Express Saver';
$_['text_eu_origin_01']    = 'UPS Next Day Air';
$_['text_eu_origin_02']    = 'UPS 2nd Day Air';
$_['text_eu_origin_03']    = 'UPS Ground';
$_['text_eu_origin_14']    = 'UPS Next Day Air Early A.M.';
$_['text_mx_origin_07']    = 'UPS Express';
$_['text_mx_origin_08']    = 'UPS Expedited';
$_['text_mx_origin_54']    = 'UPS Express Plus';
$_['text_mx_origin_65']    = 'UPS Saver';
$_['text_other_origin_07'] = 'UPS Express';
$_['text_other_origin_08'] = 'UPS Worldwide Expedited';
$_['text_other_origin_11'] = 'UPS Standard';
$_['text_other_origin_54'] = 'UPS Worldwide Express Plus';
$_['text_other_origin_65'] = 'UPS Saver';