<?php
// Heading
$_['heading_title']		 = 'Perpetual Payments';

// Text
$_['text_extension']	 = 'Extensions';
$_['text_success']		 = 'Success: You have modified Perpetual Payments account details!';
$_['text_edit']          = 'Edit Perpetual Payments';

// Entry
$_['entry_auth_id']		 = 'Authorization ID';
$_['entry_auth_pass']	 = 'Authorization Password';
$_['entry_test']		 = 'Test Mode';
$_['entry_total']		 = 'Total';
$_['entry_order_status'] = 'Order Status';
$_['entry_geo_zone']	 = 'Geo Zone';
$_['entry_status']		 = 'Status';
$_['entry_sort_order']	 = 'Sort Order';

// Help
$_['help_test']			 = 'Use this module in Test (YES) or Production mode (NO)?';
$_['help_total']		 = 'The checkout total the order must reach before this payment method becomes active.';

// Error
$_['error_permission']	 = 'Warning: You do not have permission to modify payment Perpetual Payments!';
$_['error_auth_id']		 = 'Authorization ID Required!';
$_['error_auth_pass']	 = 'Authorization Password Required!';