<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  6221 => 'Greater Jakarta',
  6222 => 'Bandung/Cimahi',
  62231 => 'Cirebon',
  62232 => 'Kuningan',
  62233 => 'Majalengka',
  62234 => 'Indramayu',
  6224 => 'Semarang/Demak',
  62251 => 'Bogor',
  62252 => 'Rangkasbitung',
  62253 => 'Pandeglang',
  62254 => 'Serang/Merak',
  62260 => 'Subang',
  62261 => 'Sumedang',
  62262 => 'Garut',
  62263 => 'Cianjur',
  62264 => 'Purwakarta/Cikampek',
  62265 => 'Tasikmalaya/Banjar/Ciamis',
  62266 => 'Sukabumi',
  62267 => 'Karawang',
  62271 => 'Surakarta/Sukoharjo/Karanganyar/Sragen',
  62272 => 'Klaten',
  62273 => 'Wonogiri',
  62274 => 'Yogyakarta',
  62275 => 'Purworejo',
  62276 => 'Boyolali',
  62280 => 'West Cilacap',
  62281 => 'Banyumas/Purbalingga',
  62282 => 'East Cilacap',
  62283 => 'Tegal/Brebes',
  62284 => 'Pemalang',
  62285 => 'Pekalongan/Batang/Comal',
  62286 => 'Banjarnegara/Wonosobo',
  62287 => 'Kebumen/Karanganyar',
  62289 => 'Bumiayu',
  62291 => 'Demak/Jepara/Kudus',
  62292 => 'Purwodadi',
  62293 => 'Magelang/Mungkid/Temanggung',
  62294 => 'Kendal',
  62295 => 'Pati/Rembang',
  62296 => 'Blora',
  62297 => 'Karimun Jawa',
  62298 => 'Salatiga/Ambarawa',
  6231 => 'Surabaya',
  62321 => 'Mojokerto/Jombang',
  62322 => 'Lamongan',
  62323 => 'Sampang',
  62324 => 'Pamekasan',
  62325 => 'Sangkapura',
  62326 => 'Masalembu Islands',
  62327 => 'Kangean/Masalembu',
  62328 => 'Sumenep',
  62331 => 'Jember',
  62332 => 'Bondowoso',
  62333 => 'Banyuwangi',
  62334 => 'Lumajang',
  62335 => 'Probolinggo',
  62336 => 'Jember',
  62338 => 'Situbondo',
  62341 => 'Malang/Batu',
  62342 => 'Blitar',
  62343 => 'Pasuruan',
  62351 => 'Madiun/Magetan/Ngawi',
  62352 => 'Ponorogo',
  62353 => 'Bojonegoro',
  62354 => 'Kediri',
  62355 => 'Tulungagung/Trenggalek',
  62356 => 'Rembang/Tuban',
  62357 => 'Pacitan',
  62358 => 'Nganjuk',
  62361 => 'Denpasar',
  62362 => 'Singaraja',
  62363 => 'Amlapura',
  62365 => 'Negara/Gilimanuk',
  62366 => 'Klungkung/Bangli',
  62368 => 'Baturiti',
  62370 => 'Mataram/Praya',
  62371 => 'Sumbawa',
  62372 => 'Alas/Taliwang',
  62373 => 'Dompu',
  62374 => 'Bima',
  62376 => 'Selong',
  62380 => 'Kupang',
  62381 => 'Ende',
  62382 => 'Maumere',
  62383 => 'Larantuka',
  62384 => 'Bajawa',
  62385 => 'Labuhanbajo/Ruteng',
  62386 => 'Kalabahi',
  62387 => 'Waingapu/Waikabubak',
  62388 => 'Kefamenanu/Soe',
  62389 => 'Atambua',
  62401 => 'Kendari',
  62402 => 'Baubau',
  62403 => 'Raha',
  62404 => 'Wanci',
  62405 => 'Kolaka',
  62408 => 'Unaaha',
  62410 => 'Pangkep',
  62411 => 'Makassar/Maros/Sungguminasa',
  62413 => 'Bulukumba/Bantaeng',
  62414 => 'Kepulauan Selayar',
  62417 => 'Malino',
  62418 => 'Takalar',
  62419 => 'Jeneponto',
  62420 => 'Enrekang',
  62421 => 'Parepare/Pinrang',
  62422 => 'Majene',
  62423 => 'Makale/Rantepao',
  62426 => 'Mamuju',
  62427 => 'Barru',
  62428 => 'Polewali',
  62430 => 'Amurang',
  62431 => 'Manado/Tomohon/Tondano',
  62432 => 'Tahuna',
  62434 => 'Kotamobagu',
  62435 => 'Gorontalo',
  62438 => 'Bitung',
  6244 => 'Marisa',
  62451 => 'Palu',
  62452 => 'Poso',
  62453 => 'Tolitoli',
  62457 => 'Donggala',
  62458 => 'Tentena',
  62461 => 'Luwuk',
  62462 => 'Banggai',
  62463 => 'Bunta',
  62464 => 'Ampana',
  62465 => 'Kolonedale',
  62471 => 'Palopo',
  62473 => 'Masamba',
  62474 => 'Malili',
  62481 => 'Watampone',
  62482 => 'Sinjai',
  62484 => 'Watansoppeng',
  62485 => 'Sengkang',
  62511 => 'Banjarmasin',
  62512 => 'Pelaihari',
  62513 => 'Muara Teweh',
  62517 => 'Kandangan/Barabai/Rantau/Negara',
  62518 => 'Kotabaru/Batulicin',
  62522 => 'Ampah',
  62525 => 'Buntok',
  62526 => 'Tamiang Layang/Tanjung',
  62527 => 'Amuntai',
  62528 => 'Purukcahu',
  62531 => 'Sampit',
  62532 => 'Pangkalan Bun',
  62534 => 'Ketapang',
  62536 => 'Palangkaraya/Kasongan',
  62537 => 'Kuala Kurun',
  62538 => 'Kuala Pembuang',
  62539 => 'Kuala Kuayan',
  62541 => 'Samarinda/Tenggarong',
  62542 => 'Balikpapan',
  62543 => 'Tanah Grogot',
  62545 => 'Melak',
  62548 => 'Bontang',
  62549 => 'Sangatta',
  62551 => 'Tarakan',
  62552 => 'Tanjungselor',
  62553 => 'Malinau',
  62554 => 'Tanjung Redeb',
  62556 => 'Nunukan',
  62561 => 'Pontianak/Mempawah',
  62562 => 'Singkawang/Sambas/Bengkayang',
  62563 => 'Ngabang',
  62564 => 'Sanggau',
  62565 => 'Sintang',
  62567 => 'Putussibau',
  62568 => 'Nanga Pinoh',
  6261 => 'Medan',
  62620 => 'Pangkalan Brandan',
  62621 => 'Tebing Tinggi/Sei Rampah',
  62622 => 'Pematangsiantar/Pematang Raya/Limapuluh',
  62623 => 'Kisaran/Tanjung Balai',
  62624 => 'Panipahan/Labuhanbatu',
  62625 => 'Parapat/Ajibata/Simanindo',
  62626 => 'Pangururan',
  62627 => 'Subulussalam/Sidikalang/Salak',
  62628 => 'Kabanjahe/Sibolangit',
  62629 => 'Kutacane',
  62631 => 'Sibolga/Pandan',
  62632 => 'Balige',
  62633 => 'Tarutung/Dolok Sanggul',
  62634 => 'Padang Sidempuan/Sipirok',
  62635 => 'Gunung Tua',
  62636 => 'Panyabungan/Sibuhuan',
  62639 => 'Gunung Sitoli',
  62641 => 'Langsa',
  62642 => 'Blang Kejeren',
  62643 => 'Takengon',
  62644 => 'Bireuen',
  62645 => 'Lhokseumawe',
  62646 => 'Idi',
  62650 => 'Sinabang',
  62651 => 'Banda Aceh/Jantho/Lamno',
  62652 => 'Sabang',
  62653 => 'Sigli',
  62654 => 'Calang',
  62655 => 'Meulaboh',
  62656 => 'Tapaktuan',
  62657 => 'Bakongan',
  62658 => 'Singkil',
  62659 => 'Blangpidie',
  6270 => 'Tebing Tinggi',
  62711 => 'Palembang',
  62712 => 'Kayu Agung/Tanjung Raja',
  62713 => 'Prabumulih/Talang Ubi',
  62714 => 'Sekayu',
  62715 => 'Belinyu',
  62716 => 'Muntok',
  62717 => 'Pangkal Pinang/Sungailiat',
  62718 => 'Koba/Toboali',
  62719 => 'Manggar/Tanjung Pandan',
  62721 => 'Bandar Lampung',
  62722 => 'Tanggamus',
  62723 => 'Blambangan Umpu',
  62724 => 'Kotabumi',
  62725 => 'Metro',
  62726 => 'Menggala',
  62727 => 'Kalianda',
  62728 => 'Liwa',
  62729 => 'Pringsewu',
  62730 => 'Pagar Alam/Kota Agung',
  62731 => 'Lahat',
  62732 => 'Curup',
  62733 => 'Lubuklinggau/Muara Beliti',
  62734 => 'Muara Enim',
  62735 => 'Baturaja/Martapura/Muaradua',
  62736 => 'Bengkulu City',
  62737 => 'Arga Makmur/Mukomuko',
  62738 => 'Muara Aman',
  62739 => 'Bintuhan/Manna',
  62741 => 'Jambi City',
  62742 => 'Kualatungkal/Tebing Tinggi',
  62743 => 'Muara Bulian',
  62744 => 'Muara Tebo',
  62745 => 'Sarolangun',
  62746 => 'Bangko',
  62747 => 'Muarabungo',
  62748 => 'Sungai Penuh/Kerinci',
  62751 => 'Padang/Pariaman',
  62752 => 'Bukittinggi/Padang Panjang/Payakumbuh/Batusangkar',
  62753 => 'Lubuk Sikaping',
  62754 => 'Sijunjung',
  62755 => 'Solok',
  62756 => 'Painan',
  62757 => 'Balai Selasa',
  62760 => 'Teluk Kuantan',
  62761 => 'Pekanbaru',
  62762 => 'Bangkinang/Pasir Pengaraian',
  62763 => 'Selatpanjang',
  62764 => 'Siak Sri Indrapura',
  62765 => 'Dumai/Duri/Bagan Batu/Ujung Tanjung',
  62766 => 'Bengkalis',
  62767 => 'Bagansiapiapi',
  62768 => 'Tembilahan',
  62769 => 'Rengat/Air Molek',
  62771 => 'Tanjung Pinang',
  62772 => 'Tarempa',
  62773 => 'Ranai',
  62776 => 'Dabosingkep',
  62777 => 'Karimun',
  62778 => 'Batam',
  62779 => 'Tanjungbatu',
  62901 => 'Timika',
  62902 => 'Agats',
  62910 => 'Bandanaira',
  62911 => 'Ambon',
  62913 => 'Namlea',
  62914 => 'Masohi',
  62915 => 'Bula',
  62916 => 'Tual',
  62917 => 'Dobo',
  62918 => 'Saumlaku',
  62921 => 'Soasiu',
  62922 => 'Jailolo',
  62923 => 'Morotai',
  62924 => 'Tobelo',
  62927 => 'Labuha',
  62929 => 'Sanana',
  62951 => 'Sorong',
  62952 => 'Teminabuan',
  62955 => 'Bintuni',
  62956 => 'Fakfak',
  62957 => 'Kaimana',
  62966 => 'Sarmi',
  62967 => 'Jayapura',
  62969 => 'Wamena',
  62971 => 'Merauke',
  62975 => 'Tanahmerah',
  62980 => 'Ransiki',
  62981 => 'Biak',
  62983 => 'Serui',
  62984 => 'Nabire',
  62986 => 'Manokwari',
);
