{{ header }}{{ column_left }}
<div id="content">
  <div class="page-header">
    <div class="container-fluid">
      <div class="pull-right">
        <button type="submit" form="form-length-class" data-toggle="tooltip" title="{{ button_save }}" class="btn btn-primary"><i class="fa fa-save"></i></button>
        <a href="{{ cancel }}" data-toggle="tooltip" title="{{ button_cancel }}" class="btn btn-default"><i class="fa fa-reply"></i></a></div>
      <h1>{{ heading_title }}</h1>
      <ul class="breadcrumb">
        {% for breadcrumb in breadcrumbs %}
        <li><a href="{{ breadcrumb.href }}">{{ breadcrumb.text }}</a></li>
        {% endfor %}
      </ul>
    </div>
  </div>
  <div class="container-fluid">
    {% if error_warning %}
    <div class="alert alert-danger alert-dismissible"><i class="fa fa-exclamation-circle"></i> {{ error_warning }}
      <button type="button" class="close" data-dismiss="alert">&times;</button>
    </div>
    {% endif %}
    <div class="panel panel-default">
      <div class="panel-heading">
        <h3 class="panel-title"><i class="fa fa-pencil"></i> {{ text_form }}</h3>
      </div>
      <div class="panel-body">
        <form action="{{ action }}" method="post" enctype="multipart/form-data" id="form-length-class" class="form-horizontal">
          <div class="form-group required">
            <label class="col-sm-2 control-label">{{ entry_title }}</label>
            <div class="col-sm-10">
              {% for language in languages %}
              <div class="input-group"> <span class="input-group-addon"><img src="language/{{ language.code }}/{{ language.code }}.png" title="{{ language.name }}" /></span>
                <input type="text" name="length_class_description[{{ language.language_id }}][title]" value="{{ length_class_description[language.language_id] ? length_class_description[language.language_id].title }}" placeholder="{{ entry_title }}" class="form-control" />
              </div>
              {% if error_title[language.language_id] %}
              <div class="text-danger">{{ error_title[language.language_id] }}</div>
              {% endif %}
              {% endfor %}
            </div>
          </div>
          <div class="form-group required">
            <label class="col-sm-2 control-label">{{ entry_unit }}</label>
            <div class="col-sm-10">
              {% for language in languages %}
              <div class="input-group"><span class="input-group-addon"><img src="language/{{ language.code }}/{{ language.code }}.png" title="{{ language.name }}" /></span>
                <input type="text" name="length_class_description[{{ language.language_id }}][unit]" value="{{ length_class_description[language.language_id] ? length_class_description[language.language_id].unit }}" placeholder="{{ entry_unit }}" class="form-control" />
              </div>
              {% if error_unit[language.language_id] %}
              <div class="text-danger">{{ error_unit[language.language_id] }}</div>
              {% endif %}
              {% endfor %}
            </div>
          </div>
          <div class="form-group">
            <label class="col-sm-2 control-label" for="input-value"><span data-toggle="tooltip" title="{{ help_value }}">{{ entry_value }}</span></label>
            <div class="col-sm-10">
              <input type="text" name="value" value="{{ value }}" placeholder="{{ entry_value }}" id="input-value" class="form-control" />
            </div>
          </div>
        </form>
      </div>
    </div>
  </div>
</div>
{{ footer }}
