<?php
// Heading
$_['heading_title']     = 'Tax Classes';

// Text
$_['text_success']      = 'Success: You have modified tax classes!';
$_['text_list']         = 'Tax Class List';
$_['text_add']          = 'Add Tax Class';
$_['text_edit']         = 'Edit Tax Class';
$_['text_tax_class']    = 'Tax Class';
$_['text_tax_rate']     = 'Tax Rates';
$_['text_shipping']     = 'Shipping Address';
$_['text_payment']      = 'Payment Address';
$_['text_store']        = 'Store Address';

// Column
$_['column_title']      = 'Tax Class Title';
$_['column_action']     = 'Action';

// Entry
$_['entry_title']       = 'Tax Class Title';
$_['entry_description'] = 'Description';
$_['entry_rate']        = 'Tax Rate';
$_['entry_based']       = 'Based On';
$_['entry_geo_zone']    = 'Geo Zone';
$_['entry_priority']    = 'Priority';

// Error
$_['error_permission']  = 'Warning: You do not have permission to modify tax classes!';
$_['error_title']       = 'Tax Class Title must be between 3 and 32 characters!';
$_['error_description'] = 'Description must be between 3 and 255 characters!';
$_['error_product']     = 'Warning: This tax class cannot be deleted as it is currently assigned to %s products!';