a#button-menu {
  -webkit-appearance: none !important; }

.welcome {
  background-position: bottom;
  background-repeat: no-repeat;
  background-size: 100%;
  min-height: 1025px;
  padding-top: 50px;
  padding-bottom: 525px; }

.welcome-into {
  text-align: center;
  max-width: 500px;
  margin: auto; }

.welcome-into-logo {
  padding-bottom: 15px; }

.welcome-into-heading {
  font-size: 30px;
  font-weight: bold;
  padding-bottom: 15px; }

.welcome-into-text {
  font-size: 18px;
  padding-bottom: 30px; }

.welcome-into-start {
  padding-bottom: 30px; }

.welcome-features {
  padding: 30px; }

.welcome-features-icon {
  padding: 20px;
  height: 130px;
  text-align: center; }
  .welcome-features-icon img {
    max-height: 100%; }

.welcome-features-text {
  text-align: center;
  font-weight: bold;
  font-size: 16px; }

.panel .panel-body {
  padding: 0px; }

/*# sourceMappingURL=welcome.css.map */
