<?php
// Heading
$_['heading_title']     = 'Events';

// Text
$_['text_success']      = 'Success: You have modified events!';
$_['text_list']         = 'Event List';
$_['text_event']        = 'Events are used by extensions to override the default functionality of your store. If you have issues you can disable or enable the events here.';
$_['text_info']         = 'Event Information';
$_['text_trigger']      = 'Trigger';
$_['text_action']       = 'Action';

// Column
$_['column_code']       = 'Event Code';
$_['column_status']     = 'Status';
$_['column_sort_order'] = 'Sort Order';
$_['column_action']     = 'Action';

// Error
$_['error_permission']  = 'Warning: You do not have permission to modify extensions!';
