<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;

/* oc01/template/common/home.twig */
class __TwigTemplate_b4a5d9ce795c962c5ee4d65a3c85e7a6ebf7d1a954ff503f5091de4f46ed000c extends \Twig\Template
{
    private $source;
    private $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = [])
    {
        $macros = $this->macros;
        // line 1
        echo ($context["header"] ?? null);
        echo "
<div id=\"common-home\">
";
        // line 3
        echo ($context["content_top"] ?? null);
        echo "
<div class=\"container\">
  <div class=\"row\">";
        // line 5
        echo ($context["column_left"] ?? null);
        echo "
    ";
        // line 6
        if ((($context["column_left"] ?? null) && ($context["column_right"] ?? null))) {
            // line 7
            echo "    ";
            $context["class"] = "col-sm-6";
            // line 8
            echo "    ";
        } elseif ((($context["column_left"] ?? null) || ($context["column_right"] ?? null))) {
            // line 9
            echo "    ";
            $context["class"] = "col-sm-9";
            // line 10
            echo "    ";
        } else {
            // line 11
            echo "    ";
            $context["class"] = "col-sm-12";
            // line 12
            echo "    ";
        }
        // line 13
        echo "    <div id=\"content\" class=\"";
        echo ($context["class"] ?? null);
        echo "\"><div class=\"breadcrumb\"></div>";
        echo ($context["content_bottom"] ?? null);
        echo "</div>
    ";
        // line 14
        echo ($context["column_right"] ?? null);
        echo "</div></div>

</div>
<script>
\$(document).ready(function(){
\$('.product-carousel').owlCarousel({
        items: 5,
        autoPlay: false,
        singleItem: false,
        navigation: true,
        pagination: false,
        itemsDesktop : [1199,4],
        itemsDesktopSmall : [991,3],
        itemsTablet : [767,3],
        itemsTabletSmall : [650,2],
        itemsMobile : [479,1]
    });
   
    \$('.banner-carousel').owlCarousel({
        items: 2,
        autoPlay: false,
        singleItem: false,
        navigation: false,
        pagination: true,
        itemsDesktop : [1199,2],
        itemsDesktopSmall : [991,2],
        itemsTablet : [767,2],
        itemsTabletSmall : [479,1],
        itemsMobile : [319,1]
    });
    
});
</script>
";
        // line 47
        echo ($context["footer"] ?? null);
        echo "
";
    }

    public function getTemplateName()
    {
        return "oc01/template/common/home.twig";
    }

    public function isTraitable()
    {
        return false;
    }

    public function getDebugInfo()
    {
        return array (  114 => 47,  78 => 14,  71 => 13,  68 => 12,  65 => 11,  62 => 10,  59 => 9,  56 => 8,  53 => 7,  51 => 6,  47 => 5,  42 => 3,  37 => 1,);
    }

    public function getSourceContext()
    {
        return new Source("", "oc01/template/common/home.twig", "");
    }
}
