<?php
// Heading
$_['heading_title']    = 'People Online';

// Text
$_['text_extension']   = 'Extensions';
$_['text_success']     = 'Success: You have modified dashboard online!';
$_['text_edit']        = 'Edit Dashboard Online';
$_['text_view']        = 'View more...';

// Entry
$_['entry_status']     = 'Status';
$_['entry_sort_order'] = 'Sort Order';
$_['entry_width']      = 'Width';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify dashboard online!';