<?php
// Heading
$_['heading_title']      = 'Anti-Fraud IP';

// Text
$_['text_extension']     = 'Extensions';
$_['text_success']       = 'Success: You have modified Anti-Fraud IP!';
$_['text_edit']          = 'Edit Anti-Fraud IP';
$_['text_ip_add']        = 'Add IP Address';
$_['text_ip_list']       = 'Fraud IP Address List';

// Column
$_['column_ip']          = 'IP';
$_['column_total']       = 'Total Accounts';
$_['column_date_added']  = 'Date Added';
$_['column_action']      = 'Action';

// Entry
$_['entry_ip']           = 'IP';
$_['entry_status']       = 'Status';
$_['entry_order_status'] = 'Order Status';

// Help
$_['help_order_status']  = 'Customers that have a banned IP on their accounts will be assigned this order status and will not be allowed to reach the complete status automatically.';

// Error
$_['error_permission']   = 'Warning: You do not have permission to modify Anti-Fraud IP!';