<?php
// Heading
$_['heading_title']     = 'Modifications';

// Text
$_['text_success']      = 'Success: You have modified modifications!';
$_['text_refresh']      = 'Whenever you enable / disable or delete a modification you need to click the refresh button to rebuild your modification cache!';
$_['text_list']         = 'Modification List';

// Column
$_['column_name']       = 'Modification Name';
$_['column_author']     = 'Author';
$_['column_version']    = 'Version';
$_['column_status']     = 'Status';
$_['column_date_added'] = 'Date Added';
$_['column_action']     = 'Action';

// Error
$_['error_permission']  = 'Warning: You do not have permission to modify modifications!';