<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  822 => 'Soul',
  8231 => 'Gjŏnggi',
  8232 => 'Inčchon',
  8233 => 'Kangwon',
  8241 => 'Jižní Čchungčchong',
  8242 => 'Tedžon',
  8243 => 'Severní Čchungčchong',
  8244 => 'Sedžong',
  8251 => 'Pusan',
  8253 => 'Tegu',
  8254 => 'Severní Kjongsang',
  8255 => 'Jižní Kjongsang',
  8261 => 'Jižní Čolla',
  8262 => 'Kwangdžu',
  8263 => 'Severní Čolla',
  8264 => 'Čedžu',
);
