<form action="https://secure.bluepay.com/interfaces/shpf" method="POST">
	<input type="hidden" name="ORDER_ID" value="{{ ORDER_ID }}">
	<input type="hidden" name="NAME1" value="{{ NAME1 }}">
	<input type="hidden" name="NAME2" value="{{ NAME2 }}">
	<input type="hidden" name="ADDR1" value="{{ ADDR1 }}">
	<input type="hidden" name="ADDR2" value="{{ ADDR2 }}">
	<input type="hidden" name="CITY" value="{{ CITY }}">
	<input type="hidden" name="STATE" value="{{ STATE }}">
	<input type="hidden" name="ZIPCODE" value="{{ ZIPCODE }}">
	<input type="hidden" name="COUNTRY" value="{{ country }}">
	<input type="hidden" name="PHONE" value="{{ PHONE }}">
	<input type="hidden" name="EMAIL" value="{{ email }}">
    <input type="hidden" name="SHPF_FORM_ID" value="{{ SHPF_FORM_ID }}">
    <input type="hidden" name="SHPF_ACCOUNT_ID" value="{{ SHPF_ACCOUNT_ID }}">
    <input type="hidden" name="SHPF_TPS" value="{{ SHPF_TPS }}">
    <input type="hidden" name="SHPF_TPS_DEF" value="{{ SHPF_TPS_DEF }}">
    <input type="hidden" name="MODE" value="{{ MODE }}">
    <input type="hidden" name="TRANSACTION_TYPE" value="{{ TRANSACTION_TYPE }}">
    <input type="hidden" name="MERCHANT" value="{{ MERCHANT }}">
    <input type="hidden" name="DBA" value="{{ DBA }}">
    <input type="hidden" name="TAMPER_PROOF_SEAL" value="{{ TAMPER_PROOF_SEAL }}">
    <input type="hidden" name="CARD_TYPES" value="{{ CARD_TYPES }}">
    <input type="hidden" name="REDIRECT_URL" value="{{ REDIRECT_URL }}">
    <input type="hidden" name="APPROVED_URL" value="{{ APPROVED_URL }}">
    <input type="hidden" name="DECLINED_URL" value="{{ DECLINED_URL }}">
    <input type="hidden" name="MISSING_URL" value="{{ MISSING_URL }}">
    <input type="hidden" name="TPS_DEF" value="{{ TPS_DEF }}">
    <input type="hidden" name="AMOUNT" value="{{ amount }}">
    <div class="buttons">
        <div class="pull-right">
            <input type="submit" value="{{ button_confirm }}" id="button-submit" data-loading-text="{{ text_loading }}" class="btn btn-primary" />
        </div>
    </div>
</form>