<?php
// Heading
$_['heading_title']     = 'Customer Searches Report';

// Text
$_['text_extension']    = 'Extensions';
$_['text_edit']         = 'Edit Customer Searches Report';
$_['text_success']      = 'Success: You have modified customer searches report!';
$_['text_filter']       = 'Filter';
$_['text_guest']        = 'Guest';
$_['text_customer']     = '<a href="%s">%s</a>';

// Column
$_['column_keyword']    = 'Keyword';
$_['column_products']   = 'Found Products';
$_['column_category']   = 'Category';
$_['column_customer']   = 'Customer';
$_['column_ip']         = 'IP';
$_['column_date_added'] = 'Date Added';

// Entry
$_['entry_date_start']  = 'Date Start';
$_['entry_date_end']    = 'Date End';
$_['entry_keyword']     = 'Keyword';
$_['entry_customer']    = 'Customer';
$_['entry_ip']          = 'IP';
$_['entry_status']      = 'Status';
$_['entry_sort_order']  = 'Sort Order';

// Error
$_['error_permission']  = 'Warning: You do not have permission to modify customer searches report!';