<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  420601 => 'O2',
  420602 => 'O2',
  420603 => 'T-Mobile',
  420604 => 'T-Mobile',
  420605 => 'T-Mobile',
  420606 => 'O2',
  420607 => 'O2',
  420608 => 'Vodafone',
  42072 => 'O2',
  42073 => 'T-Mobile',
  42077 => 'Vodafone',
  42093 => 'T-Mobile',
  420962 => 'O2',
  420963 => 'T-Mobile',
  420964 => 'T-Mobile',
  420965 => 'T-Mobile',
  420966 => 'O2',
  420967 => 'Vodafone',
);
