
/*  ANALYTICS CHART  */

.ct-series-a {

    .ct-line {
        stroke: $main_blue;
        stroke-width: 3px;
    }

    .ct-point {
        stroke: $main_blue;
    }
}

.ct-series-b {

    .ct-line {
        stroke: $some_gray;
        stroke-width: 3px;
    }

    .ct-point {
        stroke: $some_gray;
    }
}

.ct-series-c {

    .ct-line {
        stroke: $unprotected;
        stroke-width: 3px;
    }

    .ct-point {
        stroke: $unprotected;
    }
}

.ct-grid {
    stroke: rgb(56, 58, 75);
    stroke-width: 1px;
    stroke-dasharray: 0px;
}

.ct-label {
    color: rgb(176, 177, 184);
    font-size: 10px;

    &.ct-vertical {

        &.ct-start {
            padding-right: 25px;
        }
    }

    &.ct-horizontal {

        &.ct-end {
            padding-top: 10px;
        }
    }
}

.ct-point {
    stroke-width: 8px;
}
