<?php
// Heading
$_['heading_title']  = 'Administration';

// Text
$_['text_heading']   = 'Administration';
$_['text_login']     = 'Please enter your login details.';
$_['text_forgotten'] = 'Forgotten Password';

// Entry
$_['entry_username'] = 'Username';
$_['entry_password'] = 'Password';

// Button
$_['button_login']   = 'Login';

// Error
$_['error_login']    = 'No match for Username and/or Password.';
$_['error_token']    = 'Invalid token session. Please login again.';