<?php
// Text
$_['text_api']                  = 'API';
$_['text_attribute']            = 'Attributes';
$_['text_attribute_group']      = 'Attribute Groups';
$_['text_backup']               = 'Backup / Restore';
$_['text_banner']               = 'Banners';
$_['text_catalog']              = 'Catalog';
$_['text_category']             = 'Categories';
$_['text_country']              = 'Countries';
$_['text_coupon']               = 'Coupons';
$_['text_currency']             = 'Currencies';
$_['text_customer']             = 'Customers';
$_['text_customer_group']       = 'Customer Groups';
$_['text_customer_online']      = 'Customer Online';
$_['text_customer_approval']    = 'Customer Approvals';
$_['text_custom_field']         = 'Custom Fields';
$_['text_dashboard']            = 'Dashboard';
$_['text_design']               = 'Design';
$_['text_download']             = 'Downloads';
$_['text_log']                  = 'Error Logs';
$_['text_event']                = 'Events';
$_['text_extension']            = 'Extensions';
$_['text_filter']               = 'Filters';
$_['text_geo_zone']             = 'Geo Zones';
$_['text_information']          = 'Information';
$_['text_testimonials']               = 'Testimonials';
$_['text_newsletter']                = 'Newsletters';
$_['text_installer']            = 'Installer';
$_['text_language']             = 'Languages';
$_['text_language_editor']      = 'Language Editor';
$_['text_layout']               = 'Layouts';
$_['text_localisation']         = 'Localisation';
$_['text_location']             = 'Store Location';
$_['text_contact']              = 'Mail';
$_['text_marketing']            = 'Marketing';
$_['text_marketplace']          = 'Marketplace';
$_['text_maintenance']          = 'Maintenance';
$_['text_menu']                 = 'Menu Manager';
$_['text_modification']         = 'Modifications';
$_['text_manufacturer']         = 'Manufacturers';
$_['text_navigation']           = 'Navigation';
$_['text_option']               = 'Options';
$_['text_order']                = 'Orders';
$_['text_order_status']         = 'Order Statuses';
$_['text_online']               = 'Who\'s Online';
$_['text_product']              = 'Products';
$_['text_reports']              = 'Reports';
$_['text_review']               = 'Reviews';
$_['text_return']               = 'Returns';
$_['text_return_action']        = 'Return Actions';
$_['text_return_reason']        = 'Return Reasons';
$_['text_return_status']        = 'Return Statuses';
$_['text_sale']                 = 'Sales';
$_['text_setting']              = 'Settings';
$_['text_seo_url']              = 'SEO URL';
$_['text_statistics']           = 'Statistics';
$_['text_stock_status']         = 'Stock Statuses';
$_['text_system']               = 'System';
$_['text_tax']                  = 'Taxes';
$_['text_tax_class']            = 'Tax Classes';
$_['text_tax_rate']             = 'Tax Rates';
$_['text_translation']          = 'Translations';
$_['text_theme']                = 'Theme Editor';
$_['text_upload']               = 'Uploads';
$_['text_user']                 = 'Users';
$_['text_users']                = 'Users';
$_['text_user_group']           = 'User Groups';
$_['text_voucher']              = 'Gift Vouchers';
$_['text_voucher_theme']        = 'Voucher Themes';
$_['text_weight_class']         = 'Weight Classes';
$_['text_length_class']         = 'Length Classes';
$_['text_zone']                 = 'Zones';
$_['text_recurring']            = 'Recurring Profiles';
$_['text_order_recurring']      = 'Recurring Orders';
$_['text_openbay_extension']    = 'OpenBay Pro';
$_['text_openbay_dashboard']    = 'Dashboard';
$_['text_openbay_orders']       = 'Bulk order update';
$_['text_openbay_items']        = 'Manage items';
$_['text_openbay_ebay']         = 'eBay';
$_['text_openbay_amazon']       = 'Amazon (EU)';
$_['text_openbay_amazonus']     = 'Amazon (US)';
$_['text_openbay_etsy']         = 'Etsy';
$_['text_openbay_settings']     = 'Settings';
$_['text_openbay_links']        = 'Item links';
$_['text_openbay_report_price'] = 'Pricing report';
$_['text_openbay_order_import'] = 'Order import';
$_['text_paypal']               = 'PayPal';
$_['text_paypal_search']        = 'Search';
$_['text_complete_status']      = 'Orders Completed';
$_['text_processing_status']    = 'Orders Processing';
$_['text_other_status']         = 'Other Statuses';
