<div class="col-lg-6 col-md-12 col-sm-12">
  <div class="panel panel-default">
    <div class="panel-heading">
      <h3 class="panel-title"><img class="pull-right" width="135" src="https://www.paypalobjects.com/webstatic/en_US/i/buttons/PP_logo_h_200x51.png" alt="PayPal Logo"></h3>
      {% if payment_pp_express_status == "enabled" %}
        <div class="pull-right"><span class="label label-success">{{ text_enabled }}</span></div>
      {% endif %}
      {% if payment_pp_express_status == "disabled" %}
        <div class="pull-right"><span class="label label-danger">{{ text_disabled }}</span></div>
      {% endif %}
    </div>
    <div class="panel-body">
      <div class="row">
        <div class="col-lg-12 col-md-12 col-sm-12">
          <p>{{ text_preferred_main }} <a href="https://www.paypal.com/uk/webapps/mpp/express-checkout" target="_blank">{{ text_learn_more }}</a></p>
        </div>
      </div>
      <div class="row">
        <div class="col-lg-9 col-md-9 col-sm-9">
          <ul>
            <li>{{ text_preferred_li_1 }}</li>
            <li>{{ text_preferred_li_2 }}</li>
            <li>{{ text_preferred_li_3 }}</li>
            <li>{{ text_preferred_li_4 }}</li>
          </ul>
        </div>
        <div class="col-lg-3 col-md-3 col-sm-3">
          <p><img class="pull-right" src="view/image/payment/paypal-express-gold-pill.png" alt="PayPal Express" width="130" style="margin-bottom:10px;" /></p>

          {% if connect_link is not empty %}
              <p><a href="{{ connect_link }}" data-toggle="tooltip" title="" class="btn btn-primary pull-right" target="_blank" data-original-title="{{ text_connect_paypal }}">{{ text_connect_paypal }}</a></p>
          {% endif %}
          {% if module_link is not empty %}
              <p><a href="{{ module_link }}" data-toggle="tooltip" title="" class="btn btn-primary pull-right" data-original-title="{{ text_edit }}"><i class="fa fa-pencil"></i></a></p>
          {% endif %}
        </div>
      </div>
    </div>
  </div>
</div>
