<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;

/* oc01/template/product/product.twig */
class __TwigTemplate_b38ad104ce2758d412d79e07068eff30c45aa0ffd9293e432cc604d6a08c1151 extends \Twig\Template
{
    private $source;
    private $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = [])
    {
        $macros = $this->macros;
        // line 1
        echo ($context["header"] ?? null);
        echo "
<div id=\"product-product\" class=\"container product\">
  <ul class=\"breadcrumb\">
    ";
        // line 4
        $context['_parent'] = $context;
        $context['_seq'] = twig_ensure_traversable(($context["breadcrumbs"] ?? null));
        foreach ($context['_seq'] as $context["_key"] => $context["breadcrumb"]) {
            // line 5
            echo "    <li><a href=\"";
            echo twig_get_attribute($this->env, $this->source, $context["breadcrumb"], "href", [], "any", false, false, false, 5);
            echo "\">";
            echo twig_get_attribute($this->env, $this->source, $context["breadcrumb"], "text", [], "any", false, false, false, 5);
            echo "</a></li>
    ";
        }
        $_parent = $context['_parent'];
        unset($context['_seq'], $context['_iterated'], $context['_key'], $context['breadcrumb'], $context['_parent'], $context['loop']);
        $context = array_intersect_key($context, $_parent) + $_parent;
        // line 7
        echo "  </ul>
  <div class=\"row\">";
        // line 8
        echo ($context["column_left"] ?? null);
        echo "
    ";
        // line 9
        if ((($context["column_left"] ?? null) && ($context["column_right"] ?? null))) {
            // line 10
            echo "    ";
            $context["class"] = "col-sm-6";
            // line 11
            echo "    ";
        } elseif ((($context["column_left"] ?? null) || ($context["column_right"] ?? null))) {
            // line 12
            echo "    ";
            $context["class"] = "col-sm-9";
            // line 13
            echo "    ";
        } else {
            // line 14
            echo "    ";
            $context["class"] = "col-sm-12";
            // line 15
            echo "    ";
        }
        // line 16
        echo "    <div id=\"content\" class=\"productpage ";
        echo ($context["class"] ?? null);
        echo "\">";
        echo ($context["content_top"] ?? null);
        echo "
      <div class=\"row\">";
        // line 17
        if ((($context["column_left"] ?? null) || ($context["column_right"] ?? null))) {
            // line 18
            echo "        ";
            $context["class"] = "col-sm-6 left";
            // line 19
            echo "        ";
        } else {
            // line 20
            echo "        ";
            $context["class"] = "col-sm-6 col-md-5 left";
            // line 21
            echo "        ";
        }
        // line 22
        echo "        <div class=\"";
        echo ($context["class"] ?? null);
        echo "\">
         ";
        // line 23
        if ((($context["thumb"] ?? null) || ($context["images"] ?? null))) {
            // line 24
            echo "          <div class=\"thumbnails\">
            ";
            // line 25
            if (($context["thumb"] ?? null)) {
                // line 26
                echo "            <div class=\"image\"><a class=\"thumbnail\" href=\"";
                echo ($context["popup"] ?? null);
                echo "\" title=\"";
                echo ($context["heading_title"] ?? null);
                echo "\"><img id=\"zoom\" src=\"";
                echo ($context["thumb"] ?? null);
                echo "\" data-zoom-image=\"";
                echo ($context["popup"] ?? null);
                echo "\" title=\"";
                echo ($context["heading_title"] ?? null);
                echo "\" alt=\"";
                echo ($context["heading_title"] ?? null);
                echo "\" /></a></div>
             ";
            }
            // line 28
            echo "            ";
            if (($context["images"] ?? null)) {
                // line 29
                echo "             ";
                $context["sliderFor"] = 5;
                // line 30
                $context["imageCount"] = twig_length_filter($this->env, ($context["images"] ?? null));
                // line 31
                echo "            <div class=\"product-additional-block swiper-viewport\">
              ";
                // line 32
                if ((($context["imageCount"] ?? null) >= ($context["sliderFor"] ?? null))) {
                    // line 33
                    echo "              ";
                }
                // line 34
                echo "
              <div class=\"image-additional";
                // line 35
                if ((($context["imageCount"] ?? null) >= ($context["sliderFor"] ?? null))) {
                    echo " owl-carousel";
                }
                echo "\">

    \t\t\t<div class=\"item\">
                  <div class=\"product-thumb\"> <a href=\"";
                // line 38
                echo ($context["popup"] ?? null);
                echo "\" title=\"";
                echo ($context["heading_title"] ?? null);
                echo "\" class=\"elevatezoom-gallery\" data-image=\"";
                echo ($context["thumb"] ?? null);
                echo "\" data-zoom-image=\"";
                echo ($context["popup"] ?? null);
                echo "\"><img src=\"";
                echo ($context["thumb"] ?? null);
                echo "\" width=\"126\" height=\"151\" title=\"";
                echo ($context["heading_title"] ?? null);
                echo "\" alt=\"";
                echo ($context["heading_title"] ?? null);
                echo "\" /></a> </div>
                </div>
               ";
                // line 40
                $context['_parent'] = $context;
                $context['_seq'] = twig_ensure_traversable(($context["images"] ?? null));
                foreach ($context['_seq'] as $context["_key"] => $context["image"]) {
                    // line 41
                    echo "                <div class=\"item\">
                  <div class=\"product-thumb\"> <a href=\"";
                    // line 42
                    echo twig_get_attribute($this->env, $this->source, $context["image"], "popup", [], "any", false, false, false, 42);
                    echo "\" title=\"";
                    echo ($context["heading_title"] ?? null);
                    echo "\" class=\"elevatezoom-gallery\" data-image=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["image"], "thumb", [], "any", false, false, false, 42);
                    echo "\" data-zoom-image=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["image"], "popup", [], "any", false, false, false, 42);
                    echo "\"><img src=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["image"], "thumb", [], "any", false, false, false, 42);
                    echo "\" width=\"126\" height=\"151\" title=\"";
                    echo ($context["heading_title"] ?? null);
                    echo "\" alt=\"";
                    echo ($context["heading_title"] ?? null);
                    echo "\" /></a> </div>
                </div>
                ";
                }
                $_parent = $context['_parent'];
                unset($context['_seq'], $context['_iterated'], $context['_key'], $context['image'], $context['_parent'], $context['loop']);
                $context = array_intersect_key($context, $_parent) + $_parent;
                // line 45
                echo "              </div>

            </div>
            ";
            }
            // line 49
            echo "

           </div>
            ";
        }
        // line 53
        echo "          </div>
         ";
        // line 54
        if ((($context["column_left"] ?? null) || ($context["column_right"] ?? null))) {
            // line 55
            echo "        ";
            $context["class"] = "col-sm-6 right";
            // line 56
            echo "        ";
        } else {
            // line 57
            echo "        ";
            $context["class"] = "col-sm-6 col-md-7 right";
            // line 58
            echo "        ";
        }
        // line 59
        echo "        <div class=\"";
        echo ($context["class"] ?? null);
        echo "\">
         <h1>";
        // line 60
        echo ($context["heading_title"] ?? null);
        echo "</h1>
         <h2 class=\"product-title\">";
        // line 61
        echo ($context["heading_title"] ?? null);
        echo "</h2>
         ";
        // line 62
        if (($context["price"] ?? null)) {
            // line 63
            echo "          <ul class=\"list-unstyled price\">
            ";
            // line 64
            if ( !($context["special"] ?? null)) {
                // line 65
                echo "            <li>
              <h2 class=\"product-price\"><span class=\"";
                // line 66
                echo twig_get_attribute($this->env, $this->source, ($context["module_live_options"] ?? null), "module_live_options_price_container", [], "any", false, false, false, 66);
                echo "\">";
                echo ($context["price"] ?? null);
                echo "</span></h2>
            </li>
            ";
            } else {
                // line 69
                echo "            <li class=\"oldprice\"><span class=\"old-price\" style=\"text-decoration: line-through;\">";
                echo ($context["price"] ?? null);
                echo "</span></li>
            <li>
              <h2 class=\"special-price\"><span class=\"";
                // line 71
                echo twig_get_attribute($this->env, $this->source, ($context["module_live_options"] ?? null), "module_live_options_special_container", [], "any", false, false, false, 71);
                echo "\">";
                echo ($context["special"] ?? null);
                echo "</span></h2>
            </li>
            ";
            }
            // line 74
            echo "          </ul>
          ";
        }
        // line 76
        echo "          ";
        if (($context["review_status"] ?? null)) {
            // line 77
            echo "          <div class=\"rating\">
            <p>";
            // line 78
            $context['_parent'] = $context;
            $context['_seq'] = twig_ensure_traversable(range(1, 5));
            foreach ($context['_seq'] as $context["_key"] => $context["i"]) {
                // line 79
                echo "              ";
                if ((($context["rating"] ?? null) < $context["i"])) {
                    echo "<span class=\"fa fa-stack\"><i class=\"fa fa-star fa-stack-2x blank\"></i></span>";
                } else {
                    echo "<span class=\"fa fa-stack\"><i class=\"fa fa-star fa-stack-1x\"></i>
        </span>";
                }
                // line 81
                echo "               ";
            }
            $_parent = $context['_parent'];
            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['i'], $context['_parent'], $context['loop']);
            $context = array_intersect_key($context, $_parent) + $_parent;
            echo " <a class=\"ratings-link\" href=\"\" onclick=\"\$('a[href=\\'#tab-review\\']').trigger('click'); return false;\">";
            echo ($context["reviews"] ?? null);
            echo "</a> </p>
               </div>
          ";
        }
        // line 84
        echo "\t\t  <ul class=\"list-unstyled detail\">
            ";
        // line 85
        if (($context["manufacturer"] ?? null)) {
            // line 86
            echo "            <li class=\"manufacturer\">
              <div class=\"label\">";
            // line 87
            echo ($context["text_manufacturer"] ?? null);
            echo "</div>
              <a href=\"";
            // line 88
            echo ($context["manufacturers"] ?? null);
            echo "\">";
            echo ($context["manufacturer"] ?? null);
            echo "</a></li>
            ";
        }
        // line 90
        echo "            <li class=\"model\">
              <div class=\"label\">";
        // line 91
        echo ($context["text_model"] ?? null);
        echo " </div>
              ";
        // line 92
        echo ($context["model"] ?? null);
        echo "</li>



            ";
        // line 96
        if (($context["reward"] ?? null)) {
            // line 97
            echo "            <li class=\"reward\">
              <div class=\"label\">";
            // line 98
            echo ($context["text_reward"] ?? null);
            echo "</div>
              <span class=\"";
            // line 99
            echo twig_get_attribute($this->env, $this->source, ($context["module_live_options"] ?? null), "module_live_options_reward_container", [], "any", false, false, false, 99);
            echo "\">";
            echo ($context["reward"] ?? null);
            echo "</span></li>
            ";
        }
        // line 101
        echo "            <li class=\"stock\">

              ";
        // line 103
        echo ($context["stock"] ?? null);
        echo "</li>

                <!--<li class=\"quantity\">
                <div class=\"label\">";
        // line 106
        echo ($context["text_quntity"] ?? null);
        echo " </div>
              ";
        // line 107
        echo ($context["quantity"] ?? null);
        echo "</li>-->
          </ul>
\t\t  ";
        // line 109
        if (($context["price"] ?? null)) {
            // line 110
            echo "          <ul class=\"list-unstyled price2\">
            ";
            // line 111
            if (($context["tax"] ?? null)) {
                // line 112
                echo "            <li class=\"tax\">";
                echo ($context["text_tax"] ?? null);
                echo "<span> <span class=\"";
                echo twig_get_attribute($this->env, $this->source, ($context["module_live_options"] ?? null), "module_live_options_tax_container", [], "any", false, false, false, 112);
                echo "\">";
                echo ($context["tax"] ?? null);
                echo "</span></span></li>
            ";
            }
            // line 114
            echo "            ";
            if (($context["points"] ?? null)) {
                // line 115
                echo "            <li class=\"point\">";
                echo ($context["text_points"] ?? null);
                echo "<span class=\"";
                echo twig_get_attribute($this->env, $this->source, ($context["module_live_options"] ?? null), "module_live_options_points_container", [], "any", false, false, false, 115);
                echo "\">";
                echo ($context["points"] ?? null);
                echo "</span></li>
            ";
            }
            // line 117
            echo "            ";
            if (($context["discounts"] ?? null)) {
                // line 118
                echo "            ";
                $context['_parent'] = $context;
                $context['_seq'] = twig_ensure_traversable(($context["discounts"] ?? null));
                foreach ($context['_seq'] as $context["_key"] => $context["discount"]) {
                    // line 119
                    echo "            <li class=\"discount\">";
                    echo twig_get_attribute($this->env, $this->source, $context["discount"], "quantity", [], "any", false, false, false, 119);
                    echo ($context["text_discount"] ?? null);
                    echo twig_get_attribute($this->env, $this->source, $context["discount"], "price", [], "any", false, false, false, 119);
                    echo "</li>
            ";
                }
                $_parent = $context['_parent'];
                unset($context['_seq'], $context['_iterated'], $context['_key'], $context['discount'], $context['_parent'], $context['loop']);
                $context = array_intersect_key($context, $_parent) + $_parent;
                // line 121
                echo "            ";
            }
            // line 122
            echo "          </ul>
          ";
        }
        // line 124
        echo "
          <div id=\"product\">

           ";
        // line 127
        if (($context["options"] ?? null)) {
            // line 128
            echo "

            ";
            // line 130
            echo ($context["prodoptimg_module"] ?? null);
            echo "
\t\t";
            // line 131
            $context['_parent'] = $context;
            $context['_seq'] = twig_ensure_traversable(($context["options"] ?? null));
            foreach ($context['_seq'] as $context["_key"] => $context["option"]) {
                // line 132
                echo "            ";
                if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 132) == "select")) {
                    // line 133
                    echo "             <div class=\"form-group";
                    if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 133)) {
                        echo " required ";
                    }
                    echo "\">
              <label class=\"control-label\">";
                    // line 134
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 134);
                    echo "</label>
              <div id=\"input-option";
                    // line 135
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 135);
                    echo "\"> ";
                    $context['_parent'] = $context;
                    $context['_seq'] = twig_ensure_traversable(twig_get_attribute($this->env, $this->source, $context["option"], "product_option_value", [], "any", false, false, false, 135));
                    foreach ($context['_seq'] as $context["_key"] => $context["option_value"]) {
                        // line 136
                        echo "                <div class=\"radio\">
                  <label>
                    <input type=\"radio\" name=\"option[";
                        // line 138
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 138);
                        echo "]\" value=\"";
                        echo twig_get_attribute($this->env, $this->source, $context["option_value"], "product_option_value_id", [], "any", false, false, false, 138);
                        echo "\" />
                    ";
                        // line 139
                        if (twig_get_attribute($this->env, $this->source, $context["option_value"], "image", [], "any", false, false, false, 139)) {
                            echo " <img src=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "image", [], "any", false, false, false, 139);
                            echo "\" alt=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 139);
                            echo " ";
                            if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 139)) {
                                echo " ";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 139);
                                echo " ";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 139);
                                echo " ";
                            }
                            echo "\" class=\"img-thumbnail\" /> ";
                        }
                        // line 140
                        echo "                    ";
                        echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 140);
                        echo "
                    ";
                        // line 141
                        if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 141)) {
                            // line 142
                            echo "                    <span class=\"pull-right\">";
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 142);
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 142);
                            echo "</span>
                    ";
                        }
                        // line 143
                        echo " </label>
                </div>
                ";
                    }
                    $_parent = $context['_parent'];
                    unset($context['_seq'], $context['_iterated'], $context['_key'], $context['option_value'], $context['_parent'], $context['loop']);
                    $context = array_intersect_key($context, $_parent) + $_parent;
                    // line 145
                    echo " </div>
            </div>
            ";
                }
                // line 148
                echo "            ";
                if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 148) == "radio")) {
                    // line 149
                    echo "            <div class=\"form-group";
                    if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 149)) {
                        echo " required ";
                    }
                    echo "\">
              <label class=\"control-label\">";
                    // line 150
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 150);
                    echo "</label>
              <div id=\"input-option";
                    // line 151
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 151);
                    echo "\"> ";
                    $context['_parent'] = $context;
                    $context['_seq'] = twig_ensure_traversable(twig_get_attribute($this->env, $this->source, $context["option"], "product_option_value", [], "any", false, false, false, 151));
                    foreach ($context['_seq'] as $context["_key"] => $context["option_value"]) {
                        // line 152
                        echo "                <div class=\"radio\">
                  <label>
                    <input type=\"radio\" name=\"option[";
                        // line 154
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 154);
                        echo "]\" value=\"";
                        echo twig_get_attribute($this->env, $this->source, $context["option_value"], "product_option_value_id", [], "any", false, false, false, 154);
                        echo "\" />
                    ";
                        // line 155
                        if (twig_get_attribute($this->env, $this->source, $context["option_value"], "image", [], "any", false, false, false, 155)) {
                            echo " <img src=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "image", [], "any", false, false, false, 155);
                            echo "\" alt=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 155);
                            echo " ";
                            if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 155)) {
                                echo " ";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 155);
                                echo " ";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 155);
                                echo " ";
                            }
                            echo "\" class=\"img-thumbnail\" /> ";
                        }
                        // line 156
                        echo "                    ";
                        echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 156);
                        echo "
                    ";
                        // line 157
                        if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 157)) {
                            // line 158
                            echo "                    (";
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 158);
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 158);
                            echo ")
                    ";
                        }
                        // line 159
                        echo " </label>
                </div>
                ";
                    }
                    $_parent = $context['_parent'];
                    unset($context['_seq'], $context['_iterated'], $context['_key'], $context['option_value'], $context['_parent'], $context['loop']);
                    $context = array_intersect_key($context, $_parent) + $_parent;
                    // line 161
                    echo " </div>
            </div>
            ";
                }
                // line 164
                echo "            ";
                if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 164) == "checkbox")) {
                    // line 165
                    echo "            <div class=\"form-group";
                    if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 165)) {
                        echo " required ";
                    }
                    echo "\">
              <label class=\"control-label\">";
                    // line 166
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 166);
                    echo "</label>
              <div id=\"input-option";
                    // line 167
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 167);
                    echo "\"> ";
                    $context['_parent'] = $context;
                    $context['_seq'] = twig_ensure_traversable(twig_get_attribute($this->env, $this->source, $context["option"], "product_option_value", [], "any", false, false, false, 167));
                    foreach ($context['_seq'] as $context["_key"] => $context["option_value"]) {
                        // line 168
                        echo "                <div class=\"checkbox\">
                  <label>
                    <input type=\"checkbox\" name=\"option[";
                        // line 170
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 170);
                        echo "][]\" value=\"";
                        echo twig_get_attribute($this->env, $this->source, $context["option_value"], "product_option_value_id", [], "any", false, false, false, 170);
                        echo "\" />
                    ";
                        // line 171
                        if (twig_get_attribute($this->env, $this->source, $context["option_value"], "image", [], "any", false, false, false, 171)) {
                            echo " <img src=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "image", [], "any", false, false, false, 171);
                            echo "\" alt=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 171);
                            echo " ";
                            if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 171)) {
                                echo " ";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 171);
                                echo " ";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 171);
                                echo " ";
                            }
                            echo "\" class=\"img-thumbnail\" /> ";
                        }
                        // line 172
                        echo "                    ";
                        echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 172);
                        echo "
                    ";
                        // line 173
                        if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 173)) {
                            // line 174
                            echo "                    (";
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 174);
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 174);
                            echo ")
                    ";
                        }
                        // line 175
                        echo " </label>
                </div>
                ";
                    }
                    $_parent = $context['_parent'];
                    unset($context['_seq'], $context['_iterated'], $context['_key'], $context['option_value'], $context['_parent'], $context['loop']);
                    $context = array_intersect_key($context, $_parent) + $_parent;
                    // line 177
                    echo " </div>
            </div>
            ";
                }
                // line 180
                echo "            ";
                if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 180) == "text")) {
                    // line 181
                    echo "            <div class=\"form-group";
                    if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 181)) {
                        echo " required ";
                    }
                    echo "\">
              <label class=\"control-label\" for=\"input-option";
                    // line 182
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 182);
                    echo "\">";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 182);
                    echo "</label>
              <input type=\"text\" name=\"option[";
                    // line 183
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 183);
                    echo "]\" value=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 183);
                    echo "\" placeholder=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 183);
                    echo "\" id=\"input-option";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 183);
                    echo "\" class=\"form-control\" />
            </div>
            ";
                }
                // line 186
                echo "            ";
                if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 186) == "textarea")) {
                    // line 187
                    echo "            <div class=\"form-group";
                    if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 187)) {
                        echo " required ";
                    }
                    echo "\">
              <label class=\"control-label\" for=\"input-option";
                    // line 188
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 188);
                    echo "\">";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 188);
                    echo "</label>
              <textarea name=\"option[";
                    // line 189
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 189);
                    echo "]\" rows=\"5\" placeholder=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 189);
                    echo "\" id=\"input-option";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 189);
                    echo "\" class=\"form-control\">";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 189);
                    echo "</textarea>
            </div>
            ";
                }
                // line 192
                echo "            ";
                if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 192) == "file")) {
                    // line 193
                    echo "            <div class=\"form-group";
                    if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 193)) {
                        echo " required ";
                    }
                    echo "\">
              <label class=\"control-label\">";
                    // line 194
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 194);
                    echo "</label>
              <button type=\"button\" id=\"button-upload";
                    // line 195
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 195);
                    echo "\" data-loading-text=\"";
                    echo ($context["text_loading"] ?? null);
                    echo "\" class=\"btn btn-default btn-block\"><i class=\"fa fa-upload\"></i> ";
                    echo ($context["button_upload"] ?? null);
                    echo "</button>
              <input type=\"hidden\" name=\"option[";
                    // line 196
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 196);
                    echo "]\" value=\"\" id=\"input-option";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 196);
                    echo "\" />
            </div>
            ";
                }
                // line 199
                echo "            ";
                if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 199) == "date")) {
                    // line 200
                    echo "            <div class=\"form-group";
                    if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 200)) {
                        echo " required ";
                    }
                    echo "\">
              <label class=\"control-label\" for=\"input-option";
                    // line 201
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 201);
                    echo "\">";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 201);
                    echo "</label>
              <div class=\"input-group date\">
                <input type=\"text\" name=\"option[";
                    // line 203
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 203);
                    echo "]\" value=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 203);
                    echo "\" data-date-format=\"YYYY-MM-DD\" id=\"input-option";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 203);
                    echo "\" class=\"form-control\" />
                <span class=\"input-group-btn\">
                <button class=\"btn btn-default\" type=\"button\"><i class=\"fa fa-calendar\"></i></button>
                </span></div>
            </div>
            ";
                }
                // line 209
                echo "            ";
                if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 209) == "datetime")) {
                    // line 210
                    echo "            <div class=\"form-group";
                    if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 210)) {
                        echo " required ";
                    }
                    echo "\">
              <label class=\"control-label\" for=\"input-option";
                    // line 211
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 211);
                    echo "\">";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 211);
                    echo "</label>
              <div class=\"input-group datetime\">
                <input type=\"text\" name=\"option[";
                    // line 213
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 213);
                    echo "]\" value=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 213);
                    echo "\" data-date-format=\"YYYY-MM-DD HH:mm\" id=\"input-option";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 213);
                    echo "\" class=\"form-control\" />
                <span class=\"input-group-btn\">
                <button type=\"button\" class=\"btn btn-default\"><i class=\"fa fa-calendar\"></i></button>
                </span></div>
            </div>
            ";
                }
                // line 219
                echo "            ";
                if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 219) == "time")) {
                    // line 220
                    echo "            <div class=\"form-group";
                    if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 220)) {
                        echo " required ";
                    }
                    echo "\">
              <label class=\"control-label\" for=\"input-option";
                    // line 221
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 221);
                    echo "\">";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 221);
                    echo "</label>
              <div class=\"input-group time\">
                <input type=\"text\" name=\"option[";
                    // line 223
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 223);
                    echo "]\" value=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 223);
                    echo "\" data-date-format=\"HH:mm\" id=\"input-option";
                    echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 223);
                    echo "\" class=\"form-control\" />
                <span class=\"input-group-btn\">
                <button type=\"button\" class=\"btn btn-default\"><i class=\"fa fa-calendar\"></i></button>
                </span></div>
            </div>
            ";
                }
                // line 229
                echo "            ";
            }
            $_parent = $context['_parent'];
            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['option'], $context['_parent'], $context['loop']);
            $context = array_intersect_key($context, $_parent) + $_parent;
            // line 230
            echo "            ";
        }
        // line 231
        echo "            ";
        if (($context["recurrings"] ?? null)) {
            // line 232
            echo "            <hr>
            <h3>";
            // line 233
            echo ($context["text_payment_recurring"] ?? null);
            echo "</h3>
            <div class=\"form-group required\">
              <select name=\"recurring_id\" class=\"form-control\">
                <option value=\"\">";
            // line 236
            echo ($context["text_select"] ?? null);
            echo "</option>
                ";
            // line 237
            $context['_parent'] = $context;
            $context['_seq'] = twig_ensure_traversable(($context["recurrings"] ?? null));
            foreach ($context['_seq'] as $context["_key"] => $context["recurring"]) {
                // line 238
                echo "                <option value=\"";
                echo twig_get_attribute($this->env, $this->source, $context["recurring"], "recurring_id", [], "any", false, false, false, 238);
                echo "\">";
                echo twig_get_attribute($this->env, $this->source, $context["recurring"], "name", [], "any", false, false, false, 238);
                echo "</option>
                ";
            }
            $_parent = $context['_parent'];
            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['recurring'], $context['_parent'], $context['loop']);
            $context = array_intersect_key($context, $_parent) + $_parent;
            // line 240
            echo "              </select>
              <div class=\"help-block\" id=\"recurring-description\"></div>
            </div>
            ";
        }
        // line 244
        echo "           <div class=\"form-group\">
              <label class=\"control-label\" for=\"input-quantity\">";
        // line 245
        echo ($context["entry_qty"] ?? null);
        echo "</label>
              <input type=\"text\" name=\"quantity\" value=\"";
        // line 246
        echo ($context["minimum"] ?? null);
        echo "\" size=\"2\" id=\"input-quantity\" class=\"form-control\" />
              <input type=\"hidden\" name=\"product_id\" value=\"";
        // line 247
        echo ($context["product_id"] ?? null);
        echo "\" />
              <button type=\"button\" id=\"button-cart\" data-loading-text=\"";
        // line 248
        echo ($context["text_loading"] ?? null);
        echo "\" class=\"btn btn-primary btn-lg btn-block addtocart\">";
        echo ($context["button_cart"] ?? null);
        echo "</button>
               <div class=\"btn-group\">
               <button type=\"button\" data-toggle=\"tooltip\" class=\"btn btn-default wishlist\" title=\"";
        // line 250
        echo ($context["button_wishlist"] ?? null);
        echo "\" onclick=\"wishlist.add('";
        echo ($context["product_id"] ?? null);
        echo "');\"><i class=\"fa fa-heart\"></i>";
        echo ($context["button_wishlist"] ?? null);
        echo "</button>
                <button type=\"button\" data-toggle=\"tooltip\" class=\"btn btn-default compare\" title=\"";
        // line 251
        echo ($context["button_compare"] ?? null);
        echo "\" onclick=\"compare.add('";
        echo ($context["product_id"] ?? null);
        echo "');\"><i class=\"fa fa-exchange\"></i>";
        echo ($context["button_compare"] ?? null);
        echo "</button>
              </div>

            </div>
            ";
        // line 255
        if ((($context["minimum"] ?? null) > 1)) {
            // line 256
            echo "            <div class=\"alert alert-info\"><i class=\"fa fa-info-circle\"></i> ";
            echo ($context["text_minimum"] ?? null);
            echo "</div>
            ";
        }
        // line 257
        echo "</div>
          ";
        // line 258
        if (($context["review_status"] ?? null)) {
            // line 259
            echo "

                <!-- Go to www.addthis.com/dashboard to customize your tools -->
                <div class=\"addthis_inline_share_toolbox\"></div>


          </div>
          ";
        }
        // line 266
        echo " </div>


        ";
        // line 269
        if ((($context["column_left"] ?? null) && ($context["column_right"] ?? null))) {
            // line 270
            echo "        ";
            $context["class"] = "col-sm-6";
            // line 271
            echo "        ";
        } elseif ((($context["column_left"] ?? null) || ($context["column_right"] ?? null))) {
            // line 272
            echo "        ";
            $context["class"] = "col-sm-12 producttab";
            // line 273
            echo "        ";
        } else {
            // line 274
            echo "        ";
            $context["class"] = "col-sm-12 producttab";
            // line 275
            echo "        ";
        }
        // line 276
        echo "        <div class=\"";
        echo ($context["class"] ?? null);
        echo "\">
\t  <ul class=\"nav nav-tabs\">
            <li class=\"active\"><a href=\"#tab-description\" data-toggle=\"tab\">";
        // line 278
        echo ($context["tab_description"] ?? null);
        echo "</a></li>
            ";
        // line 279
        if (($context["attribute_groups"] ?? null)) {
            // line 280
            echo "            <li><a href=\"#tab-specification\" data-toggle=\"tab\">";
            echo ($context["tab_attribute"] ?? null);
            echo "</a></li>
            ";
        }
        // line 282
        echo "            ";
        if (($context["review_status"] ?? null)) {
            // line 283
            echo "            <li><a href=\"#tab-review\" data-toggle=\"tab\">";
            echo ($context["tab_review"] ?? null);
            echo "</a></li>
            ";
        }
        // line 285
        echo "          </ul>
          <div class=\"tab-content\">
            <div class=\"tab-pane active\" id=\"tab-description\">";
        // line 287
        echo ($context["description"] ?? null);
        echo "</div>
            ";
        // line 288
        if (($context["attribute_groups"] ?? null)) {
            // line 289
            echo "            <div class=\"tab-pane\" id=\"tab-specification\">
              <table class=\"table table-bordered\">
                ";
            // line 291
            $context['_parent'] = $context;
            $context['_seq'] = twig_ensure_traversable(($context["attribute_groups"] ?? null));
            foreach ($context['_seq'] as $context["_key"] => $context["attribute_group"]) {
                // line 292
                echo "                <thead>
                  <tr>
                    <td colspan=\"2\"><strong>";
                // line 294
                echo twig_get_attribute($this->env, $this->source, $context["attribute_group"], "name", [], "any", false, false, false, 294);
                echo "</strong></td>
                  </tr>
                </thead>
                <tbody>
                ";
                // line 298
                $context['_parent'] = $context;
                $context['_seq'] = twig_ensure_traversable(twig_get_attribute($this->env, $this->source, $context["attribute_group"], "attribute", [], "any", false, false, false, 298));
                foreach ($context['_seq'] as $context["_key"] => $context["attribute"]) {
                    // line 299
                    echo "                <tr>
                  <td>";
                    // line 300
                    echo twig_get_attribute($this->env, $this->source, $context["attribute"], "name", [], "any", false, false, false, 300);
                    echo "</td>
                  <td>";
                    // line 301
                    echo twig_get_attribute($this->env, $this->source, $context["attribute"], "text", [], "any", false, false, false, 301);
                    echo "</td>
                </tr>
                ";
                }
                $_parent = $context['_parent'];
                unset($context['_seq'], $context['_iterated'], $context['_key'], $context['attribute'], $context['_parent'], $context['loop']);
                $context = array_intersect_key($context, $_parent) + $_parent;
                // line 304
                echo "                  </tbody>
                ";
            }
            $_parent = $context['_parent'];
            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['attribute_group'], $context['_parent'], $context['loop']);
            $context = array_intersect_key($context, $_parent) + $_parent;
            // line 306
            echo "              </table>
            </div>
            ";
        }
        // line 309
        echo "            ";
        if (($context["review_status"] ?? null)) {
            // line 310
            echo "            <div class=\"tab-pane\" id=\"tab-review\">
              <form class=\"form-horizontal\" id=\"form-review\">
                <div id=\"review\"></div>
                <h2>";
            // line 313
            echo ($context["text_write"] ?? null);
            echo "</h2>
                ";
            // line 314
            if (($context["review_guest"] ?? null)) {
                // line 315
                echo "                <div class=\"form-group required\">
                  <div class=\"col-sm-12\">
                    <label class=\"control-label\" for=\"input-name\">";
                // line 317
                echo ($context["entry_name"] ?? null);
                echo "</label>
                    <input type=\"text\" name=\"name\" value=\"";
                // line 318
                echo ($context["customer_name"] ?? null);
                echo "\" id=\"input-name\" class=\"form-control\" />
                  </div>
                </div>
                <div class=\"form-group required\">
                  <div class=\"col-sm-12\">
                    <label class=\"control-label\" for=\"input-review\">";
                // line 323
                echo ($context["entry_review"] ?? null);
                echo "</label>
                    <textarea name=\"text\" rows=\"5\" id=\"input-review\" class=\"form-control\"></textarea>
                    <div class=\"help-block\">";
                // line 325
                echo ($context["text_note"] ?? null);
                echo "</div>
                  </div>
                </div>
                <div class=\"form-group required\">
                  <div class=\"col-sm-12\">
                    <label class=\"control-label\">";
                // line 330
                echo ($context["entry_rating"] ?? null);
                echo "</label>
                    &nbsp;&nbsp;&nbsp; ";
                // line 331
                echo ($context["entry_bad"] ?? null);
                echo "&nbsp;
                    <input type=\"radio\" name=\"rating\" value=\"1\" />
                    &nbsp;
                    <input type=\"radio\" name=\"rating\" value=\"2\" />
                    &nbsp;
                    <input type=\"radio\" name=\"rating\" value=\"3\" />
                    &nbsp;
                    <input type=\"radio\" name=\"rating\" value=\"4\" />
                    &nbsp;
                    <input type=\"radio\" name=\"rating\" value=\"5\" />
                    &nbsp;";
                // line 341
                echo ($context["entry_good"] ?? null);
                echo "</div>
                </div>
                ";
                // line 343
                echo ($context["captcha"] ?? null);
                echo "
                <div class=\"buttons clearfix\">
                  <div class=\"pull-right\">
                    <button type=\"button\" id=\"button-review\" data-loading-text=\"";
                // line 346
                echo ($context["text_loading"] ?? null);
                echo "\" class=\"btn btn-primary\">";
                echo ($context["button_continue"] ?? null);
                echo "</button>
                  </div>
                </div>
                ";
            } else {
                // line 350
                echo "                ";
                echo ($context["text_login"] ?? null);
                echo "
                ";
            }
            // line 352
            echo "              </form>
            </div>
            ";
        }
        // line 354
        echo "</div>
        </div>




      ";
        // line 360
        if (($context["products"] ?? null)) {
            // line 361
            echo "   <div class=\"section related wow fadeInUp\" data-wow-duration=\"0.5s\" data-wow-delay=\"0.5s\">
<div class=\"section-heading\">";
            // line 362
            echo ($context["text_related"] ?? null);
            echo "</div>
";
            // line 363
            $context["sliderFor"] = 5;
            // line 364
            $context["productCount"] = twig_length_filter($this->env, ($context["products"] ?? null));
            // line 365
            echo "
<div class=\"section-block\">
<div class=\"section-product ";
            // line 367
            if ((($context["productCount"] ?? null) >= ($context["sliderFor"] ?? null))) {
                echo "section-product product-carousel";
            } else {
                echo " grid ";
            }
            echo "\">
";
            // line 368
            $context['_parent'] = $context;
            $context['_seq'] = twig_ensure_traversable(($context["products"] ?? null));
            foreach ($context['_seq'] as $context["_key"] => $context["product"]) {
                // line 369
                echo "
<div class=\"";
                // line 370
                if ((($context["productCount"] ?? null) >= ($context["sliderFor"] ?? null))) {
                    echo " slider-item ";
                } else {
                    echo " product-items col-xs-4 col-sm-4 col-md-3 col-lg-3";
                }
                echo "\">
<div class=\"product-thumb transition\">
     ";
                // line 372
                if (twig_get_attribute($this->env, $this->source, $context["product"], "tag_per", [], "any", false, false, false, 372)) {
                    // line 373
                    echo "      <p class=\"tag\">";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "tag_per", [], "any", false, false, false, 373);
                    echo "<br/> % <br/> <i>off</i></p>
      ";
                }
                // line 375
                echo "<div class=\"image\">
    ";
                // line 376
                if (twig_get_attribute($this->env, $this->source, $context["product"], "thumb_swap", [], "any", false, false, false, 376)) {
                    // line 377
                    echo "    <div class=\"first_image\"> <a href=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "href", [], "any", false, false, false, 377);
                    echo "\"> <img src=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "thumb", [], "any", false, false, false, 377);
                    echo "\" alt=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 377);
                    echo "\" title=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 377);
                    echo "\" class=\"img-responsive\" /> </a> </div>
    <div class=\"swap_image\"> <a href=\"";
                    // line 378
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "href", [], "any", false, false, false, 378);
                    echo "\"> <img src=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "thumb_swap", [], "any", false, false, false, 378);
                    echo "\" alt=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 378);
                    echo "\" title=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 378);
                    echo "\" class=\"img-responsive\" /> </a></div>
  ";
                } else {
                    // line 380
                    echo "  <a href=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "href", [], "any", false, false, false, 380);
                    echo "\"> <img src=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "thumb", [], "any", false, false, false, 380);
                    echo "\" alt=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 380);
                    echo "\" title=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 380);
                    echo "\" /> </a>
  ";
                }
                // line 382
                echo "
  ";
                // line 383
                if ( !twig_get_attribute($this->env, $this->source, $context["product"], "special", [], "any", false, false, false, 383)) {
                    // line 384
                    echo "  ";
                } else {
                    // line 385
                    echo "  <div class=\"saleback\"> <span class=\"sale\">";
                    echo ($context["text_sale"] ?? null);
                    echo "</span> </div>
  ";
                }
                // line 387
                echo "
  ";
                // line 388
                if (twig_get_attribute($this->env, $this->source, $context["product"], "rating", [], "any", false, false, false, 388)) {
                    // line 389
                    echo "  <div class=\"rating\">
  ";
                    // line 390
                    $context['_parent'] = $context;
                    $context['_seq'] = twig_ensure_traversable(range(1, 5));
                    foreach ($context['_seq'] as $context["_key"] => $context["i"]) {
                        // line 391
                        echo "  ";
                        if ((twig_get_attribute($this->env, $this->source, $context["product"], "rating", [], "any", false, false, false, 391) < $context["i"])) {
                            echo " <span class=\"fa fa-stack\">
  <i class=\"fa fa-star fa-stack-2x blank\"></i></span>
  ";
                        } else {
                            // line 393
                            echo " <span class=\"fa fa-stack\"><i class=\"fa fa-star fa-stack-2x\"></i></span> ";
                        }
                        // line 394
                        echo "  ";
                    }
                    $_parent = $context['_parent'];
                    unset($context['_seq'], $context['_iterated'], $context['_key'], $context['i'], $context['_parent'], $context['loop']);
                    $context = array_intersect_key($context, $_parent) + $_parent;
                    // line 395
                    echo "  </div>
  ";
                }
                // line 397
                echo "
</div>
<div class=\"product-details\">
<div class=\"caption\">

  <h4><a href=\"";
                // line 402
                echo twig_get_attribute($this->env, $this->source, $context["product"], "href", [], "any", false, false, false, 402);
                echo "\">";
                echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 402);
                echo "</a></h4>
  ";
                // line 403
                if (twig_get_attribute($this->env, $this->source, $context["product"], "price", [], "any", false, false, false, 403)) {
                    // line 404
                    echo "  <p class=\"price\">
  ";
                    // line 405
                    if ( !twig_get_attribute($this->env, $this->source, $context["product"], "special", [], "any", false, false, false, 405)) {
                        // line 406
                        echo "  ";
                        echo twig_get_attribute($this->env, $this->source, $context["product"], "price", [], "any", false, false, false, 406);
                        echo "
  ";
                    } else {
                        // line 408
                        echo "  <span class=\"price-new\">";
                        echo twig_get_attribute($this->env, $this->source, $context["product"], "special", [], "any", false, false, false, 408);
                        echo "</span> <span class=\"price-old\">";
                        echo twig_get_attribute($this->env, $this->source, $context["product"], "price", [], "any", false, false, false, 408);
                        echo "</span>
  ";
                    }
                    // line 410
                    echo "  ";
                    if (twig_get_attribute($this->env, $this->source, $context["product"], "tax", [], "any", false, false, false, 410)) {
                        // line 411
                        echo "  <span class=\"price-tax\">";
                        echo ($context["text_tax"] ?? null);
                        echo " ";
                        echo twig_get_attribute($this->env, $this->source, $context["product"], "tax", [], "any", false, false, false, 411);
                        echo "</span>
  ";
                    }
                    // line 413
                    echo "  </p>
  ";
                }
                // line 415
                echo "   <div id=\"product-";
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 415);
                echo "\" class=\"product_option\"> ";
                if (($context["options"] ?? null)) {
                    // line 416
                    echo "

        ";
                    // line 418
                    $context['_parent'] = $context;
                    $context['_seq'] = twig_ensure_traversable(twig_get_attribute($this->env, $this->source, $context["product"], "options", [], "any", false, false, false, 418));
                    foreach ($context['_seq'] as $context["_key"] => $context["option"]) {
                        // line 419
                        echo "           ";
                        if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 419) == "select")) {
                            // line 420
                            echo "            <div class=\"form-group";
                            if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 420)) {
                                echo " required ";
                            }
                            echo "\">
              <select name=\"option[";
                            // line 421
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 421);
                            echo "]\" id=\"input-option";
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 421);
                            echo "\" class=\"form-control\">
                <option value=\"\">";
                            // line 422
                            echo ($context["text_select"] ?? null);
                            echo "</option>
                ";
                            // line 423
                            $context['_parent'] = $context;
                            $context['_seq'] = twig_ensure_traversable(twig_get_attribute($this->env, $this->source, $context["option"], "product_option_value", [], "any", false, false, false, 423));
                            foreach ($context['_seq'] as $context["_key"] => $context["option_value"]) {
                                // line 424
                                echo "                <option value=\"";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "product_option_value_id", [], "any", false, false, false, 424);
                                echo "\">";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 424);
                                echo "
                ";
                                // line 425
                                if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 425)) {
                                    // line 426
                                    echo "                (";
                                    echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 426);
                                    echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 426);
                                    echo ")
                ";
                                }
                                // line 427
                                echo " </option>
                ";
                            }
                            $_parent = $context['_parent'];
                            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['option_value'], $context['_parent'], $context['loop']);
                            $context = array_intersect_key($context, $_parent) + $_parent;
                            // line 429
                            echo "              </select>

            </div>
            ";
                        }
                        // line 433
                        echo "            ";
                        if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 433) == "radio")) {
                            // line 434
                            echo "            <div class=\"form-group";
                            if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 434)) {
                                echo " required ";
                            }
                            echo "\">
               <div id=\"input-option";
                            // line 435
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 435);
                            echo "\"> ";
                            $context['_parent'] = $context;
                            $context['_seq'] = twig_ensure_traversable(twig_get_attribute($this->env, $this->source, $context["option"], "product_option_value", [], "any", false, false, false, 435));
                            foreach ($context['_seq'] as $context["_key"] => $context["option_value"]) {
                                // line 436
                                echo "                <div class=\"radio\">
                  <label>
                    <input type=\"radio\" name=\"option[";
                                // line 438
                                echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 438);
                                echo "]\" value=\"";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "product_option_value_id", [], "any", false, false, false, 438);
                                echo "\" />
                    ";
                                // line 439
                                if (twig_get_attribute($this->env, $this->source, $context["option_value"], "image", [], "any", false, false, false, 439)) {
                                    echo " <img src=\"";
                                    echo twig_get_attribute($this->env, $this->source, $context["option_value"], "image", [], "any", false, false, false, 439);
                                    echo "\" alt=\"";
                                    echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 439);
                                    echo " ";
                                    if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 439)) {
                                        echo " ";
                                        echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 439);
                                        echo " ";
                                        echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 439);
                                        echo " ";
                                    }
                                    echo "\" class=\"img-thumbnail\" /> ";
                                }
                                // line 440
                                echo "                    ";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 440);
                                echo "
                    ";
                                // line 441
                                if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 441)) {
                                    // line 442
                                    echo "                    (";
                                    echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 442);
                                    echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 442);
                                    echo ")
                    ";
                                }
                                // line 443
                                echo " </label>
                </div>
                ";
                            }
                            $_parent = $context['_parent'];
                            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['option_value'], $context['_parent'], $context['loop']);
                            $context = array_intersect_key($context, $_parent) + $_parent;
                            // line 445
                            echo " </div>
            </div>
            ";
                        }
                        // line 448
                        echo "            ";
                        if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 448) == "checkbox")) {
                            // line 449
                            echo "            <div class=\"form-group";
                            if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 449)) {
                                echo " required ";
                            }
                            echo "\">
              <div id=\"input-option";
                            // line 450
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 450);
                            echo "\"> ";
                            $context['_parent'] = $context;
                            $context['_seq'] = twig_ensure_traversable(twig_get_attribute($this->env, $this->source, $context["option"], "product_option_value", [], "any", false, false, false, 450));
                            foreach ($context['_seq'] as $context["_key"] => $context["option_value"]) {
                                // line 451
                                echo "                <div class=\"checkbox\">
                  <label>
                    <input type=\"checkbox\" name=\"option[";
                                // line 453
                                echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 453);
                                echo "][]\" value=\"";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "product_option_value_id", [], "any", false, false, false, 453);
                                echo "\" />
                    ";
                                // line 454
                                if (twig_get_attribute($this->env, $this->source, $context["option_value"], "image", [], "any", false, false, false, 454)) {
                                    echo " <img src=\"";
                                    echo twig_get_attribute($this->env, $this->source, $context["option_value"], "image", [], "any", false, false, false, 454);
                                    echo "\" alt=\"";
                                    echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 454);
                                    echo " ";
                                    if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 454)) {
                                        echo " ";
                                        echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 454);
                                        echo " ";
                                        echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 454);
                                        echo " ";
                                    }
                                    echo "\" class=\"img-thumbnail\" /> ";
                                }
                                // line 455
                                echo "                    ";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 455);
                                echo "
                    ";
                                // line 456
                                if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 456)) {
                                    // line 457
                                    echo "                    (";
                                    echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 457);
                                    echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 457);
                                    echo ")
                    ";
                                }
                                // line 458
                                echo " </label>
                </div>
                ";
                            }
                            $_parent = $context['_parent'];
                            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['option_value'], $context['_parent'], $context['loop']);
                            $context = array_intersect_key($context, $_parent) + $_parent;
                            // line 460
                            echo " </div>
            </div>
            ";
                        }
                        // line 463
                        echo "            ";
                        if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 463) == "text")) {
                            // line 464
                            echo "            <div class=\"form-group";
                            if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 464)) {
                                echo " required ";
                            }
                            echo "\">
              <input type=\"text\" name=\"option[";
                            // line 465
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 465);
                            echo "]\" value=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 465);
                            echo "\" placeholder=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 465);
                            echo "\" id=\"input-option";
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 465);
                            echo "\" class=\"form-control\" />
            </div>
            ";
                        }
                        // line 468
                        echo "            ";
                        if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 468) == "textarea")) {
                            // line 469
                            echo "            <div class=\"form-group";
                            if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 469)) {
                                echo " required ";
                            }
                            echo "\">
              <textarea name=\"option[";
                            // line 470
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 470);
                            echo "]\" rows=\"5\" placeholder=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 470);
                            echo "\" id=\"input-option";
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 470);
                            echo "\" class=\"form-control\">";
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 470);
                            echo "</textarea>
            </div>
            ";
                        }
                        // line 473
                        echo "            ";
                        if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 473) == "file")) {
                            // line 474
                            echo "            <div class=\"form-group";
                            if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 474)) {
                                echo " required ";
                            }
                            echo "\">
              <button type=\"button\" id=\"button-upload";
                            // line 475
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 475);
                            echo "\" data-loading-text=\"";
                            echo ($context["text_loading"] ?? null);
                            echo "\" class=\"btn btn-default btn-block\"><i class=\"fa fa-upload\"></i> ";
                            echo ($context["button_upload"] ?? null);
                            echo "</button>
              <input type=\"hidden\" name=\"option[";
                            // line 476
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 476);
                            echo "]\" value=\"\" id=\"input-option";
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 476);
                            echo "\" />
            </div>
            ";
                        }
                        // line 479
                        echo "            ";
                        if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 479) == "date")) {
                            // line 480
                            echo "            <div class=\"form-group";
                            if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 480)) {
                                echo " required ";
                            }
                            echo "\">
              <div class=\"input-group date\">
                <input type=\"text\" name=\"option[";
                            // line 482
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 482);
                            echo "]\" value=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 482);
                            echo "\" data-date-format=\"YYYY-MM-DD\" id=\"input-option";
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 482);
                            echo "\" class=\"form-control\" />
                <span class=\"input-group-btn\">
                <button class=\"btn btn-default\" type=\"button\"><i class=\"fa fa-calendar\"></i></button>
                </span></div>
            </div>
            ";
                        }
                        // line 488
                        echo "            ";
                        if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 488) == "datetime")) {
                            // line 489
                            echo "            <div class=\"form-group";
                            if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 489)) {
                                echo " required ";
                            }
                            echo "\">
              <div class=\"input-group datetime\">
                <input type=\"text\" name=\"option[";
                            // line 491
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 491);
                            echo "]\" value=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 491);
                            echo "\" data-date-format=\"YYYY-MM-DD HH:mm\" id=\"input-option";
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 491);
                            echo "\" class=\"form-control\" />
                <span class=\"input-group-btn\">
                <button type=\"button\" class=\"btn btn-default\"><i class=\"fa fa-calendar\"></i></button>
                </span></div>
            </div>
            ";
                        }
                        // line 497
                        echo "            ";
                        if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 497) == "time")) {
                            // line 498
                            echo "            <div class=\"form-group";
                            if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 498)) {
                                echo " required ";
                            }
                            echo "\">
              <div class=\"input-group time\">
                <input type=\"text\" name=\"option[";
                            // line 500
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 500);
                            echo "]\" value=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 500);
                            echo "\" data-date-format=\"HH:mm\" id=\"input-option";
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 500);
                            echo "\" class=\"form-control\" />
                <span class=\"input-group-btn\">
                <button type=\"button\" class=\"btn btn-default\"><i class=\"fa fa-calendar\"></i></button>
                </span></div>
            </div>
            ";
                        }
                        // line 506
                        echo "            ";
                    }
                    $_parent = $context['_parent'];
                    unset($context['_seq'], $context['_iterated'], $context['_key'], $context['option'], $context['_parent'], $context['loop']);
                    $context = array_intersect_key($context, $_parent) + $_parent;
                    // line 507
                    echo "            ";
                }
                // line 508
                echo "
           <div class=\"input-group col-xs-12 col-sm-12 button-group\">

              <label class=\"control-label col-sm-2 col-xs-2\">";
                // line 511
                echo ($context["entry_qty"] ?? null);
                echo "</label>

              <input type=\"number\" name=\"quantity\" min=\"1\" value=\"";
                // line 513
                echo ($context["minimum"] ?? null);
                echo "\" size=\"1\" step=\"1\" id=\"input-quantity";
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 513);
                echo "\" class=\"qty form-control col-sm-2 col-xs-9\" />
              <input type=\"hidden\" name=\"product_id\" value=\"";
                // line 514
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 514);
                echo "\" />
              <button type=\"button\" class=\"addtocart col-sm-4 pull-right\" id=\"add-cart-";
                // line 515
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 515);
                echo "\" onclick=\"var xqty='input-quantity";
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 515);
                echo "';
  var aqty = parseInt(document.getElementById(xqty).value); addtoCart(";
                // line 516
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 516);
                echo ",aqty);\">";
                echo ($context["button_cart"] ?? null);
                echo "</button>

            </div>

            </div>

                </div>
            </div>
          </div>


</div>
";
            }
            $_parent = $context['_parent'];
            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['product'], $context['_parent'], $context['loop']);
            $context = array_intersect_key($context, $_parent) + $_parent;
            // line 529
            echo "
</div>
</div>


</div>

\t  ";
        }
        // line 537
        echo "        ";
        if (($context["tags"] ?? null)) {
            // line 538
            echo "        <p>";
            echo ($context["text_tags"] ?? null);
            echo "
        ";
            // line 539
            $context['_parent'] = $context;
            $context['_seq'] = twig_ensure_traversable(range(0, twig_length_filter($this->env, ($context["tags"] ?? null))));
            foreach ($context['_seq'] as $context["_key"] => $context["i"]) {
                // line 540
                echo "        ";
                if (($context["i"] < (twig_length_filter($this->env, ($context["tags"] ?? null)) - 1))) {
                    echo " <a href=\"";
                    echo twig_get_attribute($this->env, $this->source, (($__internal_f607aeef2c31a95a7bf963452dff024ffaeb6aafbe4603f9ca3bec57be8633f4 = ($context["tags"] ?? null)) && is_array($__internal_f607aeef2c31a95a7bf963452dff024ffaeb6aafbe4603f9ca3bec57be8633f4) || $__internal_f607aeef2c31a95a7bf963452dff024ffaeb6aafbe4603f9ca3bec57be8633f4 instanceof ArrayAccess ? ($__internal_f607aeef2c31a95a7bf963452dff024ffaeb6aafbe4603f9ca3bec57be8633f4[$context["i"]] ?? null) : null), "href", [], "any", false, false, false, 540);
                    echo "\">";
                    echo twig_get_attribute($this->env, $this->source, (($__internal_62824350bc4502ee19dbc2e99fc6bdd3bd90e7d8dd6e72f42c35efd048542144 = ($context["tags"] ?? null)) && is_array($__internal_62824350bc4502ee19dbc2e99fc6bdd3bd90e7d8dd6e72f42c35efd048542144) || $__internal_62824350bc4502ee19dbc2e99fc6bdd3bd90e7d8dd6e72f42c35efd048542144 instanceof ArrayAccess ? ($__internal_62824350bc4502ee19dbc2e99fc6bdd3bd90e7d8dd6e72f42c35efd048542144[$context["i"]] ?? null) : null), "tag", [], "any", false, false, false, 540);
                    echo "</a>,
        ";
                } else {
                    // line 541
                    echo " <a href=\"";
                    echo twig_get_attribute($this->env, $this->source, (($__internal_1cfccaec8dd2e8578ccb026fbe7f2e7e29ac2ed5deb976639c5fc99a6ea8583b = ($context["tags"] ?? null)) && is_array($__internal_1cfccaec8dd2e8578ccb026fbe7f2e7e29ac2ed5deb976639c5fc99a6ea8583b) || $__internal_1cfccaec8dd2e8578ccb026fbe7f2e7e29ac2ed5deb976639c5fc99a6ea8583b instanceof ArrayAccess ? ($__internal_1cfccaec8dd2e8578ccb026fbe7f2e7e29ac2ed5deb976639c5fc99a6ea8583b[$context["i"]] ?? null) : null), "href", [], "any", false, false, false, 541);
                    echo "\">";
                    echo twig_get_attribute($this->env, $this->source, (($__internal_68aa442c1d43d3410ea8f958ba9090f3eaa9a76f8de8fc9be4d6c7389ba28002 = ($context["tags"] ?? null)) && is_array($__internal_68aa442c1d43d3410ea8f958ba9090f3eaa9a76f8de8fc9be4d6c7389ba28002) || $__internal_68aa442c1d43d3410ea8f958ba9090f3eaa9a76f8de8fc9be4d6c7389ba28002 instanceof ArrayAccess ? ($__internal_68aa442c1d43d3410ea8f958ba9090f3eaa9a76f8de8fc9be4d6c7389ba28002[$context["i"]] ?? null) : null), "tag", [], "any", false, false, false, 541);
                    echo "</a> ";
                }
                // line 542
                echo "        ";
            }
            $_parent = $context['_parent'];
            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['i'], $context['_parent'], $context['loop']);
            $context = array_intersect_key($context, $_parent) + $_parent;
            echo " </p>
        ";
        }
        // line 543
        echo "</div>
      ";
        // line 544
        echo ($context["content_bottom"] ?? null);
        echo "</div>
    ";
        // line 545
        echo ($context["column_right"] ?? null);
        echo "
</div>
<script><!--
\$('select[name=\\'recurring_id\\'], input[name=\"quantity\"]').change(function(){
\t\$.ajax({
\t\turl: 'index.php?route=product/product/getRecurringDescription',
\t\ttype: 'post',
\t\tdata: \$('input[name=\\'product_id\\'], input[name=\\'quantity\\'], select[name=\\'recurring_id\\']'),
\t\tdataType: 'json',
\t\tbeforeSend: function() {
\t\t\t\$('#recurring-description').html('');
\t\t},
\t\tsuccess: function(json) {
\t\t\t\$('.alert-dismissible, .text-danger').remove();

\t\t\tif (json['success']) {
\t\t\t\t\$('#recurring-description').html(json['success']);
\t\t\t}
\t\t}
\t});
});
//--></script>
<script><!--
\$('#button-cart').on('click', function() {
\t\$.ajax({
\t\turl: 'index.php?route=checkout/cart/add',
\t\ttype: 'post',
\t\tdata: \$('#product input[type=\\'text\\'], #product input[type=\\'hidden\\'], #product input[type=\\'radio\\']:checked, #product input[type=\\'checkbox\\']:checked, #product select, #product textarea'),
\t\tdataType: 'json',
\t\tbeforeSend: function() {
\t\t\t\$('#button-cart').button('loading');
\t\t},
\t\tcomplete: function() {
\t\t\t\$('#button-cart').button('reset');
\t\t},
\t\tsuccess: function(json) {
\t\t\t\$('.alert-dismissible, .text-danger').remove();
\t\t\t\$('.form-group').removeClass('has-error');

\t\t\tif (json['error']) {
\t\t\t\tif (json['error']['option']) {
\t\t\t\t\tfor (i in json['error']['option']) {
\t\t\t\t\t\tvar element = \$('#input-option' + i.replace('_', '-'));

\t\t\t\t\t\tif (element.parent().hasClass('input-group')) {
\t\t\t\t\t\t\telement.parent().after('<div class=\"text-danger\">' + json['error']['option'][i] + '</div>');
\t\t\t\t\t\t} else {
\t\t\t\t\t\t\telement.after('<div class=\"text-danger\">' + json['error']['option'][i] + '</div>');
\t\t\t\t\t\t}
\t\t\t\t\t}
\t\t\t\t}

\t\t\t\tif (json['error']['recurring']) {
\t\t\t\t\t\$('select[name=\\'recurring_id\\']').after('<div class=\"text-danger\">' + json['error']['recurring'] + '</div>');
\t\t\t\t}

\t\t\t\t// Highlight any found errors
\t\t\t\t\$('.text-danger').parent().addClass('has-error');
\t\t\t}

\t\t\tif (json['success']) {
\t\t\t\t\$('.breadcrumb').after('<div class=\"alertmsg\"><div class=\"alert alert-success alert-dismissible\">' + json['success'] + '<button type=\"button\" class=\"close\" data-dismiss=\"alert\">&times;</button></div></div>');

        \$('#cart > .btn').addClass('active');
        \$('#cart > .btn').html('<span class=\"cart-text\">My basket</span><span class=\"cart-total\">Item ' + json['total'] + '</span><span class=\"cart-total-res\">' + json['total'] +'</span>');

      \$('.alertmsg').delay(2500).fadeOut();
        //\$('html, body').animate({ scrollTop: 0 }, 'slow');

\t\t\t\t\$('#cart > ul').load('index.php?route=common/cart/info ul li');
        \$(\"button.close\").click(function() {
                        \$(\".alertmsg\").remove()
                    })
\t\t\t}
\t\t},
        error: function(xhr, ajaxOptions, thrownError) {
            alert(thrownError + \"\\r\\n\" + xhr.statusText + \"\\r\\n\" + xhr.responseText);
        }
\t});
});
//--></script>
<script><!--
\$('.date').datetimepicker({
\tlanguage: '";
        // line 628
        echo ($context["datepicker"] ?? null);
        echo "',
\tpickTime: false
});

\$('.datetime').datetimepicker({
\tlanguage: '";
        // line 633
        echo ($context["datepicker"] ?? null);
        echo "',
\tpickDate: true,
\tpickTime: true
});

\$('.time').datetimepicker({
\tlanguage: '";
        // line 639
        echo ($context["datepicker"] ?? null);
        echo "',
\tpickDate: false
});

\$('button[id^=\\'button-upload\\']').on('click', function() {
\tvar node = this;

\t\$('#form-upload').remove();

\t\$('body').prepend('<form enctype=\"multipart/form-data\" id=\"form-upload\" style=\"display: none;\"><input type=\"file\" name=\"file\" /></form>');

\t\$('#form-upload input[name=\\'file\\']').trigger('click');

\tif (typeof timer != 'undefined') {
    \tclearInterval(timer);
\t}

\ttimer = setInterval(function() {
\t\tif (\$('#form-upload input[name=\\'file\\']').val() != '') {
\t\t\tclearInterval(timer);

\t\t\t\$.ajax({
\t\t\t\turl: 'index.php?route=tool/upload',
\t\t\t\ttype: 'post',
\t\t\t\tdataType: 'json',
\t\t\t\tdata: new FormData(\$('#form-upload')[0]),
\t\t\t\tcache: false,
\t\t\t\tcontentType: false,
\t\t\t\tprocessData: false,
\t\t\t\tbeforeSend: function() {
\t\t\t\t\t\$(node).button('loading');
\t\t\t\t},
\t\t\t\tcomplete: function() {
\t\t\t\t\t\$(node).button('reset');
\t\t\t\t},
\t\t\t\tsuccess: function(json) {
\t\t\t\t\t\$('.text-danger').remove();

\t\t\t\t\tif (json['error']) {
\t\t\t\t\t\t\$(node).parent().find('input').after('<div class=\"text-danger\">' + json['error'] + '</div>');
\t\t\t\t\t}

\t\t\t\t\tif (json['success']) {
\t\t\t\t\t\talert(json['success']);

\t\t\t\t\t\t\$(node).parent().find('input').val(json['code']);
\t\t\t\t\t}
\t\t\t\t},
\t\t\t\terror: function(xhr, ajaxOptions, thrownError) {
\t\t\t\t\talert(thrownError + \"\\r\\n\" + xhr.statusText + \"\\r\\n\" + xhr.responseText);
\t\t\t\t}
\t\t\t});
\t\t}
\t}, 500);
});
//--></script>
<script><!--
\$('#review').delegate('.pagination a', 'click', function(e) {
    e.preventDefault();

    \$('#review').fadeOut('slow');

    \$('#review').load(this.href);

    \$('#review').fadeIn('slow');
});

\$('#review').load('index.php?route=product/product/review&product_id=";
        // line 706
        echo ($context["product_id"] ?? null);
        echo "');

\$('#button-review').on('click', function() {
\t\$.ajax({
\t\turl: 'index.php?route=product/product/write&product_id=";
        // line 710
        echo ($context["product_id"] ?? null);
        echo "',
\t\ttype: 'post',
\t\tdataType: 'json',
\t\tdata: \$(\"#form-review\").serialize(),
\t\tbeforeSend: function() {
\t\t\t\$('#button-review').button('loading');
\t\t},
\t\tcomplete: function() {
\t\t\t\$('#button-review').button('reset');
\t\t},
\t\tsuccess: function(json) {
\t\t\t\$('.alert-dismissible').remove();

\t\t\tif (json['error']) {
\t\t\t\t\$('#review').after('<div class=\"alert alert-danger alert-dismissible\"><i class=\"fa fa-exclamation-circle\"></i> ' + json['error'] + '</div>');
\t\t\t}

\t\t\tif (json['success']) {
\t\t\t\t\$('#review').after('<div class=\"alert alert-success alert-dismissible\"><i class=\"fa fa-check-circle\"></i> ' + json['success'] + '</div>');

\t\t\t\t\$('input[name=\\'name\\']').val('');
\t\t\t\t\$('textarea[name=\\'text\\']').val('');
\t\t\t\t\$('input[name=\\'rating\\']:checked').prop('checked', false);
\t\t\t}
\t\t}
\t});
});

\$(document).ready(function() {
if (\$(window).width() > 767) {
\t\t\$(\"#zoom\").elevateZoom({

\t\t\t\tgallery:'product-additional-block',
\t\t\t\t//inner zoom
\t\t\t\tzoomType : \"window\",
\t\t\t\tcursor: \"crosshair\"
\t\t\t});
\t\tvar z_index = 0;

     \t\t\t    \t\t\$(document).on('click', '.thumbnail', function () {
     \t\t\t    \t\t  \$('.thumbnails').magnificPopup('open', z_index);
     \t\t\t    \t\t  return false;
     \t\t\t    \t\t});

     \t\t\t    \t\t\$('.product-additional-block a').on('mouseover', function() {
     \t\t\t    \t\t\tvar smallImage = \$(this).attr('data-image');
     \t\t\t    \t\t\tvar largeImage = \$(this).attr('data-zoom-image');
     \t\t\t    \t\t\tvar ez =   \$('#zoom').data('elevateZoom');
     \t\t\t    \t\t\t\$('.thumbnail').attr('href', largeImage);
     \t\t\t    \t\t\tez.swaptheimage(smallImage, largeImage);
     \t\t\t    \t\t\tz_index = \$(this).index('.product-additional-block a');
     \t\t\t    \t\t\treturn false;
     \t\t\t    \t\t});

\t}else{
\t\t\$(document).on('click', '.thumbnail', function () {
\t\t\$('.thumbnails').magnificPopup('open', 0);
\t\treturn false;
\t\t});
\t}
});
\$(document).ready(function() {
\t\$('.thumbnails').magnificPopup({
\t\tdelegate: 'a.elevatezoom-gallery',
\t\ttype: 'image',
\t\ttLoading: 'Loading image #%curr%...',
\t\tmainClass: 'mfp-with-zoom',
\t\tgallery: {
\t\t\tenabled: true,
\t\t\tnavigateByImgClick: true,
\t\t\tpreload: [0,1] // Will preload 0 - before current, and 1 after the current image
\t\t},
\t\timage: {
\t\t\ttError: '<a href=\"%url%\">The image #%curr%</a> could not be loaded.',
\t\t\ttitleSrc: function(item) {
\t\t\t\treturn item.el.attr('title');
\t\t\t}
\t\t}
\t});

\t  \$('.image-additional').owlCarousel({

    items: 4,

    navigation: true,

    pagination: false,

    itemsDesktop : [1199, 3],

    itemsDesktopSmall : [991, 3],

    itemsTablet : [767, 3],

    itemsTabletSmall : [479, 2],

    itemsMobile : [319, 1]

  });

\$('.product-carousel').owlCarousel({
\t\t    items: 5,
    autoPlay: false,
    singleItem: false,
    navigation: true,
    pagination: false,
    itemsDesktop : [1199,4],
    itemsDesktopSmall : [991,3],
    itemsTablet : [479,2],
    itemsMobile : [319,1]
\t});



});

//--></script>
<script src=\"";
        // line 827
        echo twig_get_attribute($this->env, $this->source, ($context["module_live_options"] ?? null), "module_live_options_js", [], "any", false, false, false, 827);
        echo "\"></script>
";
        // line 828
        echo ($context["footer"] ?? null);
        echo "
";
    }

    public function getTemplateName()
    {
        return "oc01/template/product/product.twig";
    }

    public function isTraitable()
    {
        return false;
    }

    public function getDebugInfo()
    {
        return array (  2118 => 828,  2114 => 827,  1994 => 710,  1987 => 706,  1917 => 639,  1908 => 633,  1900 => 628,  1814 => 545,  1810 => 544,  1807 => 543,  1798 => 542,  1791 => 541,  1781 => 540,  1777 => 539,  1772 => 538,  1769 => 537,  1759 => 529,  1738 => 516,  1732 => 515,  1728 => 514,  1722 => 513,  1717 => 511,  1712 => 508,  1709 => 507,  1703 => 506,  1690 => 500,  1682 => 498,  1679 => 497,  1666 => 491,  1658 => 489,  1655 => 488,  1642 => 482,  1634 => 480,  1631 => 479,  1623 => 476,  1615 => 475,  1608 => 474,  1605 => 473,  1593 => 470,  1586 => 469,  1583 => 468,  1571 => 465,  1564 => 464,  1561 => 463,  1556 => 460,  1548 => 458,  1541 => 457,  1539 => 456,  1534 => 455,  1518 => 454,  1512 => 453,  1508 => 451,  1502 => 450,  1495 => 449,  1492 => 448,  1487 => 445,  1479 => 443,  1472 => 442,  1470 => 441,  1465 => 440,  1449 => 439,  1443 => 438,  1439 => 436,  1433 => 435,  1426 => 434,  1423 => 433,  1417 => 429,  1410 => 427,  1403 => 426,  1401 => 425,  1394 => 424,  1390 => 423,  1386 => 422,  1380 => 421,  1373 => 420,  1370 => 419,  1366 => 418,  1362 => 416,  1357 => 415,  1353 => 413,  1345 => 411,  1342 => 410,  1334 => 408,  1328 => 406,  1326 => 405,  1323 => 404,  1321 => 403,  1315 => 402,  1308 => 397,  1304 => 395,  1298 => 394,  1295 => 393,  1288 => 391,  1284 => 390,  1281 => 389,  1279 => 388,  1276 => 387,  1270 => 385,  1267 => 384,  1265 => 383,  1262 => 382,  1250 => 380,  1239 => 378,  1228 => 377,  1226 => 376,  1223 => 375,  1217 => 373,  1215 => 372,  1206 => 370,  1203 => 369,  1199 => 368,  1191 => 367,  1187 => 365,  1185 => 364,  1183 => 363,  1179 => 362,  1176 => 361,  1174 => 360,  1166 => 354,  1161 => 352,  1155 => 350,  1146 => 346,  1140 => 343,  1135 => 341,  1122 => 331,  1118 => 330,  1110 => 325,  1105 => 323,  1097 => 318,  1093 => 317,  1089 => 315,  1087 => 314,  1083 => 313,  1078 => 310,  1075 => 309,  1070 => 306,  1063 => 304,  1054 => 301,  1050 => 300,  1047 => 299,  1043 => 298,  1036 => 294,  1032 => 292,  1028 => 291,  1024 => 289,  1022 => 288,  1018 => 287,  1014 => 285,  1008 => 283,  1005 => 282,  999 => 280,  997 => 279,  993 => 278,  987 => 276,  984 => 275,  981 => 274,  978 => 273,  975 => 272,  972 => 271,  969 => 270,  967 => 269,  962 => 266,  952 => 259,  950 => 258,  947 => 257,  941 => 256,  939 => 255,  928 => 251,  920 => 250,  913 => 248,  909 => 247,  905 => 246,  901 => 245,  898 => 244,  892 => 240,  881 => 238,  877 => 237,  873 => 236,  867 => 233,  864 => 232,  861 => 231,  858 => 230,  852 => 229,  839 => 223,  832 => 221,  825 => 220,  822 => 219,  809 => 213,  802 => 211,  795 => 210,  792 => 209,  779 => 203,  772 => 201,  765 => 200,  762 => 199,  754 => 196,  746 => 195,  742 => 194,  735 => 193,  732 => 192,  720 => 189,  714 => 188,  707 => 187,  704 => 186,  692 => 183,  686 => 182,  679 => 181,  676 => 180,  671 => 177,  663 => 175,  656 => 174,  654 => 173,  649 => 172,  633 => 171,  627 => 170,  623 => 168,  617 => 167,  613 => 166,  606 => 165,  603 => 164,  598 => 161,  590 => 159,  583 => 158,  581 => 157,  576 => 156,  560 => 155,  554 => 154,  550 => 152,  544 => 151,  540 => 150,  533 => 149,  530 => 148,  525 => 145,  517 => 143,  510 => 142,  508 => 141,  503 => 140,  487 => 139,  481 => 138,  477 => 136,  471 => 135,  467 => 134,  460 => 133,  457 => 132,  453 => 131,  449 => 130,  445 => 128,  443 => 127,  438 => 124,  434 => 122,  431 => 121,  420 => 119,  415 => 118,  412 => 117,  402 => 115,  399 => 114,  389 => 112,  387 => 111,  384 => 110,  382 => 109,  377 => 107,  373 => 106,  367 => 103,  363 => 101,  356 => 99,  352 => 98,  349 => 97,  347 => 96,  340 => 92,  336 => 91,  333 => 90,  326 => 88,  322 => 87,  319 => 86,  317 => 85,  314 => 84,  302 => 81,  294 => 79,  290 => 78,  287 => 77,  284 => 76,  280 => 74,  272 => 71,  266 => 69,  258 => 66,  255 => 65,  253 => 64,  250 => 63,  248 => 62,  244 => 61,  240 => 60,  235 => 59,  232 => 58,  229 => 57,  226 => 56,  223 => 55,  221 => 54,  218 => 53,  212 => 49,  206 => 45,  185 => 42,  182 => 41,  178 => 40,  161 => 38,  153 => 35,  150 => 34,  147 => 33,  145 => 32,  142 => 31,  140 => 30,  137 => 29,  134 => 28,  118 => 26,  116 => 25,  113 => 24,  111 => 23,  106 => 22,  103 => 21,  100 => 20,  97 => 19,  94 => 18,  92 => 17,  85 => 16,  82 => 15,  79 => 14,  76 => 13,  73 => 12,  70 => 11,  67 => 10,  65 => 9,  61 => 8,  58 => 7,  47 => 5,  43 => 4,  37 => 1,);
    }

    public function getSourceContext()
    {
        return new Source("", "oc01/template/product/product.twig", "");
    }
}
