<?php
// Heading
$_['heading_title']     = 'Account Downloads';

// Text
$_['text_account']      = 'Account';
$_['text_downloads']    = 'Downloads';
$_['text_empty']        = 'You have not made any previous downloadable orders!';

// Column
$_['column_order_id']   = 'Order ID';
$_['column_name']       = 'Name';
$_['column_size']       = 'Size';
$_['column_date_added'] = 'Date Added';