<?php

// Heading Goes here:
$_['heading_title']            = 'Ajax Live Search';

// Text
$_['text_extension']   		   = 'Extensions';
$_['text_edit']                = 'Edit Ajax Live Search Module';
$_['text_success']             = 'Success: You have modified Ajax Live Search module !';
$_['text_view_all_results']    = 'View all results';

// Entry
$_['entry_limit']              = 'Search Limit';
$_['entry_width']              = 'Image Width';
$_['entry_height']             = 'Image Height';
$_['entry_title_length']       = 'Title Length';
$_['entry_description_length'] = 'Description Length';
$_['entry_show_image']         = 'Show image';
$_['entry_show_price']         = 'Show price';
$_['entry_show_description']   = 'Show description';
$_['entry_status']             = 'Status';
$_['entry_view_all_results']   = 'Text of view all results link';
$_['entry_min_length']   	   = 'Search Min Length';

// Help
$_['help_length']              = 'Show \'...\' when length over this.';
$_['help_view_all_results']    = 'Text link of search results bottom';

// Error
$_['error_permission']         = 'Warning: You do not have permission to modify Live Search module !';
$_['error_limit']              = 'Search Limit required!';
$_['error_width']              = 'Image Width required!';
$_['error_height']             = 'Image Height required!';
$_['error_title_length']       = 'Image Height required!';
$_['error_description_length'] = 'Description Length required!';
$_['error_view_all_results']   = 'Text of view all results link required!';
$_['error_min_length']   	   = 'Search Min Length required!';
?>
