<?php
// Heading
$_['heading_title']       = 'Coupons';

// Text
$_['text_success']        = 'Success: You have modified coupons!';
$_['text_list']           = 'Coupon List';
$_['text_add']            = 'Add Coupon';
$_['text_edit']           = 'Edit Coupon';
$_['text_percent']        = 'Percentage';
$_['text_amount']         = 'Fixed Amount';
$_['text_coupon']         = 'Coupon History';

// Column
$_['column_name']         = 'Coupon Name';
$_['column_code']         = 'Code';
$_['column_discount']     = 'Discount';
$_['column_date_start']   = 'Date Start';
$_['column_date_end']     = 'Date End';
$_['column_status']       = 'Status';
$_['column_order_id']     = 'Order ID';
$_['column_customer']     = 'Customer';
$_['column_amount']       = 'Amount';
$_['column_date_added']   = 'Date Added';
$_['column_action']       = 'Action';

// Entry
$_['entry_name']          = 'Coupon Name';
$_['entry_code']          = 'Code';
$_['entry_type']          = 'Type';
$_['entry_discount']      = 'Discount';
$_['entry_logged']        = 'Customer Login';
$_['entry_shipping']      = 'Free Shipping';
$_['entry_total']         = 'Total Amount';
$_['entry_category']      = 'Category';
$_['entry_product']       = 'Products';
$_['entry_date_start']    = 'Date Start';
$_['entry_date_end']      = 'Date End';
$_['entry_uses_total']    = 'Uses Per Coupon';
$_['entry_uses_customer'] = 'Uses Per Customer';
$_['entry_status']        = 'Status';

// Help
$_['help_code']           = 'The code the customer enters to get the discount.';
$_['help_type']           = 'Percentage or Fixed Amount.';
$_['help_logged']         = 'Customer must be logged in to use the coupon.';
$_['help_total']          = 'The total amount that must be reached before the coupon is valid.';
$_['help_category']       = 'Choose all products under selected category.';
$_['help_product']        = 'Choose specific products the coupon will apply to. Select no products to apply coupon to entire cart.';
$_['help_uses_total']     = 'The maximum number of times the coupon can be used by any customer. Leave blank for unlimited';
$_['help_uses_customer']  = 'The maximum number of times the coupon can be used by a single customer. Leave blank for unlimited';

// Error
$_['error_permission']    = 'Warning: You do not have permission to modify coupons!';
$_['error_exists']        = 'Warning: Coupon code is already in use!';
$_['error_name']          = 'Coupon Name must be between 3 and 128 characters!';
$_['error_code']          = 'Code must be between 3 and 10 characters!';