<?php
/**
 * This file has been @generated by a phing task by {@link BuildMetadataPHPFromXml}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */


namespace libphonenumber;
class AlternateFormatsCountryCodeSet {

  // A set of all country codes for which data is available.

   public static $alternateFormatsCountryCodeSet = array (
  0 => 7,
  1 => 27,
  2 => 30,
  3 => 31,
  4 => 34,
  5 => 36,
  6 => 39,
  7 => 43,
  8 => 44,
  9 => 49,
  10 => 52,
  11 => 54,
  12 => 55,
  13 => 58,
  14 => 61,
  15 => 62,
  16 => 63,
  17 => 64,
  18 => 66,
  19 => 81,
  20 => 84,
  21 => 90,
  22 => 91,
  23 => 94,
  24 => 95,
  25 => 255,
  26 => 350,
  27 => 351,
  28 => 352,
  29 => 358,
  30 => 359,
  31 => 372,
  32 => 373,
  33 => 380,
  34 => 381,
  35 => 385,
  36 => 505,
  37 => 506,
  38 => 595,
  39 => 675,
  40 => 676,
  41 => 679,
  42 => 855,
  43 => 856,
  44 => 971,
  45 => 972,
  46 => 995,
);

}
