<?php
// Heading
$_['heading_title']			  = 'View Transaction';

// Text
$_['text_pp_express']		  = 'PayPal Express Checkout';
$_['text_product_lines']	  = 'Product lines';
$_['text_ebay_txn_id']		  = 'eBay transaction ID';
$_['text_name']				  = 'Name';
$_['text_qty']				  = 'Quantity';
$_['text_price']			  = 'Price';
$_['text_number']			  = 'Number';
$_['text_coupon_id']		  = 'Coupon ID';
$_['text_coupon_amount']	  = 'Coupon amount';
$_['text_coupon_currency']	  = 'Coupon currency';
$_['text_loyalty_disc_amt']	  = 'Loyalty card disc amount';
$_['text_loyalty_currency']	  = 'Loyalty card currency';
$_['text_options_name']		  = 'Options name';
$_['text_tax_amt']			  = 'Tax amount';
$_['text_currency_code']	  = 'Currency code';
$_['text_amount']			  = 'Amount';
$_['text_gift_msg']			  = 'Gift message';
$_['text_gift_receipt']		  = 'Gift receipt';
$_['text_gift_wrap_name']	  = 'Gift wrap name';
$_['text_gift_wrap_amt']	  = 'Gift wrap amount';
$_['text_buyer_email_market'] = 'Buyer marketing email';
$_['text_survey_question']	  = 'Survey question';
$_['text_survey_chosen']	  = 'Survey choice selected';
$_['text_receiver_business']  = 'Receiver business';
$_['text_receiver_email']	  = 'Receiver email';
$_['text_receiver_id']		  = 'Receiver ID';
$_['text_buyer_email']		  = 'Buyer email';
$_['text_payer_id']			  = 'Payer ID';
$_['text_payer_status']		  = 'Payer status';
$_['text_country_code']		  = 'Country code';
$_['text_payer_business']	  = 'Payer business';
$_['text_payer_salute']		  = 'Payer salutation';
$_['text_payer_firstname']	  = 'Payer first name';
$_['text_payer_middlename']   = 'Payer middle name';
$_['text_payer_lastname']	  = 'Payer last name';
$_['text_payer_suffix']		  = 'Payer suffix';
$_['text_address_owner']	  = 'Address owner';
$_['text_address_status']	  = 'Address status';
$_['text_ship_sec_name']	  = 'Ship to secondary name';
$_['text_ship_name']		  = 'Ship to name';
$_['text_ship_street1']		  = 'Ship to address 1';
$_['text_ship_street2']		  = 'Ship to address 2';
$_['text_ship_city']		  = 'Ship to city';
$_['text_ship_state']		  = 'Ship to state';
$_['text_ship_zip']			  = 'Ship to ZIP';
$_['text_ship_country']		  = 'Ship to country code';
$_['text_ship_phone']		  = 'Ship to phone number';
$_['text_ship_sec_add1']	  = 'Ship to secondary address 1';
$_['text_ship_sec_add2']	  = 'Ship to secondary address 2';
$_['text_ship_sec_city']	  = 'Ship to secondary city';
$_['text_ship_sec_state']	  = 'Ship to secondary state';
$_['text_ship_sec_zip']		  = 'Ship to secondary ZIP';
$_['text_ship_sec_country']	  = 'Ship to secondary country code';
$_['text_ship_sec_phone']	  = 'Ship to secondary phone';
$_['text_trans_id']			  = 'Transaction ID';
$_['text_receipt_id']		  = 'Receipt ID';
$_['text_parent_trans_id']	  = 'Parent transaction ID';
$_['text_trans_type']		  = 'Transaction type';
$_['text_payment_type']		  = 'Payment type';
$_['text_order_time']		  = 'Order time';
$_['text_fee_amount']		  = 'Fee amount';
$_['text_settle_amount']	  = 'Settle amount';
$_['text_tax_amount']		  = 'Tax amount';
$_['text_exchange']			  = 'Exchange rate';
$_['text_payment_status']	  = 'Payment status';
$_['text_pending_reason']	  = 'Pending reason';
$_['text_reason_code']		  = 'Reason code';
$_['text_protect_elig']		  = 'Protection eligibility';
$_['text_protect_elig_type']  = 'Protection eligibility type';
$_['text_store_id']			  = 'Store ID';
$_['text_terminal_id']		  = 'Terminal ID';
$_['text_invoice_number']	  = 'Invoice number';
$_['text_custom']			  = 'Custom';
$_['text_note']				  = 'Note';
$_['text_sales_tax']		  = 'Sales tax';
$_['text_buyer_id']			  = 'Buyer ID';
$_['text_close_date']		  = 'Closing date';
$_['text_multi_item']		  = 'Multi item';
$_['text_sub_amt']			  = 'Subscription amount';
$_['text_sub_period']		  = 'Subscription period';