<?php
// Heading
$_['heading_title']  = 'Reset your password';

// Text
$_['text_account']   = 'Account';
$_['text_password']  = 'Enter the new password you wish to use.';
$_['text_success']   = 'Success: Your password has been successfully updated.';

// Entry
$_['entry_password'] = 'Password';
$_['entry_confirm']  = 'Confirm';

// Error
$_['error_password'] = 'Password must be between 4 and 20 characters!';
$_['error_confirm']  = 'Password and password confirmation do not match!';
$_['error_code']     = 'Password reset code is invalid or was used previously!';