<?php
// HTTP
define('HTTP_SERVER', 'http://www.soben.in/');

// HTTPS
define('HTTPS_SERVER', 'https://www.soben.in/');

// DIR
define('DIR_APPLICATION', '/home/ltyvjmsd/public_html/catalog/');
define('DIR_SYSTEM', '/home/ltyvjmsd/public_html/system/');
define('DIR_IMAGE', '/home/ltyvjmsd/public_html/image/');
define('DIR_STORAGE', '/home/ltyvjmsd/public_html/storage/');
define('DIR_LANGUAGE', DIR_APPLICATION . 'language/');
define('DIR_TEMPLATE', DIR_APPLICATION . 'view/theme/');
define('DIR_CONFIG', DIR_SYSTEM . 'config/');
define('DIR_CACHE', DIR_STORAGE . 'cache/');
define('DIR_DOWNLOAD', DIR_STORAGE . 'download/');
define('DIR_LOGS', DIR_STORAGE . 'logs/');
define('DIR_MODIFICATION', DIR_STORAGE . 'modification/');
define('DIR_SESSION', DIR_STORAGE . 'session/');
define('DIR_UPLOAD', DIR_STORAGE . 'upload/');

// DB
define('DB_DRIVER', 'mysqli');
define('DB_HOSTNAME', 'localhost');
define('DB_USERNAME', 'ltyvjmsd_sobn');
define('DB_PASSWORD', '}m6vXv~S^_)m');
define('DB_DATABASE', 'ltyvjmsd_ecom');
define('DB_PORT', '3306');
define('DB_PREFIX', 'oc_');