<?php
// Heading
$_['heading_title']      = 'Cheque / Money Order';

// Text
$_['text_extension']     = 'Extensions';
$_['text_success']       = 'Success: You have modified cheque / money order account details!';
$_['text_edit']          = 'Edit Cheque / Money Order';

// Entry
$_['entry_payable']      = 'Payable To';
$_['entry_total']        = 'Total';
$_['entry_order_status'] = 'Order Status';
$_['entry_geo_zone']     = 'Geo Zone';
$_['entry_status']       = 'Status';
$_['entry_sort_order']   = 'Sort Order';

// Help
$_['help_total']         = 'The checkout total the order must reach before this payment method becomes active.';

// Error
$_['error_permission']   = 'Warning: You do not have permission to modify payment cheque / money order!';
$_['error_payable']      = 'Payable To Required!';