<div class="sidebar section information">
<div class="section-heading"><div class="border"></div>{{ heading_title }}</div>
    <div class="list-group">
			{% for information in informations %}
					<a class="list-group-item" href="{{ information.href }}">{{ information.title }}</a>
			{% endfor %}
				<a class="list-group-item" href="{{ contact }}">{{ text_contact }}</a>
	
				<a class="list-group-item" href="{{ sitemap }}">{{ text_sitemap }}</a>
	</div>
</div>