{{ text_return_id }} {{ return_id }}
{{ text_date_added }} {{  date_added }}

{{ text_return_status }}

{{ return_status }}

{% if comment %}

{{ text_comment }}

{{ comment }}
{{ text_footer }}
{% else %} 
{{ text_footer }}
{% endif %}