<?php
// Heading
$_['heading_title']    = 'Sales Analytics';

// Text
$_['text_extension']   = 'Extensions';
$_['text_success']     = 'Success: You have modified dashboard chart!';
$_['text_edit']        = 'Edit Dashboard Chart';
$_['text_order']       = 'Orders';
$_['text_customer']    = 'Customers';
$_['text_day']         = 'Today';
$_['text_week']        = 'Week';
$_['text_month']       = 'Month';
$_['text_year']        = 'Year';

// Entry
$_['entry_status']     = 'Status';
$_['entry_sort_order'] = 'Sort Order';
$_['entry_width']      = 'Width';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify dashboard chart!';