<?php
// Text
$_['text_title']				= 'Credit Card / Debit Card (Paymate)';
$_['text_unable']				= 'Unable to locate or update your order status';
$_['text_declined']				= 'Payment was declined by Paymate';
$_['text_failed']				= 'Paymate Transaction Failed';
$_['text_failed_message']		= '<p>Unfortunately there was an error processing your Paymate transaction.</p><p><b>Warning: </b>%s</p><p>Please verify your Paymate account balance before attempting to re-process this order</p><p> If you believe this transaction has completed successfully, or is showing as a deduction in your Paymate account, please <a href="%s">Contact Us</a> with your order details.</p>';
$_['text_basket']				= 'Basket';
$_['text_checkout']				= 'Checkout';
$_['text_success']				= 'Success';