<form action="https://www.secpay.com/java-bin/ValCard" method="post">
  <input type="hidden" name="merchant" value="{{ merchant }}" />
  <input type="hidden" name="trans_id" value="{{ trans_id }}" />
  <input type="hidden" name="amount" value="{{ amount }}" />
  {% if digest %}
  <input type="hidden" name="digest" value="{{ digest }}" />
  {% endif %}
  <input type="hidden" name="bill_name" value="{{ bill_name }}" />
  <input type="hidden" name="bill_addr_1" value="{{ bill_addr_1 }}" />
  <input type="hidden" name="bill_addr_2" value="{{ bill_addr_2 }}" />
  <input type="hidden" name="bill_city" value="{{ bill_city }}" />
  <input type="hidden" name="bill_state" value="{{ bill_state }}" />
  <input type="hidden" name="bill_post_code" value="{{ bill_post_code }}" />
  <input type="hidden" name="bill_country" value="{{ bill_country }}" />
  <input type="hidden" name="bill_tel" value="{{ bill_tel }}" />
  <input type="hidden" name="bill_email" value="{{ bill_email }}" />
  <input type="hidden" name="ship_name" value="{{ ship_name }}" />
  <input type="hidden" name="ship_addr_1" value="{{ ship_addr_1 }}" />
  <input type="hidden" name="ship_addr_2" value="{{ ship_addr_2 }}" />
  <input type="hidden" name="ship_city" value="{{ ship_city }}" />
  <input type="hidden" name="ship_state" value="{{ ship_state }}" />
  <input type="hidden" name="ship_post_code" value="{{ ship_post_code }}" />
  <input type="hidden" name="ship_country" value="{{ ship_country }}" />
  <input type="hidden" name="currency" value="{{ currency }}" />
  <input type="hidden" name="callback" value="{{ callback }}" />
  <input type="hidden" name="options" value="{{ options }}" />
  <div class="buttons">
    <div class="pull-right">
      <input type="submit" value="{{ button_confirm }}" class="btn btn-primary" />
    </div>
  </div>
</form>
