<?php

$_['heading_title'] = 'Square Credit Cards';

$_['text_account'] = 'Account';
$_['text_back'] = 'Back';
$_['text_delete'] = 'Delete';
$_['text_no_cards'] = 'There are no cards stored on our database.';
$_['text_card_ends_in'] = '%s card ending in &bull;&bull;&bull;&bull; &bull;&bull;&bull;&bull; &bull;&bull;&bull;&bull; %s';
$_['text_warning_card'] = 'Do you confirm you want to remove this card? You may add it again later on your next checkout.';
$_['text_success_card_delete'] = 'Success! This card has been removed.';