<div class="col-lg-6 col-md-12 col-sm-12">
  <div class="panel panel-default">
    <div class="panel-heading">
      <h3 class="panel-title"><img class="pull-right" width="192" src="https://s3-us-west-1.amazonaws.com/bt-partner-assets/paypal-braintree.png" alt="PayPal powered by Braintree"></h3>
      {% if payment_pp_braintree_status == "enabled" %}
        <div class="pull-right"><span class="label label-success">{{ text_enabled }}</span></div>
      {% endif %}
      {% if payment_pp_braintree_status == "disabled" %}
        <div class="pull-right"><span class="label label-danger">{{ text_disabled }}</span></div>
      {% endif %}
    </div>
    <div class="panel-body">
      <div class="row">
        <div class="col-lg-12 col-md-12 col-sm-12">
          <p>{{ text_preferred_main }} <a href="https://www.braintreepayments.com/partners/learn-more" target="_blank">{{ text_learn_more }}</a></p>
        </div>
      </div>
      <div class="row">
        <div class="col-lg-8 col-md-8 col-sm-8">
          <ul>
            <li>{{ text_preferred_li_1 }}</li>
            <li>{{ text_preferred_li_2 }}</li>
            <li>{{ text_preferred_li_3 }}</li>
            <li>{{ text_preferred_li_4 }}</li>
          </ul>
        </div>
        <div class="col-lg-4 col-md-4 col-sm-4">
          <img class="pull-right img-responsive" src="https://s3-us-west-1.amazonaws.com/bt-partner-assets/payment-methods.png" alt="Accept Visa, Mastercard, Discover, American Express, and PayPal payments" />
          {% if connect_link is not empty %}
            <br /><br /><a href="{{ connect_link }}" target="_blank" class="pull-right" style="margin-top:10px;"><img src="https://s3-us-west-1.amazonaws.com/bt-partner-assets/connect-braintree.png" alt="Connect with Braintree" class="img-responsive"></a>
          {% endif %}
          {% if module_link is not empty %}
            <br /><br /><a href="{{ module_link }}" data-toggle="tooltip" title="" class="btn btn-primary pull-right" data-original-title="{{ text_edit }}"><i class="fa fa-pencil"></i></a>
          {% endif %}
        </div>
      </div>
    </div>
  </div>
</div>
