<div class="tile tile-primary">
  <div class="tile-heading">{{ heading_title }} <span class="pull-right">
    {% if percentage > 0 %}
    <i class="fa fa-caret-up"></i>
    {% elseif percentage < 0 %}
    <i class="fa fa-caret-down"></i>
    {% endif %}
    {{ percentage }}%</span></div>
  <div class="tile-body"><i class="fa fa-credit-card"></i>
    <h2 class="pull-right">{{ total }}</h2>
  </div>
  <div class="tile-footer"><a href="{{ sale }}">{{ text_view }}</a></div>
</div>
