<?php
// Heading
$_['heading_title']      = 'Geo Zones';

// Text
$_['text_success']       = 'Success: You have modified geo zones!';
$_['text_list']          = 'Geo Zone List';
$_['text_add']           = 'Add Geo Zone';
$_['text_edit']          = 'Edit Geo Zone';
$_['text_geo_zone']      = 'Geo Zones';

// Column
$_['column_name']        = 'Geo Zone Name';
$_['column_description'] = 'Description';
$_['column_action']      = 'Action';

// Entry
$_['entry_name']         = 'Geo Zone Name';
$_['entry_description']  = 'Description';
$_['entry_country']      = 'Country';
$_['entry_zone']         = 'Zone';

// Error
$_['error_permission']   = 'Warning: You do not have permission to modify geo zones!';
$_['error_name']         = 'Geo Zone Name must be between 3 and 32 characters!';
$_['error_description']  = 'Description Name must be between 3 and 255 characters!';
$_['error_tax_rate']     = 'Warning: This geo zone cannot be deleted as it is currently assigned to one or more tax rates!';