<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  24380 => 'Supercell',
  24381 => 'Vodacom',
  24382 => 'Vodacom',
  24384 => 'CCT',
  24388 => 'Yozma Timeturns sprl -YTT',
  24389 => 'Tigo',
  24390 => 'Africell',
  24391 => 'Africell',
  24397 => 'Zain',
  24398 => 'Zain',
  24399 => 'Zain',
);
