<?php
// Heading
$_['heading_title']     = 'Product Comparison';

// Text
$_['text_product']      = 'Product Details';
$_['text_name']         = 'Product';
$_['text_image']        = 'Image';
$_['text_price']        = 'Price';
$_['text_model']        = 'Model';
$_['text_manufacturer'] = 'Brand';
$_['text_availability'] = 'Availability';
$_['text_instock']      = 'In Stock';
$_['text_rating']       = 'Rating';
$_['text_reviews']      = 'Based on %s reviews.';
$_['text_summary']      = 'Summary';
$_['text_weight']       = 'Weight';
$_['text_dimension']    = 'Dimensions (L x W x H)';
$_['text_compare']      = 'Product Compare (%s)';
$_['text_success']      = 'Success: You have added <a href="%s">%s</a> to your <a href="%s">product comparison</a>!';
$_['text_remove']       = 'Success: You have modified your product comparison!';
$_['text_empty']        = 'You have not chosen any products to compare.';