<?php
$_['heading_title']    = 'Google Analytics';

// Text
$_['text_extension']   = 'Extensions';
$_['text_success']	   = 'Success: You have modified Google Analytics!';
$_['text_edit']        = 'Edit Google Analytics';
$_['text_signup']      = 'Login to your <a href="http://www.google.com/analytics/" target="_blank"><u>Google Analytics</u></a> account and after creating your website profile copy and paste the analytics code into this field.';
$_['text_default']     = 'Default';

// Entry
$_['entry_code']       = 'Google Analytics Code';
$_['entry_status']     = 'Status';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify Google Analytics!';
$_['error_code']	   = 'Code required!';
