#sapphire {
  line-height: 18px;
  font-size: 24px;
  font-weight: 500;
  cursor: pointer;
  color: rgba(67, 235, 171, 0.6); }
  #sapphire a {
    color: rgba(67, 235, 171, 0.6); }
  #sapphire .sph_unprotected {
    color: #fa5b6d; }

/*# sourceMappingURL=headerold.css.map */
