<?php

$_['text_payment_method'] = 'Payment method';
$_['text_payment_popups'] = 'Payment method popups:';
$_['text_display_images'] = 'Display payment images';
$_['text_display_options'] = 'Display options';
$_['text_input_style'] = 'Input style';