<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  3212 => 'Tongres',
  3215 => 'Malines',
  3216 => 'Louvain',
  322 => 'Bruxelles',
  323 => 'Anvers',
  3251 => 'Roulers',
  3252 => 'Termonde',
  3253 => 'Alost',
  3255 => 'Renaix',
  3256 => 'Courtrai',
  3258 => 'Furnes',
  3259 => 'Ostende',
  329 => 'Gand',
);
