<div class="panel panel-default">
  <div class="panel-heading">
    <h3 class="panel-title"><i class="fa fa-calendar"></i> {{ heading_title }}</h3>
  </div>
  <ul class="list-group">
    {% if activities %}
    {% for activity in activities %}
    <li class="list-group-item">{{ activity.comment }}<br />
      <small class="text-muted"><i class="fa fa-clock-o"></i> {{ activity.date_added }}</small></li>
    {% endfor %}
    {% else %}
    <li class="list-group-item text-center">{{ text_no_results }}</li>
    {% endif %}
  </ul>
</div>