.d_social_login{font-size:16px;color:#6f6f6f}.d_social_login input{display:initial;width:100%}.d_social_login .modal-content{-webkit-transition:all ease .4s;transition:all ease .4s}.d_social_login .control-label{color:#6f6f6f}.d_social_login .modal-dialog{max-width:450px;margin:30px auto}.d_social_login #dsl_popup{padding:4.5em}.d_social_login #dsl_intro{line-height:1.2;font-size:.82em;padding:1em;margin-top:1em;margin-bottom:1em;color:#8194b0;background-color:#f0f4f9;border:1px solid #c6d1e3;-webkit-border-radius:4px;border-radius:4px}.d_social_login #dsl_submit{width:100%}.d_social_login .error{margin:0;color:#bc3d3d}.d_social_login .error.form-control{background-color:#fbeded;border:1px solid #e76262}.d_social_login label{padding-top:0}.d_social_login #dsl_profile_image{max-width:100%;-webkit-border-radius:100%;border-radius:100%}.d_social_login .img-wrap{display:block;margin:auto;max-width:100px;position:relative}.d_social_login .img-wrap .log-small-icon{display:block;width:30px;height:30px;background-size:40%;background-position:center center;background-repeat:no-repeat;padding:2px;-webkit-border-radius:100%;border-radius:100%;position:absolute;bottom:0;right:0}.d_social_login .pre_loader{position:absolute;left:50%;-webkit-transform:translate(-50%,-50%);-ms-transform:translate(-50%,-50%);transform:translate(-50%,-50%);top:50%;z-index:1056}.dsl_confirm{text-align:center}.dsl_confirm .wrap{display:inline-block}.dsl_confirm .wrap-circul{display:table;background:#1bce6f;-webkit-border-radius:100%;border-radius:100%;width:50px;height:50px;color:#fff}.dsl_confirm .wrap-circul .fa{display:table-cell;vertical-align:middle;font-size:25px}@media only screen and (max-width:500px){.d_social_login .modal-dialog{max-width:100%}.d_social_login #dsl_popup{padding:2em}}.modal-open{overflow:scroll}