<?php
// Heading
$_['heading_title']    = 'Google reCAPTCHA';

// Text
$_['text_extension']   = 'Extensions';
$_['text_success']     = 'Success: You have modified Google reCAPTCHA!';
$_['text_edit']        = 'Edit Google reCAPTCHA';
$_['text_signup']      = 'Go to <a href="https://www.google.com/recaptcha/intro/index.html" target="_blank"><u>Google reCAPTCHA page</u></a> and register your website.';

// Entry
$_['entry_key']        = 'Site key';
$_['entry_secret']     = 'Secret key';
$_['entry_status']     = 'Status';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify Google reCAPTCHA!';
$_['error_key']        = 'Key required!';
$_['error_secret']     = 'Secret required!';