<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;

/* oc01/template/product/category.twig */
class __TwigTemplate_d4d8464d13712bce5d13b9537a19b912022f87b50484d383cfcf01d786d492c7 extends \Twig\Template
{
    private $source;
    private $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = [])
    {
        $macros = $this->macros;
        // line 1
        echo ($context["header"] ?? null);
        echo "
<div id=\"product-category\" class=\"container category\">
  <ul class=\"breadcrumb\">
    ";
        // line 4
        $context['_parent'] = $context;
        $context['_seq'] = twig_ensure_traversable(($context["breadcrumbs"] ?? null));
        foreach ($context['_seq'] as $context["_key"] => $context["breadcrumb"]) {
            // line 5
            echo "    <li><a href=\"";
            echo twig_get_attribute($this->env, $this->source, $context["breadcrumb"], "href", [], "any", false, false, false, 5);
            echo "\">";
            echo twig_get_attribute($this->env, $this->source, $context["breadcrumb"], "text", [], "any", false, false, false, 5);
            echo "</a></li>
    ";
        }
        $_parent = $context['_parent'];
        unset($context['_seq'], $context['_iterated'], $context['_key'], $context['breadcrumb'], $context['_parent'], $context['loop']);
        $context = array_intersect_key($context, $_parent) + $_parent;
        // line 7
        echo "  </ul>
  <div class=\"row\">";
        // line 8
        echo ($context["column_left"] ?? null);
        echo "
    ";
        // line 9
        if ((($context["column_left"] ?? null) && ($context["column_right"] ?? null))) {
            // line 10
            echo "    ";
            $context["class"] = "col-sm-6";
            // line 11
            echo "    ";
        } elseif ((($context["column_left"] ?? null) || ($context["column_right"] ?? null))) {
            // line 12
            echo "    ";
            $context["class"] = "col-sm-9";
            // line 13
            echo "    ";
        } else {
            // line 14
            echo "    ";
            $context["class"] = "col-sm-12";
            // line 15
            echo "    ";
        }
        // line 16
        echo "    <div id=\"content\" class=\"";
        echo ($context["class"] ?? null);
        echo "\">";
        echo ($context["content_top"] ?? null);
        echo "
      <h1>";
        // line 17
        echo ($context["heading_title"] ?? null);
        echo "</h1>
      ";
        // line 18
        if ((($context["thumb"] ?? null) || ($context["description"] ?? null))) {
            // line 19
            echo "      <div class=\"row category_thumb\"> ";
            if (($context["thumb"] ?? null)) {
                // line 20
                echo "        <div class=\"col-sm-2\"><img src=\"";
                echo ($context["thumb"] ?? null);
                echo "\" alt=\"";
                echo ($context["heading_title"] ?? null);
                echo "\" title=\"";
                echo ($context["heading_title"] ?? null);
                echo "\" class=\"img-thumbnail\" /></div>
        ";
            }
            // line 22
            echo "        ";
            if (($context["description"] ?? null)) {
                // line 23
                echo "        <div class=\"col-sm-10\">";
                echo ($context["description"] ?? null);
                echo "</div>
        ";
            }
            // line 24
            echo "</div>
      
      ";
        }
        // line 27
        echo "      ";
        if (($context["categories"] ?? null)) {
            // line 28
            echo "     <div class=\"subcateory\">\t  
\t  <h3>";
            // line 29
            echo ($context["text_refine"] ?? null);
            echo "</h3>
      ";
            // line 30
            if ((twig_length_filter($this->env, ($context["categories"] ?? null)) <= 5)) {
                // line 31
                echo "      <div class=\"row\">
        <div class=\"col-sm-3\">
          <ul>
            ";
                // line 34
                $context['_parent'] = $context;
                $context['_seq'] = twig_ensure_traversable(($context["categories"] ?? null));
                foreach ($context['_seq'] as $context["_key"] => $context["category"]) {
                    // line 35
                    echo "            <li><a href=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["category"], "href", [], "any", false, false, false, 35);
                    echo "\">";
                    echo twig_get_attribute($this->env, $this->source, $context["category"], "name", [], "any", false, false, false, 35);
                    echo "</a></li>
            ";
                }
                $_parent = $context['_parent'];
                unset($context['_seq'], $context['_iterated'], $context['_key'], $context['category'], $context['_parent'], $context['loop']);
                $context = array_intersect_key($context, $_parent) + $_parent;
                // line 37
                echo "          </ul>
        </div>
      </div>
      ";
            } else {
                // line 41
                echo "      <div class=\"row\">";
                $context['_parent'] = $context;
                $context['_seq'] = twig_ensure_traversable(twig_array_batch(($context["categories"] ?? null), twig_round((twig_length_filter($this->env, ($context["categories"] ?? null)) / 4), 1, "ceil")));
                foreach ($context['_seq'] as $context["_key"] => $context["category"]) {
                    // line 42
                    echo "        <div class=\"col-sm-3\">
          <ul>
            ";
                    // line 44
                    $context['_parent'] = $context;
                    $context['_seq'] = twig_ensure_traversable($context["category"]);
                    foreach ($context['_seq'] as $context["_key"] => $context["child"]) {
                        // line 45
                        echo "            <li><a href=\"";
                        echo twig_get_attribute($this->env, $this->source, $context["child"], "href", [], "any", false, false, false, 45);
                        echo "\">";
                        echo twig_get_attribute($this->env, $this->source, $context["child"], "name", [], "any", false, false, false, 45);
                        echo "</a></li>
            ";
                    }
                    $_parent = $context['_parent'];
                    unset($context['_seq'], $context['_iterated'], $context['_key'], $context['child'], $context['_parent'], $context['loop']);
                    $context = array_intersect_key($context, $_parent) + $_parent;
                    // line 47
                    echo "          </ul>
        </div>
        ";
                }
                $_parent = $context['_parent'];
                unset($context['_seq'], $context['_iterated'], $context['_key'], $context['category'], $context['_parent'], $context['loop']);
                $context = array_intersect_key($context, $_parent) + $_parent;
                // line 49
                echo "</div>
      <br />
      ";
            }
            // line 52
            echo "      </div>
\t  ";
        }
        // line 54
        echo "      
      ";
        // line 55
        if (($context["products"] ?? null)) {
            // line 56
            echo "      
      <div class=\"filter-product\">
        <div class=\"btn-grid-list\">
          <div class=\"btn-group btn-group-sm\">
            <button type=\"button\" id=\"filter-view\" class=\"btn btn-default filter collapsed\" data-target=\"#ajaxfilter\" data-toggle=\"collapse\" title=\"";
            // line 60
            echo ($context["button_filter"] ?? null);
            echo "\"><i class=\"fa fa-th-list\"></i></button>
            <button type=\"button\" id=\"grid-view\" class=\"btn btn-default grid\" data-toggle=\"tooltip\" title=\"";
            // line 61
            echo ($context["button_grid"] ?? null);
            echo "\"><i class=\"fa fa-th\"></i></button>
            <button type=\"button\" id=\"list-view\" class=\"btn btn-default list\" data-toggle=\"tooltip\" title=\"";
            // line 62
            echo ($context["button_list"] ?? null);
            echo "\"><i class=\"fa fa-th-list\"></i></button>
            
          </div>
        </div>
        <div class=\"compare-total\"><a href=\"";
            // line 66
            echo ($context["compare"] ?? null);
            echo "\" id=\"compare-total\">";
            echo ($context["text_compare"] ?? null);
            echo "</a></div>
        <div class=\"filter-product-right text-right\">
          <div class=\"sort-filter\">
            <div class=\"col-xs-4 col-sm-4 col-md-4 text-right\">
              <label class=\"control-label\" for=\"input-sort\">";
            // line 70
            echo ($context["text_sort"] ?? null);
            echo "</label>
            </div>
            <div class=\"col-xs-8 col-sm-8 col-md-8 text-right\">
              <select id=\"input-sort\" class=\"form-control\" onchange=\"location = this.value;\">
                ";
            // line 74
            $context['_parent'] = $context;
            $context['_seq'] = twig_ensure_traversable($context["sorts"]);
            foreach ($context['_seq'] as $context["_key"] => $context["sorts"]) {
                // line 75
                echo "              ";
                if ((twig_get_attribute($this->env, $this->source, $context["sorts"], "value", [], "any", false, false, false, 75) == sprintf("%s-%s", ($context["sort"] ?? null), ($context["order"] ?? null)))) {
                    // line 76
                    echo "                <option value=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["sorts"], "href", [], "any", false, false, false, 76);
                    echo "\" selected=\"selected\">";
                    echo twig_get_attribute($this->env, $this->source, $context["sorts"], "text", [], "any", false, false, false, 76);
                    echo "</option>
                ";
                } else {
                    // line 78
                    echo "                <option value=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["sorts"], "href", [], "any", false, false, false, 78);
                    echo "\">";
                    echo twig_get_attribute($this->env, $this->source, $context["sorts"], "text", [], "any", false, false, false, 78);
                    echo "</option>
                ";
                }
                // line 80
                echo "              ";
            }
            $_parent = $context['_parent'];
            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['sorts'], $context['_parent'], $context['loop']);
            $context = array_intersect_key($context, $_parent) + $_parent;
            // line 81
            echo "              </select>
            </div>
          </div>
          <div class=\"show-filter\">
            <div class=\"col-xs-6 col-sm-6 col-md-6 text-right\">
              <label class=\"control-label\" for=\"input-limit\">";
            // line 86
            echo ($context["text_limit"] ?? null);
            echo "</label>
            </div>
            <div class=\"col-xs-6 col-sm-6 col-md-6 text-right\">
              <select id=\"input-limit\" class=\"form-control\" onchange=\"location = this.value;\">
                ";
            // line 90
            $context['_parent'] = $context;
            $context['_seq'] = twig_ensure_traversable($context["limits"]);
            foreach ($context['_seq'] as $context["_key"] => $context["limits"]) {
                // line 91
                echo "              ";
                if ((twig_get_attribute($this->env, $this->source, $context["limits"], "value", [], "any", false, false, false, 91) == ($context["limit"] ?? null))) {
                    // line 92
                    echo "                <option value=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["limits"], "href", [], "any", false, false, false, 92);
                    echo "\" selected=\"selected\">";
                    echo twig_get_attribute($this->env, $this->source, $context["limits"], "text", [], "any", false, false, false, 92);
                    echo "</option>
               ";
                } else {
                    // line 94
                    echo "                <option value=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["limits"], "href", [], "any", false, false, false, 94);
                    echo "\">";
                    echo twig_get_attribute($this->env, $this->source, $context["limits"], "text", [], "any", false, false, false, 94);
                    echo "</option>
                ";
                }
                // line 96
                echo "              ";
            }
            $_parent = $context['_parent'];
            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['limits'], $context['_parent'], $context['loop']);
            $context = array_intersect_key($context, $_parent) + $_parent;
            // line 97
            echo "              </select>
            </div>
          </div>
        </div>
      </div>
      <div class=\"products-collection\">
      <div class=\"row product-layoutrow\"> ";
            // line 103
            $context['_parent'] = $context;
            $context['_seq'] = twig_ensure_traversable(($context["products"] ?? null));
            foreach ($context['_seq'] as $context["_key"] => $context["product"]) {
                // line 104
                echo "
        <div class=\"product-layout product-list col-xs-12\">
          <div class=\"product-thumb\">
            <div class=\"image\">
      \t\t\t";
                // line 108
                if (twig_get_attribute($this->env, $this->source, $context["product"], "tag_per", [], "any", false, false, false, 108)) {
                    // line 109
                    echo "      \t\t\t <p class=\"tag\">";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "tag_per", [], "any", false, false, false, 109);
                    echo "<br/> % <br/> <i>off</i></p>
      \t\t\t";
                }
                // line 111
                echo "      \t\t\t
           
            <a href=\"";
                // line 113
                echo twig_get_attribute($this->env, $this->source, $context["product"], "href", [], "any", false, false, false, 113);
                echo "\"><img src=\"";
                echo twig_get_attribute($this->env, $this->source, $context["product"], "thumb", [], "any", false, false, false, 113);
                echo "\" alt=\"";
                echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 113);
                echo "\" title=\"";
                echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 113);
                echo "\" class=\"img-responsive\" /></a>
             ";
                // line 114
                if ( !twig_get_attribute($this->env, $this->source, $context["product"], "special", [], "any", false, false, false, 114)) {
                    // line 115
                    echo "                    ";
                } else {
                    // line 116
                    echo "                    <div class=\"saleback\"> <span class=\"sale\">";
                    echo ($context["text_sale"] ?? null);
                    echo "</span> </div>
                    ";
                }
                // line 118
                echo "       ";
                if (twig_get_attribute($this->env, $this->source, $context["product"], "rating", [], "any", false, false, false, 118)) {
                    // line 119
                    echo "      <div class=\"rating\">
        ";
                    // line 120
                    $context['_parent'] = $context;
                    $context['_seq'] = twig_ensure_traversable(range(1, 5));
                    foreach ($context['_seq'] as $context["_key"] => $context["i"]) {
                        // line 121
                        echo "          ";
                        if ((twig_get_attribute($this->env, $this->source, $context["product"], "rating", [], "any", false, false, false, 121) < $context["i"])) {
                            echo " <span class=\"fa fa-stack\">
          <i class=\"fa fa-star fa-stack-2x blank\"></i></span>
           ";
                        } else {
                            // line 123
                            echo " <span class=\"fa fa-stack\"><i class=\"fa fa-star fa-stack-2x\"></i></span> ";
                        }
                        // line 124
                        echo "          ";
                    }
                    $_parent = $context['_parent'];
                    unset($context['_seq'], $context['_iterated'], $context['_key'], $context['i'], $context['_parent'], $context['loop']);
                    $context = array_intersect_key($context, $_parent) + $_parent;
                    echo "</div>
           ";
                }
                // line 126
                echo " 
                    </div>

            <div class=\"product-details\">
              <div class=\"caption\">
                 
                 <h4><a href=\"";
                // line 132
                echo twig_get_attribute($this->env, $this->source, $context["product"], "href", [], "any", false, false, false, 132);
                echo "\">";
                echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 132);
                echo "</a></h4>    
              
                ";
                // line 134
                if (twig_get_attribute($this->env, $this->source, $context["product"], "price", [], "any", false, false, false, 134)) {
                    // line 135
                    echo "                <p class=\"price\"> ";
                    if ( !twig_get_attribute($this->env, $this->source, $context["product"], "special", [], "any", false, false, false, 135)) {
                        // line 136
                        echo "                  ";
                        echo twig_get_attribute($this->env, $this->source, $context["product"], "price", [], "any", false, false, false, 136);
                        echo "
                  ";
                    } else {
                        // line 137
                        echo " <span class=\"price-new\">";
                        echo twig_get_attribute($this->env, $this->source, $context["product"], "special", [], "any", false, false, false, 137);
                        echo "</span> <span class=\"price-old\">";
                        echo twig_get_attribute($this->env, $this->source, $context["product"], "price", [], "any", false, false, false, 137);
                        echo "</span> ";
                    }
                    // line 138
                    echo "                  ";
                    if (twig_get_attribute($this->env, $this->source, $context["product"], "tax", [], "any", false, false, false, 138)) {
                        echo " <span class=\"price-tax\">";
                        echo ($context["text_tax"] ?? null);
                        echo " ";
                        echo twig_get_attribute($this->env, $this->source, $context["product"], "tax", [], "any", false, false, false, 138);
                        echo "</span> ";
                    }
                    echo " </p>
                ";
                }
                // line 140
                echo "                  
                <p class=\"desc\">";
                // line 141
                echo twig_get_attribute($this->env, $this->source, $context["product"], "description", [], "any", false, false, false, 141);
                echo "</p>
\t\t\t\t                    
    <div id=\"product-";
                // line 143
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 143);
                echo "\" class=\"product_option\"> 
            
        ";
                // line 145
                $context['_parent'] = $context;
                $context['_seq'] = twig_ensure_traversable(twig_get_attribute($this->env, $this->source, $context["product"], "options", [], "any", false, false, false, 145));
                foreach ($context['_seq'] as $context["_key"] => $context["option"]) {
                    echo "           
            ";
                    // line 146
                    if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 146) == "select")) {
                        // line 147
                        echo "            <div class=\"form-group";
                        if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 147)) {
                            echo " required ";
                        }
                        echo "\">              
              <label class=\"control-label\">";
                        // line 148
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 148);
                        echo "</label>
              <select name=\"option[";
                        // line 149
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 149);
                        echo "]\" id=\"input-option";
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 149);
                        echo "\" class=\"form-control\">
                <option value=\"\">";
                        // line 150
                        echo ($context["text_select"] ?? null);
                        echo "</option>
                ";
                        // line 151
                        $context['_parent'] = $context;
                        $context['_seq'] = twig_ensure_traversable(twig_get_attribute($this->env, $this->source, $context["option"], "product_option_value", [], "any", false, false, false, 151));
                        foreach ($context['_seq'] as $context["_key"] => $context["option_value"]) {
                            // line 152
                            echo "                <option value=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "product_option_value_id", [], "any", false, false, false, 152);
                            echo "\">";
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 152);
                            echo "
                ";
                            // line 153
                            if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 153)) {
                                // line 154
                                echo "                (";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 154);
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 154);
                                echo ")
                ";
                            }
                            // line 155
                            echo " </option>
                ";
                        }
                        $_parent = $context['_parent'];
                        unset($context['_seq'], $context['_iterated'], $context['_key'], $context['option_value'], $context['_parent'], $context['loop']);
                        $context = array_intersect_key($context, $_parent) + $_parent;
                        // line 157
                        echo "              </select>
            </div>
            ";
                    }
                    // line 160
                    echo "            ";
                    if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 160) == "radio")) {
                        // line 161
                        echo "            <div class=\"form-group";
                        if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 161)) {
                            echo " required ";
                        }
                        echo "radio-block\">
               <label class=\"control-label\">";
                        // line 162
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 162);
                        echo "</label>
               <div id=\"input-option";
                        // line 163
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 163);
                        echo "\">
              ";
                        // line 164
                        $context["i"] = 1;
                        // line 165
                        echo "               ";
                        $context['_parent'] = $context;
                        $context['_seq'] = twig_ensure_traversable(twig_get_attribute($this->env, $this->source, $context["option"], "product_option_value", [], "any", false, false, false, 165));
                        foreach ($context['_seq'] as $context["_key"] => $context["option_value"]) {
                            // line 166
                            echo "                <div class=\"radio\">
                  <label data-toggle=\"tooltip\" title=\"";
                            // line 167
                            if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 167)) {
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 167);
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 167);
                            }
                            echo "\">
                    <input type=\"radio\" name=\"option[";
                            // line 168
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 168);
                            echo "]\" value=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "product_option_value_id", [], "any", false, false, false, 168);
                            echo "\" ";
                            if ((($context["i"] ?? null) == 1)) {
                                echo " checked=\"checked\" ";
                            }
                            echo "/>
                    ";
                            // line 169
                            if (twig_get_attribute($this->env, $this->source, $context["option_value"], "image", [], "any", false, false, false, 169)) {
                                echo "<span> <img src=\"";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "image", [], "any", false, false, false, 169);
                                echo "\" alt=\"";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 169);
                                echo " ";
                                if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 169)) {
                                    echo " ";
                                    echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 169);
                                    echo " ";
                                    echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 169);
                                    echo " ";
                                }
                                echo "\" class=\"img-thumbnail\" /> </span>
                    ";
                            } else {
                                // line 171
                                echo "                    <span>";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 171);
                                echo "</span>
                    ";
                            }
                            // line 172
                            echo " 
                     </label>
                </div>
                 ";
                            // line 175
                            $context["i"] = (($context["i"] ?? null) + 1);
                            // line 176
                            echo "                ";
                        }
                        $_parent = $context['_parent'];
                        unset($context['_seq'], $context['_iterated'], $context['_key'], $context['option_value'], $context['_parent'], $context['loop']);
                        $context = array_intersect_key($context, $_parent) + $_parent;
                        echo " </div>
            </div>
            ";
                    }
                    // line 179
                    echo "            ";
                    if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 179) == "checkbox")) {
                        // line 180
                        echo "            <div class=\"form-group";
                        if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 180)) {
                            echo " required ";
                        }
                        echo "\">              
              <div id=\"input-option";
                        // line 181
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 181);
                        echo "\"> ";
                        $context['_parent'] = $context;
                        $context['_seq'] = twig_ensure_traversable(twig_get_attribute($this->env, $this->source, $context["option"], "product_option_value", [], "any", false, false, false, 181));
                        foreach ($context['_seq'] as $context["_key"] => $context["option_value"]) {
                            // line 182
                            echo "                <div class=\"checkbox\">
                  <label>
                    <input type=\"checkbox\" name=\"option[";
                            // line 184
                            echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 184);
                            echo "][]\" value=\"";
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "product_option_value_id", [], "any", false, false, false, 184);
                            echo "\" />
                    ";
                            // line 185
                            if (twig_get_attribute($this->env, $this->source, $context["option_value"], "image", [], "any", false, false, false, 185)) {
                                echo " <img src=\"";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "image", [], "any", false, false, false, 185);
                                echo "\" alt=\"";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 185);
                                echo " ";
                                if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 185)) {
                                    echo " ";
                                    echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 185);
                                    echo " ";
                                    echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 185);
                                    echo " ";
                                }
                                echo "\" class=\"img-thumbnail\" /> ";
                            }
                            // line 186
                            echo "                    ";
                            echo twig_get_attribute($this->env, $this->source, $context["option_value"], "name", [], "any", false, false, false, 186);
                            echo "
                    ";
                            // line 187
                            if (twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 187)) {
                                // line 188
                                echo "                    (";
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price_prefix", [], "any", false, false, false, 188);
                                echo twig_get_attribute($this->env, $this->source, $context["option_value"], "price", [], "any", false, false, false, 188);
                                echo ")
                    ";
                            }
                            // line 189
                            echo " </label>
                </div>
                ";
                        }
                        $_parent = $context['_parent'];
                        unset($context['_seq'], $context['_iterated'], $context['_key'], $context['option_value'], $context['_parent'], $context['loop']);
                        $context = array_intersect_key($context, $_parent) + $_parent;
                        // line 191
                        echo " </div>
            </div>
            ";
                    }
                    // line 194
                    echo "            ";
                    if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 194) == "text")) {
                        // line 195
                        echo "            <div class=\"form-group";
                        if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 195)) {
                            echo " required ";
                        }
                        echo "\">             
              <label class=\"control-label\">";
                        // line 196
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 196);
                        echo "</label>
              <input type=\"text\" name=\"option[";
                        // line 197
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 197);
                        echo "]\" value=\"";
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 197);
                        echo "\" placeholder=\"";
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 197);
                        echo "\" id=\"input-option";
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 197);
                        echo "\" class=\"form-control\" />
            </div>
            ";
                    }
                    // line 200
                    echo "            ";
                    if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 200) == "textarea")) {
                        // line 201
                        echo "            <div class=\"form-group";
                        if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 201)) {
                            echo " required ";
                        }
                        echo "\">
              <label class=\"control-label\">";
                        // line 202
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 202);
                        echo "</label>
              <textarea name=\"option[";
                        // line 203
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 203);
                        echo "]\" rows=\"5\" placeholder=\"";
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 203);
                        echo "\" id=\"input-option";
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 203);
                        echo "\" class=\"form-control\">";
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 203);
                        echo "</textarea>
            </div>
            ";
                    }
                    // line 206
                    echo "            ";
                    if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 206) == "file")) {
                        // line 207
                        echo "            <div class=\"form-group";
                        if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 207)) {
                            echo " required ";
                        }
                        echo "\">             
              <label class=\"control-label\">";
                        // line 208
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 208);
                        echo "</label>
              <button type=\"button\" id=\"button-upload";
                        // line 209
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 209);
                        echo "\" data-loading-text=\"";
                        echo ($context["text_loading"] ?? null);
                        echo "\" class=\"btn btn-default btn-block\"><i class=\"fa fa-upload\"></i> ";
                        echo ($context["button_upload"] ?? null);
                        echo "</button>
              <input type=\"hidden\" name=\"option[";
                        // line 210
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 210);
                        echo "]\" value=\"\" id=\"input-option";
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 210);
                        echo "\" />
            </div>
            ";
                    }
                    // line 213
                    echo "            ";
                    if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 213) == "date")) {
                        // line 214
                        echo "            <div class=\"form-group";
                        if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 214)) {
                            echo " required ";
                        }
                        echo "\">              
              <label class=\"control-label\">";
                        // line 215
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 215);
                        echo "</label>
              <div class=\"input-group date\">
                <input type=\"text\" name=\"option[";
                        // line 217
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 217);
                        echo "]\" value=\"";
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 217);
                        echo "\" data-date-format=\"YYYY-MM-DD\" id=\"input-option";
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 217);
                        echo "\" class=\"form-control\" />
                <span class=\"input-group-btn\">
                <button class=\"btn btn-default\" type=\"button\"><i class=\"fa fa-calendar\"></i></button>
                </span></div>
            </div>
            ";
                    }
                    // line 223
                    echo "            ";
                    if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 223) == "datetime")) {
                        // line 224
                        echo "            <div class=\"form-group";
                        if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 224)) {
                            echo " required ";
                        }
                        echo "\">             
              <label class=\"control-label\">";
                        // line 225
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 225);
                        echo "</label>
              <div class=\"input-group datetime\">
                <input type=\"text\" name=\"option[";
                        // line 227
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 227);
                        echo "]\" value=\"";
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 227);
                        echo "\" data-date-format=\"YYYY-MM-DD HH:mm\" id=\"input-option";
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 227);
                        echo "\" class=\"form-control\" />
                <span class=\"input-group-btn\">
                <button type=\"button\" class=\"btn btn-default\"><i class=\"fa fa-calendar\"></i></button>
                </span></div>
            </div>
            ";
                    }
                    // line 233
                    echo "            ";
                    if ((twig_get_attribute($this->env, $this->source, $context["option"], "type", [], "any", false, false, false, 233) == "time")) {
                        // line 234
                        echo "            <div class=\"form-group";
                        if (twig_get_attribute($this->env, $this->source, $context["option"], "required", [], "any", false, false, false, 234)) {
                            echo " required ";
                        }
                        echo "\">            
              <label class=\"control-label\">";
                        // line 235
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "name", [], "any", false, false, false, 235);
                        echo "</label>
              <div class=\"input-group time\">
                <input type=\"text\" name=\"option[";
                        // line 237
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 237);
                        echo "]\" value=\"";
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "value", [], "any", false, false, false, 237);
                        echo "\" data-date-format=\"HH:mm\" id=\"input-option";
                        echo twig_get_attribute($this->env, $this->source, $context["option"], "product_option_id", [], "any", false, false, false, 237);
                        echo "\" class=\"form-control\" />
                <span class=\"input-group-btn\">
                <button type=\"button\" class=\"btn btn-default\"><i class=\"fa fa-calendar\"></i></button>
                </span></div>
            </div>
            ";
                    }
                    // line 243
                    echo "            ";
                }
                $_parent = $context['_parent'];
                unset($context['_seq'], $context['_iterated'], $context['_key'], $context['option'], $context['_parent'], $context['loop']);
                $context = array_intersect_key($context, $_parent) + $_parent;
                // line 244
                echo "           
            
           <div class=\"input-group col-xs-12 col-sm-12 button-group\"> 
             
              <label class=\"control-label col-sm-2 col-xs-2\">";
                // line 248
                echo ($context["entry_qty"] ?? null);
                echo "</label>
              
              <input type=\"number\" name=\"quantity\" min=\"1\" value=\"";
                // line 250
                echo ($context["minimum"] ?? null);
                echo "\" size=\"1\" step=\"1\" id=\"input-quantity";
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 250);
                echo "\" class=\"qty form-control col-sm-2 col-xs-9\" />
              <input type=\"hidden\" name=\"product_id\" value=\"";
                // line 251
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 251);
                echo "\" />
              <button type=\"button\" class=\"addtocart\" id=\"add-cart-";
                // line 252
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 252);
                echo "\" onclick=\"var xqty='input-quantity";
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 252);
                echo "';
              var aqty = parseInt(document.getElementById(xqty).value); addtoCart(";
                // line 253
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 253);
                echo ",aqty);\">";
                echo ($context["button_cart"] ?? null);
                echo "</button>
              <button type=\"button\" class=\"compare pull-right\"  onclick=\"compare.add('";
                // line 254
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 254);
                echo "');\">
            <i class=\"fa fa-exchange\"></i></button>
            <button type=\"button\" class=\"wishlist pull-right\" onclick=\"wishlist.add('";
                // line 256
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 256);
                echo "');\"><i class=\"fa fa-heart\"></i> </button>
            <a class=\"quickview pull-right\" href=\"";
                // line 257
                echo twig_get_attribute($this->env, $this->source, $context["product"], "quick", [], "any", false, false, false, 257);
                echo "\"><i class=\"fa fa-eye\"></i></a>
            </div>
           
            </div>

      
                </div>
            </div>
          </div>
        
        
</div>
        ";
            }
            $_parent = $context['_parent'];
            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['product'], $context['_parent'], $context['loop']);
            $context = array_intersect_key($context, $_parent) + $_parent;
            // line 269
            echo " </div>
      <div class=\"row\">
        <div class=\"col-sm-6 text-left\">";
            // line 271
            echo ($context["pagination"] ?? null);
            echo "</div>
        <div class=\"col-sm-6 text-right\">";
            // line 272
            echo ($context["results"] ?? null);
            echo "</div>
      </div>
      ";
        }
        // line 275
        echo "      </div>
      ";
        // line 276
        if (( !($context["categories"] ?? null) &&  !($context["products"] ?? null))) {
            // line 277
            echo "      <p>";
            echo ($context["text_empty"] ?? null);
            echo "</p>
      <div class=\"buttons\">
        <div class=\"pull-right\"><a href=\"";
            // line 279
            echo ($context["continue"] ?? null);
            echo "\" class=\"btn btn-primary\">";
            echo ($context["button_continue"] ?? null);
            echo "</a></div>
      </div>
      ";
        }
        // line 282
        echo "      ";
        echo ($context["content_bottom"] ?? null);
        echo "</div>
    ";
        // line 283
        echo ($context["column_right"] ?? null);
        echo "</div>
</div>
";
        // line 285
        echo ($context["footer"] ?? null);
        echo " 
";
    }

    public function getTemplateName()
    {
        return "oc01/template/product/category.twig";
    }

    public function isTraitable()
    {
        return false;
    }

    public function getDebugInfo()
    {
        return array (  947 => 285,  942 => 283,  937 => 282,  929 => 279,  923 => 277,  921 => 276,  918 => 275,  912 => 272,  908 => 271,  904 => 269,  885 => 257,  881 => 256,  876 => 254,  870 => 253,  864 => 252,  860 => 251,  854 => 250,  849 => 248,  843 => 244,  837 => 243,  824 => 237,  819 => 235,  812 => 234,  809 => 233,  796 => 227,  791 => 225,  784 => 224,  781 => 223,  768 => 217,  763 => 215,  756 => 214,  753 => 213,  745 => 210,  737 => 209,  733 => 208,  726 => 207,  723 => 206,  711 => 203,  707 => 202,  700 => 201,  697 => 200,  685 => 197,  681 => 196,  674 => 195,  671 => 194,  666 => 191,  658 => 189,  651 => 188,  649 => 187,  644 => 186,  628 => 185,  622 => 184,  618 => 182,  612 => 181,  605 => 180,  602 => 179,  592 => 176,  590 => 175,  585 => 172,  579 => 171,  562 => 169,  552 => 168,  545 => 167,  542 => 166,  537 => 165,  535 => 164,  531 => 163,  527 => 162,  520 => 161,  517 => 160,  512 => 157,  505 => 155,  498 => 154,  496 => 153,  489 => 152,  485 => 151,  481 => 150,  475 => 149,  471 => 148,  464 => 147,  462 => 146,  456 => 145,  451 => 143,  446 => 141,  443 => 140,  431 => 138,  424 => 137,  418 => 136,  415 => 135,  413 => 134,  406 => 132,  398 => 126,  389 => 124,  386 => 123,  379 => 121,  375 => 120,  372 => 119,  369 => 118,  363 => 116,  360 => 115,  358 => 114,  348 => 113,  344 => 111,  338 => 109,  336 => 108,  330 => 104,  326 => 103,  318 => 97,  312 => 96,  304 => 94,  296 => 92,  293 => 91,  289 => 90,  282 => 86,  275 => 81,  269 => 80,  261 => 78,  253 => 76,  250 => 75,  246 => 74,  239 => 70,  230 => 66,  223 => 62,  219 => 61,  215 => 60,  209 => 56,  207 => 55,  204 => 54,  200 => 52,  195 => 49,  187 => 47,  176 => 45,  172 => 44,  168 => 42,  163 => 41,  157 => 37,  146 => 35,  142 => 34,  137 => 31,  135 => 30,  131 => 29,  128 => 28,  125 => 27,  120 => 24,  114 => 23,  111 => 22,  101 => 20,  98 => 19,  96 => 18,  92 => 17,  85 => 16,  82 => 15,  79 => 14,  76 => 13,  73 => 12,  70 => 11,  67 => 10,  65 => 9,  61 => 8,  58 => 7,  47 => 5,  43 => 4,  37 => 1,);
    }

    public function getSourceContext()
    {
        return new Source("", "oc01/template/product/category.twig", "");
    }
}
