<?php

$_['textual_js'] = array(
    '_code' => 'en',
    // This format is self-invented and quite fragile. Test carefully.
    'view_active' => 'The special expires in {days}&nbsp;day{day_number::s}&nbsp;{hours}:{minutes}:{seconds}',
    'view_expired' => 'The special offer is already expired.',
);

$_['simple'] = array(
    'text' => 'The special expires in',
    'text_expired' => 'The special expired',
    'day_abbr' => 'd',

    'day_title' => 'days',
    'hour_title' => 'hours',
    'min_title' => 'min',
    'sec_title' => 'sec',
);
