<?php
// Heading
$_['heading_title']    = 'Stock Statuses';

// Text
$_['text_success']     = 'Success: You have modified stock statuses!';
$_['text_list']        = 'Stock Status List';
$_['text_add']         = 'Add Stock Status';
$_['text_edit']        = 'Edit Stock Status';

// Column
$_['column_name']      = 'Stock Status Name';
$_['column_action']    = 'Action';

// Entry
$_['entry_name']       = 'Stock Status Name';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify stock statuses!';
$_['error_name']       = 'Stock Status Name must be between 3 and 32 characters!';
$_['error_product']    = 'Warning: This stock status cannot be deleted as it is currently assigned to %s products!';