<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  961788 => 'Touch',
  9617890 => 'Touch',
  9617891 => 'Touch',
  9617892 => 'Touch',
  9617893 => 'Touch',
  9617894 => 'Touch',
  961791 => 'Alfa',
  961793 => 'Alfa',
  961810 => 'Touch',
  961811 => 'Alfa',
  961812 => 'Alfa',
  961813 => 'Alfa',
  961814 => 'Alfa',
  961815 => 'Alfa',
  961816 => 'Touch',
  961817 => 'Touch',
  961818 => 'Touch',
  961819 => 'Touch',
);
