<?php

// Heading Goes here:
$_['heading_title']            = 'Ajax Live Options';

// Text
$_['text_extension']   		   = 'Extensions';
$_['text_edit']                = 'Edit Ajax Live Options Module';
$_['text_success']             = 'Success: You have modified Ajax Live Options module !';
$_['text_total']               = 'Show Total Price (Product Price + Option Price)';
$_['text_added']               = 'Show Option Price';
$_['text_none']                = 'Hide Option Price';

// Entry
$_['entry_show_type']          = 'Sell Price Type';
$_['entry_show_options_type']  = 'Options Price Type';
$_['entry_use_cache']          = 'Use Cache';
$_['entry_calculate_quantity'] = 'Calculate Quantity';
$_['entry_status']             = 'Status';
$_['entry_options_container']  = 'Product Page Container';
$_['entry_special_container']  = 'Special Price Container';
$_['entry_price_container']    = 'Sell Price Container';
$_['entry_tax_container']      = 'Tax Price Container';
$_['entry_points_container']   = 'Points Container';
$_['entry_reward_container']   = 'Reward Container';

// Help
$_['help_calculate']           = 'Calculate price with quantity';
$_['help_tab_css_desc']        = 'For some special themes, you may need to define your css container with this setting.';
$_['help_options_container']   = 'Set default: \'#content\'';
$_['help_special_container']   = 'Set default: \'.price-new-live\'';
$_['help_price_container']     = 'Set default: \'.price-old-live\'';
$_['help_tax_container']       = 'Set default: \'.price-tax-live\'';
$_['help_points_container']    = 'Set default: \'.spend-points-live\'';
$_['help_reward_container']    = 'Set default: \'.get-reward-live\'';
$_['help_use_cache']    	   = 'Disable for Develop, Enable for Production';

// Error
$_['error_permission']         = 'Warning: You do not have permission to modify Ajax Live Options module !';
$_['error_options_container']  = 'Product Page Container required!';
$_['error_special_container']  = 'Special Price Container required!';
$_['error_price_container']    = 'Sell Price Container required!';
$_['error_tax_container']      = 'Tax Price Container required!';
$_['error_points_container']   = 'Points Container required!';
$_['error_reward_container']   = 'Reward Container required!';
