<?php
// Heading
$_['heading_title']    = 'Store Locations';

// Text
$_['text_success']     = 'Success: You have modified store locations!';
$_['text_list']        = 'Store Location List';
$_['text_add']         = 'Add Store Location';
$_['text_edit']        = 'Edit Store Location';
$_['text_default']     = 'Default';
$_['text_time']        = 'Opening Times';
$_['text_geocode']     = 'Geocode was not successful for the following reason:';

// Column
$_['column_name']      = 'Store Name';
$_['column_address']   = 'Address';
$_['column_action']    = 'Action';

// Entry
$_['entry_name']       = 'Store Name';
$_['entry_address']    = 'Address';
$_['entry_geocode']    = 'Geocode';
$_['entry_telephone']  = 'Telephone';
$_['entry_fax']        = 'Fax';
$_['entry_image']      = 'Image';
$_['entry_open']       = 'Opening Times';
$_['entry_comment']    = 'Comment';

// Help
$_['help_geocode']     = 'Please enter your store location geocode manually.';
$_['help_open']        = 'Fill in your stores opening times.';
$_['help_comment']     = 'This field is for any special notes you would like to tell the customer i.e. Store does not accept cheques.';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify store locations!';
$_['error_name']       = 'Store name must be between 3 and 32 characters!';
$_['error_address']    = 'Address must be between 3 and 128 characters!';
$_['error_telephone']  = 'Telephone must be between 3 and 32 characters!';