<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  8862 => 'Taipei',
  8863 => 'Taoyuan/Hsinchu/Yilan/Hualien',
  88637 => 'Miaoli',
  88642 => 'Taichung/Changhua',
  88643 => 'Taichung/Changhua',
  88647 => 'Taichung/Changhua',
  88648 => 'Taichung/Changhua',
  88649 => 'Nantou',
  8865 => 'Chiayi/Yunlin',
  8866 => 'Tainan/Penghu',
  8867 => 'Kaohsiung',
  88680 => 'Pingtung',
  886823 => 'Kinmen',
  886826 => 'Wuqiu',
  88687 => 'Pingtung',
  88688 => 'Pingtung',
  88689 => 'Taitung',
);
