<?php
$_['text_editor_title'] = 'AQC7 Visual Editor';
$_['text_loading'] = 'Loading...';
$_['text_register'] = 'Register';
$_['text_guest'] = 'Guest';
$_['text_logged'] = 'Logged';
$_['text_display'] = 'Display';
$_['text_require'] = 'Require';
$_['text_title'] = 'Title';
$_['text_description'] = 'Description';
$_['text_placeholder'] = 'Placeholder';
$_['text_tooltip'] = 'Tooltip';
$_['text_error_rules'] = 'Error rules';
$_['text_depends'] = 'Depends';
$_['text_add'] = 'Add';
$_['text_value'] = 'Value';
$_['text_default'] = 'Default';
$_['text_not_checked'] = 'Not checked';
$_['text_checked'] = 'Checked';
$_['text_has_dependencies'] = 'This field has dependencies setup';
$_['text_no_payment_step'] = 'Your checkout does not have a Payment step. Customers will not be able to checkout without a payment step. Please add this step and hide it if required.';

$_['entry_select'] = 'select';
$_['entry_radio'] = 'radio';

$_['text_telephone_validation'] = 'Telephone validation';
$_['text_telephone_countries'] = 'Allowed telephone countries';
$_['text_layout'] = 'Select layout';
$_['text_skin'] = 'Select skin';

$_['text_general'] = 'General';
$_['text_css'] = 'CSS';
$_['text_script'] = 'Scripts';
$_['text_error'] = 'Errors';
$_['text_dependency'] = 'Dependency';
$_['text_design'] = 'Design';
$_['text_style'] = 'Style';
$_['text_mask'] = 'Mask';
$_['text_header_footer'] = 'Header & footer';
$_['text_reset'] = 'Reset layout';

$_['text_add_page'] = 'Add page';
$_['text_page_1'] = 'Page 1';
$_['text_settings'] = 'Settings';
$_['text_hidden'] = 'Hidden';

$_['text_not_empty'] = 'Not empty';
$_['text_min_length'] = 'Min length';
$_['text_max_length'] = 'Max length';
$_['text_checked'] = 'Is checked';
$_['text_compare_to'] = 'Compare to';
$_['text_telephone'] = 'Telephone';
$_['text_email_exists'] = 'Email Exists';
$_['text_regex'] = 'Regex';

$_['entry_not_empty'] = 'Not empty';
$_['entry_checked'] = 'Is checked';
$_['entry_telephone'] = 'Telephone';
$_['entry_email_exists'] = 'Email Exists';
$_['entry_min_length'] = 'Set minimal length';
$_['entry_max_length'] = 'Set maximum length';
$_['entry_compare_to'] = 'Select field we should compare to';
$_['entry_regex'] = 'Set Regular expression';
$_['entry_text'] = 'Enter error text';
$_['entry_fax'] = 'Fax';

$_['error_min_length'] = 'Sorry, but you need to have the length of the text more then 3 and less then 96';
$_['error_max_length'] = 'Sorry, but you need to have the length of the text more then 3 and less then 96';
$_['error_compare_to'] = 'Email confirmation does not match email';
$_['error_not_empty'] = 'This field is required';
$_['error_checked'] = 'This field is required';
$_['error_regex'] = 'Please check the value';
$_['error_telephone'] = 'This is not a valid telephone number';
$_['error_email_exists'] = 'This email already exists';
