/* CSS Document */
.swiper-viewport {
    margin: 0;
    z-index: 1;
    position: relative;
    overflow: visible;
	float:  left;
	width: 100%;

}

/* OpenCart Code */

.testimonialpage .swiper-pagination-bullet{margin: 5px;}
.swiper-wrapper,.swiper-slide{height: auto;}
.swiper-pager.mainbanner {top: 50%;}
.customtab .swiper-pager {top: 42%;}
.product-additional-block .swiper-pager {top: 74px;}
.swiper-pager {
	width: 100%;
	position: absolute;
	top:0;
	line-height: 45px;
	opacity: 0;
}
.main-slider:hover .swiper-pager{opacity: 1;}
.swiper-button-prev, .swiper-button-next {
	color: rgba(0, 0, 0, 0.8);
	transition: all .3s ease;
	z-index: 2;
 	background-image: none;
	height:25px;
	width:25px;
	line-height:30px;
}


.mainbanner .swiper-button-next{
 display: inline-block;
    width: 40px;
    height: 40px;
    text-align: center;
    vertical-align: middle;
	margin:0px ;
	right: 0px;
    border-radius: 5px;
    transition: all 0.5s;

}
.mainbanner .swiper-button-prev{
	display: inline-block;
    width: 40px;
    height: 40px;
    text-align: center;
    vertical-align: middle;
	margin:0;
	top:45%;
	left: 0px;
    border-radius: 5px;
    transition: all 0.5s;

}

.product-additional-block.swiper-viewport .swiper-button-prev {
	left: 10px;
}
.swiper-viewport .swiper-button-next {
	opacity: 1;


}
.swiper-viewport .swiper-button-prev {
	opacity: 1;

}

/* Desktop */
@media (min-width: 768px){

.customtab  .swiper-viewport:hover .swiper-button-prev {
	opacity: 1;
	left: 10px;

}
.swiper-viewport:hover .swiper-button-next {
	opacity: 1;
    right: 20px;
    transition: all 0.5s;

}
.swiper-viewport:hover .swiper-button-prev {
	opacity: 1;
    left: 20px;
    transition: all 0.5s;
}
}

.swiper-pagination {
	bottom: 20px;
	left: 0;
	text-align: center;
	width: 100%;
	display: none;
}
.swiper-pagination-bullet {
	width: 11px;
	height: 11px;
	background: #000;
	border-radius: 20px;
	margin: 0 5px;
	opacity: 1;
	transition: 0.5s;
}
.swiper-pagination-bullet:hover {
	background: #84c225;
}
.swiper-pagination-bullet-active {
	background: #84c225;
	width: 25px;
	transition: 0.5s;
}
.swiper-button-next.swiper-button-disabled, .swiper-button-prev.swiper-button-disabled {
    opacity: 0;
    cursor: pointer;
    pointer-events: auto;
}
