<?php
// Heading
$_['heading_title']    = 'Return Actions';

// Text
$_['text_success']     = 'Success: You have modified return actions!';
$_['text_list']        = 'Return Action List';
$_['text_add']         = 'Add Return Action';
$_['text_edit']        = 'Edit Return Action';

// Column
$_['column_name']      = 'Return Action Name';
$_['column_action']    = 'Action';

// Entry
$_['entry_name']       = 'Return Action Name';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify return actions!';
$_['error_name']       = 'Return Action Name must be between 3 and 64 characters!';
$_['error_return']     = 'Warning: This return action cannot be deleted as it is currently assigned to %s returned products!';