<?php
// Heading
$_['heading_title']    = 'Google Hangouts';

// Text
$_['text_extension']   = 'Extensions';
$_['text_success']     = 'Success: You have modified Google Hangouts module!';
$_['text_edit']        = 'Edit Google Hangouts Module';

// Entry
$_['entry_code']       = 'Google Talk Code';
$_['entry_status']     = 'Status';

// Help
$_['help_code']        = 'Goto <a href="https://developers.google.com/+/hangouts/button" target="_blank">Create a Google Hangout chatback badge</a> and copy &amp; paste the generated code into the text box.';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify Google Hangouts module!';
$_['error_code']       = 'Code Required';