<?php
// Heading
$_['heading_title']          = 'Attributes';

// Text
$_['text_success']           = 'Success: You have modified attributes!';
$_['text_list']              = 'Attribute List';
$_['text_add']               = 'Add Attribute';
$_['text_edit']              = 'Edit Attribute';

// Column
$_['column_name']            = 'Attribute Name';
$_['column_attribute_group'] = 'Attribute Group';
$_['column_sort_order']      = 'Sort Order';
$_['column_action']          = 'Action';

// Entry
$_['entry_name']             = 'Attribute Name';
$_['entry_attribute_group']  = 'Attribute Group';
$_['entry_sort_order']       = 'Sort Order';

// Error
$_['error_permission']       = 'Warning: You do not have permission to modify attributes!';
$_['error_attribute_group']  = 'Attribute Group Required!';
$_['error_name']             = 'Attribute Name must be between 1 and 64 characters!';
$_['error_product']          = 'Warning: This attribute cannot be deleted as it is currently assigned to %s products!';