<?php
$_['text_checkout_title']      = 'Pay in instalments';
$_['text_choose_plan']         = 'Choose your plan';
$_['text_choose_deposit']      = 'Choose your deposit';
$_['text_monthly_payments']    = 'monthly payments of';
$_['text_months']              = 'months';
$_['text_term']                = 'Term';
$_['text_deposit']             = 'Deposit';
$_['text_credit_amount']       = 'Cost of credit';
$_['text_amount_payable']      = 'Total payable';
$_['text_total_interest']      = 'Total interest APR';
$_['text_monthly_installment'] = 'Monthly installment';
$_['text_redirection']         = 'You will be redirected to Divido to complete this finance application when you confirm your order';
$_['divido_checkout']          = 'Confirm and checkout with Divido';
$_['deposit_to_low']           = 'Deposit to low';
$_['credit_amount_to_low']     = 'Credit amount to low';
$_['no_country']               = 'Country not accepted';
