<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;

/* extension/d_quickcheckout/editor.twig */
class __TwigTemplate_1790497396db29eafd37532b43d88fde5e1ca6e7c38b7abd237bb59783f04442 extends \Twig\Template
{
    private $source;
    private $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = [])
    {
        $macros = $this->macros;
        // line 1
        echo "<!DOCTYPE html>
<html>
<head>
    <title>Editor</title>
</head>
<body>
<style>
html, body {
    height: 100%;
    margin: 0;
}
iframe{
    display:block;
}
</style>
<iframe src=\"";
        // line 16
        echo ($context["editor"] ?? null);
        echo "\" style=\"border: 0; width: 100%; height: 100%\">Your browser doesn't support iFrames.</iframe>

</body>
</html>
";
    }

    public function getTemplateName()
    {
        return "extension/d_quickcheckout/editor.twig";
    }

    public function isTraitable()
    {
        return false;
    }

    public function getDebugInfo()
    {
        return array (  54 => 16,  37 => 1,);
    }

    public function getSourceContext()
    {
        return new Source("", "extension/d_quickcheckout/editor.twig", "");
    }
}
