<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  3892 => 'Skopje',
  38931 => 'Kumanovo/Kriva Palanka/Kratovo',
  38932 => 'Stip/Probistip/Sveti Nikole/Radovis',
  38933 => 'Kocani/Berovo/Delcevo/Vinica',
  38934 => 'Gevgelija/Valandovo/Strumica/Dojran',
  38942 => 'Gostivar',
  38943 => 'Veles/Kavadarci/Negotino',
  38944 => 'Tetovo',
  38945 => 'Kicevo/Makedonski Brod',
  38946 => 'Ohrid/Struga/Debar',
  38947 => 'Bitola/Demir Hisar/Resen',
  38948 => 'Prilep/Krusevo',
);
