<?php
// Heading
$_['heading_title'] = 'Failed Payment!';

// Text
$_['text_basket']   = 'Shopping Cart';
$_['text_checkout'] = 'Checkout';
$_['text_failure']  = 'Failed Payment';
$_['text_message']  = '<p>There was a problem processing your payment and the order did not complete.</p>

<p>Possible reasons are:</p>
<ul>
  <li>Insufficient funds</li>
  <li>Verification failed</li>
</ul>

<p>Please try to order again using a different payment method.</p>

<p>If the problem persists please <a href="%s">contact us</a> with the details of the order you are trying to place.</p>
';