<form action="https://payments.securetrading.net/process/payments/details" method="POST" class="form-horizontal">
  <fieldset id="payment">
    <legend>{{ text_payment_details }}</legend>
    <input type="hidden" name="sitereference" value="{{ site_reference }}" />
    <input type="hidden" name="currencyiso3a" value="{{ currency }}" />
    <input type="hidden" name="mainamount" value="{{ total }}" />
    <input type="hidden" name="version" value="1" />
    <input type="hidden" name="orderreference" value="{{ order_info.order_id }}" />
    <input type="hidden" name="settlestatus" value="{{ settle_status }}" />
    <input type="hidden" name="settleduedate" value="{{ settle_due_date }}" />
    <input type="hidden" name="billingfirstname" value="{{ order_info.payment_firstname }}" />
    <input type="hidden" name="billinglastname" value="{{ order_info.payment_lastname }}" />
    <input type="hidden" name="billingpremise" value="{{ order_info.payment_address_1 }}" />
    <input type="hidden" name="billingstreet" value="{{ order_info.payment_address_2 }}" />
    <input type="hidden" name="billingtown" value="{{ order_info.payment_city }}" />
    <input type="hidden" name="billingcounty" value="{{ billing_county }}" />
    <input type="hidden" name="billingpostcode" value="{{ order_info.payment_postcode }}" />
    <input type="hidden" name="billingcountryiso2a" value="{{ payment_country.iso_code_2 }}" />
    <input type="hidden" name="billingemail" value="{{ order_info.email }}" />
    <input type="hidden" name="customerfirstname" value="{{ order_info.shipping_firstname }}" />
    <input type="hidden" name="customerlastname" value="{{ order_info.shipping_lastname }}" />
    <input type="hidden" name="customerpremise" value="{{ order_info.shipping_address_1 }}" />
    <input type="hidden" name="customerstreet" value="{{ order_info.shipping_address_2 }}" />
    <input type="hidden" name="customertown" value="{{ order_info.shipping_city }}" />
    <input type="hidden" name="customercounty" value="{{ shipping_county }}" />
    <input type="hidden" name="customerpostcode" value="{{ order_info.shipping_postcode }}" />
    <input type="hidden" name="customercountryiso2a" value="{{ shipping_country.iso_code_2 }}" />
    <input type="hidden" name="customeremail" value="{{ order_info.email }}" />
    {% if parent_css %}
    <input type="hidden" name="parentcss" value="{{ parent_css }}" />
    {% endif %}
    
    {% if child_css %}
    <input type="hidden" name="childcss" value="{{ child_css }}" />
    {% endif %}
    
    {% if site_security %}
    <input type="hidden" name="sitesecurity" value="g{{ site_security }}" />
    {% endif %}
    <div class="form-group required">
      <label class="col-sm-2 control-label" for="input-type">{{ entry_card_type }}</label>
      <div class="col-sm-10">
        <select name="paymenttypedescription" id="input-type" class="form-control">
          
                    {% for key, title in cards %}
                    
          <option value="{{ key }}">{{ title }}</option>
          
                    {% endfor %}
                
        </select>
      </div>
    </div>
    <div class="form-group">
      <div class="col-sm-12">
        <div class="buttons">
          <div class="pull-right">
            <input type="submit" value="{{ button_confirm }}" class="btn btn-primary" />
          </div>
        </div>
      </div>
    </div>
  </fieldset>
</form>
