{{ header }}{{ column_left }}
<div id="content">
  <div class="page-header">
    <div class="container-fluid">
      <div class="pull-right">
        <button type="submit" form="form-coupon" data-toggle="tooltip" title="{{ button_save }}" class="btn btn-primary"><i class="fa fa-save"></i></button>
        <a href="{{ cancel }}" data-toggle="tooltip" title="{{ button_cancel }}" class="btn btn-default"><i class="fa fa-reply"></i></a></div>
        <h1>{{ heading_title }}</h1>
        <ul class="breadcrumb">
           {% for breadcrumb in breadcrumbs %}
        <li><a href="{{ breadcrumb.href }}">{{ breadcrumb.text }}</a></li>
        {% endfor %}
        </ul>
      </div>
    </div>
    <div class="container-fluid">
      {% if error_warning %}
      <div class="alert alert-danger"><i class="fa fa-exclamation-circle"></i> {{ error_warning }}
        <button type="button" class="close" data-dismiss="alert">&times;</button>
      </div>
       {% endif %}
      <div class="panel panel-default">
        <div class="panel-heading">
          <h3 class="panel-title"><i class="fa fa-pencil"></i> {{ text_form }}</h3>
        </div>
        <div class="panel-body">
          <form action="{{ action }}" method="post" enctype="multipart/form-data" id="form-newsletter" class="form-horizontal">
            <div class="tab-content">
              <div class="tab-pane active" id="tab-general">
                <div class="form-group required">
                  <label class="col-sm-2 control-label" for="input-news_email">{{ entry_news_email }}</label>
                  <div class="col-sm-10">
                    <input type="text" name="news_email" value="{{ news_email }}" placeholder="{{ entry_news_email }}" id="input-news_email" class="form-control" />
                    {% if error_news_email %}
                    <div class="text-danger">{{ error_news_email }}</div>
                    {% endif %}
                  </div>
                  <input type="hidden" name="subscribe_date" value="{{ subscribe_date }}" />
                </div>
              </div>
            </div>
          </form>
        </div>
      </div>
    </div>
  </div>
  {{ footer }}