<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;

/* oc01/template/information/contact.twig */
class __TwigTemplate_c7cf4be10548b8e57f86703fa983998570d71aea868208f4d3c02c764672d8b6 extends \Twig\Template
{
    private $source;
    private $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = [])
    {
        $macros = $this->macros;
        // line 1
        echo ($context["header"] ?? null);
        echo "

<div id=\"information-contact\" class=\"container\">
  <ul class=\"breadcrumb\">
    ";
        // line 5
        $context['_parent'] = $context;
        $context['_seq'] = twig_ensure_traversable(($context["breadcrumbs"] ?? null));
        foreach ($context['_seq'] as $context["_key"] => $context["breadcrumb"]) {
            // line 6
            echo "    <li><a href=\"";
            echo twig_get_attribute($this->env, $this->source, $context["breadcrumb"], "href", [], "any", false, false, false, 6);
            echo "\">";
            echo twig_get_attribute($this->env, $this->source, $context["breadcrumb"], "text", [], "any", false, false, false, 6);
            echo "</a></li>
    ";
        }
        $_parent = $context['_parent'];
        unset($context['_seq'], $context['_iterated'], $context['_key'], $context['breadcrumb'], $context['_parent'], $context['loop']);
        $context = array_intersect_key($context, $_parent) + $_parent;
        // line 8
        echo "  </ul>
  <div class=\"row\">";
        // line 9
        echo ($context["column_left"] ?? null);
        echo "
    ";
        // line 10
        if ((($context["column_left"] ?? null) && ($context["column_right"] ?? null))) {
            // line 11
            echo "    ";
            $context["class"] = "col-sm-6";
            // line 12
            echo "    ";
        } elseif ((($context["column_left"] ?? null) || ($context["column_right"] ?? null))) {
            // line 13
            echo "    ";
            $context["class"] = "col-sm-9";
            // line 14
            echo "    ";
        } else {
            // line 15
            echo "    ";
            $context["class"] = "col-sm-12";
            // line 16
            echo "    ";
        }
        // line 17
        echo "    <div id=\"content\" class=\"";
        echo ($context["class"] ?? null);
        echo " contactpage\">";
        echo ($context["content_top"] ?? null);
        echo "
      <h1>";
        // line 18
        echo ($context["heading_title"] ?? null);
        echo "</h1>
     <div id=\"googleMap\" style=\"width:100%;height:500px;\"></div>  
      <script src=\"https://maps.googleapis.com/maps/api/js?key=AIzaSyCBtMUBDEpq49tm1g8lcYUSreyya6tQ6-4\"></script>

<script>
\tgoogle.maps.event.addDomListener(window, 'load', init);
\t
\tfunction init() {
\t\t var locations = [
\t\t\t['California', 36.7783, 119.4179, 1],
\t\t\t/*['Coogee Beach', -33.923036, 151.259052, 5],
\t\t\t['Cronulla Beach', -34.028249, 151.157507, 3],
\t\t\t['Manly Beach', -33.80010128657071, 151.28747820854187, 2],
\t\t\t['Maroubra Beach', -33.950198, 151.259302, 4]*/
\t\t  ];
\t   
\t\tvar mapOptions = {                    
\t\t\tzoom: 10,
\t\t\tscrollwheel:false,                  
\t\t\tcenter: new google.maps.LatLng(36.7783, 119.4179, 1),                   
\t\t};                
\t\tvar mapElement = document.getElementById('googleMap');
\t\t
\t\tvar map = new google.maps.Map(mapElement, mapOptions);\t\t\t    
\t\t var marker, i;
\t\t
\t\tfor (i = 0; i < locations.length; i++) {  
\t\t  marker = new google.maps.Marker({
\t\t\tposition: new google.maps.LatLng(locations[i][1], locations[i][2]),
\t\t\tmap: map
\t\t  });
\t\tinfowindow = new google.maps.InfoWindow({content: \"New york<?php if (\$locations){?><?php foreach (\$locations as \$location) { ?><?php echo \$location['address']; ?><?php } ?><?php } ?>\"});
\t
\t\t  google.maps.event.addListener(marker, 'click', (function(marker, i) {
\t\t\treturn function() {
\t\t\t  infowindow.setContent(locations[i][0]);
\t\t\t  infowindow.open(map, marker);
\t\t\t}
\t\t  })(marker, i));
\t\t}\t\t
\t}
\t
</script>      
      

\t  
\t  <div class=\"panel panel-default\">
        <div class=\"panel-body\">
          <div class=\"row\">
            ";
        // line 67
        if (($context["image"] ?? null)) {
            // line 68
            echo "            <div class=\"col-sm-3\"><img src=\"";
            echo ($context["image"] ?? null);
            echo "\" alt=\"";
            echo ($context["store"] ?? null);
            echo "\" title=\"";
            echo ($context["store"] ?? null);
            echo "\" class=\"img-thumbnail\" /></div>
            ";
        }
        // line 70
        echo "            <div class=\"col-sm-3\"><h2>";
        echo ($context["store"] ?? null);
        echo "</h2><br />
              <address>
              ";
        // line 72
        echo ($context["address"] ?? null);
        echo "
              </address>
              ";
        // line 74
        if (($context["geocode"] ?? null)) {
            // line 75
            echo "              <a href=\"https://maps.google.com/maps?q=";
            echo twig_urlencode_filter(($context["geocode"] ?? null));
            echo "&hl=";
            echo ($context["geocode_hl"] ?? null);
            echo "&t=m&z=15\" target=\"_blank\" class=\"btn btn-info\"><i class=\"fa fa-map-marker\"></i> ";
            echo ($context["button_map"] ?? null);
            echo "</a>
              ";
        }
        // line 77
        echo "            </div>
            <div class=\"col-sm-3\"><h2>";
        // line 78
        echo ($context["text_telephone"] ?? null);
        echo "</h2><br>
              ";
        // line 79
        echo ($context["telephone"] ?? null);
        echo "<br />
              <br />
              ";
        // line 81
        if (($context["fax"] ?? null)) {
            // line 82
            echo "              <h2>";
            echo ($context["text_fax"] ?? null);
            echo "</h2><br>
              ";
            // line 83
            echo ($context["fax"] ?? null);
            echo "
              ";
        }
        // line 85
        echo "            </div>
            <div class=\"col-sm-3\">
              ";
        // line 87
        if (($context["open"] ?? null)) {
            // line 88
            echo "              <h2>";
            echo ($context["text_open"] ?? null);
            echo "</h2><br />
              ";
            // line 89
            echo ($context["open"] ?? null);
            echo "<br />
              <br />
              ";
        }
        // line 92
        echo "              ";
        if (($context["comment"] ?? null)) {
            // line 93
            echo "              <h2>";
            echo ($context["text_comment"] ?? null);
            echo "</h2><br />
              ";
            // line 94
            echo ($context["comment"] ?? null);
            echo "
              ";
        }
        // line 96
        echo "            </div>
          </div>
        </div>
      </div>
      ";
        // line 100
        if (($context["locations"] ?? null)) {
            // line 101
            echo "      <h3>";
            echo ($context["text_store"] ?? null);
            echo "</h3>
      <div class=\"panel-group\" id=\"accordion\">
        ";
            // line 103
            $context['_parent'] = $context;
            $context['_seq'] = twig_ensure_traversable(($context["locations"] ?? null));
            foreach ($context['_seq'] as $context["_key"] => $context["location"]) {
                // line 104
                echo "        <div class=\"panel panel-default\">
          <div class=\"panel-heading\">
            <h4 class=\"panel-title\"><a href=\"#collapse-location";
                // line 106
                echo twig_get_attribute($this->env, $this->source, $context["location"], "location_id", [], "any", false, false, false, 106);
                echo "\" class=\"accordion-toggle\" data-toggle=\"collapse\" data-parent=\"#accordion\">";
                echo twig_get_attribute($this->env, $this->source, $context["location"], "name", [], "any", false, false, false, 106);
                echo " <i class=\"fa fa-caret-down\"></i></a></h4>
          </div>
          <div class=\"panel-collapse collapse\" id=\"collapse-location";
                // line 108
                echo twig_get_attribute($this->env, $this->source, $context["location"], "location_id", [], "any", false, false, false, 108);
                echo "\">
            <div class=\"panel-body\">
              <div class=\"row\">
                ";
                // line 111
                if (twig_get_attribute($this->env, $this->source, $context["location"], "image", [], "any", false, false, false, 111)) {
                    // line 112
                    echo "                <div class=\"col-sm-3\"><img src=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["location"], "image", [], "any", false, false, false, 112);
                    echo "\" alt=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["location"], "name", [], "any", false, false, false, 112);
                    echo "\" title=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["location"], "name", [], "any", false, false, false, 112);
                    echo "\" class=\"img-thumbnail\" /></div>
                ";
                }
                // line 114
                echo "                <div class=\"col-sm-3\"><strong>";
                echo twig_get_attribute($this->env, $this->source, $context["location"], "name", [], "any", false, false, false, 114);
                echo "</strong><br />
                  <address>
                  ";
                // line 116
                echo twig_get_attribute($this->env, $this->source, $context["location"], "address", [], "any", false, false, false, 116);
                echo "
                  </address>
                  ";
                // line 118
                if (twig_get_attribute($this->env, $this->source, $context["location"], "geocode", [], "any", false, false, false, 118)) {
                    // line 119
                    echo "                  <a href=\"https://maps.google.com/maps?q=";
                    echo twig_urlencode_filter(twig_get_attribute($this->env, $this->source, $context["location"], "geocode", [], "any", false, false, false, 119));
                    echo "&hl=";
                    echo ($context["geocode_hl"] ?? null);
                    echo "&t=m&z=15\" target=\"_blank\" class=\"btn btn-info\"><i class=\"fa fa-map-marker\"></i> ";
                    echo ($context["button_map"] ?? null);
                    echo "</a>
                  ";
                }
                // line 121
                echo "                </div>
                <div class=\"col-sm-3\"> <strong>";
                // line 122
                echo ($context["text_telephone"] ?? null);
                echo "</strong><br>
                  ";
                // line 123
                echo twig_get_attribute($this->env, $this->source, $context["location"], "telephone", [], "any", false, false, false, 123);
                echo "<br />
                  <br />
                  ";
                // line 125
                if (twig_get_attribute($this->env, $this->source, $context["location"], "fax", [], "any", false, false, false, 125)) {
                    // line 126
                    echo "                  <strong>";
                    echo ($context["text_fax"] ?? null);
                    echo "</strong><br>
                  ";
                    // line 127
                    echo twig_get_attribute($this->env, $this->source, $context["location"], "fax", [], "any", false, false, false, 127);
                    echo "
                  ";
                }
                // line 129
                echo "                </div>
                <div class=\"col-sm-3\">
                  ";
                // line 131
                if (twig_get_attribute($this->env, $this->source, $context["location"], "open", [], "any", false, false, false, 131)) {
                    // line 132
                    echo "                  <strong>";
                    echo ($context["text_open"] ?? null);
                    echo "</strong><br />
                  ";
                    // line 133
                    echo twig_get_attribute($this->env, $this->source, $context["location"], "open", [], "any", false, false, false, 133);
                    echo "<br />
                  <br />
                  ";
                }
                // line 136
                echo "                  ";
                if (twig_get_attribute($this->env, $this->source, $context["location"], "comment", [], "any", false, false, false, 136)) {
                    // line 137
                    echo "                  <strong>";
                    echo ($context["text_comment"] ?? null);
                    echo "</strong><br />
                  ";
                    // line 138
                    echo twig_get_attribute($this->env, $this->source, $context["location"], "comment", [], "any", false, false, false, 138);
                    echo "
                  ";
                }
                // line 140
                echo "                </div>
              </div>
            </div>
          </div>
        </div>
        ";
            }
            $_parent = $context['_parent'];
            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['location'], $context['_parent'], $context['loop']);
            $context = array_intersect_key($context, $_parent) + $_parent;
            // line 146
            echo "      </div>
      ";
        }
        // line 148
        echo "      <form action=\"";
        echo ($context["action"] ?? null);
        echo "\" method=\"post\" enctype=\"multipart/form-data\" class=\"form-horizontal\">
        <fieldset>
          <legend>";
        // line 150
        echo ($context["text_contact"] ?? null);
        echo "</legend>
          <div class=\"form-group required\">
            <label class=\"col-sm-2 control-label\" for=\"input-name\">";
        // line 152
        echo ($context["entry_name"] ?? null);
        echo "</label>
            <div class=\"col-sm-10\">
              <input type=\"text\" name=\"name\" value=\"";
        // line 154
        echo ($context["name"] ?? null);
        echo "\" id=\"input-name\" class=\"form-control\" />
              ";
        // line 155
        if (($context["error_name"] ?? null)) {
            // line 156
            echo "              <div class=\"text-danger\">";
            echo ($context["error_name"] ?? null);
            echo "</div>
              ";
        }
        // line 158
        echo "            </div>
          </div>
          <div class=\"form-group required\">
            <label class=\"col-sm-2 control-label\" for=\"input-email\">";
        // line 161
        echo ($context["entry_email"] ?? null);
        echo "</label>
            <div class=\"col-sm-10\">
              <input type=\"text\" name=\"email\" value=\"";
        // line 163
        echo ($context["email"] ?? null);
        echo "\" id=\"input-email\" class=\"form-control\" />
              ";
        // line 164
        if (($context["error_email"] ?? null)) {
            // line 165
            echo "              <div class=\"text-danger\">";
            echo ($context["error_email"] ?? null);
            echo "</div>
              ";
        }
        // line 167
        echo "            </div>
          </div>
          <div class=\"form-group required\">
            <label class=\"col-sm-2 control-label\" for=\"input-enquiry\">";
        // line 170
        echo ($context["entry_enquiry"] ?? null);
        echo "</label>
            <div class=\"col-sm-10\">
              <textarea name=\"enquiry\" rows=\"10\" id=\"input-enquiry\" class=\"form-control\">";
        // line 172
        echo ($context["enquiry"] ?? null);
        echo "</textarea>
              ";
        // line 173
        if (($context["error_enquiry"] ?? null)) {
            // line 174
            echo "              <div class=\"text-danger\">";
            echo ($context["error_enquiry"] ?? null);
            echo "</div>
              ";
        }
        // line 176
        echo "            </div>
          </div>
          ";
        // line 178
        echo ($context["captcha"] ?? null);
        echo "
        </fieldset>
        <div class=\"buttons\">
          <div class=\"pull-right\">
            <input class=\"btn btn-primary\" type=\"submit\" value=\"";
        // line 182
        echo ($context["button_submit"] ?? null);
        echo "\" />
          </div>
        </div>
      </form>
      ";
        // line 186
        echo ($context["content_bottom"] ?? null);
        echo "</div>
    ";
        // line 187
        echo ($context["column_right"] ?? null);
        echo "</div>
</div>
";
        // line 189
        echo ($context["footer"] ?? null);
        echo "
";
    }

    public function getTemplateName()
    {
        return "oc01/template/information/contact.twig";
    }

    public function isTraitable()
    {
        return false;
    }

    public function getDebugInfo()
    {
        return array (  472 => 189,  467 => 187,  463 => 186,  456 => 182,  449 => 178,  445 => 176,  439 => 174,  437 => 173,  433 => 172,  428 => 170,  423 => 167,  417 => 165,  415 => 164,  411 => 163,  406 => 161,  401 => 158,  395 => 156,  393 => 155,  389 => 154,  384 => 152,  379 => 150,  373 => 148,  369 => 146,  358 => 140,  353 => 138,  348 => 137,  345 => 136,  339 => 133,  334 => 132,  332 => 131,  328 => 129,  323 => 127,  318 => 126,  316 => 125,  311 => 123,  307 => 122,  304 => 121,  294 => 119,  292 => 118,  287 => 116,  281 => 114,  271 => 112,  269 => 111,  263 => 108,  256 => 106,  252 => 104,  248 => 103,  242 => 101,  240 => 100,  234 => 96,  229 => 94,  224 => 93,  221 => 92,  215 => 89,  210 => 88,  208 => 87,  204 => 85,  199 => 83,  194 => 82,  192 => 81,  187 => 79,  183 => 78,  180 => 77,  170 => 75,  168 => 74,  163 => 72,  157 => 70,  147 => 68,  145 => 67,  93 => 18,  86 => 17,  83 => 16,  80 => 15,  77 => 14,  74 => 13,  71 => 12,  68 => 11,  66 => 10,  62 => 9,  59 => 8,  48 => 6,  44 => 5,  37 => 1,);
    }

    public function getSourceContext()
    {
        return new Source("", "oc01/template/information/contact.twig", "");
    }
}
