<?php
// Heading
$_['heading_title']      = 'Your Reward Points';

// Column
$_['column_date_added']  = 'Date Added';
$_['column_description'] = 'Description';
$_['column_points']      = 'Points';

// Text
$_['text_account']       = 'Account';
$_['text_reward']        = 'Reward Points';
$_['text_total']         = 'Your total number of reward points is:';
$_['text_empty']         = 'You do not have any reward points!';