<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  9050 => 'Turk Telekom',
  9051616 => 'Turkcell',
  9053 => 'Turkcell',
  9053383 => 'Kuzey Kibris Turkcell',
  9053384 => 'Kuzey Kibris Turkcell',
  9053385 => 'Kuzey Kibris Turkcell',
  9053386 => 'Kuzey Kibris Turkcell',
  9053387 => 'Kuzey Kibris Turkcell',
  9054 => 'Vodafone',
  9054285 => 'KKTC Telsim',
  9054286 => 'KKTC Telsim',
  9054287 => 'KKTC Telsim',
  9054288 => 'KKTC Telsim',
  9055 => 'Turk Telekom',
  9056 => 'Turkcell',
);
