<?php

$_['text_title'] = 'Credit / Debit card';
$_['button_confirm'] = 'Confirm';

$_['text_postcode_check'] = 'Postcode check: %s';
$_['text_security_code_check'] = 'CVV2 check: %s';
$_['text_address_check'] = 'Address check: %s';
$_['text_not_given'] = 'Not given';
$_['text_not_checked'] = 'Not checked';
$_['text_match'] = 'Matched';
$_['text_not_match'] = 'Not matched';
$_['text_payment_details'] = 'Payment details';

$_['entry_card_type'] = 'Card type';