{{ header}}
<div class="container" id="container">
  {% if error_warning %}
  <div class="alert alert-danger"><i class="fa fa-exclamation-circle"></i> <{{ error_warning }}
    <button type="button" class="close" data-dismiss="alert">&times;</button>
  </div>
  {% endif %}
  <div class="row">{{ column_left }}
    {% if column_left and column_right %}
    {% set class = 'col-sm-6' %}
    {% elseif column_left or column_right %}
    {% set class = 'col-sm-9' %}
    {% else %}
    {% set class = 'col-sm-12' %}
    {% endif %}
    <div id="content" class="{{ class }}">{{ content_top }}

        <!-- Quick Checkout v7.0.0 by Dreamvention.com checkout/quickcheckout.tpl -->
        {{ d_quickcheckout }}
      {{ content_bottom }}</div>
    {{ column_right }}</div>
</div>
{{ footer }}
