<?php
// Text
$_['text_address']       = 'Success: Shipping address has been set!';
$_['text_method']        = 'Success: Shipping method has been set!';

// Error
$_['error_permission']   = 'Warning: You do not have permission to access the API!';
$_['error_firstname']    = 'First Name must be between 1 and 32 characters!';
$_['error_lastname']     = 'Last Name must be between 1 and 32 characters!';
$_['error_address_1']    = 'Address 1 must be between 3 and 128 characters!';
$_['error_city']         = 'City must be between 3 and 128 characters!';
$_['error_postcode']     = 'Postcode must be between 2 and 10 characters for this country!';
$_['error_country']      = 'Please select a country!';
$_['error_zone']         = 'Please select a region / state!';
$_['error_custom_field'] = '%s required!';
$_['error_address']      = 'Warning: Shipping address required!';
$_['error_method']       = 'Warning: Shipping method required!';
$_['error_no_shipping']  = 'Warning: No Shipping options are available!';