<?php
// Heading
$_['heading_title']			  = 'Skrill';

// Text
$_['text_extension']		  = 'Extensions';
$_['text_success']			  = 'Success: You have modified the Skrill details.';
$_['text_edit']               = 'Edit Skrill';
$_['text_skrill']	     	  = '<a href="https://content.skrill.com/en/ecommerce-solutions/opencart/" target="_blank"><img src="view/image/payment/skrill.png" alt="Skrill" title="Skrill" style="border: 1px solid #EEEEEE;" /></a>';

// Entry
$_['entry_email']			  = 'E-Mail';
$_['entry_secret']		      = 'Secret';
$_['entry_total']			  = 'Total';
$_['entry_order_status']	  = 'Order Status';
$_['entry_pending_status']	  = 'Pending Status ';
$_['entry_canceled_status']	  = 'Canceled Status';
$_['entry_failed_status']	  = 'Failed Status';
$_['entry_chargeback_status'] = 'Chargeback Status';
$_['entry_geo_zone']		  = 'Geo Zone';
$_['entry_status']			  = 'Status';
$_['entry_sort_order']		  = 'Sort Order';

// Help
$_['help_total']			  = 'The checkout total the order must reach before this payment method becomes active.';

// Error
$_['error_permission']		  = 'Warning: You do not have permission to modify Skrill!';
$_['error_email']			  = 'E-Mail Required!';