<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;

/* oc01/template/common/footer.twig */
class __TwigTemplate_7fe2d7c6f126e87a6e9622efc020ceca3a01cd2e1946e63b06dce7481f505f5f extends \Twig\Template
{
    private $source;
    private $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = [])
    {
        $macros = $this->macros;
        // line 1
        echo "<footer>
  <div id=\"footer\">
    <div class=\"container\">
        <div class=\"footer_block\">
       <div class=\"row\">
        <div class=\"col-xs-12 col-sm-12 col-md-3 column myaccount\">
          <h4>";
        // line 7
        echo ($context["text_account"] ?? null);
        echo "</h4>
          <h5 class=\"collapsed\" data-target=\"#dropdown-account\" data-toggle=\"collapse\">";
        // line 8
        echo ($context["text_account"] ?? null);
        echo " <span class=\"icon\"></span></h5>
          <ul class=\"list-unstyled collapse\" id=\"dropdown-account\">
            <li><a href=\"";
        // line 10
        echo ($context["account"] ?? null);
        echo "\">";
        echo ($context["text_account"] ?? null);
        echo "</a></li>
            <li><a href=\"";
        // line 11
        echo ($context["order"] ?? null);
        echo "\">";
        echo ($context["text_order"] ?? null);
        echo "</a></li>
            <li><a href=\"";
        // line 12
        echo ($context["wishlist"] ?? null);
        echo "\">";
        echo ($context["text_wishlist"] ?? null);
        echo "</a></li>
            <li><a href=\"";
        // line 13
        echo ($context["newsletter"] ?? null);
        echo "\">";
        echo ($context["text_newsletter"] ?? null);
        echo "</a></li>
            <li><a href=\"";
        // line 14
        echo ($context["contact"] ?? null);
        echo "\">";
        echo ($context["text_contact"] ?? null);
        echo "</a></li>
          </ul>
        </div>
        ";
        // line 17
        if (($context["informations"] ?? null)) {
            // line 18
            echo "        <div class=\"col-xs-12 col-sm-12 col-md-3 column information\">
          <h4>";
            // line 19
            echo ($context["text_information"] ?? null);
            echo "</h4>
          <h5 class=\"collapsed\" data-target=\"#dropdown-information\" data-toggle=\"collapse\">";
            // line 20
            echo ($context["text_information"] ?? null);
            echo " <span class=\"icon\"></span></h5>
          <ul class=\"list-unstyled collapse\" id=\"dropdown-information\">
            ";
            // line 22
            $context['_parent'] = $context;
            $context['_seq'] = twig_ensure_traversable(($context["informations"] ?? null));
            foreach ($context['_seq'] as $context["_key"] => $context["information"]) {
                // line 23
                echo "            <li><a href=\"";
                echo twig_get_attribute($this->env, $this->source, $context["information"], "href", [], "any", false, false, false, 23);
                echo "\">";
                echo twig_get_attribute($this->env, $this->source, $context["information"], "title", [], "any", false, false, false, 23);
                echo "</a></li>
            ";
            }
            $_parent = $context['_parent'];
            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['information'], $context['_parent'], $context['loop']);
            $context = array_intersect_key($context, $_parent) + $_parent;
            // line 25
            echo "            <li><a href=\"";
            echo ($context["return"] ?? null);
            echo "\">";
            echo ($context["text_return"] ?? null);
            echo "</a></li>
          </ul>
        </div>
        ";
        }
        // line 29
        echo "    \t";
        echo ($context["footer_top"] ?? null);
        echo "
        <div class=\"col-xs-12 col-sm-12 col-md-3 column extra\">
          <h4>";
        // line 31
        echo ($context["text_extra"] ?? null);
        echo "</h4>
          <h5 class=\"collapsed\" data-target=\"#dropdown-extra\" data-toggle=\"collapse\">";
        // line 32
        echo ($context["text_extra"] ?? null);
        echo " <span class=\"icon\"></span></h5>
          <ul class=\"list-unstyled collapse\" id=\"dropdown-extra\">
            <li><a href=\"";
        // line 34
        echo ($context["manufacturer"] ?? null);
        echo "\">";
        echo ($context["text_manufacturer"] ?? null);
        echo "</a></li>
            <li><a href=\"";
        // line 35
        echo ($context["voucher"] ?? null);
        echo "\">";
        echo ($context["text_voucher"] ?? null);
        echo "</a></li>
            <li><a href=\"";
        // line 36
        echo ($context["affiliate"] ?? null);
        echo "\">";
        echo ($context["text_affiliate"] ?? null);
        echo "</a></li>
            <li><a href=\"";
        // line 37
        echo ($context["special"] ?? null);
        echo "\">";
        echo ($context["text_special"] ?? null);
        echo "</a></li>
            <li><a href=\"";
        // line 38
        echo ($context["sitemap"] ?? null);
        echo "\">";
        echo ($context["text_sitemap"] ?? null);
        echo "</a></li>
          </ul>
        </div>
         <div class=\"col-xs-12 col-sm-12 col-md-3 column contacts\"> ";
        // line 41
        echo ($context["footer_left"] ?? null);
        echo " </div>
         </div>
        <div class=\"footer-bottom-up\">";
        // line 43
        echo ($context["footer_bottom"] ?? null);
        echo " </div>
      </div>
    </div>
    <div class=\"container\">
      <div class=\"row\">
       <div class=\"footer-bottom-down col-md-12 col-sm-12 col-xs-12\">";
        // line 48
        echo ($context["footer_right"] ?? null);
        echo " </div>

        <div class=\"footer-bottom\">
          <div class=\"copy-right col-md-12 col-sm-12 col-xs-12\">
             <div id=\"powered\">";
        // line 52
        echo ($context["powered"] ?? null);
        echo "</div>
          </div>
        </div>
      </div>
    </div>
  </div>
</footer>

        ";
        // line 60
        if (($context["module_live_search_status"] ?? null)) {
            // line 61
            echo "
\t\t\t<script><!--
\t\t\t\tvar live_search = {
\t\t\t\t\tselector: '#search input[name=\\'search\\']',
\t\t\t\t\ttext_no_matches: '";
            // line 65
            echo ($context["text_empty"] ?? null);
            echo "',
\t\t\t\t\theight: '50px'
\t\t\t\t}

\t\t\t\t\$(document).ready(function() {
\t\t\t\t\tvar html = '';
\t\t\t\t\thtml += '<div class=\"live-search\">';
\t\t\t\t\thtml += '\t<ul>';
\t\t\t\t\thtml += '\t</ul>';
\t\t\t\t\thtml += '<div class=\"result-text\"></div>';
\t\t\t\t\thtml += '</div>';

\t\t\t\t\t//\$(live_search.selector).parent().closest('div').after(html);
\t\t\t\t\t\$(live_search.selector).after(html);

\t\t\t\t\t\$(live_search.selector).autocomplete({
\t\t\t\t\t\t'source': function(request, response) {
\t\t\t\t\t\t\tvar filter_name = \$(live_search.selector).val();
\t\t\t\t\t\t\tvar cat_id = 0;
\t\t\t\t\t\t\tvar module_live_search_min_length = '";
            // line 84
            echo abs(($context["module_live_search_min_length"] ?? null));
            echo "';
\t\t\t\t\t\t\tif (filter_name.length < module_live_search_min_length) {
\t\t\t\t\t\t\t\t\$('.live-search').css('display','none');
\t\t\t\t\t\t\t}
\t\t\t\t\t\t\telse{
\t\t\t\t\t\t\t\tvar html = '';
\t\t\t\t\t\t\t\thtml += '<li style=\"text-align: center;height:10px;\">';
\t\t\t\t\t\t\t\thtml +=\t'<img class=\"loading\" src=\"catalog/view/theme/oc01/image/loading.gif\" />';
\t\t\t\t\t\t\t\thtml +=\t'</li>';
\t\t\t\t\t\t\t\t\$('.live-search ul').html(html);
\t\t\t\t\t\t\t\t\$('.live-search').css('display','block');

\t\t\t\t\t\t\t\t\$.ajax({
\t\t\t\t\t\t\t\t\turl: 'index.php?route=extension/module/live_search&filter_name=' +  encodeURIComponent(filter_name),
\t\t\t\t\t\t\t\t\tdataType: 'json',
\t\t\t\t\t\t\t\t\tsuccess: function(result) {
\t\t\t\t\t\t\t\t\t\tvar products = result.products;
\t\t\t\t\t\t\t\t\t\t\$('.live-search ul li').remove();
\t\t\t\t\t\t\t\t\t\t\$('.result-text').html('');
\t\t\t\t\t\t\t\t\t\tif (!\$.isEmptyObject(products)) {
\t\t\t\t\t\t\t\t\t\t\tvar show_image = ";
            // line 104
            echo abs(($context["module_live_search_show_image"] ?? null));
            echo ";
\t\t\t\t\t\t\t\t\t\t\tvar show_price = ";
            // line 105
            echo abs(($context["module_live_search_show_price"] ?? null));
            echo ";
\t\t\t\t\t\t\t\t\t\t\tvar show_description = ";
            // line 106
            echo abs(($context["module_live_search_show_description"] ?? null));
            echo ";
\t\t\t\t\t\t\t\t\t\t\t\$('.result-text').html('<a href=\"";
            // line 107
            echo ($context["module_live_search_href"] ?? null);
            echo "'+filter_name+'\" class=\"view-all-results\">";
            echo twig_escape_filter($this->env, ($context["text_view_all_results"] ?? null));
            echo " ('+result.total+')</a>');

\t\t\t\t\t\t\t\t\t\t\t\$.each(products, function(index,product) {
\t\t\t\t\t\t\t\t\t\t\t\tvar html = '';

\t\t\t\t\t\t\t\t\t\t\t\thtml += '<li>';
\t\t\t\t\t\t\t\t\t\t\t\thtml += '<a href=\"' + product.url + '\" title=\"' + product.name + '\">';
\t\t\t\t\t\t\t\t\t\t\t\tif(product.image && show_image){
\t\t\t\t\t\t\t\t\t\t\t\t\thtml += '\t<div class=\"product-image\"><img alt=\"' + product.name + '\" src=\"' + product.image + '\"></div>';
\t\t\t\t\t\t\t\t\t\t\t\t}
\t\t\t\t\t\t\t\t\t\t\t\thtml += '\t<div class=\"product-name\">' + product.name ;
\t\t\t\t\t\t\t\t\t\t\t\tif(show_description){
\t\t\t\t\t\t\t\t\t\t\t\t\thtml += '<p>' + product.extra_info + '</p>';
\t\t\t\t\t\t\t\t\t\t\t\t}\t\t\t\t\t\t\t\t\t\t\t\t
\t\t\t\t\t\t\t\t\t\t\t\thtml += '</div>';
\t\t\t\t\t\t\t\t\t\t\t\tif(show_price){
\t\t\t\t\t\t\t\t\t\t\t\t\tif (product.special) {
\t\t\t\t\t\t\t\t\t\t\t\t\t\thtml += '\t<div class=\"product-price\"><span class=\"special\">' + product.price + '</span><span class=\"price\">' + product.special + '</span></div>';
\t\t\t\t\t\t\t\t\t\t\t\t\t} else {
\t\t\t\t\t\t\t\t\t\t\t\t\t\thtml += '\t<div class=\"product-price\"><span class=\"price\">' + product.price + '</span></div>';
\t\t\t\t\t\t\t\t\t\t\t\t\t}
\t\t\t\t\t\t\t\t\t\t\t\t}\t\t\t\t\t\t\t\t\t\t\t\t       \t
\t\t\t\t\t\t\t\t\t\t\t\thtml += '<span style=\"clear:both\"></span>';
\t\t\t\t\t\t\t\t\t\t\t\thtml += '</a>';
\t\t\t\t\t\t\t\t\t\t\t\thtml += '<div class=\"button-group\"><button type=\"button\" class=\"btn btn-primary btn-block ajaxcart\" onclick=\"addtocart.add('+ product.product_id +')\" >";
            // line 131
            echo ($context["button_cart"] ?? null);
            echo "</button><div>';       
\t\t\t\t\t\t\t\t\t\t\t\thtml += '</li>';
\t\t\t\t\t\t\t\t\t\t\t\t\$('.live-search ul').append(html);
\t\t\t\t\t\t\t\t\t\t\t});
\t\t\t\t\t\t\t\t\t\t} else {
\t\t\t\t\t\t\t\t\t\t\tvar html = '';
\t\t\t\t\t\t\t\t\t\t\thtml += '<li style=\"text-align: center;height:10px;\">';
\t\t\t\t\t\t\t\t\t\t\thtml +=\tlive_search.text_no_matches;
\t\t\t\t\t\t\t\t\t\t\thtml +=\t'</li>';

\t\t\t\t\t\t\t\t\t\t\t\$('.live-search ul').html(html);
\t\t\t\t\t\t\t\t\t\t}
\t\t\t\t\t\t\t\t\t\t\$('.live-search').css('display','block');
\t\t\t\t\t\t\t\t\t\treturn false;
\t\t\t\t\t\t\t\t\t}
\t\t\t\t\t\t\t\t});
\t\t\t\t\t\t\t}
\t\t\t\t\t\t},
\t\t\t\t\t\t'select': function(product) {
\t\t\t\t\t\t\t\$(live_search.selector).val(product.name);
\t\t\t\t\t\t}
\t\t\t\t\t});

\t\t\t\t\t\$(document).bind( \"mouseup touchend\", function(e){
\t\t\t\t\t  var container = \$('.live-search');
\t\t\t\t\t  if (!container.is(e.target) && container.has(e.target).length === 0)
\t\t\t\t\t  {
\t\t\t\t\t    container.hide();
\t\t\t\t\t  }
\t\t\t\t\t});
\t\t\t\t});
\t\t\t//--></script>
\t\t";
        }
        // line 164
        echo "

<link rel=\"stylesheet\" href=\"catalog/view/javascript/jquery/owl-carousel/owl.transitions.css\" />
<script>
\$('button[id^=\\'button-upload\\']').on('click', function() {
\tvar node = this;

\t\$('#form-upload').remove();

\t\$('body').prepend('<form enctype=\"multipart/form-data\" id=\"form-upload\" style=\"display: none;\"><input type=\"file\" name=\"file\" /></form>');

\t\$('#form-upload input[name=\\'file\\']').trigger('click');

\tif (typeof timer != 'undefined') {
    \tclearInterval(timer);
\t}

\ttimer = setInterval(function() {
\t\tif (\$('#form-upload input[name=\\'file\\']').val() != '') {
\t\t\tclearInterval(timer);

\t\t\t\$.ajax({
\t\t\t\turl: 'index.php?route=tool/upload',
\t\t\t\ttype: 'post',
\t\t\t\tdataType: 'json',
\t\t\t\tdata: new FormData(\$('#form-upload')[0]),
\t\t\t\tcache: false,
\t\t\t\tcontentType: false,
\t\t\t\tprocessData: false,
\t\t\t\tbeforeSend: function() {
\t\t\t\t\t\$(node).button('loading');
\t\t\t\t},
\t\t\t\tcomplete: function() {
\t\t\t\t\t\$(node).button('reset');
\t\t\t\t},
\t\t\t\tsuccess: function(json) {
\t\t\t\t\t\$('.text-danger').remove();

\t\t\t\t\tif (json['error']) {
\t\t\t\t\t\t\$(node).parent().find('input').after('<div class=\"text-danger\">' + json['error'] + '</div>');
\t\t\t\t\t}

\t\t\t\t\tif (json['success']) {
\t\t\t\t\t\talert(json['success']);

\t\t\t\t\t\t\$(node).parent().find('input').val(json['code']);
\t\t\t\t\t}
\t\t\t\t},
\t\t\t\terror: function(xhr, ajaxOptions, thrownError) {
\t\t\t\t\talert(thrownError + \"\\r\\n\" + xhr.statusText + \"\\r\\n\" + xhr.responseText);
\t\t\t\t}
\t\t\t});
\t\t}
\t}, 500);
});
</script>
<script>
\$(document).ready(function(){

\$('.productpage-carousel').owlCarousel({
    items: 5,
    autoPlay: false,
    singleItem: false,
    navigation: true,
    pagination: false,
    itemsDesktop : [1199,4],
    itemsDesktopSmall : [991,3],
    itemsTablet : [479,2],
    itemsMobile : [319,1]
  });
});
function addtoCart(product_id){
          \$.ajax({
            url: 'index.php?route=checkout/cart/add',
            type: 'post',
            data: \$('#product-' + product_id + ' input[type=\\'text\\'],#product-' + product_id + ' input[type=\\'number\\'], #product-' + product_id + ' input[type=\\'hidden\\'], #product-' + product_id + ' input[type=\\'radio\\']:checked, #product-' + product_id + ' input[type=\\'checkbox\\']:checked, #product-' + product_id + ' select, #product-' + product_id + ' textarea'),
            dataType: 'json',
            beforeSend: function() {
              \$('#add-cart-'+ product_id).button('loading');
            },
            complete: function() {
              \$('#add-cart-'+ product_id).button('reset');
            },
            success: function(json) {
              \$('.alert, .text-danger').remove();
              \$('.form-group').removeClass('has-error');

              if (json['error']) {
                if (json['error']['option']) {
                  for (i in json['error']['option']) {
                    var element = \$('#input-option' + i.replace('_', '-'));

                    if (element.parent().hasClass('input-group')) {
                      element.parent().after('<div class=\"text-danger\">' + json['error']['option'][i] + '</div>');
                    } else {
                      element.after('<div class=\"text-danger\">' + json['error']['option'][i] + '</div>');
                    }
                  }
                }

                if (json['error']['recurring']) {
                  \$('select[name=\\'recurring_id\\']').after('<div class=\"text-danger\">' + json['error']['recurring'] + '</div>');
                }

                // Highlight any found errors
                \$('.text-danger').parent().addClass('has-error');
              }

              if (json['success']) {
                \$('.breadcrumb').after('<div class=\"alertmsg\"><div class=\"alert alert-success alert-dismissible\">' + json['success'] + '<button type=\"button\" class=\"close\" data-dismiss=\"alert\">&times;</button></div></div>');

               \$('#cart > .btn').addClass('active');
        \$('#cart > .btn').html('<span class=\"cart-text\">My basket</span><span class=\"cart-total\">Item ' + json['total'] + '</span><span class=\"cart-total-res\">' + json['total'] +'</span>');
        \$('.alertmsg').delay(1500).fadeOut();

        //\$('html, body').animate({ scrollTop: 0 }, 'slow');

        \$('#cart > ul').load('index.php?route=common/cart/info ul li');
        \$(\"button.close\").click(function() {
                        \$(\".alertmsg\").remove()
                    })
              }
            },
            error: function(xhr, ajaxOptions, thrownError) {
              alert(thrownError + \"\\r\\n\" + xhr.statusText + \"\\r\\n\" + xhr.responseText);
            }
          });         
        }
</script>


<!-- Go to www.addthis.com/dashboard to customize your tools -->
<script src=\"//s7.addthis.com/js/300/addthis_widget.js#pubid=ra-5b45d725b77d622c\"></script>

<!--
OpenCart is open source software and you are free to remove the powered by OpenCart if you want, but its generally accepted practise to make a small donation.
Please donate via PayPal to donate@opencart.com
//-->
</body></html>
";
    }

    public function getTemplateName()
    {
        return "oc01/template/common/footer.twig";
    }

    public function isTraitable()
    {
        return false;
    }

    public function getDebugInfo()
    {
        return array (  333 => 164,  297 => 131,  268 => 107,  264 => 106,  260 => 105,  256 => 104,  233 => 84,  211 => 65,  205 => 61,  203 => 60,  192 => 52,  185 => 48,  177 => 43,  172 => 41,  164 => 38,  158 => 37,  152 => 36,  146 => 35,  140 => 34,  135 => 32,  131 => 31,  125 => 29,  115 => 25,  104 => 23,  100 => 22,  95 => 20,  91 => 19,  88 => 18,  86 => 17,  78 => 14,  72 => 13,  66 => 12,  60 => 11,  54 => 10,  49 => 8,  45 => 7,  37 => 1,);
    }

    public function getSourceContext()
    {
        return new Source("", "oc01/template/common/footer.twig", "");
    }
}
