<?php
// Heading
$_['heading_title']				 	  = 'G2APay';

// Text
$_['text_extension']				  = 'Extensions';
$_['text_success']				 	  = 'Success: You have modified the G2APay details.';
$_['text_edit']					 	  = 'Edit G2APay';
$_['text_g2apay']				 	  = '<a href="https://pay.g2a.com/" target="_blank"><img src="view/image/payment/g2apay.png" alt="G2APay" title="G2APay" style="border: 1px solid #EEEEEE;" /></a>';
$_['text_payment_info']			 	  = 'Payment information';
$_['text_refund_status']		 	  = 'Payment refund';
$_['text_order_ref']			 	  = 'Order ref';
$_['text_order_total']			 	  = 'Total authorised';
$_['text_total_released']		 	  = 'Total released';
$_['text_transactions']			 	  = 'Transactions';
$_['text_column_amount']		 	  = 'Amount';
$_['text_column_type']			 	  = 'Type';
$_['text_column_date_added']	 	  = 'Added';
$_['text_refund_ok']			 	  = 'Refund was successfully requested';
$_['text_refund_ok_order']		 	  = 'Refund was successfully requested, amount fully refunded';

// Entry
$_['entry_username']			 	  = 'Username';
$_['entry_secret']				 	  = 'Secret';
$_['entry_api_hash']		     	  = 'API Hash';
$_['entry_environment']			 	  = 'Environment';
$_['entry_secret_token']		 	  = 'Secret Token';
$_['entry_ipn_url']				 	  = 'IPN URL:';
$_['entry_total']				 	  = 'Total';
$_['entry_geo_zone']			 	  = 'Geo Zone';
$_['entry_status']				 	  = 'Status';
$_['entry_sort_order']			 	  = 'Sort Order';
$_['entry_debug']				 	  = 'Debug logging';
$_['entry_order_status']			  = 'Order Status';
$_['entry_complete_status']			  = 'Complete Status:';
$_['entry_rejected_status']			  = 'Rejected Status:';
$_['entry_cancelled_status']		  = 'Canceled Status:';
$_['entry_pending_status']            = 'Pending Status:';
$_['entry_refunded_status']			  = 'Refunded Status:';
$_['entry_partially_refunded_status'] = 'Partially Refunded Status:';

// Help
$_['help_username']					  = 'The email address used for your account';
$_['help_total']				 	  = 'The checkout total the order must reach before this payment method becomes active.';
$_['help_debug']				 	  = 'Enabling debug will write sensitive data to a log file. You should always disable unless instructed otherwise';

// Tab
$_['tab_settings']				 	  = 'Settings';
$_['tab_order_status']				  = 'Order Status';

// Error
$_['error_permission']			 	  = 'Warning: You do not have permission to modify G2APay!';
$_['error_email']				 	  = 'E-Mail Required!';
$_['error_secret']				 	  = 'Secret Required!';
$_['error_api_hash']			 	  = 'API Hash Required!';
$_['entry_status']				 	  = 'Status';

//Button
$_['btn_refund']				 	  = 'refund';

$_['g2apay_environment_live']	 	  = 'Live';
$_['g2apay_environment_test']	 	  = 'Test';