<?php
// Heading
$_['heading_title']     = 'Sales Report';

// Text
$_['text_extension']    = 'Extensions';
$_['text_edit']         = 'Edit Sales Report';
$_['text_success']      = 'Success: You have modified sales report!';
$_['text_filter']       = 'Filter';
$_['text_year']         = 'Years';
$_['text_month']        = 'Months';
$_['text_week']         = 'Weeks';
$_['text_day']          = 'Days';
$_['text_all_status']   = 'All Statuses';

// Column
$_['column_date_start'] = 'Date Start';
$_['column_date_end']   = 'Date End';
$_['column_orders']     = 'No. Orders';
$_['column_products']   = 'No. Products';
$_['column_tax']        = 'Tax';
$_['column_total']      = 'Total';

// Entry
$_['entry_date_start']  = 'Date Start';
$_['entry_date_end']    = 'Date End';
$_['entry_group']       = 'Group By';
$_['entry_status']      = 'Order Status';
$_['entry_status']      = 'Status';
$_['entry_sort_order']  = 'Sort Order';

// Error
$_['error_permission']  = 'Warning: You do not have permission to modify sales report!';