<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  59771 => 'Digicel',
  59772 => 'Digicel',
  59774 => 'Digicel',
  59775 => 'Telesur',
  59776 => 'Digicel',
  597770 => 'Telesur',
  597771 => 'Telesur',
  597772 => 'Telesur',
  597773 => 'Telesur',
  597774 => 'Telesur',
  59781 => 'Digicel',
  59782 => 'Digicel',
  59785 => 'Telesur',
  59786 => 'Telesur',
  59787 => 'Telesur',
  59788 => 'Telesur',
  59789 => 'Telesur',
);
