<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;

/* oc01/template/extension/module/testimonials.twig */
class __TwigTemplate_6d5578875996e3ebf6c77f33b5d4c995026a2657b4339e712639beaeb2379586 extends \Twig\Template
{
    private $source;
    private $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = [])
    {
        $macros = $this->macros;
        // line 1
        echo "
 <div  class=\"testimonial-block section fadeInUp\" data-wow-duration=\"0.5s\" data-wow-delay=\"0.5s\">
 <div class=\"section-heading\">";
        // line 3
        echo ($context["module_testimonials_heading"] ?? null);
        echo "</div>
<div  class=\"testimonial owlCarousel\">


        ";
        // line 7
        $context['_parent'] = $context;
        $context['_seq'] = twig_ensure_traversable(($context["testimonials"] ?? null));
        foreach ($context['_seq'] as $context["_key"] => $context["testimonial"]) {
            // line 8
            echo "       <div class=\"item\">
               <img class=\"testimonial-img img-responsive\" src=\"";
            // line 9
            echo twig_get_attribute($this->env, $this->source, $context["testimonial"], "thumb", [], "any", false, false, false, 9);
            echo "\" alt=\"";
            echo twig_get_attribute($this->env, $this->source, $context["testimonial"], "thumb", [], "any", false, false, false, 9);
            echo "\" />
              <div class=\"testmonial-author-name\">";
            // line 10
            echo twig_get_attribute($this->env, $this->source, $context["testimonial"], "author", [], "any", false, false, false, 10);
            echo "</div>
              <div class=\"testmonial-author\">";
            // line 11
            echo twig_get_attribute($this->env, $this->source, $context["testimonial"], "designation", [], "any", false, false, false, 11);
            echo "</div>
              <div class=\"desc\">";
            // line 12
            echo twig_get_attribute($this->env, $this->source, $context["testimonial"], "description", [], "any", false, false, false, 12);
            echo "</div>

             </div>
        ";
        }
        $_parent = $context['_parent'];
        unset($context['_seq'], $context['_iterated'], $context['_key'], $context['testimonial'], $context['_parent'], $context['loop']);
        $context = array_intersect_key($context, $_parent) + $_parent;
        // line 16
        echo "
  </div>
   </div>

<script>
    \$(document).ready(function(){

    \$('.testimonial').owlCarousel({
        items: 1,
        autoPlay: true,
        singleItem: true,
        navigation: false,
        pagination: false
    });
    });
</script>
";
    }

    public function getTemplateName()
    {
        return "oc01/template/extension/module/testimonials.twig";
    }

    public function isTraitable()
    {
        return false;
    }

    public function getDebugInfo()
    {
        return array (  79 => 16,  69 => 12,  65 => 11,  61 => 10,  55 => 9,  52 => 8,  48 => 7,  41 => 3,  37 => 1,);
    }

    public function getSourceContext()
    {
        return new Source("", "oc01/template/extension/module/testimonials.twig", "");
    }
}
