<?php
// Heading
$_['newsletter_title']    = 'Subscribe for our offer news';
$_['email']='Email';
$_['subscribe']='Subscribe';
$_['text_success_add']     = 'Subscription Success';
$_['text_success_already']   = 'Email Is already Subscribed';
$_['text_subscribe_placeholder']   = 'Enter your email address';
$_['newsletter_static_title1']   = 'special offer';
$_['newsletter_static_title2']   = '';
$_['newsletter_static_desc1']   = '32% Instant Discount*';
$_['newsletter_static_desc2']   = 'Code: <span>BMLESS32</span>';

/* Popup Text */


$_['chk_text']       = 'Do not show again';

