<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  99241 => 'Megafon',
  99250 => 'Tcell',
  99255 => 'Megafon',
  9927 => 'Tcell',
  9928 => 'Megafon',
  99290 => 'Megafon',
  992917 => 'Tacom',
  992918 => 'Babilon-M',
  992919 => 'Tacom',
  99292 => 'Tcell',
  99293 => 'Tcell',
  99298 => 'Babilon-M',
);
