$padding: 15px;
$background: #f8f9fc;
$heading_background: #e9ebf4;
$panel_background: #e9ebf4;
$color: #000;
$border_color: #dbdfef;
$main_blue: #4fb5e7;
$dark_blue: #3573ee;
$red: #fa5b6d;
$warning: #f46b42;
$green: #86ce99;
$some_gray: #e9ebf4;
$code-bgc: $panel_background;
$code-c: $color;
$tile-bgc: $main_blue;
$tile-c: #fff;
$pagination-color: #111111;
$pagination-background-color: #fffffff;
$pagination-border-color: #cfd7e7;
$pagination-hover-background-color: #dde4f2;
$pagination-active-background-color: #dde4f2;
$pagination-active-hover-background-color: #c6cce4;
$pagination-active-hover-border-color: #adbcd9;

$very_slow_speed: 20.0s;
$slow_speed: 10.0s;
$fast_speed: 3.0s;
$very_fast_speed: 0.5s;


$whoopsy_background: #e9ebf4;
