.qc-title {
    margin-bottom: 10px;
    font-weight: 600;
}

.error {
    margin-top: 10px;
}

.add-custom-field {
    cursor: pointer;
}

.qc-field-col {
    width: 50%;
    float: left;
    position: relative;
    @media (max-device-width: 480px) {
        width: 100%;
    }
}

.qc-clearboth {
    clear: both;
}

.intl-tel-input {
    display: block;
}

.col-half {
    width: 50%;
    padding: 0px 15px;
    float: left;
}

.col-full {
    width: 100%;
    padding: 0px 15px;
    display: block;
}

.radio-input:not(:last-child) {
    margin-bottom: 10px;
}

//select
.bootstrap-select {
    border: none !important;
    padding: 0px !important;
    width: 100% !important;
}

.qc-select {
    position: relative;
}

.qc-select select {
    z-index: 1;
    color: transparent;
    background: transparent;
    position: relative;
    option {
        color: #333;
    }
}

.qc-select-placeholder {
    position: absolute;
    top: 0px;
    padding: 6px 11px;
    font-style: normal;
    width: calc(100% - 30px);
    display: block;
    background: #fff;
    border-radius: 3px;
    height: 30px;
}

.ve-field--error .qc-select-placeholder {
    background-color: #fee2e1;
}