<?php
// Heading
$_['heading_title']                = 'Customer Activity Report';

// Text
$_['text_extension']               = 'Extensions';
$_['text_edit']                    = 'Edit Customer Activity Report';
$_['text_success']                 = 'Success: You have modified customer activity report!';
$_['text_filter']                  = 'Filter';
$_['text_activity_register']       = '<a href="customer_id=%d">%s</a> registered for an account.';
$_['text_activity_edit']           = '<a href="customer_id=%d">%s</a> updated their account details.';
$_['text_activity_password']       = '<a href="customer_id=%d">%s</a> updated their account password.';
$_['text_activity_reset']          = '<a href="customer_id=%d">%s</a> reset their account password.';
$_['text_activity_login']          = '<a href="customer_id=%d">%s</a> logged in.';
$_['text_activity_forgotten']      = '<a href="customer_id=%d">%s</a> requested a reset password.';
$_['text_activity_address_add']    = '<a href="customer_id=%d">%s</a> added a new address.';
$_['text_activity_address_edit']   = '<a href="customer_id=%d">%s</a> updated their address.';
$_['text_activity_address_delete'] = '<a href="customer_id=%d">%s</a> deleted one of their addresses.';
$_['text_activity_return_account'] = '<a href="customer_id=%d">%s</a> submitted a product return.';
$_['text_activity_return_guest']   = '%s submitted a product return.';
$_['text_activity_order_account']  = '<a href="customer_id=%d">%s</a> created a <a href="order_id=%d">new order</a>.';
$_['text_activity_order_guest']    = '%s created a <a href="order_id=%d">new order</a>.';
$_['text_activity_affiliate_add']  = '<a href="customer_id=%d">%s</a> registered for a affiliate account.';
$_['text_activity_affiliate_edit'] = '<a href="customer_id=%d">%s</a> updated their affiliate details.';
$_['text_activity_transaction']    = '<a href="customer_id=%d">%s</a> received commission from an new <a href="order_id=%d">order</a>.';

// Column
$_['column_customer']              = 'Customer';
$_['column_comment']               = 'Comment';
$_['column_ip']                    = 'IP';
$_['column_date_added']            = 'Date Added';

// Entry
$_['entry_customer']               = 'Customer';
$_['entry_ip']                     = 'IP';
$_['entry_date_start']             = 'Date Start';
$_['entry_date_end']               = 'Date End';
$_['entry_status']                 = 'Status';
$_['entry_sort_order']             = 'Sort Order';

// Error
$_['error_permission']             = 'Warning: You do not have permission to modify customer activity report!';