!function(e){function t(r){if(n[r])return n[r].exports;var i=n[r]={i:r,l:!1,exports:{}};return e[r].call(i.exports,i,i.exports,t),i.l=!0,i.exports}var n={};t.m=e,t.c=n,t.d=function(e,n,r){t.o(e,n)||Object.defineProperty(e,n,{configurable:!1,enumerable:!0,get:r})},t.n=function(e){var n=e&&e.__esModule?function(){return e.default}:function(){return e};return t.d(n,"a",n),n},t.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},t.p="",t(t.s=0)}([function(e,t){!function(){function e(e){return $.post(location.toString(),$.extend({ajax:!0},e))}var t=function(){function t(){this.elem=$(".ntcd--notification-service"),this.tries=3,this.except=this.elem.data("except"),this.request()}return t.prototype.request=function(){var n=this,r={name:"notification",api:"2",version:"0.3.0",lang:$("html").attr("lang")};this.except&&(r.except=this.except),$.post(t.url,r).done(function(r){var i=n.elem.find("template").html();$.each(r,function(r,a){if(a.id&&a.type&&a.message&&a.params){for(var o=/^[1-9][0-9]*$/.test(String(a.id)),c=~$.inArray(a.type,["info","warning","danger"]),s=!0,f=0;f<a.params.length;f++)if("http"!==a.params[f].slice(0,4)){s=!1;break}if(o&&c&&s){var u=$(i).addClass("alert-"+a.type),l=t.render(t.stripTags(a.message),a.params);$("<span>"+l+"</span>").prependTo(u),u.appendTo(n.elem),u.find(".close").click(function(){e({"dont-show-notification-id":a.id})})}}})}).fail(function(){--n.tries&&n.request()})},t.stripTags=function(e){return $("<div>"+e+"</div>").text()},t.render=function(e,t){var n=["a","b","i"];return $.each(n,function(n,r){for(var i="a"==r?t.length:100,a=0,o=0;o<i;o++){var c=e.indexOf("["+r+"]",a),s=e.indexOf("[/"+r+"]",a);if(!(~c&&~s&&c<s))break;var f=e.slice(c+3,s),u={a:'<a href="'+t[o]+'">'+f+"</a>",b:"<b>"+f+"</b>",i:"<i>"+f+"</i>"};e=e.slice(0,c)+u[r]+e.slice(s+4),a=s-3-f.length+u[r].length}}),e},t.url="http://neat-countdown.chugylo.org.ua/ntcd_server",t}();$(function(){var n=$(".ntcd");$(".ntcd--timezone-warning .ntcd--close-forever",n).on("click",function(){e({"never-show-timezone-warning":!0})}),window.NTCDServiceOff||!1||new t})}()}]);