{{ header }}{{ column_left }}
<div id="content">
  <div class="page-header">
	<div class="container-fluid">
	  <div class="pull-right">
		<button type="submit" form="form-module" data-toggle="tooltip" title="{{ button_save }}" class="btn btn-primary"><i class="fa fa-check-circle"></i></button>
		<a href="{{ cancel }}" data-toggle="tooltip" title="{{ button_cancel }}" class="btn btn-default"><i class="fa fa-reply"></i></a></div>
	  <h1>{{ heading_title }}</h1>
	  <ul class="breadcrumb">
		{% for breadcrumb in breadcrumbs %}
			<li><a href="{{ breadcrumb.href }}">{{ breadcrumb.text }}</a></li>
		{% endfor %}
	  </ul>
	</div>
  </div>
  <div class="container-fluid">
	{% if error_warning %}
		<div class="alert alert-danger alert-dismissible"><i class="fa fa-exclamation-circle"></i> {{ error_warning }}
		  <button type="button" class="close" data-dismiss="alert">&times;</button>
		</div>
	{% endif %}
	<div class="panel panel-default">
      <div class="panel-heading">
        <h3 class="panel-title"><i class="fa fa-pencil"></i> {{ heading_title }}</h3>
      </div>
      <div class="panel-body">
		<form action="{{ action }}" method="post" enctype="multipart/form-data" id="form-module" class="form-horizontal">
		  <div class="form-group">
            <label class="col-sm-2 control-label" for="input-module-status">{{ entry_status }}</label>
            <div class="col-sm-10">
              <select name="module_klarna_checkout_status" id="input-module-status" class="form-control">
				{% if module_klarna_checkout_status %}
					<option value="1" selected="selected">{{ text_enabled }}</option>
					<option value="0">{{ text_disabled }}</option>
				{% else %}
					<option value="1">{{ text_enabled }}</option>
					<option value="0" selected="selected">{{ text_disabled }}</option>
				{% endif %}
              </select>
            </div>
          </div>
		</form>
	  </div>
	</div>
  </div>
</div>
{{ footer }}