<?php
// Heading
$_['text_title']				= 'Credit / Debit card (Realex)';

// Button
$_['button_confirm']			= 'Confirm';

// Entry
$_['entry_cc_type']				= 'Card Type';

// Text
$_['text_success']				= 'Your payment has been authorised.';
$_['text_decline']				= 'Your payment was unsuccessful';
$_['text_bank_error']			= 'There was an error processing your request with the bank.';
$_['text_generic_error']		= 'There was an error processing your request.';
$_['text_hash_failed']			= 'Hash check failed. Do not try your payment again as the payment status is unknown. Please contact the merchant.';
$_['text_link']					= 'Please click <a href="%s">here</a> to continue';
$_['text_select_card']			= 'Please select your card type';
$_['text_result']				= 'Auth result';
$_['text_message']				= 'Message';
$_['text_cvn_result']			= 'CVN result';
$_['text_avs_postcode']			= 'AVS postcode';
$_['text_avs_address']			= 'AVS address';
$_['text_eci']					= 'ECI (3D secure) result';
$_['text_tss']					= 'TSS result';
$_['text_order_ref']			= 'Order ref';
$_['text_timestamp']			= 'Timestamp';
$_['text_card_type']			= 'Card type';
$_['text_card_digits']			= 'Card number';
$_['text_card_exp']				= 'Card expire';
$_['text_card_name']			= 'Card name';
$_['text_3d_s1']				= 'Cardholder Not Enrolled, liability shift';
$_['text_3d_s2']				= 'Unable To Verify Enrolment, no liability shift';
$_['text_3d_s3']				= 'Invalid Response From Enrolment Server, no liability shift';
$_['text_3d_s4']				= 'Enrolled, But Invalid Response From ACS (Access Control Server), no liability shift';
$_['text_3d_s5']				= 'Successful Authentication, liability shift';
$_['text_3d_s6']				= 'Authentication Attempt Acknowledged, liability shift';
$_['text_3d_s7']				= 'Incorrect Password Entered, no liability shift';
$_['text_3d_s8']				= 'Authentication Unavailable, no liability shift';
$_['text_3d_s9']				= 'Invalid Response From ACS, no liability shift';
$_['text_3d_s10']				= 'RealMPI Fatal Error, no liability shift';
$_['text_3d_liability']     	= 'No Liability Shift';
$_['text_card_visa']			= 'Visa';
$_['text_card_mc']				= 'Mastercard';
$_['text_card_amex']			= 'American Express';
$_['text_card_switch']			= 'Switch';
$_['text_card_laser']			= 'Laser';
$_['text_card_diners']			= 'Diners';