<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  35191 => 'Vodafone',
  3519200 => 'Lycamobile',
  3519201 => 'Lycamobile',
  3519202 => 'Lycamobile',
  3519203 => 'Lycamobile',
  3519204 => 'Lycamobile',
  3519205 => 'Lycamobile',
  351921 => 'Vodafone',
  3519220 => 'CTT',
  3519221 => 'CTT',
  3519222 => 'CTT',
  3519230 => 'Vectone',
  3519231 => 'Vectone',
  3519232 => 'Vectone',
  3519233 => 'Vectone',
  3519234 => 'Vectone',
  3519240 => 'MEO',
  3519241 => 'MEO',
  3519242 => 'MEO',
  3519243 => 'MEO',
  3519244 => 'MEO',
  351925 => 'MEO',
  351926 => 'MEO',
  351927 => 'MEO',
  3519280 => 'NOWO',
  3519281 => 'NOWO',
  3519285 => 'ONITELECOM',
  3519290 => 'NOS',
  3519291 => 'NOS',
  3519292 => 'NOS',
  3519293 => 'NOS',
  3519294 => 'NOS',
  35193 => 'NOS',
  35196 => 'MEO',
);
