{{ header }}{{ column_left }}
<div id="content">
  <div class="page-header">
    <div class="container-fluid">
      <div class="pull-right">
        <button type="submit" form="form-fraud" data-toggle="tooltip" title="{{ button_save }}" class="btn btn-primary"><i class="fa fa-save"></i></button>
        <a href="{{ cancel }}" data-toggle="tooltip" title="{{ button_cancel }}" class="btn btn-default"><i class="fa fa-reply"></i></a></div>
      <h1>{{ heading_title }}</h1>
      <ul class="breadcrumb">
        {% for breadcrumb in breadcrumbs %}
        <li><a href="{{ breadcrumb.href }}">{{ breadcrumb.text }}</a></li>
        {% endfor %}
      </ul>
    </div>
  </div>
  <div class="container-fluid"> {% if error_warning %}
    <div class="alert alert-danger alert-dismissible"><i class="fa fa-exclamation-circle"></i> {{ error_warning }}
      <button type="button" class="close" data-dismiss="alert">&times;</button>
    </div>
    {% endif %}
    <div class="panel panel-default">
      <div class="panel-heading">
        <h3 class="panel-title"><i class="fa fa-pencil"></i> {{ text_edit }}</h3>
      </div>
      <div class="panel-body">
        <div class="alert alert-info"><i class="fa fa-exclamation-circle"></i> {{ text_signup }}</div>
        <form action="{{ action }}" method="post" enctype="multipart/form-data" id="form-fraud" class="form-horizontal">
          <div class="form-group">
            <label class="col-sm-2 control-label" for="input-status">{{ entry_status }}</label>
            <div class="col-sm-10">
              <select name="fraud_fraudlabspro_status" id="input-status" class="form-control">
                
                
								{% if fraud_fraudlabspro_status %}
								
                
                <option value="1" selected="selected">{{ text_enabled }}</option>
                <option value="0">{{ text_disabled }}</option>
                
                
								{% else %}
								
                
                <option value="1">{{ text_enabled }}</option>
                <option value="0" selected="selected">{{ text_disabled }}</option>
                
                
								{% endif %}
							
              
              </select>
            </div>
          </div>
          <div class="form-group">
            <label class="col-sm-2 control-label" for="input-key">{{ entry_key }}</label>
            <div class="col-sm-10">
              <input type="text" name="fraud_fraudlabspro_key" value="{{ fraud_fraudlabspro_key }}" placeholder="{{ entry_key }}" id="input-key" class="form-control" />
              {% if error_key %}
              <div class="text-danger">{{ error_key }}</div>
              {% endif %} </div>
          </div>
          <div class="form-group">
            <label class="col-sm-2 control-label" for="input-score"><span data-toggle="tooltip" title="{{ help_score }}">{{ entry_score }}</span></label>
            <div class="col-sm-10">
              <input type="text" name="fraud_fraudlabspro_score" value="{{ fraud_fraudlabspro_score }}" placeholder="{{ entry_score }}" id="input-score" class="form-control" />
            </div>
          </div>
          <div class="form-group">
            <label class="col-sm-2 control-label" for="input-order-status"><span data-toggle="tooltip" title="{{ help_order_status }}">{{ entry_order_status }}</span></label>
            <div class="col-sm-10">
              <select name="fraud_fraudlabspro_order_status_id" id="input-order-status" class="form-control">
                
                
								{% for order_status in order_statuses %}
								{% if order_status.order_status_id == fraud_fraudlabspro_order_status_id %}
								
                
                <option value="{{ order_status.order_status_id }}" selected="selected">{{ order_status.name }}</option>
                
                
								{% else %}
								
                
                <option value="{{ order_status.order_status_id }}">{{ order_status.name }}</option>
                
                
								{% endif %}
								{% endfor %}
							
              
              </select>
            </div>
          </div>
          <fieldset>
            <legend>Rules Validation</legend>
            <div class="form-group">
              <label class="col-sm-2 control-label" for="input-fraud-review-status"><span data-toggle="tooltip" title="{{ help_review_status }}">{{ entry_review_status }}</span></label>
              <div class="col-sm-10">
                <select name="fraud_fraudlabspro_review_status_id" id="input-fraud-review-status" class="form-control">
                  
                  
									{% for order_status in order_statuses %}
									{% if order_status.order_status_id == fraud_fraudlabspro_review_status_id %}
									
                  
                  <option value="{{ order_status.order_status_id }}" selected="selected">{{ order_status.name }}</option>
                  
                  
									{% else %}
									
                  
                  <option value="{{ order_status.order_status_id }}">{{ order_status.name }}</option>
                  
                  
									{% endif %}
									{% endfor %}
								
                
                </select>
              </div>
            </div>
            <div class="form-group">
              <label class="col-sm-2 control-label" for="input-fraud-approve-status"><span data-toggle="tooltip" title="{{ help_approve_status }}">{{ entry_approve_status }}</span></label>
              <div class="col-sm-10">
                <select name="fraud_fraudlabspro_approve_status_id" id="input-fraud-approve-status" class="form-control">
                  
                  
									{% for order_status in order_statuses %}
									{% if order_status.order_status_id == fraud_fraudlabspro_approve_status_id %}
									
                  
                  <option value="{{ order_status.order_status_id }}" selected="selected">{{ order_status.name }}</option>
                  
                  
									{% else %}
									
                  
                  <option value="{{ order_status.order_status_id }}">{{ order_status.name }}</option>
                  
                  
									{% endif %}
									{% endfor %}
								
                
                </select>
              </div>
            </div>
            <div class="form-group">
              <label class="col-sm-2 control-label" for="input-fraud-reject-status"><span data-toggle="tooltip" title="{{ help_reject_status }}">{{ entry_reject_status }}</span></label>
              <div class="col-sm-10">
                <select name="fraud_fraudlabspro_reject_status_id" id="input-fraud-reject-status" class="form-control">
                  
                  
								{% for order_status in order_statuses %}
								{% if order_status.order_status_id == fraud_fraudlabspro_reject_status_id %}
								
                  
                  <option value="{{ order_status.order_status_id }}" selected="selected">{{ order_status.name }}</option>
                  
                  
								{% else %}
								
                  
                  <option value="{{ order_status.order_status_id }}">{{ order_status.name }}</option>
                  
                  
								{% endif %}
								{% endfor %}
								
                
                </select>
              </div>
            </div>
          </fieldset>
          <fieldset>
            <legend>Testing Purpose</legend>
            <div class="form-group">
              <label class="col-sm-2 control-label" for="input-score"><span data-toggle="tooltip" title="{{ help_simulate_ip }}">{{ entry_simulate_ip }}</span></label>
              <div class="col-sm-10">
                <input type="text" name="fraud_fraudlabspro_simulate_ip" value="{{ fraud_fraudlabspro_simulate_ip }}" placeholder="{{ entry_simulate_ip }}" id="input-score" class="form-control" />
              </div>
            </div>
          </fieldset>
        </form>
      </div>
    </div>
  </div>
</div>
{{ footer }}