<?php
// Heading
$_['heading_title']       			= 'Newsletters';

// Text
$_['text_success']        			= 'Success: You have modified newsletters!';
$_['text_list']           			= 'Newsletter List';
$_['text_add']            			= 'Add Newsletter';
$_['text_edit']           			= 'Edit Newsletter';

// Column
$_['column_news_id']         		= 'Newsletter ID';
$_['column_news_email']         	= 'Newsletter email';
$_['column_subscribe_date']   		= 'Subscribe Date';
$_['column_action']       			= 'Action';

// Entry
$_['entry_news_email']          	= 'Newsletter Email';

// Error
$_['error_permission']    			= 'Warning: You do not have permission to modify newsletters!';
$_['error_exists']        			= 'Warning: Newsletter code is already in use!';
$_['error_news_email']          	= 'E-Mail Address does not appear to be valid!';
$_['error_news_email_duplicate']    = 'Your email is already in our database!';