<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;

/* oc01/template/extension/module/productcategory.twig */
class __TwigTemplate_8fdbbcd71dbb8f3cf0edc865e1fa5399ea1e1d7c8842777b9ee91eab74ce64ca extends \Twig\Template
{
    private $source;
    private $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = [])
    {
        $macros = $this->macros;
        // line 1
        echo "<div class=\"category_product section wow fadeInUp\" data-wow-duration=\"0.5s\" data-wow-delay=\"0.5s\">
";
        // line 2
        $context['_parent'] = $context;
        $context['_seq'] = twig_ensure_traversable(($context["categories"] ?? null));
        foreach ($context['_seq'] as $context["_key"] => $context["category"]) {
            // line 3
            echo "<div class=\"row\">
<div class=\"panel-heading\">
\t<h4 class=\"panel-title\">";
            // line 5
            echo twig_get_attribute($this->env, $this->source, $context["category"], "name", [], "any", false, false, false, 5);
            echo "</h4>
</div>

";
            // line 8
            if (twig_get_attribute($this->env, $this->source, $context["category"], "thumb", [], "any", false, false, false, 8)) {
                // line 9
                echo "<div class=\"col-sm-3 productcategory_thumb\">
<a href=\"";
                // line 10
                echo twig_get_attribute($this->env, $this->source, $context["category"], "href", [], "any", false, false, false, 10);
                echo "\"><img src=\"";
                echo twig_get_attribute($this->env, $this->source, $context["category"], "thumb", [], "any", false, false, false, 10);
                echo "\" alt=\"\" title=\"\" class=\"img-thumbnail\" /></a>
</div>
<div class=\"col-sm-9 right_block\">
";
            } else {
                // line 14
                echo "<div class=\"col-sm-12 right_block\">
";
            }
            // line 16
            echo "\t  ";
            $context['_parent'] = $context;
            $context['_seq'] = twig_ensure_traversable(twig_get_attribute($this->env, $this->source, $context["category"], "products", [], "any", false, false, false, 16));
            foreach ($context['_seq'] as $context["_key"] => $context["product"]) {
                // line 17
                echo "  <div class=\"product-layout col-lg-4 col-md-4 col-sm-6 col-xs-4\">
    <div class=\"product-thumb transition\">
      ";
                // line 19
                if (twig_get_attribute($this->env, $this->source, $context["product"], "tag_per", [], "any", false, false, false, 19)) {
                    // line 20
                    echo "      <p class=\"tag\">";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "tag_per", [], "any", false, false, false, 20);
                    echo "<br/> % <br/> <i>off</i></p>
      ";
                }
                // line 22
                echo "      <h4><a href=\"";
                echo twig_get_attribute($this->env, $this->source, $context["product"], "href", [], "any", false, false, false, 22);
                echo "\">";
                echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 22);
                echo "</a></h4>
    <div class=\"image\"><a href=\"";
                // line 23
                echo twig_get_attribute($this->env, $this->source, $context["product"], "href", [], "any", false, false, false, 23);
                echo "\">
    ";
                // line 24
                if (twig_get_attribute($this->env, $this->source, $context["product"], "thumb", [], "any", false, false, false, 24)) {
                    // line 25
                    echo "    <img src=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "thumb", [], "any", false, false, false, 25);
                    echo "\" alt=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 25);
                    echo "\" title=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 25);
                    echo "\" class=\"img-responsive\" />
    ";
                } else {
                    // line 27
                    echo "    <img src=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "image", [], "any", false, false, false, 27);
                    echo "\" alt=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 27);
                    echo "\" title=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["product"], "name", [], "any", false, false, false, 27);
                    echo "\" class=\"img-responsive\" />
    ";
                }
                // line 29
                echo "    </a></div>
      
    <div class=\"caption\">\t\t\t
\t\t\t";
                // line 32
                if (twig_get_attribute($this->env, $this->source, $context["product"], "price", [], "any", false, false, false, 32)) {
                    // line 33
                    echo "        <p class=\"price\">
\t\t  ";
                    // line 34
                    if ( !twig_get_attribute($this->env, $this->source, $context["product"], "special", [], "any", false, false, false, 34)) {
                        // line 35
                        echo "\t\t\t\t";
                        echo twig_get_attribute($this->env, $this->source, $context["product"], "price", [], "any", false, false, false, 35);
                        echo "
\t\t\t";
                    } else {
                        // line 37
                        echo "\t\t\t\t<span class=\"price-new\">";
                        echo twig_get_attribute($this->env, $this->source, $context["product"], "special", [], "any", false, false, false, 37);
                        echo "</span> <span class=\"price-old\">";
                        echo twig_get_attribute($this->env, $this->source, $context["product"], "price", [], "any", false, false, false, 37);
                        echo "</span>
\t\t\t";
                    }
                    // line 39
                    echo "\t\t  ";
                    if (twig_get_attribute($this->env, $this->source, $context["product"], "tax", [], "any", false, false, false, 39)) {
                        // line 40
                        echo "          <span class=\"price-tax\">";
                        echo ($context["text_tax"] ?? null);
                        echo " ";
                        echo twig_get_attribute($this->env, $this->source, $context["product"], "tax", [], "any", false, false, false, 40);
                        echo "</span>
\t\t\t  ";
                    }
                    // line 42
                    echo "        </p>
        ";
                }
                // line 44
                echo "    </div>
      <div class=\"button-group\">
        <button type=\"button\" onclick=\"cart.add('";
                // line 46
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 46);
                echo "');\"><i class=\"fa fa-shopping-cart\"></i> <span class=\"hidden-xs hidden-sm hidden-md\">";
                echo ($context["button_cart"] ?? null);
                echo "</span></button>
        <button type=\"button\" data-toggle=\"tooltip\" title=\"";
                // line 47
                echo ($context["button_wishlist"] ?? null);
                echo "\" onclick=\"wishlist.add('";
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 47);
                echo "');\"><i class=\"fa fa-heart\"></i></button>
        <button type=\"button\" data-toggle=\"tooltip\" title=\"";
                // line 48
                echo ($context["button_compare"] ?? null);
                echo "\" onclick=\"compare.add('";
                echo twig_get_attribute($this->env, $this->source, $context["product"], "product_id", [], "any", false, false, false, 48);
                echo "');\"><i class=\"fa fa-exchange\"></i></button>
      </div>

    </div>
  </div>
  ";
            }
            $_parent = $context['_parent'];
            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['product'], $context['_parent'], $context['loop']);
            $context = array_intersect_key($context, $_parent) + $_parent;
            // line 54
            echo "</div>
  <div class=\"col-sm-12\">
  <div class=\"btn btn-primary viewall\"><a href=\"";
            // line 56
            echo twig_get_attribute($this->env, $this->source, $context["category"], "href", [], "any", false, false, false, 56);
            echo "\">View All</a></div>
  </div>
</div>
";
        }
        $_parent = $context['_parent'];
        unset($context['_seq'], $context['_iterated'], $context['_key'], $context['category'], $context['_parent'], $context['loop']);
        $context = array_intersect_key($context, $_parent) + $_parent;
        // line 60
        echo "</div>
";
    }

    public function getTemplateName()
    {
        return "oc01/template/extension/module/productcategory.twig";
    }

    public function isTraitable()
    {
        return false;
    }

    public function getDebugInfo()
    {
        return array (  207 => 60,  197 => 56,  193 => 54,  179 => 48,  173 => 47,  167 => 46,  163 => 44,  159 => 42,  151 => 40,  148 => 39,  140 => 37,  134 => 35,  132 => 34,  129 => 33,  127 => 32,  122 => 29,  112 => 27,  102 => 25,  100 => 24,  96 => 23,  89 => 22,  83 => 20,  81 => 19,  77 => 17,  72 => 16,  68 => 14,  59 => 10,  56 => 9,  54 => 8,  48 => 5,  44 => 3,  40 => 2,  37 => 1,);
    }

    public function getSourceContext()
    {
        return new Source("", "oc01/template/extension/module/productcategory.twig", "");
    }
}
