<?php
// Heading
$_['heading_title']			= 'Klarna Account';

// Text
$_['text_extension']		= 'Extensions';
$_['text_success']			= 'Success: You have modified Klarna Payment module!';
$_['text_edit']             = 'Edit Klarna Account';
$_['text_klarna_account']	= '<a href="https://merchants.klarna.com/signup?locale=en&partner_id=d5c87110cebc383a826364769047042e777da5e8&utm_campaign=Platform&utm_medium=Partners&utm_source=Opencart" target="_blank"><img src="https://cdn.klarna.com/public/images/global/logos/v1/basic/global_basic_logo_std_blue-black.png?width=60&eid=opencart" alt="Klarna Account" title="Klarna Account" style="border: 1px solid #EEEEEE;" /></a>';
$_['text_live']				= 'Live';
$_['text_beta']				= 'Beta';
$_['text_sweden']			= 'Sweden';
$_['text_norway']			= 'Norway';
$_['text_finland']			= 'Finland';
$_['text_denmark']			= 'Denmark';
$_['text_germany']			= 'Germany';
$_['text_netherlands']		= 'The Netherlands';

// Entry
$_['entry_merchant']		= 'Klarna Merchant ID';
$_['entry_secret']			= 'Klarna Secret';
$_['entry_server']			= 'Server';
$_['entry_total']			= 'Total';
$_['entry_pending_status']	= 'Pending Status';
$_['entry_accepted_status'] = 'Accepted Status';
$_['entry_geo_zone']		= 'Geo Zone';
$_['entry_status']			= 'Status';
$_['entry_sort_order']		= 'Sort Order';

// Help
$_['help_merchant']			= '(estore id) to use for the Klarna service (provided by Klarna).';
$_['help_secret']			= 'Shared secret to use with the Klarna service (provided by Klarna).';
$_['help_total']			= 'The checkout total the order must reach before this payment method becomes active.';

// Error
$_['error_permission']		= 'Warning: You do not have permission to modify payment Klarna Part Payment!';
$_['error_pclass']			= 'Could not retrieve pClass for %s. Error Code: %s; Error Message: %s';
$_['error_curl']			= 'Curl Error - Code: %d; Message: %s';
$_['error_log']				= 'There were errors updating the module. Please check the log file.';