.pages {
    >.page {
        display: none;
    }
    >.active {
        display: block;
    }
}

.process {
    display: flex;
    margin-bottom: 30px;
    &-page {
        padding: 0;
        position: relative;
        flex: 1;
        text-align: center;
        &-label {
            color: #595959;
            font-size: 16px;
            margin-bottom: 5px;
        }
        &-description {
            color: #999;
            font-size: 14px;
        }
        .process-page-dot {
            position: absolute;
            width: 30px;
            height: 30px;
            display: block;
            background: #b7c8f9;
            top: 45px;
            left: 50%;
            margin-top: -15px;
            margin-left: -15px;
            border-radius: 50%;
            &:after {
                content: ' ';
                width: 14px;
                height: 14px;
                background: #648bfd;
                border-radius: 50px;
                position: absolute;
                top: 8px;
                left: 8px;
            }
        }
        &-progress {
            position: relative;
            border-radius: 0px;
            height: 8px;
            box-shadow: none;
            margin: 20px 0;
            background: #f5f5f5;
            &-bar {
                width: 0px;
                box-shadow: none;
                background: #b7c8f9;
                height: 100%;
            }
        }
        &.complete {
            .process-page-progress {
                &-bar {
                    width: 100%;
                }
            }
        }
        &.active {
            .process-page-progress {
                &-bar {
                    width: 50%;
                }
            }
        }
        &.disabled {
            .process-page-dot {
                background-color: #f5f5f5;
                pointer-events: none;
                &:after {
                    opacity: 0;
                }
            }
        }
        &:first-child {
            .process-page-progress {
                left: 50%;
                width: 50%;
            }
            &.active {
                .process-page-progress {
                    &-bar {
                        width: 0%;
                    }
                }
            }
            &.complete {
                .process-page-progress {
                    &-bar {
                        width: 100%;
                    }
                }
                .process-page-dot {
                    cursor: pointer;
                }
            }
        }
        &:last-child {
            .process-page-progress {
                width: 50%;
            }
            &.active {
                .process-page-progress {
                    &-bar {
                        width: 100%;
                    }
                }
            }
        }
        @media (max-width: 767.98px) {
            .process-page-progress,
            .process-page-dot {
                display: none !important;
            }
            .process-page-label {
                font-size: 14px;
            }
            .process-page-description {
                font-size: 12px;
            }
            &.active {
                background: #f1f5ff;
            }
            &.active .process-page-label {
                color: #648bfd;
                font-weight: 600;
            }
            &.page-nav-item {
                padding: 5px;
                display: flex;
                &:last-child {
                    border-right: none;
                }
                &:last-child {
                    border-radius: 0px 3px 3px 0px;
                }
                &:first-child {
                    border-radius: 3px 0px 0px 3px;
                }
                >a {
                    display: flex;
                    flex-direction: column;
                    align-items: center;
                    justify-content: center;
                }
            }
        }
    }
    @media (max-width: 767.98px) {
        & {
            box-shadow: 0 0 0 1px rgba(63, 63, 68, 0.1), 0 1px 3px 0 rgba(63, 63, 68, 0.1);
            border-radius: 3px;
            margin-bottom: 15px;
        }
    }
}

.edit {
    .process {
        display: block;
        border-bottom: 1px solid #ccc;
        padding-left: 1px;
        &-page {
            position: relative;
            width: 20%;
            float: left;
            &-edit {
                border: 1px solid #ccc;
                display: block;
                padding: 10px;
                cursor: pointer;
                background: #fff;
                text-align: left;
                height: 67px;
                .text {
                    font-size: 16px;
                    font-weight: bold;
                    color: #333;
                    margin-bottom: 5px;
                }
                .description {
                    font-size: 10px;
                    color: #666;
                }
                .qc-badge {
                    position: absolute;
                    top: 0px;
                    right: 0px;
                    margin: 10px;
                    display: block;
                    padding: 4px;
                }
                &-hidden {
                    .text {
                        opacity: 0.5;
                    }
                    .description {
                        opacity: 0.5;
                    }
                }
            }
        }
        .page-nav-add {
            display: block;
            float: left;
            width: 20%;
            margin-bottom: -1px;
            margin-left: -1px;
            .icon {
                float: left;
                font-size: 20px;
                padding: 10px 15px 10px 5px;
                .fa {
                    font-size: 25px;
                    color: #000;
                }
            }
            .content {
                float: left;
            }
        }
        .active {
            .process-page-edit {
                background: #F5F5F8;
            }
        }
        .page-nav-item,
        .sortable-placeholder {
            margin: 0px;
            margin-bottom: -1px;
            margin-left: -1px;
            &:hover {
                .page-nav-setting {
                    display: block;
                }
            }
            &:first-child {
                .process-page-edit {
                    border-radius: 3px 0px 0px 0px;
                }
            }
            &:last-child {
                .process-page-edit {
                    border-radius: 0px 3px 0px 0px;
                }
            }
        }
        .ui-sortable-placeholder {
            width: 20%;
            height: 67px;
        }
    }
    .page-add-module {
        display: block;
        border: none;
        padding: 10px;
        color: #fff;
        margin-bottom: 20px;
        border-radius: 3px;
        text-align: center;
        font-size: 14px;
        font-weight: bold;
        cursor: pointer;
        background: #3cb1d4;
    }
    .add-step {
        cursor: pointer;
    }
}