<?php
// Heading
$_['heading_title']    = 'Handling Fee';

// Text
$_['text_extension']   = 'Extensions';
$_['text_success']     = 'Success: You have modified handling fee total!';
$_['text_edit']        = 'Edit Handling Fee Total';

// Entry
$_['entry_total']      = 'Order Total';
$_['entry_fee']        = 'Fee';
$_['entry_tax_class']  = 'Tax Class';
$_['entry_status']     = 'Status';
$_['entry_sort_order'] = 'Sort Order';

// Help
$_['help_total']       = 'The checkout total the order must reach before this order total becomes active.';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify handling fee total!';