{{ text_welcome }}

{% if not approval %}
{{ text_login }}

{{ login }}

{{ text_service }}

{{ text_thanks }}
{{ store }}
{% else %}
{{ text_approval }}

{{ login }}

{{ text_thanks }}
{{ store }}
{% endif %}