<?php
// Heading
$_['heading_title']					 = 'PayPal (Powered by Braintree)';

// Text
$_['text_extension']		 		 = 'Extensions';
$_['text_pp_braintree']				 = '<img src="view/image/payment/paypal.png" alt="PayPal (Powered by Braintree)" title="PayPal (Powered by Braintree)" style="border: 1px solid #EEEEEE;" />';
$_['text_payment']					 = 'Payment';
$_['text_success']					 = 'Success: You have modified Braintree account details!';
$_['text_success_connect']			 = 'Success: You have connected your PayPal (Powered by Braintree) account!';
$_['text_edit']						 = 'Edit PayPal (Powered by Braintree)';
$_['text_production']				 = 'Production';
$_['text_sandbox']					 = 'Sandbox';
$_['text_currency']					 = 'Currency';
$_['text_immediate']				 = 'Immediate';
$_['text_deferred']					 = 'Deferred';
$_['text_merchant_account_id']		 = 'Merchant Account ID (Leave blank to use default merchant account)';
$_['text_payment_info']				 = 'Payment information';
$_['text_confirm_void']				 = 'Are you sure you want to void this transaction?';
$_['text_avs_response']				 = 'Street Address: %s, Postal Code: %s';
$_['text_confirm_settle']			 = 'Are you sure you want to settle/capture';
$_['text_confirm_refund']			 = 'Are you sure you want to refund';
$_['text_success_action']			 = 'Success';
$_['text_error_settle']				 = 'Error: %s';
$_['text_error_generic']			 = 'Error: There was an error with your request.';
$_['text_na']						 = 'N/A';
$_['text_all']						 = 'All';
$_['text_sale']						 = 'Sale';
$_['text_credit']					 = 'Credit';
$_['text_credit_card']				 = 'Credit Card';
$_['text_paypal']					 = 'PayPal';
$_['text_enable_transactions']		 = 'Please enable Braintree before viewing transactions.';
$_['text_yes']						 = 'Yes';
$_['text_no']						 = 'No';
$_['text_no_refund']				 = 'No refund history';
$_['text_app_connected']		     = 'Module is connected via Braintree auth';
$_['text_braintree']        		 = '<img width="100" src="https://s3-us-west-1.amazonaws.com/bt-partner-assets/paypal-braintree.png" alt="PayPal powered by Braintree" style="border: 1px solid #EEEEEE;">';
$_['text_paypal_gold'] 				 = 'Gold';
$_['text_paypal_blue'] 				 = 'Blue';
$_['text_paypal_silver'] 			 = 'Silver';
$_['text_paypal_tiny']		 		 = 'Tiny';
$_['text_paypal_small']		 		 = 'Small';
$_['text_paypal_medium']		 	 = 'Medium';
$_['text_paypal_pill']		 		 = 'Pill';
$_['text_paypal_rectangular']		 = 'Rectangular';
$_['text_paypal_preview']		 	 = 'Button preview<br />Save to view changes';
$_['text_braintree_learn']		 	 = 'To start accepting credit/debit cards and PayPal, click Connect with Braintree. <a href="https://www.braintreepayments.com/partners/learn-more" target="_blank">Learn more</a>';
$_['text_3ds']		 	 			 = '3D Secure';
$_['text_cvv']		 	 			 = 'CVV Number';
$_['text_promotion_main']		 	 = 'Designed for businesses of all sizes, from small to large enterprise, easily accept and process payments to help maximise business opportunities and revenue growth, with no setup or monthly fees';
$_['text_promotion_li_1']			 = 'All the benefits of PayPal, plus cards acceptance on your checkout page';
$_['text_promotion_li_2']			 = 'Fast configuration and setup';
$_['text_promotion_li_3']			 = 'Achieve PCI DSS v3.0 SAQ-A compliance using Hosted Fields';
$_['text_promotion_li_4']			 = 'Allow customers to vault card details';
$_['text_learn_more']			 	 = '(Learn more)';
$_['text_accept']			 	 	 = 'Accept';
$_['text_decline']			 	 	 = 'Decline';
$_['text_merchant_connected']		 = 'Connected Merchant ID: ';
$_['text_enable_button']			 = 'We recommend offering PayPal Express Shortcut to maximise checkout conversion, this allows customers to use their PayPal address book and <strong>checkout is as little as three taps</strong> from the basket page. Click enable to install the extension and access the layout manager, you will ned to add "PayPal (Powered by Braintree) Button" to the checkout layout';
$_['text_3ds_ssl']		 			 = '3D Secure requires the store to be using an SSL certificate';
$_['text_unlink']		 			 = 'Delete link';

// Column
$_['column_void']					 = 'Void';
$_['column_settle']					 = 'Settle';
$_['column_refund']					 = 'Refund';
$_['column_transaction_id']			 = 'Transaction ID';
$_['column_transaction_type']		 = 'Transaction Type';
$_['column_transaction_date']		 = 'Transaction Date';
$_['column_merchant_account']		 = 'Merchant Account';
$_['column_payment_type']			 = 'Payment Type';
$_['column_order_id']				 = 'Order ID';
$_['column_processor_code']			 = 'Processor Authorization Code';
$_['column_cvv_response']			 = 'CVV Response';
$_['column_avs_response']			 = 'AVS Response';
$_['column_3ds_enrolled']			 = '3DS Enrolled';
$_['column_3ds_status']				 = '3DS Status';
$_['column_3ds_shifted']			 = '3DS Liability Shifted';
$_['column_3ds_shift_possible']		 = '3DS Liability Shift Possible';
$_['column_transaction_history']	 = 'Transaction Status History';
$_['column_date']					 = 'Date';
$_['column_refund_history']			 = 'Refund History';
$_['column_action']					 = 'Action';
$_['column_amount']					 = 'Amount';
$_['column_status']					 = 'Status';
$_['column_type']					 = 'Type';
$_['column_customer']				 = 'Customer';
$_['column_order']					 = 'Order';
$_['column_date_added']				 = 'Date Added';

// Entry
$_['entry_merchant_id']				 = 'Merchant ID';
$_['entry_public_key']				 = 'Public Key';
$_['entry_private_key']				 = 'Private Key';
$_['entry_environment']				 = 'Environment';
$_['entry_settlement_type']			 = 'Settlement Type';
$_['entry_card_vault']				 = 'Enable card vault';
$_['entry_card_check_vault']		 = 'Card vault is pre-checked';
$_['entry_paypal_vault']			 = 'Enable PayPal vault';
$_['entry_paypal_check_vault']		 = 'PayPal vault is pre-checked';
$_['entry_vault_cvv_3ds']			 = 'Require CVV2 or 3D secure?';
$_['entry_debug']					 = 'Debug Logging';
$_['entry_total']					 = 'Total';
$_['entry_geo_zone']				 = 'Geo Zone';
$_['entry_status']					 = 'Status';
$_['entry_sort_order']				 = 'Sort Order';
$_['entry_authorization_expired']	 = 'Authorization Expired';
$_['entry_authorized']				 = 'Authorized';
$_['entry_authorizing']				 = 'Authorizing';
$_['entry_settlement_pending']		 = 'Settlement Pending';
$_['entry_failed']					 = 'Failed';
$_['entry_gateway_rejected']		 = 'Gateway Rejected';
$_['entry_processor_declined']		 = 'Processor Declined';
$_['entry_settled']					 = 'Settled';
$_['entry_settling']				 = 'Settling';
$_['entry_submitted_for_settlement'] = 'Submitted For Settlement';
$_['entry_voided']					 = 'Voided';
$_['entry_transaction_id']			 = 'Transaction ID';
$_['entry_transaction_type']		 = 'Transaction Type';
$_['entry_date_from']				 = 'Date From';
$_['entry_date_to']					 = 'Date To';
$_['entry_payment_type']			 = 'Payment Type';
$_['entry_card_type']				 = 'Card Type';
$_['entry_amount_from']				 = 'Amount From';
$_['entry_amount_to']				 = 'Amount To';
$_['entry_transaction_status']		 = 'Transaction Status';
$_['entry_merchant_account_id']		 = 'Merchant Account ID';
$_['entry_connection']		 		 = 'API Connection Status';
$_['entry_paypal_option']		     = 'Display PayPal Option';
$_['entry_paypal_button_colour']	 = 'Button Colour';
$_['entry_paypal_button_shape']		 = 'Button Shape';
$_['entry_paypal_button_size']		 = 'Button Size';
$_['entry_paypal_billing_agreement'] = 'Billing agreement description';
$_['entry_3ds_status']				 = 'Enable 3-D Secure';

$_['entry_3ds_unsupported_card'] 		= 'Unsupported Card<br />Default: Accept';
$_['entry_3ds_lookup_error'] 			= 'Lookup Error<br />Default: Accept';
$_['entry_3ds_lookup_enrolled'] 		= 'Lookup Enrolled<br />Default: Accept';
$_['entry_3ds_lookup_not_enrolled'] 	= 'Lookup Not Enrolled<br />Default: Accept';
$_['entry_3ds_not_participating'] 		= 'Auth Success, Issuer Not Participating<br />Default: Accept';
$_['entry_3ds_unavailable'] 			= 'Auth Unavailable<br />Default: Accept';
$_['entry_3ds_signature_failed'] 		= 'Auth Signature Verification Failed<br />Default: Decline';
$_['entry_3ds_successful'] 				= 'Auth Successful<br />Default: Accept';
$_['entry_3ds_attempt_successful'] 		= 'Auth Attempt Successful<br />Default: Accept';
$_['entry_3ds_failed'] 					= 'Auth Failed<br />Default: Decline';
$_['entry_3ds_unable_to_auth'] 			= 'Unable To Authenticate<br />Default: Accept';
$_['entry_3ds_error'] 					= 'Authentication Error<br />Default: Accept';

// Help
$_['help_settlement_type']			 	= 'Immediate will Submit For Settlement straight away. Deferred will set the transaction to Authorized and the merchant must Submit For Settlement manually in the OpenCart order details.';
$_['help_card_vault']				 	= 'Allow customer to remember their card';
$_['help_paypal_vault']				 	= 'Allow customer to remember their PayPal account';
$_['help_card_check_vault']			 	= 'The checkbox for card vault is already checked when the page loads';
$_['help_paypal_check_vault']		 	= 'The checkbox for PayPal vault is already checked when the page loads';
$_['help_vault_cvv_3ds']			 	= 'This will require customers using a vaulted card to re-enter the CVV2 number or use 3D secure. It is not possible to enable both options for a vaulted card.';
$_['help_debug']					 	= 'Enabling debug will write sensitive data to a log file. You should always disable unless instructed otherwise';
$_['help_total']					 	= 'The checkout total the order must reach before this payment method becomes active';
$_['help_paypal_option']			 	= 'If you have your PayPal account linked with Braintree you can display the PayPal payment option as well';
$_['help_paypal_billing_agreement']	 	= 'You can add a billing agreement description that will be shown to users in the PayPal window when opting to vault their PayPal account';

// Button
$_['button_void']					 	= 'Void';
$_['button_settle']					 	= 'Settle';
$_['button_refund']					 	= 'Refund';
$_['button_filter']					 	= 'Filter';

// Error
$_['error_permission']				 	= 'Warning: You do not have permission to modify payment Braintree!';
$_['error_php_version']				 	= 'Minimum version of PHP 5.4.0 is required!';
$_['error_merchant_id']				 	= 'Merchant ID Required!';
$_['error_public_key']				 	= 'Public Key Required!';
$_['error_private_key']				 	= 'Private Key Required!';
$_['error_connection']				 	= 'There was a problem establishing a connection to the Braintree API. Please check your Merchant ID, Public Key, Private Key and Environment settings.';
$_['error_account']					 	= 'Please enter a valid Merchant Account ID as specified in your Braintree Account';
$_['error_warning']					 	= 'Warning: Please check the form carefully for errors!';
$_['error_3ds_not_ready']			 	= 'You have enabled 3D secure however your Braintree account does not have it configured, please check your <a href="https://www.braintreegateway.com/login" title="Braintree login" target="_blank">Braintree Control Panel</a> or contact Braintree support';
$_['error_paypal_not_ready']		 	= 'You have enabled PayPal however your Braintree account does not have it configured, please check your <a href="https://www.braintreegateway.com/login" title="Braintree login" target="_blank">Braintree Control Panel</a> or contact Braintree support';
$_['error_paypal_billing_not_ready'] 	= 'You have enabled PayPal vaulting/billing agreements however your Braintree account does not have it configured, please check your <a href="https://www.braintreegateway.com/login" title="Braintree login" target="_blank">Braintree Control Panel</a> or contact Braintree support';
$_['error_braintree_account_3ds'] 	 	= '3DS is not enabled in your Braintree account yet, however it is not available for all countries. Please check your <a href="https://www.braintreegateway.com/login" title="Braintree login" target="_blank">Braintree Control Panel</a> or contact Braintree support';
$_['error_braintree_account_paypal'] 	= 'PayPal is not enabled in your Braintree account yet. Please check your <a href="https://www.braintreegateway.com/login" title="Braintree login" target="_blank">Braintree Control Panel</a> or contact Braintree support';
$_['error_braintree_account_billing']	= 'Billing agreements are not enabled in your Braintree account yet. Please check your <a href="https://www.braintreegateway.com/login" title="Braintree login" target="_blank">Braintree Control Panel</a> or contact Braintree support';
$_['error_environment']					= 'You cannot set your environment to %s when your credentials are for the %s environment in Braintree';

// Tab
$_['tab_setting']					 	= 'Settings';
$_['tab_currency']					 	= 'Currencies';
$_['tab_order_status']				 	= 'Order Statuses (New Orders)';
$_['tab_3ds']						 	= '3-D Secure';
$_['tab_transaction']				 	= 'Transaction Search';
$_['tab_vault']				 	 	 	= 'Vault';
$_['tab_paypal']				 	 	= 'PayPal';
