<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  84203 => 'Quang Ninh province',
  84204 => 'Bac Giang province',
  84205 => 'Lang Son province',
  84206 => 'Cao Bang province',
  84207 => 'Tuyen Quang province',
  84208 => 'Thai Nguyen province',
  84209 => 'Bac Can province',
  84210 => 'Phu Tho province',
  84211 => 'Vinh Phuc province',
  84212 => 'Son La province',
  84213 => 'Lai Chau province',
  84214 => 'Lao Cai province',
  84215 => 'Dien Bien province',
  84216 => 'Yen Bai province',
  84218 => 'Hoa Binh province',
  84219 => 'Ha Giang province',
  84220 => 'Hai Duong province',
  84221 => 'Hung Yen province',
  84222 => 'Bac Ninh province',
  84225 => 'Hai Phong City',
  84226 => 'Ha Nam province',
  84227 => 'Thai Binh province',
  84228 => 'Nam Dinh province',
  84229 => 'Ninh Binh province',
  84232 => 'Quang Binh province',
  84233 => 'Quang Tri province',
  84234 => 'Thua Thien-Hue province',
  84235 => 'Quang Nam province',
  84236 => 'Da Nang',
  84237 => 'Thanh Hoa province',
  84238 => 'Nghe An province',
  84239 => 'Ha Tinh province',
  8424 => 'Hanoi City',
  84251 => 'Dong Nai province',
  84252 => 'Binh Thuan province',
  84254 => 'Ba Ria Vung Tau province',
  84255 => 'Quang Ngai province',
  84256 => 'Binh Dinh province',
  84257 => 'Phu Yen province',
  84258 => 'Khanh Hoa province',
  84259 => 'Ninh Thuan province',
  84260 => 'Kon Tum province',
  84261 => 'Dak Nong province',
  84262 => 'Dak Lak province',
  84263 => 'Lam Dong province',
  84269 => 'Gia Lai province',
  84270 => 'Ving Long province',
  84271 => 'Binh Phuoc province',
  84272 => 'Long An province',
  84273 => 'Tien Giang province',
  84274 => 'Binh Duong province',
  84275 => 'Ben Tre province',
  84276 => 'Tay Ninh province',
  84277 => 'Dong Thap province',
  8428 => 'Ho Chi Minh City',
  84290 => 'Ca Mau province',
  84291 => 'Bac Lieu province',
  84292 => 'Can Tho City',
  84293 => 'Hau Giang province',
  84294 => 'Tra Vinh province',
  84296 => 'An Giang province',
  84297 => 'Kien Giang province',
  84299 => 'Soc Trang province',
);
