<?php
// Text
$_['text_title']						= 'PayPal';
$_['text_checkout_payment_address']  	= 'Billing Details';
$_['text_checkout_shipping_address'] 	= 'Delivery Details';
$_['text_checkout_shipping_method']  	= 'Delivery Method';
$_['text_checkout_payment_method']  	= 'Payment Method';
$_['text_your_details']              	= 'Your Personal Details';
$_['text_your_address']              	= 'Your Address';
$_['text_cart']               			= 'Shopping Cart';
$_['text_shipping_updated']   			= 'Shipping service updated';
$_['text_order_message']				= 'PayPal Seller Protection - %s';
$_['text_day']                 			= 'day';
$_['text_week']                			= 'week';
$_['text_semi_month']          			= 'half-month';
$_['text_month']               			= 'month';
$_['text_year']                			= 'year';
$_['text_trial']               			= '%s every %s %s for %s payments then ';
$_['text_recurring']          			= '%s every %s %s';
$_['text_recurring_item']      			= 'Recurring Item';
$_['text_payment_recurring']   			= 'Payment Profile';
$_['text_trial_description']   			= '%s every %d %s(s) for %d payment(s) then';
$_['text_payment_description'] 			= '%s every %d %s(s) for %d payment(s)';
$_['text_payment_cancel']      			= '%s every %d %s(s) until canceled';

// Column
$_['column_image']             			= 'Image';
$_['column_name']              			= 'Product Name';
$_['column_model']             			= 'Model';
$_['column_quantity']          			= 'Quantity';
$_['column_price']             			= 'Unit Price';
$_['column_total']             			= 'Total';

// Entry
$_['entry_email']                    	= 'E-Mail';
$_['entry_firstname']                	= 'First Name';
$_['entry_lastname']                 	= 'Last Name';
$_['entry_telephone']               	= 'Telephone';
$_['entry_company']                  	= 'Company';
$_['entry_address_1']                	= 'Address 1';
$_['entry_address_2']                	= 'Address 2';
$_['entry_postcode']                 	= 'Post Code';
$_['entry_city']                     	= 'City';
$_['entry_country']                  	= 'Country';
$_['entry_zone']                    	= 'Region / State';

// Button
$_['button_confirm']  					= 'Confirm';
$_['button_shipping'] 					= 'Update shipping';

// Error
$_['error_stock']              			= 'Products marked with *** are not available in the desired quantity or not in stock!';
$_['error_minimum']            			= 'Minimum order amount for %s is %s!';
$_['error_required']           			= '%s required!';
$_['error_product']            			= 'Warning: There are no products in your cart!';
$_['error_recurring_required'] 			= 'Please select a payment recurring!';
$_['error_unavailable'] 	  			= 'Please use the full checkout with this order!';
$_['error_shipping']                 	= 'Warning: Shipping method required!';
$_['error_no_shipping']    				= 'Warning: No Shipping options are available.';
$_['error_firstname']                	= 'First Name must be between 1 and 32 characters!';
$_['error_lastname']                 	= 'Last Name must be between 1 and 32 characters!';
$_['error_email']                    	= 'E-Mail address does not appear to be valid!';
$_['error_telephone']                	= 'Telephone must be between 3 and 32 characters!';
$_['error_password']                 	= 'Password must be between 4 and 20 characters!';
$_['error_confirm']                  	= 'Password confirmation does not match password!';
$_['error_address_1']                	= 'Address 1 must be between 3 and 128 characters!';
$_['error_city']                     	= 'City must be between 2 and 128 characters!';
$_['error_postcode']                 	= 'Postcode must be between 2 and 10 characters!';
$_['error_country']                  	= 'Please select a country!';
$_['error_zone']                     	= 'Please select a region / state!';
$_['error_agree']                    	= 'Warning: You must agree to the %s!';
$_['error_address']                  	= 'Warning: You must select address!';
$_['error_custom_field']             	= '%s required!';
$_['error_timeout'] 	  				= 'Sorry, PayPal is currently busy. Please try again later!';