<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;

/* oc01/template/extension/module/ajax_filter.twig */
class __TwigTemplate_46c35e16cf5cc625a114e8ee128b8cb9a74663ee0c669b04234949e19e35c77d extends \Twig\Template
{
    private $source;
    private $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = [])
    {
        $macros = $this->macros;
        // line 1
        echo "<div class=\"ajaxfilter collapse\" id=\"ajaxfilter\" data-action=\"";
        echo ($context["action"] ?? null);
        echo "\" data-store-action=\"";
        echo ($context["store_action"] ?? null);
        echo "\">
\t
\t<div class=\"panel panel-default\">

\t  <div class=\"panel-heading\">";
        // line 5
        echo ($context["heading_title"] ?? null);
        echo "</div>

\t <div class=\"list-group filter-selection hide\">
\t\t<a class=\"list-group-item\">";
        // line 8
        echo ($context["filter_group_selection"] ?? null);
        echo "</a>
\t\t<div class=\"list-group-content\"> 
\t\t</div>\t
\t\t<div class=\"clear-all\">";
        // line 11
        echo ($context["text_clear_all"] ?? null);
        echo "</div>
\t</div>


\t<div class=\"list-group filter-by-price ajax-slider\" data-min=\"";
        // line 15
        echo ($context["min_price"] ?? null);
        echo "\" data-max=\"";
        echo ($context["max_price"] ?? null);
        echo "\" data-prefix=\"";
        echo ($context["currency_symbol_left"] ?? null);
        echo "\" data-postfix=\"";
        echo ($context["currency_symbol_right"] ?? null);
        echo "\"> 
\t\t<a class=\"list-group-item\">";
        // line 16
        echo ($context["filter_group_price_name"] ?? null);
        echo " 
\t\t\t<span class=\"clear-price hide\"><i class=\"fa fa-times\" aria-hidden=\"true\"></i></span></a>
\t\t<div class=\"list-group-item\">
\t        <input id=\"filter_price\" name=\"filter_price\" class=\"ajax-slider-el\" />
\t    </div>
\t</div>


\t<div class=\"list-group filter-by-others filter-group\" data-group=\"filter\" > 
\t  \t";
        // line 25
        $context['_parent'] = $context;
        $context['_seq'] = twig_ensure_traversable(($context["filter_groups"] ?? null));
        foreach ($context['_seq'] as $context["_key"] => $context["filter_group"]) {
            echo " <a class=\"list-group-item\">";
            echo twig_get_attribute($this->env, $this->source, $context["filter_group"], "name", [], "any", false, false, false, 25);
            echo "</a>
\t    <div class=\"list-group-item\">
\t      <div id=\"filter-group";
            // line 27
            echo twig_get_attribute($this->env, $this->source, $context["filter_group"], "filter_group_id", [], "any", false, false, false, 27);
            echo "\">";
            $context['_parent'] = $context;
            $context['_seq'] = twig_ensure_traversable(twig_get_attribute($this->env, $this->source, $context["filter_group"], "filter", [], "any", false, false, false, 27));
            foreach ($context['_seq'] as $context["_key"] => $context["filter"]) {
                // line 28
                echo "\t        <div class=\"checkbox\">
\t          <label>";
                // line 29
                if (twig_in_filter(twig_get_attribute($this->env, $this->source, $context["filter"], "filter_id", [], "any", false, false, false, 29), ($context["filter_category"] ?? null))) {
                    // line 30
                    echo "\t            <input type=\"checkbox\" name=\"filter[]\" value=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["filter"], "filter_id", [], "any", false, false, false, 30);
                    echo "\" data-group=\"filter\" checked=\"checked\" data-filter-name=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["filter"], "filter_name", [], "any", false, false, false, 30);
                    echo "\" />
\t            ";
                    // line 31
                    echo twig_get_attribute($this->env, $this->source, $context["filter"], "name", [], "any", false, false, false, 31);
                    echo "
\t            ";
                } else {
                    // line 33
                    echo "\t            <input type=\"checkbox\" name=\"filter[]\" value=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["filter"], "filter_id", [], "any", false, false, false, 33);
                    echo "\" data-filter-name=\"";
                    echo twig_get_attribute($this->env, $this->source, $context["filter"], "filter_name", [], "any", false, false, false, 33);
                    echo "\"/>
\t            ";
                    // line 34
                    echo twig_get_attribute($this->env, $this->source, $context["filter"], "name", [], "any", false, false, false, 34);
                    echo "
\t            ";
                }
                // line 35
                echo "</label>
\t        </div>
\t        ";
            }
            $_parent = $context['_parent'];
            unset($context['_seq'], $context['_iterated'], $context['_key'], $context['filter'], $context['_parent'], $context['loop']);
            $context = array_intersect_key($context, $_parent) + $_parent;
            // line 37
            echo "</div>
\t    </div>
\t    ";
        }
        $_parent = $context['_parent'];
        unset($context['_seq'], $context['_iterated'], $context['_key'], $context['filter_group'], $context['_parent'], $context['loop']);
        $context = array_intersect_key($context, $_parent) + $_parent;
        // line 40
        echo "\t</div>

\t<div class=\"list-group filter-by-manufacturers filter-group\" data-group=\"manufacturer\" >
\t\t<a class=\"list-group-item\">";
        // line 43
        echo ($context["filter_group_manufacturers"] ?? null);
        echo " </a>
\t\t<div class=\"list-group-item\">
\t\t\t<div id=\"filter-group-manufacturers\">";
        // line 45
        $context['_parent'] = $context;
        $context['_seq'] = twig_ensure_traversable(($context["manufacturers"] ?? null));
        foreach ($context['_seq'] as $context["_key"] => $context["filter"]) {
            // line 46
            echo "\t        <div class=\"checkbox\">
\t          <label>";
            // line 47
            if (twig_in_filter(twig_get_attribute($this->env, $this->source, $context["filter"], "manufacturer_id", [], "any", false, false, false, 47), ($context["filter_category"] ?? null))) {
                // line 48
                echo "\t            <input type=\"checkbox\" name=\"manufacturer[]\" data-group=\"manufacturer\" value=\"";
                echo twig_get_attribute($this->env, $this->source, $context["filter"], "manufacturer_id", [], "any", false, false, false, 48);
                echo "\" checked=\"checked\" data-filter-name=\"";
                echo twig_get_attribute($this->env, $this->source, $context["filter"], "name", [], "any", false, false, false, 48);
                echo "\" />
\t            ";
                // line 49
                echo twig_get_attribute($this->env, $this->source, $context["filter"], "name", [], "any", false, false, false, 49);
                echo "
\t            ";
            } else {
                // line 51
                echo "\t            <input type=\"checkbox\" name=\"manufacturer[]\" data-group=\"manufacturer\" 
\t            value=\"";
                // line 52
                echo twig_get_attribute($this->env, $this->source, $context["filter"], "manufacturer_id", [], "any", false, false, false, 52);
                echo "\" data-filter-name=\"";
                echo twig_get_attribute($this->env, $this->source, $context["filter"], "filter_name", [], "any", false, false, false, 52);
                echo "\"/>
\t            ";
                // line 53
                echo twig_get_attribute($this->env, $this->source, $context["filter"], "name", [], "any", false, false, false, 53);
                echo "
\t            ";
            }
            // line 54
            echo "</label>
\t        </div>
\t        ";
        }
        $_parent = $context['_parent'];
        unset($context['_seq'], $context['_iterated'], $context['_key'], $context['filter'], $context['_parent'], $context['loop']);
        $context = array_intersect_key($context, $_parent) + $_parent;
        // line 56
        echo "</div>
\t    </div>    
\t</div>\t

\t</div>
</div>

";
    }

    public function getTemplateName()
    {
        return "oc01/template/extension/module/ajax_filter.twig";
    }

    public function isTraitable()
    {
        return false;
    }

    public function getDebugInfo()
    {
        return array (  201 => 56,  193 => 54,  188 => 53,  182 => 52,  179 => 51,  174 => 49,  167 => 48,  165 => 47,  162 => 46,  158 => 45,  153 => 43,  148 => 40,  140 => 37,  132 => 35,  127 => 34,  120 => 33,  115 => 31,  108 => 30,  106 => 29,  103 => 28,  97 => 27,  88 => 25,  76 => 16,  66 => 15,  59 => 11,  53 => 8,  47 => 5,  37 => 1,);
    }

    public function getSourceContext()
    {
        return new Source("", "oc01/template/extension/module/ajax_filter.twig", "");
    }
}
