<form id="alipaysubmit" name="alipaysubmit" action="{{ action }}" method="GET">
    {% for key, value in params %}
        <input type="hidden" name="{{ key }}" value="{{ value }}"/>
    {% endfor %}
</form>
<div class="buttons">
    <div class="pull-right">
        <input type="button" value="{{ button_confirm }}" id="button-confirm" class="btn btn-primary" />
    </div>
</div>
<script type="text/javascript"><!--
    $('#button-confirm').bind('click', function() {
        $('#alipaysubmit').submit();
    });
//--></script>
