<?php
// Heading
$_['heading_title']		 = 'Payza';

// Text
$_['text_extension']	 = 'Extensions';
$_['text_success']		 = 'Success: You have modified Payza account details!';
$_['text_edit']          = 'Edit Payza';

// Entry
$_['entry_merchant']	 = 'Merchant ID';
$_['entry_security']	 = 'Security Code';
$_['entry_callback']	 = 'Alert URL';
$_['entry_total']		 = 'Total';
$_['entry_order_status'] = 'Order Status';
$_['entry_geo_zone']	 = 'Geo Zone';
$_['entry_status']		 = 'Status';
$_['entry_sort_order']	 = 'Sort Order';

// Help
$_['help_callback']		 = 'This has to be set in the Payza control panel. You will also need to check the "IPN Status" to enabled.';
$_['help_total']		 = 'The checkout total the order must reach before this payment method becomes active.';

// Error
$_['error_permission']	 = 'Warning: You do not have permission to modify payment Payza!';
$_['error_merchant']	 = 'Merchant ID Required!';
$_['error_security']	 = 'Security Code Required!';