{{ header }}
<div id="content">
  <div class="container-fluid"><br />
    <br />
    <div class="row">
      <div class="col-sm-offset-4 col-sm-4">
        <div class="panel panel-default">
          <div class="panel-heading">
            <h1 class="panel-title"><i class="fa fa-repeat"></i> {{ heading_title }}</h1>
          </div>
          <div class="panel-body">
            <form action="{{ action }}" method="post" enctype="multipart/form-data">
              <p>{{ text_password }}</p>
              <div class="form-group">
                <label class="control-label" for="input-password">{{ entry_password }}</label>
                <input type="password" name="password" value="{{ password }}" id="input-password" class="form-control" />
                {% if error_password %}
                <div class="text-danger">{{ error_password }}</div>
                {% endif %}
              </div>
              <div class="form-group">
                <label class="control-label" for="input-confirm">{{ entry_confirm }}</label>
                <input type="password" name="confirm" value="{{ confirm }}" id="input-confirm" class="form-control" />
                {% if error_confirm %}
                <div class="text-danger">{{ error_confirm }}</div>
                {% endif %}
              </div>
              <div class="text-right">
                <button type="submit" class="btn btn-primary"><i class="fa fa-save"></i> {{ button_save }}</button>
                <a href="{{ cancel }}" data-toggle="tooltip" title="{{ button_cancel }}" class="btn btn-default"><i class="fa fa-reply"></i></a>
              </div>
            </form>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
{{ footer }}