{{ text_signup }}

{% if company %}
{{ text_company }} {{ customer_group }}
{% endif %}
{{ text_website }} {{ website }}
{{ text_firstname }} {{ firstname }}
{{ text_lastname }} {{ lastname }}
{% if customer_group %}
{{ text_customer_group }} {{ customer_group }}
{% endif %}
{{ text_email }} {{ email }}
{{ text_telephone }} {{ telephone }}
