<?php
// Heading
$_['heading_title']     = 'Banners';

// Text
$_['text_success']      = 'Success: You have modified banners!';
$_['text_list']         = 'Banner List';
$_['text_add']          = 'Add Banner';
$_['text_edit']         = 'Edit Banner';
$_['text_default']      = 'Default';

// Column
$_['column_name']       = 'Banner Name';
$_['column_status']     = 'Status';
$_['column_action']     = 'Action';

// Entry
$_['entry_name']        = 'Banner Name';
$_['entry_title']       = 'Title';
$_['entry_link']        = 'Link';
$_['entry_image']       = 'Image';
$_['entry_status']      = 'Status';
$_['entry_sort_order']  = 'Sort Order';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify banners!';
$_['error_name']       = 'Banner Name must be between 3 and 64 characters!';
$_['error_title']      = 'Banner Title must be between 2 and 64 characters!';