a#button-menu {
  -webkit-appearance: none !important; }

.setup {
  padding: 0; }
  .setup .setup-back {
    background-position: bottom;
    background-repeat: no-repeat;
    background-size: 100%;
    min-height: 1025px;
    padding-top: 50px;
    padding-bottom: 525px; }
  .setup .setup-into {
    text-align: center;
    max-width: 500px;
    margin: auto; }
  .setup .setup-into-logo {
    padding-bottom: 15px; }
  .setup .setup-into-heading {
    font-size: 30px;
    font-weight: bold;
    padding-bottom: 15px; }
  .setup .setup-into-text {
    font-size: 18px;
    padding-bottom: 30px; }
  .setup .setup-into-start {
    padding-bottom: 30px; }
  .setup .setup-features {
    padding: 30px; }
  .setup .setup-features-icon {
    padding: 20px;
    height: 130px;
    text-align: center; }
  .setup .setup-features-text {
    text-align: center;
    font-weight: bold;
    font-size: 16px; }
  .setup .panel-body {
    padding: 0px; }
  .setup .setup-features-icon img {
    max-height: 100%; }

/*# sourceMappingURL=setup.css.map */
