<?php
// Heading
$_['heading_title']     = 'Marketing Tracking';

// Text
$_['text_success']      = 'Success: You have modified marketing tracking!';
$_['text_list']         = 'Marketing Tracking List';
$_['text_add']          = 'Add Marketing Tracking';
$_['text_edit']         = 'Edit Marketing Tracking';
$_['text_filter']       = 'Filter';
		
// Column
$_['column_name']       = 'Campaign Name';
$_['column_code']       = 'Code';
$_['column_clicks']     = 'Clicks';
$_['column_orders']     = 'Orders';
$_['column_date_added'] = 'Date Added';
$_['column_action']     = 'Action';

// Entry
$_['entry_name']        = 'Campaign Name';
$_['entry_description'] = 'Campaign Description';
$_['entry_code']        = 'Tracking Code';
$_['entry_example']     = 'Examples';
$_['entry_date_added']  = 'Date Added';

// Help
$_['help_code']         = 'The tracking code that will be used to track marketing campaigns.';
$_['help_example']      = 'So the system can track referrals you need to add the tracking code to the end of the URL linking to your site.';

// Error
$_['error_permission']  = 'Warning: You do not have permission to modify marketing tracking!';
$_['error_name']        = 'Campaign must be between 1 and 32 characters!';
$_['error_code']        = 'Tracking Code required!';
$_['error_exists']      = 'Tracking code is being used by another campaign!';