{% if reviews %}
{% for review in reviews %}
<table class="table table-striped table-bordered">
  <tr>
    <td style="width: 50%;"><strong>{{ review.author }}</strong></td>
    <td class="text-right">{{ review.date_added }}</td>
  </tr>
  <tr>
    <td colspan="2"><p>{{ review.text }}</p>
      {% for i in 1..5 %}
          {% if review.rating < i %} <span class="fa fa-stack">
          <i class="fa fa-star fa-stack-2x blank"></i></span>
           {% else %} <span class="fa fa-stack"><i class="fa fa-star fa-stack-1x"></i></span> {% endif %}
          {% endfor %}
      </td>
  </tr>
</table>
{% endfor %}
<div class="text-right">{{ pagination }}</div>
{% else %}
<p>{{ text_no_reviews }}</p>
{% endif %}
