<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  822 => '首爾市',
  8231 => '京畿道',
  8232 => '仁川廣',
  8233 => '江原道',
  8241 => '忠清南道',
  8242 => '大田廣',
  8243 => '忠清北道',
  8244 => '世宗市',
  8251 => '釜山廣',
  8252 => '蔚山廣',
  8253 => '大邱廣',
  8254 => '慶尚北道',
  8255 => '慶尚南道',
  8261 => '全羅南道',
  8262 => '光州廣',
  8263 => '全羅北道',
  8264 => '濟州道',
);
