<?php
// Heading
$_['heading_title']    = 'Language Editor';

// Text
$_['text_success']     = 'Success: You have modified language editor!';
$_['text_list']        = 'Translation List';
$_['text_edit']        = 'Edit Translation';
$_['text_add']         = 'Add Translation';
$_['text_default']     = 'Default';
$_['text_store']       = 'Store';
$_['text_language']    = 'Language';

// Column
$_['column_store']     = 'Store';
$_['column_language']  = 'Language';
$_['column_route']     = 'Route';
$_['column_key']       = 'Key';
$_['column_value']     = 'Value';
$_['column_action']    = 'Action';

// Entry
$_['entry_store']      = 'Store';
$_['entry_language']   = 'Language';
$_['entry_route']      = 'Route';
$_['entry_key']        = 'Key';
$_['entry_default']    = 'Default';
$_['entry_value']      = 'Value';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify language editor!';
$_['error_key']        = 'Key must be between 3 and 64 characters!';
